<?php
/**
 * Main Administration page
 *
 * Presents the end-user with a listing of the installed modules for which the user
 * is authorized.  Additional modules may be available beyond what is displayed to
 * the user.
 * @package Core-Scripts
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | ADMIN.PHP                                            |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | ADMIN.PHP is part of FreeWPS.                        |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: admin.php,v 1.7 2004/08/15 05:47:42 ytztech Exp $
//

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

// Testing for admin rights.
if (strpos($user_perms,'[-') !== FALSE) {
	// Get HTML for the admin panel.
	$pgcontent = admin_getpanel();
	// Create the page.
	core_createPage($pgcontent,'',_ADMINPANEL);
} else {
	// No admin permissions for you!
	if ($_SESSION['authorization'] == '') {
		// If the user isn't logged in, send them to LOGIN.PHP with a referral.
		Header('Location: login.php?referer='.core_getReferer());
	} else {
		// Otherwise, display an "Access Denied" page.
		core_createPage(access_denied(),'',_ACCESSDENIED);
	}
}


/**
 * Retrieves a panel of administrative functions and returns them to the calling
 * function.
 *
 * @access private
 * @return string Returns the HTML for the admin panel
 */
function admin_getpanel()
{
	// Setup the query to return the list of authorized modules.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_MODULES.MODNAME, '.
						   $GLOBALS['dbpref'].'_MODULES.TITLE FROM ';

	// This part of the query will help determine the number of returned rows
	// for those RDBMS that do not support that function directly.
	$query_pt2 = $GLOBALS['dbpref'].'_MODULES';

	// Since superusers have access to all areas in FreeWPS,
	// checking for those who do not have superusers rights
	// will allow those users to have the restrictions placed
	// them with the additional query components.

	if (core_checkUser(SUPERUSERS_GROUP,FALSE)) {

		// Add the table WPS_GRPMODULES to the query to check
		// for user rights to the modules returned.
		$query_pt2 .= ', '.$GLOBALS['dbpref'].'_GRPMODULES';
		$query_pt2 .= ' WHERE '.$GLOBALS['dbpref'].'_GRPMODULES.MODULEID = '.
								$GLOBALS['dbpref'].'_MODULES.ID';

		// Determine whether any user permissions are available to parse.
		if (strstr($GLOBALS['user_perms'],'[') !== FALSE) {
			// Separate this clause from the rest of the where clause.
			$query_pt2 .= ' AND (';
			// Remove the first and last bracket from $GLOBALS['user_perms'].
			$user_perms = substr($GLOBALS['user_perms'], 1, -1);
			// Explode the permissions into an array.
			$permarray = explode('][',$user_perms);
			// Move the array pointer to the first element.
			reset($permarray);

			// Set the initial group comparison clause.
			$query_pt2 .= $GLOBALS['dbpref'].'_GRPMODULES.GROUPID = '.$permarray[0];
			while ($userperm = next($permarray)) {
				// Get the next group from $permarray and set the next group
				// comparison clause.
				$query_pt2 .= ' OR '.$GLOBALS['dbpref'].'_GRPMODULES.GROUPID = '.
									 $userperm;
			}
			// Close the groups clause.
			$query_pt2 .= ')';
		}
	}

	// Set the "Order By" clause for sorting the list of results in alphabetical
	// order by title.
	$query_pt3 = ' ORDER BY '.$GLOBALS['dbpref'].'_MODULES.TITLE';

	// Run the query to determine which modules to show.
	$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

	// Initialize the content to return.
	$content = '';

	switch (sql_num_rows($results,$query_pt2)) {
		// How many rows will it return?
		case 0:
			// Return an "Access Denied" error message.
			return access_denied();
			// End this joyride.
			break;

		case 1:
			// Get the one row of data as an array.
			$row = sql_fetch_row($results);
			// Take the user to directly to the one, accessible module
			Header('Location: modules.php?id='.$row[0]);
			die();
			// End this joyride.
			break;

		default:
			// Setup the HTML of the Admin Panel.
			$content .= '<h3 align="center">'._ADMINPANEL.'</h3>';
			if (isset($_SESSION['sql_success'])) {
				// So an upgrade took place, display a message about the success
				// or failure of that upgrade.
				$content .= '<p align="center"><strong>';
				$content .= ($_SESSION['sql_success']) ? _UPGRADESUCCESS : _UPGRADESQLFAIL;
				$content .= '</strong></p>';
				unset($_SESSION['sql_success']);
				unset($GLOBALS['sql_success']);
			}

			if (is_dir($GLOBALS['site_path'].'/install')) {
				// Warn the end user to delete the INSTALL directory.
				$content .= '<p align="center"><span class="regularText"><strong>';
				$content .= _WARNINGCOLON.'</strong>&nbsp; '._WARNDELETEINSTALL;
				$content .= '<br />&nbsp;</span></p>';
			}

			// Setup the table of modules.
			$content .= '<table align="center" border="1" class="tableAdmin">';
			$content .= '<tr><td align="center" class="columnAdminHeader">'._MODNAME;
			$content .= '</td>';
			$content .= '<td align="center" class="columnAdminHeader">'._MODTITLE;
			$content .= '</td></tr>';

			// Initialize the row highlights.
			$hilite = 1;
			// Initialize duplicate modules check.
			$lastmod = '';
			while ($row = sql_fetch_row($results)) {
				if ($lastmod == $row[0]) {
					// Skip this module since it's already displayed.
					continue;
				}
				// Setup the class to use for each row.
				$style = 'columnAdminCell';
				if (($hilite % 2) == 0) {
					$style .= '2';
				}
				// Insert the row of links to the module.
				$content .= '<tr>';
				$content .= '<td align="center" class="'.$style.'">';
				$content .= '<a href="modules.php?id='.$row[0];
				$content .= '&amp;mode=admin">'.$row[0].'</a>';
				$content .= '</td>';
				$content .= '<td align="center" class="'.$style.'">';
				$content .= '<a href="modules.php?id='.$row[0];
				$content .= '&amp;mode=admin">'.$row[1].'</a>';
				$content .= '</td>';
				$content .= '</tr>';
				// Switch to the other highlight class.
				$hilite++;
				// Update the last display mod...
				$lastmod = $row[0];
			}
			// Close the modules table.
			$content .= '</table>';
			break;
	}

	// Return the HTML for the Admin Panel.
	return $content;
}
?>