/***********************************************************************
** Title.........:  HTMLArea Addons for FreeWPS v2.0
** Version.......:  1.0
** Author........:  jwhite@ytztech.com
** Filename......:  wpsaddons.js
** Last changed..:  1 Dec 2003
** Notes.........:  Consolidates ImageManager, ImageEditor, LinkManager,
**                  and other functions.
************************************************************************/


//  Taken from modified HTMLAREA.JS from function HTMLArea.prototype._insertimage()
//  and relocated here to ensure no upgrades to HTMLArea will interfere with using
//  the excellent ImageManager/ImageEditor from <wei@zhuo.org>.

HTMLArea.prototype.wps_insertimage = function(image) {
  var editor = this;  // for nested functions
  var outparam = null;
  if (typeof image == "undefined") {
    image = this.getParentElement();
    if (image && !/^img$/i.test(image.tagName))
      image = null;
  }
  if (image) {
    outparam = {
      f_url    : HTMLArea.is_ie ? editor.stripBaseURL(image.src) : image.getAttribute("src"),
      f_alt    : image.alt,
      f_border : image.border,
      f_align  : image.align,
      f_vert   : image.vspace == -1 ? '' : image.vspace,
      f_horiz  : image.hspace == -1 ? '' : image.hspace,
      f_height : image.height,
      f_width  : image.width
    };
  }
  this._popupDialog("insert_image.php", function(param) {
    if (!param) {  // user must have pressed Cancel
      return false;
    }
    var img = image;
    if (!img) {
      if (HTMLArea.is_ie) {
        var sel = editor._getSelection();
        var range = editor._createRange(sel);
        editor._doc.execCommand("insertimage", false, param.f_url);
        img = range.parentElement();
        // wonder if this works...
        if (img.tagName.toLowerCase() != "img") {
          img = img.previousSibling;
        }
		for (field in param) {
			var value = param[field];
			switch (field) {
			    case "f_alt"    : img.alt	 = value; break;
			    case "f_border" : img.border = parseInt(value || "0"); break;
			    case "f_align"  : img.align	 = value; break;
			    case "f_vert"   : img.vspace = parseInt(value || "0"); break;
			    case "f_horiz"  : img.hspace = parseInt(value || "0"); break;
	            case "f_height" : img.height = parseInt(value || "0"); break;
	            case "f_width"  : img.width  = parseInt(value || "0"); break;
			}
		}
      } else {
        img = '<img src="'+param.f_url+'"';
        for (field in param) {
          var value = param[field];
          if (!value) {
            continue;
          }
          switch (field) {
            case "f_alt"    : img += ' alt="'+value+'"'; break;
            case "f_border" : img += ' border="'+parseInt(value)+'"'; break;
            case "f_align"  : img += ' align="'+value+'"'; break;
            case "f_vert"   : img += ' vspace="'+parseInt(value)+'"'; break;
            case "f_horiz"  : img += ' hspace="'+parseInt(value)+'"'; break;
            case "f_height" : img += ' height="'+parseInt(value)+'"'; break;
            case "f_width"  : img += ' width="'+parseInt(value)+'"'; break;
          }
        }
        img += ' />';
        editor.insertHTML(img);
      }
    } else {
      var sel = editor._getSelection();
      var range = editor._createRange(sel);
      editor._doc.execCommand("insertimage", false, param.f_url);
      img.src = param.f_url;
      for (field in param) {
        var value = param[field];
        if (!value) {
          continue;
        }
        switch (field) {
          case "f_alt"    : img.alt    = value; break;
          case "f_border" : img.border = parseInt(value); break;
          case "f_align"  : img.align  = value; break;
          case "f_vert"   : img.vspace = parseInt(value); break;
          case "f_horiz"  : img.hspace = parseInt(value); break;
          case "f_height" : img.height = parseInt(value); break;
          case "f_width"  : img.width  = parseInt(value); break;
        }
      }
    }
  }, outparam);
}

// get attributes of selected element

HTMLArea.prototype.getAttributes = function(node) {

  var attrs = node.attributes;

  var attribList = new Array();

  for (i = 0; i < attrs.length; ++i) {
    var a = attrs.item(i);
    if (!a.specified) {
      continue;
    }
    attribList[a.name.toLowerCase()] = a.value;
  }
  return attribList;

}

//  getBlock is similar to _isBlockElement but accepts second arguments and checks
//  if the element (provided by second argument) is in current selection.

HTMLArea.getBlock = function( element, tags ) {
        var blockTags = (tags ? "|" + tags + "|" : "|H1|H2|H3|H4|H5|H6|P|PRE|LI|TD|DIV|BLOCKQUOTE|DT|DD|TABLE|HR|IMG|")
        while (( element != null) && (blockTags.indexOf("|"+element.tagName+"|")==-1)) element = element.parentElement
        return element
}

//  An original function to replace the "createlink" functions in HTMLArea.
//  Allows a custom dialog box to popup and display lists of pages internal
//  to FreeWPS and filenames available in the file system for linking.

HTMLArea.prototype.wps_insertlink = function() {

  var sel = this._getSelection();
  var range = this._createRange(sel);
  var editor = this;  // for nested functions
  var node = range.startContainer;
  var aLink = "";
  aLink = this.getSelectedHTML();

  if (!HTMLArea.is_ie) {
    if (node.nodeType == 1) {
      if ((node.nodeName == "A") || (node.nodeName == "a")) {
        aLink = node.innerHTML;
//        node = node.parentNode;
       }
       else {
        var pos = range.startOffset;
        node = node.childNodes[pos];
       }
    }
  }

  if (aLink != '') {
    var linkText = "";
    var props = new Array();
    props["f_href"] = "";
    props["f_target"] = "";
    props["f_title"] = "";

    if (HTMLArea.is_ie) {
      linkText = range.text;
      var anchor = null;
      var parent_el = range.parentElement();

      if (parent_el != null) {
        anchor = HTMLArea.getBlock(parent_el,"A");
      }
      else {
        anchor = HTMLArea.getBlock(range.item(0),"A");
      }

      if (anchor) {
        props["f_href"] = anchor.href;
        props["f_target"] = anchor.target;
        props["f_title"] = anchor.title;
      }
    }
    else {
      if (node.nodeType == 1) {
        linkText = aLink;
        var linkAttr = this.getAttributes(node);
        props["f_href"] = linkAttr["href"];
        props["f_target"] = linkAttr["target"];
        props["f_title"] = linkAttr["title"];/*
        if (node.nodeName == "A") {
          var linkText2 = aLink.split(/>/);
          var lt = linkText2[1].split(/</);
          linkText = lt[0];
        }*/
      }

    }

    this._popupDialog("insert_link.php", function(param) {
      if (!param) {  // user must have pressed Cancel
        return false;
      }
      else {
        newlink = "<a href=\""+param["f_href"]+"\"";
        if (param.target != "") {
          newlink += " target=\""+param["f_target"]+"\"";
        }
        if (param.title != "") {
          newlink += " title=\""+param["f_title"]+"\"";
        }
        newlink += ">"+aLink+"</a>";
      }
      if (HTMLArea.is_ie) {
        range.pasteHTML(newlink);
      }
      else {
        // insert link
        editor.insertHTML(newlink);
      }

      return true;

    }, props);

    return true;

  }
  else {
     alert("Select a region to create hyperlink");
  }

}

HTMLArea.prototype.wps_popupeditor = function() {
  editor = this;
  if (HTMLArea.is_ie) {
      window.open(this.popupURL("fullscreen.php"), "ha_fullscreen",
            "toolbar=no,location=no,directories=no,status=no,menubar=no," +
            "scrollbars=no,resizable=yes,width=640,height=480");
  } else {
    window.open(this.popupURL("fullscreen.php"), "ha_fullscreen",
          "toolbar=no,menubar=no,personalbar=no,width=640,height=480," +
          "status=no,scrollbars=no,resizable=yes");
  }
  // pass this object to the newly opened window
  HTMLArea._object = this;
}