<?php
/**
 * Core Library for Miscellaneous FreeWPS APIs
 * Reusable functions found in use throughout all Core Scripts in FreeWPS.
 * @package Core-Libraries
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | FUNCTIONS.PHP                                        |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | FUNCTIONS.PHP is part of FreeWPS.                    |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: functions.php,v 1.18 2005/05/29 16:38:41 ytztech Exp $
//

if (stristr($_SERVER['PHP_SELF'],'functions.php')) {
	// To make sure no one calls this script directly, this conditional ensures
	// that the client browser is redirected to the Home Page if this script's
	// filename is found in $_SERVER['PHP_SELF'].
	Header('Location: ../index.php');
	die();
}

$local_path = str_replace('\\','/',dirname(__FILE__));
$site_path  = str_replace('/includes','',$local_path);
$file_pos	= strrpos($_SERVER['PHP_SELF'],'/')+1;
$url_path	= substr($_SERVER['PHP_SELF'],0,$file_pos);
$file_name	= substr($_SERVER['PHP_SELF'],$file_pos);
$cmd_line   = '';

if (isset($_SERVER['QUERY_STRING'])) {
	$cmd_line = $_SERVER['QUERY_STRING'];
}

if (file_exists($local_path.'/config.php')) {
	/** Include the global configuration (SQL). */
	include_once $local_path.'/config.php';

	/** Include the global defines. */
	include_once $local_path.'/defines.php';

	/** Include the template class. */
	include_once $local_path.'/openlayout.php';

	/** Include the SQL abstraction layer. */
	include_once $local_path.'/sql_al.php';

	/** Include the site-specific PHP functions. */
	include_once $local_path.'/style.php';
} else {
	// If the configuration file (CONFIG.PHP) is not found, redirect the
	// end user to the FreeWPS Setup Wizard to install FreeWPS.  Does not
	// guarantee the presence of the installer.
	Header('Location: install/install.php');
	die();
}

if (ini_get('arg_separator.output') != '&amp;') {
	// Ensure the argument separator is &amp; to provide full W3C compliance with
	// the XHTML 1.0 standard.  This step was included since PHP 4.x will not use
	// the &amp; when inserting the PHPSESSID variable into anchor tags.
	ini_set('arg_separator.output','&amp;');
}

if ($dbtype == 'postgresql') {
	// It is necessary to force UPPERCASE in any results returned from PostgreSQL.
	// The FUNCTION sql_fetch_array() will not return uppercase array elements for
	// the result set without this step.
	$sql_changecase = 'upper';
}

if (!isset($db_id)) {
	// Connect to the configured SQL RDBMS.  Configuration provided by CONFIG.PHP.
	$db_id = sql_connect($dbhost,$dbuser,$dbpass,$dbname);
}

if (!isset($site_url)) {
	// Load the FreeWPS global site configuration from table WPS_SETTINGS.
	// Only the variable name and its value are returned from the query.
	$query_cmd     = 'SELECT SETTING_NAME, SETTING_VALUE, SETTING_TYPE,'.
					 ' POSSIBLE_VALUES FROM '.$dbpref.'_SETTINGS';
	$results = @sql_query($query_cmd, $db_id);
	if ($results !== FALSE) {
		// Reaching this step is very good.  This site is healthy and returned a
		// valid set of site settings.  Not reaching this step is very, very bad.
		while ($row = sql_fetch_row($results)) {
			// Assign each setting to a global variable.  HTML columns must be stored
			// in the "Possible Values" field to avoid truncating the setting.
			$GLOBALS[$row[0]] = ($row[2] == 'html') ? $row[3] : $row[1];
		}
		// The VARIABLE $GLOBALS['freewps_language'] returned as part of the settings
		// must be in lowercase to properly load the language files for FreeWPS.
		$freewps_language = strtolower($freewps_language);
	} else {
		// Reaching this step is very, very bad.  This step indicates that no site
		// settings could be retrieved from the database.  As a last ditch effort,
		// look for the FreeWPS Setup Wizard.
		if (file_exists($site_path.'/install/install.php')) {
			// Congrats.  You get to reinstall.  How lucky.  This step probably
			// will not fix things, since some tables may still exist.  Try your
			// backups.  You do have backups, don't you? :)
			Header('Location: install/install.php');
		} else {
			// No site should ever reach here.  This step means that site has been
			// completely corrupted to the point that the site settings are gone
			// and no installation script exists to fix the install.  Instead,
			// display an error with instructions on where to find help.
			?>
	<h2>FreeWPS has been damaged.</h2>
	<p>Please consult some help from the <a href="http://www.ytztech.com/freewps/community">FreeWPS
	  Community forums</a>.&nbsp; Look at the forums labeled Installation,
	  Upgrading, and Troubleshooting for assistance.</p>
			<?php
		}
		die();
	}
}

$majorver = substr($freewps_version,0,3);
$version  = FREEWPS_VERSION;

if ($version == $majorver) {
	// Adding a zero to the version ensures that the comparison in the next
	// conditional will recognize a final version over any betas or release
	// candidates.
	$version .= '0';
}

if (($majorver == FREEWPS_MAJORVER) && ($version > $freewps_version)) {
	// When the major version is the same, but the minor versions are different,
	// we need to update the version in the database to major the running version.
	$freewps_version = FREEWPS_VERSION;
	$query_cmd       = 'UPDATE '.$dbpref.'_SETTINGS'.
						' SET SETTING_VALUE = \''.FREEWPS_VERSION.'\''.
						' WHERE SETTING_NAME = \'freewps_version\'';
	sql_query($query_cmd,$db_id);
}

if (file_exists($site_path.'/languages/'.$freewps_language.'/lang-freewps.php')) {
	/** Attempt to use the locale-specific constants. */
	include_once $site_path.'/languages/'.$freewps_language.'/lang-freewps.php';
} else {
	/**
	 * Attempting to include the configured language for FreeWPS may not work,
	 * so to fix the issue, we include English since that may be available.
	 */
	include_once $site_path.'/languages/english/lang-freewps.php';
}

session_start();

if (!isset($_SESSION['siteurl'])) {
	$_SESSION['siteurl'] = $site_url;
} else {
	if ($_SESSION['siteurl'] != $site_url) {
		// Check the current SiteURL against the one in the user's session and log
		// out any mismatching users.  Just one site can be managed at a time.
		// @todo Place all the site globals in a separate array for this site.
		$_SESSION['siteurl']        = $site_url;
		$_SESSION['authorization']  = '';
		$_SESSION['registereduser'] = '';
		$_SESSION['user_timestamp'] = time();
		$_SESSION['seedhash']       = 'COMPLETELYRANDOMSEEDHASH';
	}
}

if (!isset($_SESSION['authorization'])) {
	$_SESSION['authorization']  = '';
}

if (!isset($_SESSION['registereduser'])) {
	$_SESSION['registereduser'] = '';
}

if (!isset($_SESSION['user_timestamp'])) {
	$_SESSION['user_timestamp'] = time();
}

if (!isset($_SESSION['seedhash'])) {
	$_SESSION['seedhash'] = 'COMPLETELYRANDOMSEEDHASH';
}

if (((stristr($_SERVER['PHP_SELF'],'index.php')) ||
	 (stristr($_SERVER['PHP_SELF'],'modules.php'))) &&
	($_SERVER['REQUEST_METHOD'] == 'GET') &&
	(!stristr($cmd_line,'popup'))) {

	// Only set the REFERER variables for pages not using the popup template.
	if (!isset($_SESSION['referer'])) {
		// Initialize the referer.
		// @todo Expand into a "history" array for tracking changes.
		$_SESSION['prev_page']  = '';
		$_SESSION['referer']    = urldecode(core_getReferer());
	} else {
		if ($_SESSION['referer']    != urldecode(core_getReferer())) {
			$_SESSION['prev_page']   = $_SESSION['referer'];
			$_SESSION['referer']     = urldecode(core_getReferer());
		}
	}
}

// Initialize the user permissions to nothing.
$user_perms = '';

if (!stristr($_SERVER['PHP_SELF'],'logout.php')) {
	// Check the user permissions only if the user is NOT logging out.
	// Verify that the user session has not timed out.
	$user_perms = core_authorizeUser($_SESSION['authorization'],TRUE);
}



if (!function_exists('file_get_contents')) {
    /**
	 * Reads entire contents of a file into a string.
	 * Provides binary-safe method for reading a file into a string for PHP versions
	 * below 4.3.0.
	 *
	 * @param  string $filename           Filename to read
	 * @param  int    $use_include_path   Set to 1 to check the include_path for file
	 * @access public
	 * @return string Contents of file as a string
	 */
    function file_get_contents($filename, $use_include_path = 0)
    {
        $file = @fopen($filename, 'rb', $use_include_path);
        if ($file) {
            if ($fsize = @filesize($filename)) {
                $data = fread($file, $fsize);
            } else {
                while (!feof($file)) {
                    $data .= fread($file, 1024);
                }
            }
            fclose($file);
        }
        return $data;
    }
}


/**
 * Determines whether TABLE $table contains $pg_id when matching $column to $value.
 *
 * @param  int    $pg_id    ID of page to check against $table
 * @param  string $table    SQL table name to check
 * @param  string $column   SQL field name to check
 * @param  mixed  $value    Value to match with $column
 * @access public
 * @return bool   TRUE if $pg_id is found matching $column and $value in $table
 */
function core_checkPerPage($pg_id, $table, $column, $value)
{
	// Setup the query to return the list of matching pages.
	$query_pt1 = 'SELECT PAGEID FROM ';

	// This part of the query will help determine the number of returned rows
	// for those RDBMS that do not support that function directly.
	$query_pt2 = $table.' WHERE '.$column.' = '.$value;

	$results   = sql_query($query_pt1.$query_pt2, $GLOBALS['db_id']);

	if (sql_num_rows($results, $query_pt2) > 0) {
		// When more than one row is found, look for a match.
		while ($row = sql_fetch_row($results)) {
			if (($row[0] == $pg_id) OR ($row[0] == 0)) {
				// Matching the original page or all pages.
				return TRUE;
			}
		}
	}
	return FALSE;
}


/**
 * When using the "convert" $action (which is default), all single and double quotes
 * are replaced with &wpsapos; and &wpsquot;, respectively.  When using the "revert"
 * action, all instances of &wpsapos; and &wpsquot; are replaced with single and
 * double quotes, respectively.
 *
 * @param  string $string   String to be converted
 * @param  string $action   (optional) Either 'convert' or 'revert'
 * @access public
 * @return string The converted/reverted $string
 */
function core_convertQuotes($string, $action = 'convert')
{
	if ($action == 'revert') {
		return str_replace('&wpsapos;','\'',str_replace('&wpsquot;','"',$string));
	} else {
		return str_replace('\'','&wpsapos;',str_replace('"','&wpsquot;',$string));
	}
}


/**
 * Recursively copy the contents of a source folder into a destination folder.
 *
 * @param  string $source   Path of source folder to copy
 * @param  string $dest     Path of destination folder to copy
 * @access public
 * @return bool   TRUE when copy operations succeed
 */
function core_copyDir($source,$dest)
{
	if (!isset($GLOBALS['filelist'])) {
		// Set the three possible ending for each file copy operation.
		// Allows the lists to be shared recursively.
		$GLOBALS['filelist'] = array();
		$GLOBALS['noperms']  = array();
		$GLOBALS['preexist'] = array();
	}

	if ($dirh = opendir($source)) {
		// Open a handle to $source to read the file listing.
		while (($filename = readdir($dirh)) !== FALSE) {
			// The only check of the end of the folder is to test for complete
			// match against FALSE.  Files named "0" would match FALSE with "==".
			if ($filename != '.' && $filename != '..') {
				// OK, so this file isn't the current/previous folder markers.
				if (is_dir($source.$filename)) {
					// Yippie.  A folder.
					if (!file_exists($dest.$filename)) {
						// Destination directory doesn't exist.
						if (!@mkdir($dest.$filename)) {
							// If you can't make it, you don't have permission.
							$GLOBALS['noperms'][] = $source.$filename;
						}
					}
					if (!core_copyDir($source.$filename.'/',$dest.$filename.'/')) {
						// Recursively copy this folder.  If not, no perms exist.
						$GLOBALS['noperms'][] = $source.$filename;
					}
				} else {
					// Nope. It's a file, buddy.
					if (file_exists($dest.$filename)) {
						// The file is already there.  Oops.  Oh well.
						$GLOBALS['preexist'][] = $source.$filename;
					}
					if (!@copy($source.$filename,$dest.$filename)) {
						// If you can't copy it, you don't have permission.
						$GLOBALS['filelist'][] = $source.$filename;
					}
				}
			}
		}
		// Not closing a directory handle is bad, m'kay.
		closedir($dirh);
		// Since we did something, return true.
		return TRUE;
	}
	// Oops, no copying.  Return false.
	return FALSE;
}


/**
 * Delete a folder even if not empty.
 *
 * @param  string $folder   Path of the folder to remove.
 * @access public
 * @return void
 */
function core_removeDir($folder)
{
	$dirh = opendir($folder);
	while (($filename = readdir($dirh)) !== FALSE) {
		// The only check of the end of the folder is to test for complete
		// match against FALSE.  Files named "0" would match FALSE with "==".
		if ($filename != '.' && $filename != '..') {
			// OK, so this file isn't the current/previous folder markers.
			if (is_dir($folder.'/'.$filename)) {
				// Doh! How deep is this rabbit hole.
				core_removeDir($folder.'/'.$filename);
			} else {
				// Yeah.  Deleting files is fun, m'kay.
				unlink($folder.'/'.$filename);
			}
		}
	}
	// Not closing a directory handle is bad, m'kay.
	closedir($dirh);
	// The moment we've all waited for.  Remove the directory.
	rmdir($folder);
}


/**
 * Recursively list the subfolders of source folder.
 * Each folder returned is an array of two values:
 * o 0 => [Actual Path]
 * o 1 => [Level + Folder Name]
 *
 * @param  string $folder   Path of the folder to remove
 * @param  string $level    (optional) The folder depth of $source
 * @access public
 * @return array
 */
function core_listDir($source,$level = '+-')
{
	$dirarray = array();
	if (!isset($GLOBALS['dirlist'])) {
		// Globally set the list of folders to return.
		// Useful for further processing folder names externally.
		$GLOBALS['dirlist'] = '['.$source.']';
	}
	if ($dirh = opendir($source)) {
		// Open the directory handle to read the file listing.
		while (($folder = readdir($dirh)) !== FALSE) {
			// The only check of the end of the folder is to test for complete
			// match against FALSE.  Folders named "0" would match FALSE with "==".
			if ($folder != '.' && $folder != '..') {
				// OK, so this file isn't the current/previous folder markers.
				if (is_dir($source.$folder)) {
					// Yeah.  It's a folder.
					if (!stristr($GLOBALS['dirlist'],'['.$source.$folder.']')) {
						// Since this directory hasn't been assimilated...
						$GLOBALS['dirlist'] .= '['.$source.$folder.']';
						$dirarray[]          = array(0 => $source.$folder,
						                             1 => $level.'[ '.$folder.' ]');
					}
					// Look for subdirectorys.  Array_merge can be fun!
					$newdir   = core_listDir($source.$folder.'/','&nbsp; '.$level);
					$dirarray = array_merge($dirarray,$newdir);
				}
			}
		}
		// Not closing a directory handle is bad, m'kay.
		closedir($dirh);
	}
	return $dirarray;
}


/**
 * Return the next available ID to assign to a new record in TABLE $table.
 *
 * @param  string $table   Path of the folder to remove
 * @param  string $after   (optional) After the last or before the first ID
 * @access public
 * @return int    Next available ID to use in $table.
 */
function core_getNextID($table, $after = TRUE)
{
	if ($after) {
		// Starting numbering ID with positive numbers.
		$newid    = 1;
		// Look for the largest ID.
		$operator = sql_operator('max');
	} else {
		// Starting numbering ID with negative numbers.
		$newid    = -1;
		// Look for the smallest ID.
		$operator = sql_operator('min');
	}

	$query_cmd = 'SELECT '.$operator.'(ID) AS NEWID FROM '.$table;
	if ($newid == -1) {
		$query_cmd .= ' WHERE ID > -2000000000';
	}

	$results = sql_query($query_cmd,$GLOBALS['db_id']);
	$id_row  = sql_fetch_row($results);
	$newid  += $id_row[0];

	if ($newid == 0) {
		return ($after) ? 1 : -1;
	} else {
		return $newid;
	}
}


/**
 * Compile an HTTP_REFERER string for use with various functions.
 *
 * @access public
 * @return string URL Encoded referer for the current requested script
 *                plus any arguments to be passed to the script
 */
function core_getReferer()
{
	// Get the script name.
	$http_referer = substr(strrchr($_SERVER['PHP_SELF'],'/'),1);
	if ($http_referer == 'index.php') {
		if (stristr($GLOBALS['link_format'],'[NAME]')) {
			if (isset($_GET['page'])) {
				return str_replace('[NAME]',$_GET['page'],$GLOBALS['link_format']);
			}
		} elseif (stristr($GLOBALS['link_format'],'[ID]')) {
			if (isset($_GET['id'])) {
				return str_replace('[ID]',$_GET['id'],$GLOBALS['link_format']);
			}
		}
	}
	if (isset($_SERVER['QUERY_STRING'])) {
		if ($_SERVER['QUERY_STRING'] != '') {
			// If arguments exist to be passed, include them.
			$http_referer .= '?'.$_SERVER['QUERY_STRING'];
		}
	}
	// Return the URL encoded referer.
	return urlencode($http_referer);
}


/**
 * Performs the security lookup functions needed to determine:
 * o Whether the username and password submitted are valid
 * o What level of permissions does the authenticated user have
 * o (Optionally) Whether the timestamp on the user's session has exceeded the
 *   allowable limit
 * o Whether the timeout used to validate the timestamp on the user's session should
 *   be for the "login" or "authorization" process.
 *
 * Four return values are possible:
 * o 0 (Meaning no permissions)
 * o -1 (Meaning the login screen timeout expired)
 * o -2 (Meaning the user session timeout expired)
 * o A string containing the IDs of groups from table WPS_GROUPS of which the user
 *   is a member.  Each ID is surrounded with brackets, like "[1][2]".
 *
 * @param  string  $token    The md5-hashed string to match against the PASSHASH
 *                           field in table WPS_USERS
 * @param  boolean $expired  (optional) Whether to check for an expired user
 *                           session
 * @access private
 * @return mixed See description for list of returned values.
 */
function core_authorizeUser($token, $expired = FALSE)
{
	if ($token == '') {
		// If the user hasn't logged in, the user has no permissions.
		return 0;
	}

	// Initialize the user permission to return to the calling function.
	$permissions = '';

	// Initialize the timeout level to ZERO.
	$timeout     = 0;

	if ($expired) {
		// If checking for a login or session timeout, set $timeout to the
		// appropriate level, dependent on the logged-in status of the user's
		// session.
		if ($_SESSION['authorization'] == $token) {
			// This user is logged in, so set the timeout to check to the globally
			// configured user session timeout.
			$timeout = $GLOBALS['authorization_timeout'];
		} else {
			// This user is not logged in, so set the timeout to check to the
			// globally configured login screen timeout.
			$timeout = $GLOBALS['login_timeout'];
		}
	}

	if ((time() < ($_SESSION['user_timestamp'] + $timeout)) ||
	    ($expired == FALSE)) {
		// Check the timeout and timestamp against the current time. The check for
		// a timeout will not matter if $expired has been set to false.

		// Setup the query to check the user's security level.
		$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_GRPUSERS.GROUPID FROM ';

		// This part of the query will help determine the number of returned rows
		// for those RDBMS that do not support that function directly.
		$query_pt2 = $GLOBALS['dbpref'].'_GRPUSERS, '.$GLOBALS['dbpref'].'_USERS'.
		             ' WHERE '.$GLOBALS['dbpref'].'_USERS.PASSHASH=\''.$token.'\''.
		             ' AND '.$GLOBALS['dbpref'].'_USERS.ENABLED=\'y\''.
		             ' AND '.$GLOBALS['dbpref'].'_GRPUSERS.USERID = '.
		                     $GLOBALS['dbpref'].'_USERS.ID';

		// Get the security level.
		$results = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
		if (sql_num_rows($results,$query_pt2) > 0) {
			// Determine if a match was found.
			while ($row = sql_fetch_row($results)) {
				// If there's a match, get the group ids for that user.
				$permissions .= '['.$row[0].']';
			}
			if ($expired) {
				// Update the user's timestamp if the checking expiration.
				$_SESSION['user_timestamp'] = time();
			}
		} else {
			return 0;	  // Returning no permissions.
		}  // End of ELSE
	} elseif ($_SESSION['authorization'] == $token) {
		// Returning -2 shows the "session" timeout message.
		return -2;
	} else {
		// Returning -1 shows the "login" timeout message.
		return -1;
	}
	// Return the $permissions found for the username/password ($token).
	return $permissions;
}


/**
 * Determines whether a GROUPID exists in TABLE $table when matching $column and
 * $value and verifies whether the current user is in that group.
 * <p>TRUE returned if GROUPID is found matching $column and $value in $table and if
 * the current user is a member of that group.  Also, TRUE returned if no GROUPIDs
 * found (assumes EVERYONE_GROUP).  Also, TRUE returned if GROUPID is zero.</p>
 *
 * @param  string $table    SQL table name to check
 * @param  string $column   SQL field name to check
 * @param  mixed  $value    Value to match with $column
 * @access public
 * @return bool TRUE is returned when GROUPID is matched or is set to Everyone
 */
function core_checkGroup($table, $column, $value)
{
	// Setup and execute the query to check find a GROUPID match.
	$query_pt1 = 'SELECT GROUPID FROM ';
	$query_pt2 = $table.' WHERE '.$column.' = '.$value;
	$results   = sql_query($query_pt1.$query_pt2, $GLOBALS['db_id']);
	if (sql_num_rows($results, $query_pt2) > 0) {
		// Since one or more results were returned, examine each result row.
		while ($row = sql_fetch_row($results)) {
			if ($row[0] == EVERYONE_GROUP) {
				// Everyone has access because the EVERYONE_GROUP was returned.
				return TRUE;
			}
			if (core_checkUser($row[0])) {
				// This user is a member of group $row[0], so give them access.
				return TRUE;
			}
		}
	} else {
		// Since no results returned, everyone must have access.
		return TRUE;
	}
	// If you get here, you don't have access.
	return FALSE;
}


/**
 * Creates an syslog entry in table WPS_SYSLOG.
 *
 * Three fields are stored for each event:
 * o Incident Timestamp (field ID)
 * o Category Type (field CATEGORY)
 * o Incident Summary (field (STATEMENT)
 * The four $type defined in LOGIN.PHP are:
 * o Invalid Username or Password (type 0)
 * o Login Time Expired (type 1)
 * o Session Time Expired (type 2)
 * o Bad Hashingseed Received (type 3)
 * The first three categories are minor and may be very common.  Case 3 is either
 * a blantant attempt to hack into the system outside the normal authentication
 * means used by FreeWPS or a result of corrupted form data (which can and probably
 * will happen from time to time).
 * <p>The logged "Incident Summary" will include the username in question (if
 * available), an explanation of the incident, and the IP address and the
 * HTTP_USER_AGENT (if available) of the client browser.
 * @param  string $type       ID of the event category
 * @param  int    $userhash   (optional) MD5-hashed username from table WPS_USERS
 * @access public
 * @return void
 */
function core_createSyslog($type, $userhash = '')
{
	// Initialize the username to NULL.
	$user_name = '';

	if ($userhash != '') {
		// Good, a userhash was sent.
		// Setup and execute the query to find the username of the user.
		$query_cmd = 'SELECT USERNAME '.
					   'FROM '.$GLOBALS['dbpref'].'_USERS '.
					   'WHERE USERHASH=\''.$userhash.'\'';
		$results   = sql_query($query_cmd,$GLOBALS['db_id']);
		$row   = sql_fetch_row($results);
		$user_name = $row[0];
	}

	if ($user_name != '') {
		// Yeah, a username WAS found.
		switch ($type) {
			case 0:
				// A bad password was used.
				$str  = str_replace('<!--USERNAME-->',$user_name,_ERRORBADATTEMPT1);
				break;
			case 1:
				// Login Screen Timeout expired.
				$str  = str_replace('<!--USERNAME-->',$user_name,_ERRORTIMELIMIT1);
				break;
			case 2:
				// User Session Timeout expired.
				$str  = str_replace('<!--USERNAME-->',$user_name,_ERRORTIMELIMIT2);
				break;
			case 3:
				// Yikes! A different seedhash was sent by the client.
				$str  = str_replace('<!--USERNAME-->',$user_name,_ERRORBADHASH);
				break;
		}
	} else {
		// Damn, no username.
		switch ($type) {
			case 0:
				// A bad username was used.
				$str = _ERRORBADATTEMPT2;
				break;
			case 1:
				// Login Screen Timeout expired.
				$str = _ERRORTIMELIMIT3;
				break;
			case 2:
				// How the hell did you get here?
				break;
			case 3:
				// Yikes! A different seedhash was sent by the client.
				$str  = _ERRORBADATTEMPT3;
				break;
		}
	}

    // Add the address of the user to the statement.
    $user_ip  = $_SERVER['REMOTE_ADDR'];
	$str     .= '&nbsp; ';
	$str     .= str_replace('<!--REMOTE_ADDR-->',$user_ip,_ERRORINCIDENTIP);

	if (!empty($_SERVER['HTTP_X_FORWARDED_FOR'])) {
		// If the FORWARDED_FOR value is present, include it in the statement.
        $fwd_for = $_SERVER['HTTP_X_FORWARDED_FOR'];
		$fwd_by  = str_replace('<!--REMOTE_ADDR-->',$user_ip,_ERRORFORWARDEDBY1);
		$str    .= '&nbsp; ';
		$str    .= str_replace('<!--FORWARDED_FOR-->',$fwd_for,$fwd_by);
	}

	if (!empty($_SERVER['HTTP_USER_AGENT'])) {
		// If the USER_AGENT value is present, include it in the statement.
		$agent = $_SERVER['HTTP_USER_AGENT'];
		$str  .= '&nbsp; '.str_replace('<!--USER_AGENT-->',$agent,_ERRORBROWSER1);
	} else {
		// If the USER_AGENT value is unknown, include alternate browser statement.
		$str  .= '&nbsp; '._ERRORBROWSER2;
	}

	$query_cmd = 'INSERT INTO '.$GLOBALS['dbpref'].'_SYSLOG '.
				  'VALUES ('.time().',\''.$type.'\',\''.$str.'\')';
	sql_query($query_cmd, $GLOBALS['db_id']);
}


/**
 * Determines whether the $group is included or excluded from the current user's
 * permission set.
 *
 * @param  string $group    SQL table name to check
 * @param  int    $obj_id   Value to match with column ID in $table
 * @access public
 * @return bool TRUE or FALSE, depending on the user and inclusion of $group
 */
function core_checkUser($group, $includes = TRUE)
{
	if ($includes) {
		// Look at included permissions.
		if (strstr($GLOBALS['user_perms'],'['.SUPERUSERS_GROUP.']') !== FALSE) {
			// Check for Superuser permission.  Superusers ALWAYS have permission.
			return true;
		}
		// Check for $group.
		return strstr($GLOBALS['user_perms'],'['.$group.']') !== FALSE;
	} else {
		// Look at excluded permissions.
		if (strstr($GLOBALS['user_perms'],'['.SUPERUSERS_GROUP.']') !== FALSE) {
			// Check for Superuser permission.  Superusers CANNOT be excluded.
			return false;
		}
		// Check for $group.
		return strstr($GLOBALS['user_perms'],'['.$group.']') === FALSE;
	}
}


/**
 * Determines the locked status for editing of the $obj_id requested from $table.
 *
 * Four possible conditions exist:
 *  o No lock was found on $obj_id.  Returns "GRANTED".
 *  o A lock was found, but the timeout expired.  Returns "GRANTED".
 *  o A lock was found and the locking user is the current user.  Returns "GRANTED".
 *  o A lock was found and another user has a valid lock. Returns an error message
 *    stating the locked status.
 *
 * @param  string $table    SQL table name to check
 * @param  int    $obj_id   Value to match with column ID in $table
 * @access public
 * @return string See description for list of returned strings
 */
function core_checkLock($table, $obj_id)
{
	// Query the "object" table for a match against the "obj_id".
	$query_cmd   = 'SELECT LOCKSET, LOCKUSER, LOCKTIME'.
	                ' FROM '.$table.' WHERE ID='.$obj_id;
	$results     = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the contents of the match.
	$row         = sql_fetch_row($results);

	// Get the current UNIX timestamp.
	$currenttime = time();

	// Setting the $timeout to check to $GLOBALS['authorization_timeout']
	$timeout      = $GLOBALS['authorization_timeout'];


	if ($row[0] == 'n') {
		// With no lock set for $obj_id, grant this user access.
		$query_cmd = 'UPDATE '.$table.
		              ' SET LOCKSET=\'y\', '.
		                   'LOCKUSER=\''.$_SESSION['registereduser'].'\', '.
		                   'LOCKTIME='.$currenttime.
		              ' WHERE ID='.$obj_id;
		sql_query($query_cmd, $GLOBALS['db_id']);
	} elseif ($row[1] == $_SESSION['registereduser']) {
		// With no lock set for $obj_id, grant this user access.
		$query_cmd = 'UPDATE '.$table.
					  ' SET LOCKTIME='.$currenttime.
					  ' WHERE ID='.$obj_id;
		sql_query($query_cmd, $GLOBALS['db_id']);
	} elseif ($currenttime > ($row[2] + $timeout)) {
		$query_cmd = 'UPDATE '.$table.
					  ' SET LOCKUSER=\''.$_SESSION['registereduser'].'\', '.
						   'LOCKTIME='.$currenttime.
					  ' WHERE ID='.$obj_id;
		sql_query($query_cmd, $GLOBALS['db_id']);
	} else {
		$time_current = date('l, F jS, Y \a\t g:i:s A (T)',$currenttime);
		$time_lock    = date('l, F jS, Y \a\t g:i:s A (T)',$row[2]);
		reset($row);
		next($row);
		$lockobject = stripslashes(current($row));
		return '
<h2 align="center">'._ACCESSDENIED.' ('._RECORDLOCKED.')</h2>
<p>'._ERRORRECORDLOCKED.'&nbsp; '.
str_replace('<!--TIMEOUT-->',$timeout,_PLEASEWAIT).'</p>
<div align="center">
  <table align="center" border="1" cellspacing="2" cellpadding="2" width="570">
    <tr>
      <td align="right">&nbsp; '._MODULECOLON.'&nbsp; </td>
      <td align="left">&nbsp; '.$table.'&nbsp; </td>
    </tr>
    <tr>
      <td align="right">&nbsp; '._OBJECTCOLON.'&nbsp; </td>
      <td align="left">&nbsp; '.$lockobject.'&nbsp; </td>
    </tr>
    <tr>
      <td align="right">&nbsp; '._USERNAMECOLON.'&nbsp; </td>
      <td>&nbsp; '.$row[1].'&nbsp; </td>
    </tr>
    <tr>
      <td align="right">&nbsp; '._TIMELOCKEDCOLON.'&nbsp; </td>
      <td>&nbsp; '.$time_lock.'&nbsp; </td>
    </tr>
    <tr>
      <td align="right">&nbsp; '._TIMECURRENTCOLON.'&nbsp; </td>
      <td>&nbsp; '.$time_current.'&nbsp; </td>
    </tr>
  </table>
</div>';
	}
	// Only the worse case won't get this far.  Tell this user everything is good.
	return "GRANTED";
}


/**
 * Performs the data gathering and formatting process needed to output a dynamic
 * web page.
 *
 * To output a page without displaying an authored page in FreeWPS, $content and
 * $title are required.  $pg_id (which should be '') and $template (which can be
 * specified if a particular template should be used, like the popup or printable
 * templates) are not required to produce a page.
 *
 * @param  string $content    (optional) HTML to display
 * @param  string $pg_id      (optional) ID from table WPS_PAGES to be displayed
 * @param  string $title      (optional) Title of page to be displayed
 * @param  string $template   (optional) Filename with which to display $content
 * @access public
 * @return void
 */
function core_createPage($content = '', $pg_id = '1', $title = '', $template = '')
{
	// Determine whether $pg_id is a valid integer.
	if (($pg_id != '') && !is_numeric($pg_id) && ($content != 'WPS-BY-PAGENAME')) {
		header('Location: 404.php');
		die();
	}
	// Determine page ID to use.
	$pageid = $pg_id;
	// Initialize the meta tags for $pageid.
	$metatags = '';

	if ($content == 'WPS-BY-PAGENAME') {
		$query_pt1 = 'SELECT ID FROM ';
		$query_pt2 = $GLOBALS['dbpref'].'_PAGES WHERE PAGENAME = \''.$pg_id.'\'';
		$idresults = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
		if (sql_num_rows($idresults,$query_pt2) == 0) {
			header('Location: 404.php');
			die();
		} else {
			$row = sql_fetch_row($idresults);
			$pageid = $row[0];
		}
	}

	// Determine which template to use.
	if ($template == '') {
		// No filename was specified, so we need to look up the template.
		if ($pg_id != '') {
			// Since a particular page was requested, get the template for that page.
			$templatefile = core_getTemplate($pageid);
			if ($templatefile == '!default') {
				// No filename is specified for $pg_id.
				$templatefile = $GLOBALS['template_main'];
			}
		} else {
			// All other pages get the Default template.
			$templatefile = $GLOBALS['template_main'];
		}
	} else {
		// Check the specified template name before using.
		if (file_exists($GLOBALS['site_path'].'/templates/'.$template)) {
			$templatefile = $template;
		} else {
			$templatefile = $GLOBALS['template_main'];
		}
	}

	if (($GLOBALS['user_perms'] == -2) && (!eregi('login.php',$_SERVER['PHP_SELF']))) {
		// This user's session has exceeded the idle timeout.
		// We do not want to include the referer if the referer is LOGIN.PHP.
		Header('Location: login.php?referer='.core_getReferer());
		die();
	}

	if (strstr($GLOBALS['user_perms'],'[') !== FALSE) {
		// This user has logged in.  The following IF conditional should be
		// deprecated and removed before v3.0.
		if ($templatefile == $GLOBALS['template_main']) {
			$templatefile = $GLOBALS['template_member'];
		}
		// Get the HTML content for user links, login information, etc.
		$memberinfo = member_info();
	}

	// Get the HTML content for the blocks appearing on $pageid.
	$blockcontent = core_getBlocks($pageid);

	if ($pg_id != '') {
		// A real page will be displayed.
		if ($templatefile == $GLOBALS['template_printable']) {
			// Be sure to not include the "print friendly" link, since this page
			// is using the printable template.
			$pageinfo = core_getContent($pageid,'n');
		} else {
			// All other pages should get the content normally for $pg_id.
			$pageinfo = core_getContent($pageid);
		}
		if (($pageinfo[0] == '') && ($pageinfo[1] == '')) {
			// If nothing is returned, send the user to the Home Page.
			Header("Location: index.php");
			die();
		}
		// Assign the HTML content for $pg_id (template tag PAGECONTENT)
		$pgcontent = $pageinfo[0];

		// Assign the page title for $pg_id (template tag PAGETITLE)
		$pagetitle = $GLOBALS['site_name'];
		if ($pageid != '1') {
			// We don't add a special title for the Home Page (ID 1).
			$pagetitle .= ' - '.$pageinfo[1];
		}
		$metatags = core_getPageTags($pageid);
	} elseif ($content != '') {
		// Since it's not a real page, add the content passed as $content.
		$pgcontent = $content;

		// Include the passed page title, if one exists.
		$pagetitle = $GLOBALS['site_name'];
		if ($title != '') {
			$pagetitle .= ' - '.$title;
		}
	}

	// Setup the template class (PageLayout) from library OPENLAYOUT.PHP.
	$tpl = new PageLayout;

	// Setup the beginning and ending delimiter to use for template tags.
	// These delimiters are configured in the Website Configuration module.
	$tpl->set_delimiters($GLOBALS['tag_start'],$GLOBALS['tag_stop']);


	// Allows adding of custom tags without changing the rest of the functions.
	$tplarray = custom_createpage();
	for ($i = 0; $i < count($tplarray); $i++) {
		// Stepping through the returned list of tags and content.
		// Create a rule for each custom tag to be replaced.
		$tpl->create_rule($tplarray[$i][0], $tplarray[$i][1]);
	}

	// Create a rule to insert the character set for the language selected.
	$tpl->create_rule('CHARSET',_CHARSET);

	// Create a rule to insert the title, after removing the SQL friendly quotes.
	$tpl->create_rule('PAGETITLE',core_convertQuotes($pagetitle,'revert'));

	if (isset($memberinfo)) {
		// When a user is logged in, create a rule to insert the defined member info.
		$tpl->create_rule('MEMBERINFO',$memberinfo);
	}

	// Create a rule for the meta tags of $pageid.
	if ($metatags != '') {
		$tpl->create_rule('METATAGS',$metatags);
	}

	for ($i = 0; $i < count($blockcontent); $i++) {
		// Create a rule for each block side configured.
		$blk_name    = $blockcontent[$i][0];
		$blk_content = core_convertQuotes($blockcontent[$i][1],'revert');
		$tpl->create_rule($blk_name,$blk_content);
	}
	// Create a rule for the chief content of the page.
	$tpl->create_rule('PAGECONTENT',core_convertQuotes($pgcontent,'revert'));
	// Parse the template using the created rules and display that HTML to the user.
	echo $tpl->create_page($GLOBALS['site_path'].'/templates/'.$templatefile);
}


/**
 * Displays the "Inline Web Editor" for all the modules where a WYSIWYG web editor
 * is needed.
 *
 * @param  string $fieldname   Represents the ID or NAME of the TEXTAREA to replace
 * @access public
 * @return string HTML content to display with the Inline Web Editor in it.
 */
function core_getEditor($fieldname)
{
	/** Include the library to load the Inline Web Editor */
	include($GLOBALS['local_path'].'/webedit.php');

	// Initialize the editor object.
	$obj = new WebEditor();

	if (isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
		// If the client browser sends a accepted language value, try to load
		// the equivalent language files for the Inline Web Editor.
		$obj->language = substr($_SERVER['HTTP_ACCEPT_LANGUAGE'], 0, 2);
		$file = $GLOBALS['site_path'].'/htmlarea/lang'.$obj->language.'.js';
		if (!file_exists($file)) {
			// Since that language isn't available, the user gets English.
		 	$obj->language = 'en';
		}
	} else {
		// Since the user can't choose a language, the user gets English.
		$obj->language = 'en';
	}
	// Set the TEXTAREA name to $fieldname.
	$obj->textarea = $fieldname;
	// Return the HTML for the editor.
	return $obj->CreateEditor();
}


/**
 * Retrieve all of the block sections for a page (if defined).
 *
 * Returns an array of arrays.  Each array contains a block side and can consist of
 * multiple blocks.  Each side array has two elements:
 * o The template tag to replace (this is the block side defined for the
 *   block + the word "CONTENT").
 * o The HTML content making up the block side (and probably multiple blocks).
 *
 * @param  string $pg_id   (optional) ID of the page for which to retrieve blocks.
 * @access public
 * @return array Set description for return value information.
 */
function core_getBlocks($pg_id = '')
{
	// Create a blank array of the block sides.
	$side = array();

	// Create the query to return the list of blocks.
	$query_pt1 = 'SELECT '.
	             $GLOBALS['dbpref'].'_BLOCKS.ID, '.
	             $GLOBALS['dbpref'].'_BLOCKS.CONTENT, '.
	             $GLOBALS['dbpref'].'_BLOCKS.MODNAME, '.
	             $GLOBALS['dbpref'].'_BLOCKSIDES.SIDENAME FROM ';

	// This part of the query will help determine the number of returned rows
	// for those RDBMS that do not support that function directly.
	$query_pt2 = $GLOBALS['dbpref'].'_BLOCKS, '.
	             $GLOBALS['dbpref'].'_BLOCKSIDES WHERE '.
	             $GLOBALS['dbpref'].'_BLOCKS.SIDEID = '.
	             $GLOBALS['dbpref'].'_BLOCKSIDES.ID AND '.
	             $GLOBALS['dbpref'].'_BLOCKS.ISACTIVE=\'y\'';

	// This part of the query will sort the list of blocks by side and
	// precedence (in that order).
	$query_pt3 = ' ORDER BY '.$GLOBALS['dbpref'].'_BLOCKSIDES.SIDENAME, '.
	                          $GLOBALS['dbpref'].'_BLOCKS.PRECEDENCE';

	// Execute the query and determine if one or more blocks were returned.
	$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);
	$row_total = sql_num_rows($results,$query_pt2);
	if ($row_total > 0) {
		// Since at least one block exists, we have to process them.

		// $firsttime checks for the first created side array element.
		$firsttime = TRUE;

		// $i tracks the number of sides found.
		$i = 0;

		while ($row = sql_fetch_row($results)) {
			// Stepping through the list of blocks.
			$id  = $row[0];
			$table = $GLOBALS['dbpref'].'_GRPBLOCKS';
			if (!core_checkGroup($table,'BLOCKID',$id)) {
				// Since this user does NOT have access to see this block,
				// go to the next block in the returned results.
				continue;
			}
			if ($pg_id != '') {
				// Since a specific page was requested, check whether this block
				// should appear on that page.
				$table = $GLOBALS['dbpref'].'_PAGEBLOCKS';
				if (!core_checkPerPage($pg_id,$table,'BLOCKID',$id)) {
					// Since this page should NOT display this block, go to the
					// next block in the returned results.
					continue;
				}
			}
			// Check whether a system page was requested.
			if (stristr($GLOBALS['syspages'],$GLOBALS['file_name'])) {
				// Check whether this block should appear on that page.
				$filename	= $GLOBALS['file_name'];
				if ($filename  == 'modules.php') {
					$filename .= '?id='.$_REQUEST['id'];
				}
				$query_pt1	= 'SELECT ID FROM ';
				$query_pt2	= $GLOBALS['dbpref'].'_SYSBLOCKS'.
							  ' WHERE (PAGENAME = \''.$filename.'\' '.
							  '  OR PAGENAME = \'all\')'.
							  ' AND BLOCKID = '.$id;
				$sysresults	= sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
				if (sql_num_rows($sysresults,$query_pt2) == 0) {
					continue;
				}
			}
			if ($firsttime) {
				// The first time through, no sides have been allocated.
				// So this step will only happen once.
				$firsttime = FALSE;
			} else {
				// All other trips through, we'll see if this is a differnt side.
				if (!stristr($side[$i][0],strtoupper($row[3]))) {
					$i++;
				}
			}
			if (!isset($side[$i])) {
				// Yeah, another side was returned.
				$side[$i] = array();
				// Element zero is the name of the block side (in uppercase letters).
				$side[$i][0] = strtoupper($row[3]).'CONTENT';
				// Element one will be the HTML content for that side.
				$side[$i][1] = '';
			}
			if ($row[2] == 'blocks') {
				// For normal blocks, the content is available in WPS_BLOCKS.
				// We must strip any slashes that were added by the RDBMS.
				$side[$i][1] .= stripslashes($row[1]);
			} else {
				// For special blocks, the content is available through a special
				// function called MODULE_getblock, where MODULE is the module name.
				// This function will perform the necessary processing for the block
				// $id returned.  The function should return the HTML content for
				// the requested block.
				include_once 'modules/'.$row[2].'/getblock.php';
				$side[$i][1] .= call_user_func($row[2].'_getBlock',$id);
			}
		}
	}
	// Return the array of block sides, whether empty or not.
	return $side;
}


/**
 * Retrieves the "content sections" for $pg_id.
 *
 * By default, the "Home Page" (or page id #1) will be retrieved.
 *
 * @param  int  $pg_id       (optional) ID of the page for which to retrieve content
 * @param  char $printable   (optional) 'y' to display printable link or 'n' to not
 * @access public
 * @return array Two elements (0 => page title, 1=> page content)
 */
function core_getContent($pg_id = 1,$printable = 'y')
{
	// Initialize the page content and title to NULL, ''.
	$content = '';
	$title = '';

	// Initialize the page access to FALSE.
	$access = FALSE;

	// Initialize the display of the edit page and printable links to FALSE.
	$page_edit = FALSE;
	$print_easy = FALSE;

	// Setup and execute the query to return the properties of $pg_id.
	$query_cmd = 'SELECT TITLE,CATID,PAGEDATE,PRINTERFRIENDLY,'.
						'SHOWDATE,SHOWTITLE,LINKSTITLE'.
	              ' FROM '.$GLOBALS['dbpref'].'_PAGES WHERE ID = '.$pg_id;
	$results = sql_query($query_cmd,$GLOBALS['db_id']);
	if ($results === FALSE) {
		// Either the requested page is disabled, inactive, or non-existant.
		// Redirect to the 404 page.
		Header('Location: 404.php');
		die();
	} else {
		$row = sql_fetch_row($results);
		sql_free_result($results);
		if (($row[1] < 0) || ($row === FALSE)) {
			// Either the requested page is disabled, inactive, or non-existant.
			// Redirect to the 404 page.
			Header('Location: 404.php');
			die();
		} else {
			// Since this page hasn't been disabled or deactivated, setup and execute
			// the query to return the group permissions for $pg_id.
			$query_cmd = 'SELECT GROUPID'.
			              ' FROM '.$GLOBALS['dbpref'].'_GRPPAGES'.
			              ' WHERE PAGEID = '.$pg_id.
			              ' ORDER BY GROUPID';
			$grp_results = sql_query($query_cmd, $GLOBALS['db_id']);

			while ($grp_row = sql_fetch_row($grp_results)) {
				// Stepping through the list of permissions.
				if ($grp_row[0] == EVERYONE_GROUP) {
					// If any group is set to Everyone, grant access.
					$access = TRUE;
					break;
				}
				if (core_checkUser($grp_row[0])) {
					// If user is a member of the group, grant access.
					$access = TRUE;
					break;
				}
			}
		}
	}

	if ($access) {
		// Yeah, this user has access.

		// Pull the page properties for later use.
		$title		= $row[0];
		$showdate	= $row[4];
		$pagedate	= $row[2];
		$linkstitle = $row[6];

		if (core_checkUser(CONTENT_EDITORS)) {
			// Editors and Superusers will get the links to edit this page and/or
			// its numerous content sections.
			$page_edit = TRUE;
		} elseif (core_checkUser(CONTENT_AUTHORS)) {
			// Authors require that we check to find
			// Setup and execute the query to return the list
			// of valid owners for the page.
			$query_cmd = 'SELECT '.$GLOBALS['dbpref'].'_USERS.ID '.
						  ' FROM '.$GLOBALS['dbpref'].'_USERS, '.
								   $GLOBALS['dbpref'].'_PAGEOWNERS'.
						' WHERE ('.$GLOBALS['dbpref'].'_USERS.ID = '.
								   $GLOBALS['dbpref'].'_PAGEOWNERS.USERID)'.
						  ' AND ('.$GLOBALS['dbpref'].'_USERS.USERNAME = '.
							  '\''.$_SESSION['registereduser'].'\')'.
						  ' AND ('.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.
								   $pg_id.')';
			$owner_results = sql_query($query_cmd, $GLOBALS['db_id']);

			// By trying to fetch the first row, we can tell whether or not the
			// user is an owner of this page.  An owner can edit their own pages.
			$page_edit = is_array(@sql_fetch_row($owner_results));
		}

		// Force all "printable" pages to not display the editing links.
		if ($GLOBALS['file_name'] == 'printable.php') {
			$page_edit = FALSE;
		}

		if ($printable == 'y') {
			// We determine whether to show the printable link, which is defined
			// on a per-page basis.  If $printable were 'n', the link would never
			// show, even if configured to show for a page.
			$print_easy = ($row[3] == 'y');
		}

		if ($print_easy || $page_edit) {
			// If displaying the edit page or printable links, we have to construct
			// a table for the alignment of all the page elements.  This table
			// should not skew the look of a page badly, but it will permit each
			// page owner or editor to have access to links for quickly editing
			// a particular page or content section.
			$content .= '<table border="0" cellpadding="0" cellspacing="0"';
			$content .= ' width="100%"><tr>';
		}

		if ($row[5] == 'y') {
			// Show the page title as an <h2>.  If an editor or page owner views this
			// page, we must wrap the title with a table data tag.
			if ($print_easy || $page_edit) {
				$content .= '<td>';
			}
			$content .= '<h2>'.$row[0].'</h2>';
			if ($print_easy || $page_edit) {
				$content .= '</td>';
			}
		}

		if ($print_easy || $page_edit) {
			// Show the printable or edit page links.  If an editor or page owner
			// views this page, we must wrap the links with a table data tag.
			$content .= '<td align="right" class="regularText" valign="top">&nbsp;';
			if ($print_easy) {
				// Display the printable link.
				$content .= '<a href="'.core_getLinkFormat($pg_id,true);
				$content .= '" target="_blank">'.$GLOBALS['print_link'].'</a>';
				if ($page_edit) {
					// If both links are displayed, put them on separate lines.
					$content .= '<br />';
				}
			}
			if ($page_edit) {
				// Display the page edit link.
				$content .= '<a href="modules.php?id=pages&amp;mode=admincontent';
				$content .= '&amp;pageid='.$pg_id;
				$content .= '">['._EDITPAGE.']</a>';
			}
			// The content sections must also be displayed inside the necessary
			// table wrappers for the printable and page edit links.
			$content .= '</td></tr><tr><td class="regularText"';
			if ($row[5] == 'y') {
				// If we displayed the title with the links, we must span the two
				// columns in the table for the content sections.
				$content .= ' colspan="2"';
			}
			$content .= '>';
		}

		// Setup the query to return the properties of all page sections for $pg_id.
		$query_pt1 = 'SELECT ID,TITLE,CONTENT,CONTENTDATE,'.
							'SHOWDATE,SHOWTITLE,SECTNAME FROM ';

		// This part of the query will help determine the number of returned rows
		// for those RDBMS that do not support that function directly.
		$query_pt2 = $GLOBALS['dbpref'].'_CONTENT'.
					 ' WHERE PAGEID = '.$pg_id.
					 ' AND ISACTIVE = \'y\'';

		// This part of the query will sort the content sections by precedence.
		$query_pt3 = ' ORDER BY PRECEDENCE';

		// Execute the query.
		$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

		if (sql_num_rows($results,$query_pt2) > 0) {
			// OK, more than one section exists, so let's process them.
			while ($row = sql_fetch_row($results)) {
				// Stepping through each content section...

				// Placing the Section Name in an anchor for quick and easy linking.
				$content .= '<a name="';
				$content .= ($row[6] == '') ? 'section'.$row[0] : $row[6];
				$content .= '"></a>';

				// We wrap the content in a DIV to group all the sections together
				// and provide a uniform class for all content, if one is not
				// explicitly specified by the author/editor.
				$content .= '<div class="regularText">';

				if ($page_edit) {
					// If an editor or page owner views this page, we must wrap
					// the content sections with a table to display the edit links.
					$content .= '<table border="0" cellpadding="0" cellspacing="0"';
					$content .= ' width="100%"><tr>';
				}
				if ($row[5] == 'y') {
					// Show the section title as an <h3>.  If an editor or page owner
					// views this page, we must wrap the title with a table data tag.
					if ($page_edit) {
						$content .= '<td>';
					}

					// Strip any slashes the title could have from the RDBMS.
					$content .= '<h3>'.stripslashes($row[1]).'</h3>';
					if ($page_edit) {
						$content .= '</td>';
					}
				}

				if ($page_edit) {
					// If an editor or page owner views this page, we must wrap
					// the the edit links with a table data tag.
					$content .= '<td align="right" valign="top"';
					$content .= ' class="regularText">';
					$content .= '<a href="modules.php?id=pages&amp;mode=editcontent';
					$content .= '&amp;contentid='.$row[0].'">[';
					$content .= _EDITSECTION.']</a>';
					$content .= '</td></tr>';
					$content .= '<tr><td';
					if ($row[5] == 'y') {
						// If we displayed the title with the links, we must span the
						// two columns in the section table for the content.
						$content .= ' colspan="2"';
					}
					$content .= ' class="regularText">';
				}

				// Strip any slashes the content could have from the RDBMS.
				$content .= stripslashes($row[2]);

				if ($row[4] == 'y') {
					// Show the last date this section was updated.
					$content .= '<p>(<strong><em>'._LASTUPDATED.' ';
					$content .= date('n-j-Y',$row[3]).'</em></strong>)';
					if ($page_edit) {
						// An extra break is needed to make the page layout more
						// normally with the section edit link table.
						$content .= '<br />&nbsp;';
					}
					$content .= '</p>';
				}

				if ($page_edit) {
					// Close the section edit link table.
					$content .= '</td></tr></table>';
				}

				// This section has been processed.
				$content .= '</div>';
			}

			$query		= 'SELECT LINKURL,LINKTARGET,LINKTITLE,LINKTEXT FROM ';
			$query_pt2	= $GLOBALS['dbpref'].'_PAGELINKS WHERE PAGEID = '.$pg_id;
			$query		.= $query_pt2.' ORDER BY PRECEDENCE';
			$lnkresults = sql_query($query,$GLOBALS['db_id']);
			if (sql_num_rows($lnkresults,$query_pt2) > 0) {
				// Display the list of related links.
				$linkstitle = core_convertQuotes($linkstitle,'revert');
				$content .= '<div class="relatedTitle">'.$linkstitle;
				if ($page_edit) {
					// Display an "edit" link for the related links area.
					$content .= '&nbsp; [';
					$content .= '<a href="modules.php?id=pages';
					$content .= '&mode=adminrelated&pageid='.$pg_id.'">';
					$content .= _CLICKTOEDIT.'</a>]';
				}
				$content .= '</div>';
				$content .= '<div class="relatedDiv">';
				$content .= '<ul class="relatedList">';
				while ($row = sql_fetch_row($lnkresults)) {
					$content .= '<li>';
					$content .= '<a href="'.$row[0].'" target="'.$row[1].'"';
					$content .= ' title="'.$row[2].'">'.$row[3].'</a>';
					$content .= '</li>';
				}
				$content .= '</ul>';
				$content .= '</div>';
			}

			if ($showdate == 'y') {
				// Show the last date this page was updated.
				$content .= '<p class="regularText">(<strong><em>'._LASTUPDATED.' ';
				$content .= date('n-j-Y',$pagedate).'</em></strong>)</p>';
			}
		}

		if ($print_easy || $page_edit) {
			// Close the printable/page edit link table.
			$content .= '</td></tr></table>';
		}
	} else {
		// This user doesn't have access, but have they logged in yet?
		if ($_SESSION['authorization'] == '') {
			// Give the user a chance to login before erroring out.
			Header('Location: login.php?referer='.core_getReferer());
			die();
		} else {
			// This user explicitly doesn't have access, so display an error message.
			$content = access_denied();
			$title = _ACCESSDENIED;
		}
	}
	// Return the HTML and title.
	return array(0 => $content, 1 => $title);
}


/**
 * Retrieve the template filename for $pg_id.
 *
 * @param  int  $pg_id   ID of the page for which to retrieve the template filename
 * @access public
 * @return string The filename set in table WPS_PAGES
 */
function core_getTemplate($pg_id)
{
	// Setup and execute the query to lookup the template for $pg_id.
	$query_cmd = 'SELECT TEMPLATE FROM '.$GLOBALS['dbpref'].'_PAGES'.
				  ' WHERE ID = '.$pg_id;
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	if ($results === FALSE) {
		return $GLOBALS['template_main'];
	} else {
		// Get the template filename.
		$row = sql_fetch_row($results);
		// Return the template filename.
		return $row[0];
	}
}


/**
 * Determine the URL format to link to either normal or printable pages.
 *
 * @param  int      $pg_id       ID of the page for which to determine the URL format
 * @param  boolean  $printable   (optional) Whether to return printable URL
 * @access public
 * @return string Link string formatted for user-defined URLs
 */
function core_getLinkFormat($pg_id,$printable = false)
{
	// Setup and execute the query to lookup the pagename for $pg_id.
	$query_cmd = 'SELECT PAGENAME FROM '.$GLOBALS['dbpref'].'_PAGES'.
				  ' WHERE ID = '.$pg_id;
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the pagename.
	$row = sql_fetch_row($results);
	$format = ($printable) ? $GLOBALS['prnlink_format'] : $GLOBALS['link_format'];
	if (stristr($format,'[ID]')) {
		$idtype = '[ID]';
		$iddata = $pg_id;
	} else {
		$idtype = '[NAME]';
		$iddata = $row[0];
	}

	// Return the link string with the user-defined URL format.
	return str_replace($idtype,$iddata,$format);
}


/**
 * Retrieve the META tags for the current page.
 *
 * @param  int      $pg_id       ID of the page for which to determine the URL format
 * @access public
 * @return string The HTML representing the set of META tags for $pg_id.
 */
function core_getPageTags($pg_id)
{
	// Setup and execute the query to lookup the pagename for $pg_id.
	$query_cmd = 'SELECT TAGTYPE, TAGNAME, TAGCONTENT'.
				 ' FROM '.$GLOBALS['dbpref'].'_PAGETAGS'.
				 ' WHERE PAGEID = '.$pg_id.' ORDER BY TAGTYPE, TAGNAME';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the list of tags.
	$html = '';
	while ($row = sql_fetch_row($results)) {
		$html .= '<meta '.$row[0].'="'.$row[1].'" content="'.$row[2].'" />'."\r\n";
	}


	// Return the link string with the user-defined URL format.
	return $html;
}


/**
 * Removes all CORE records for a block.
 *
 * @param  int      $block_id       ID of the block to remove
 * @access public
 * @return boolean Returns TRUE for success and FALSE if the block records do not
 *                 exist.
 */
function core_removeBlock($blk_id)
{
	// Setup and execute the query to determine whether the block exists.
	$query_pt1 = 'SELECT PRECEDENCE FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_BLOCKS WHERE ID = '.$block_id;
	$results = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);

	// Determine whether the block still exists.
	if (sql_num_rows($results,$query_pt2) == 1) {
		$row = sql_fetch_row($results);
		// Execute the query to update the precedence of all blocks below $block_id.
		sql_query('UPDATE '.$GLOBALS['dbpref'].'_BLOCKS'.
				  ' SET PRECEDENCE = (PRECEDENCE - 1)'.
				  ' WHERE PRECEDENCE > '.$row[0], $GLOBALS['db_id']);
		// Execute the query to remove all permissions for this block.
		sql_query('DELETE FROM '.$GLOBALS['dbpref'].'_GRPBLOCKS'.
				  ' WHERE BLOCKID = '.$block_id, $GLOBALS['db_id']);
		// Execute the query to remove all regular page associations for this block.
		sql_query('DELETE FROM '.$GLOBALS['dbpref'].'_PAGEBLOCKS'.
				  ' WHERE BLOCKID = '.$block_id, $GLOBALS['db_id']);
		// Execute the query to remove all system page associations for this block.
		sql_query('DELETE FROM '.$GLOBALS['dbpref'].'_SYSBLOCKS'.
				  ' WHERE BLOCKID = '.$block_id, $GLOBALS['db_id']);
		// Execute the query to delete this block.
		sql_query('DELETE FROM '.$GLOBALS['dbpref'].'_BLOCKS'.
				  ' WHERE ID = '.$block_id, $GLOBALS['db_id']);
	} else {
		// Since the block doesn't exist, return FALSE.
		return FALSE;
	}
}


/**
 * Removes all CORE records for a page.
 *
 * @param  int      $page_id       ID of the page to remove
 * @access public
 * @return boolean Returns TRUE for success and FALSE if the page records do not
 *                 exist.
 */
function core_removePage($page_id)
{
	// Prevent anyone from programatically deleting the home page.
	if ($page_id > 1) {
		// Execute the query to delete this page.
		sql_query('DELETE FROM '.$dbpref.'_PAGES'.
				  ' WHERE ID='.$pageid,$db_id);
		// Execute the query to delete the content for this page.
		sql_query('DELETE FROM '.$dbpref.'_CONTENT'.
				  ' WHERE PAGEID='.$pageid,$db_id);
		// Execute the query to delete the permissions for this page.
		sql_query('DELETE FROM '.$dbpref.'_GRPPAGES'.
				  ' WHERE PAGEID='.$pageid,$db_id);
		// Execute the query to delete the block-page associations for this page.
		sql_query('DELETE FROM '.$dbpref.'_PAGEBLOCKS'.
				  ' WHERE PAGEID='.$pageid,$db_id);
		// Execute the query to delete the related links for this page.
		sql_query('DELETE FROM '.$dbpref.'_PAGELINKS'.
				  ' WHERE PAGEID='.$pageid,$db_id);
		// Execute the query to delete the owner records for this page.
		sql_query('DELETE FROM '.$dbpref.'_PAGEOWNERS'.
				  ' WHERE PAGEID='.$pageid,$db_id);
		// Execute the query to delete the META tags for this page.
		sql_query('DELETE FROM '.$dbpref.'_PAGETAGS'.
				  ' WHERE PAGEID='.$pageid,$db_id);
	} else {
		// Deleting the home page is bad, m'kay.
		return FALSE;
	}
}

?>