<?php
/**
 * Provides a lightweight HTML template class for building web pages.
 *
 * @package Core-Libraries
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +-------------------------------------------------------+
// | OPENLAYOUT.PHP                                        |
// +-------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC.  |
// +-------------------------------------------------------+
// | OPENLAYOUT.PHP is free software; you can redistribute |
// | it and/or modify it under the terms of the GNU        |
// | General Public License as published by the Free       |
// | Software Foundation; either version 2 of the          |
// | License, or (at your option) any later version.       |
// |                                                       |
// | OPENLAYOUT.PHP is distributed in the hope that it     |
// | will be useful, but WITHOUT ANY WARRANTY; without     |
// | even the implied warranty of MERCHANTABILITY or       |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        |
// | General Public License (included as COPYING.txt)      |
// | for more details.                                     |
// |                                                       |
// | You should have received a copy of the GNU General    |
// | Public License along with OPENLAYOUT.PHP. If you did  |
// | not, you may download a copy at:                      |
// |                                                       |
// | URL:  http://www.fsf.org/licenses/gpl.txt             |
// |                                                       |
// | You may also request a copy from:                     |
// |                                                       |
// | Free Software Foundation, Inc.                        |
// | 59 Temple Place, Suite 330                            |
// | Boston, MA 02111-1307                                 |
// | USA                                                   |
// +-------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>             |
// +-------------------------------------------------------+
//
// $Id: openlayout.php,v 1.4 2004/03/31 05:34:32 ytztech Exp $
//


/**
 * PageLayout class
 *
 * A lightweight HTML template class for building web pages.
 * @package Class-PageLayout
 * @subpackage Core-Libraries
 */
class PageLayout
{
	// Define the properties of the class.

	/**
	 * Holds the array of rules for dynamic content
	 *
	 * @access public
	 * @var array
	 */
	var $rule_set  = array();

	/**#@+
	 * Holds the delimiters for template tags.
	 *
	 * @access public
	 * @var string
	 */
	var $tag_start = '<!--';
	var $tag_stop  = '-->';
	/**#@-*/


	/**
	 * Processes layout rules to create the page from the specified template.
	 *
	 * This function will the array of layout rules ($this->rule_set) created by the
	 * FUNCTION $this->create_rule() to replace the template tags found in the HTML
	 * template, $tpl_name. Each rule can be used an unlimited number of times in the
	 * template file.
	 *
	 * @param  string $tpl_name   Filename of HTML template to parse for layout rules
	 * @return string URL Encoded referer for the current requested script
	 *                plus any arguments to be passed to the script
	 */
	function create_page($tpl_name)
	{
		// Initialize the page output.
		$page_output   = '';

		// Read in the FILE $tpl_name to ARRAY $template_file.
		$template_file = file($tpl_name);

		// Determine the total number of rules to process.
		$total_rules   = count($this->rule_set);

		// Determine the total number of lines to process.
		$total_lines   = count($template_file);

		for ($i = 0; $i < $total_lines; $i++) {
			// Check all of the lines in the $template file.
			if ((strstr($template_file[$i],$this->tag_start)) &&
				(strstr($template_file[$i],$this->tag_stop))) {
				// Since this line contains the tag delimiters, replace any matching
				// layout rules.
				for ($j = 0; $j < $total_rules; $j++) {
					// Replace the rule with the HTML in the next template line.
					// Nothing will occur if the rule is not present.
					$name = $this->rule_set[$j][0];
					$html = $this->rule_set[$j][1];
					$template_file[$i] = str_replace($name,$html,$template_file[$i]);
				}
			}
			//  Add the line (changed or not) to the page output.
			$page_output .= $template_file[$i];
		}
		//  Return the page output.
		return $page_output;
	}


	/**
	 * Adds another layout rule to the array $this->rule_set.
	 *
	 * This function will place the rule name and its specified content into an array
	 * of layout rules($this->rule_set).  This array will be processed by the
	 * FUNCTION $this->create_page() to replace template tags specified for the rule
	 * found in the HTML template.
	 *
	 * @param  string $rule      Text within the delimiters of the template tag
	 * @param  string $content   HTML to replace the template tag
	 * @return void
	 */
	function create_rule($rule,$content)
	{
		// Wrap the $rule_name with the delimiters of the template tag.
		$name = $this->tag_start.$rule.$this->tag_stop;

		// Add another rule set.
		$this->rule_set[] = array(0 => $name, 1 => $content);
	}



	/**
	 * Set the beginning and ending tag delimiters.
	 *
	 * @param  string $start   The beginning delimiter of a template tag
	 * @param  string $stop    The ending delimiter of a template tag
	 * @return void
	 */
	function set_delimiters($start, $stop)
	{
		//  Set the beginning delimiter.
		$this->tag_start = $start;

		//  Set the ending delimiter.
		$this->tag_stop  = $stop;
	}

}


?>