<?php
/**
 * SQL_AL.PHP is a PHP library providing a single, unified interface to multiple
 * RDBMS types. SQL_AL.PHP is a free, open-source API with support available for
 * DB2, Firebird SQL, Frontbase, Informix, Interbase, Microsoft SQL, MySQL, Oracle
 * (OCI7/8), PostgreSQL, SQLite, and Sybase.  Query debugging begins on line 366.
 * @package Core-Libraries
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | SQL_AL.PHP[tm] :: SQL Abstraction Library            |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | SQL_AL.PHP is free software; you can redistribute    |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | SQL_AL.PHP is distributed in the hope that it        |
// | will be useful, but WITHOUT ANY WARRANTY; without    |
// | even the implied warranty of MERCHANTABILITY or      |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: sql_al.php,v 1.6 2004/08/15 05:49:26 ytztech Exp $
//


if (!isset($usetrans)) {
	// If not using transactions, force DB2, IBASE, and OCI7/8 to AUTO-COMMIT.
	$usetrans = FALSE;
}


/**
 * Connect to SQL host ($host) and select a database ($db).
 *
 * @param  string $host      Hostname or IP address of database server
 * @param  string $user      Username to authenticate with $host
 * @param  string $pass      Password to authenticate with $host
 * @param  string $db        Database name
 * @param  string $db_pass   (optional) Database Password (only Frontbase)
 * @access public
 * @return int Returns the connection identifier ($dbid)
 */
function sql_connect($host, $user, $pass, $db, $dbpass = '')
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Determine which cursor type to include for DB2.
			if (isset($GLOBALS['db2_cursor'])) {
				// Use the specified cursor.
				$curtype = $GLOBALS['db2_cursor'];
			} else {
				// Be safe and use the ODBC cursor by default.
				$curtype = SQL_CUR_USE_ODBC;
			}
			// Create the connection to the DB2 server.
			$dbid = odbc_connect($db, $user, $pass, $curtype);
			// End this joyride.
			break;

		case 'fbsql':
			// Create the connection to the Frontbase server.
			$dbid = fbsql_connect($host, $user, $pass);
			if ($dbid) {
				// Connection was successful.
				if ($dbpass != '') {
					// Set the Frontbase database password for $dbid.
					fbsql_database_password($dbid, $dbpass);
				}
				if (!fbsql_select_db($db)) {
					// Return FALSE since the database could not be selected.
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Create the connection to the Firebird/Interbase server.
			$dbid = ibase_connect($host.':'.$db, $user, $pass);
			// End this joyride.
			break;

		case 'informix':
			// Create the connection to the Informix server.
			$dbid = ifx_connect($db.'@'.$host, $user, $pass);
			// End this joyride.
			break;

		case 'mssql':
			// Create the connection to the Microsoft SQL server.
			$dbid = mssql_connect($host, $user, $pass);
			if ($dbid) {
				// Connection was successful.
				if (!mssql_select_db($db)) {
					// Return FALSE since the database could not be selected.
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'mysql':
			// Create the connection to the MySQL server.
			$dbid = mysql_connect($host, $user, $pass);
			if ($dbid) {
				// Connection was successful.
				if (!mysql_select_db($db)) {
					// Return FALSE since the database could not be selected.
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'oracle':
			// Create the connection to the Oracle OCI7 server.
			$dbid = ora_logon($user.'@'.$db, $pass);
			if ($GLOBALS['usetrans']) {
				// If transactions are being used, disable auto-committing.
				ora_commitoff($dbid);
			}
			// End this joyride.
			break;

		case 'oci8':
			// Create the connection to the Oracle OCI8 server.
			$dbid = ocilogon($user, $pass, $db);
			// End this joyride.
			break;

		case 'postgresql':
			// Create the connection string for the PostgreSQL server.
			$str  = 'host='.$host.' user='.$user;
			$str .= ' password='.$pass.' port=5432 dbname='.$db;
			// Create the connection to the PostgreSQL server.
			$dbid = pg_connect($str);
			// End this joyride.
			break;

		case 'sqlite':
			// Create the connection to the SQLite database.
			$dbid = sqlite_open($db);
			// End this joyride.
			break;

		case 'sybase':
			// Create the connection to the Sybase server.
			$dbid = @sybase_connect($host, $user, $pass);
			if ($dbid) {
				// Connection was successful.
				if (!@sybase_select_db($db,$dbid)) {
					// Return FALSE since the database could not be selected.
					return FALSE;
				}
			}
			// End this joyride.
			break;
	}

	// Return the connection identifier.
	return $dbid;
}


/**
 * Free the result set $resid from memory.
 *
 * @param  int $resid   Identifier for a result set.
 * @access public
 * @return bool Returns TRUE/FALSE condition regarding successful release of $resid
 */
function sql_free_result($resid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Free the DB2 result set from memory.
			$row = odbc_free_result($resid);
			// End this joyride.
			break;

		case 'fbsql':
			// Free the Frontbase result set from memory.
			$row = fbsql_free_result($resid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Free the Firebird/Interbase result set from memory.
			$row = ibase_free_result($resid);
			// End this joyride.
			break;

		case 'informix':
			// Free the Informix result set from memory.
			$row = ifx_free_result($resid);
			// End this joyride.
			break;

		case 'mssql':
			// Free the Microsoft SQL result set from memory.
			$row = mssql_free_result($resid);
			// End this joyride.
			break;

		case 'mysql':
			// Free the MySQL result set from memory.
			$row = mysql_free_result($resid);
			// End this joyride.
			break;

		case 'oracle':
			// Free the Oracle OCI7 result set from memory.
			$row = ora_close($resid);
			// End this joyride.
			break;

		case 'oci8':
			// Free the Oracle OCI8 result set from memory.
			$row = ocicancel($resid);
			// End this joyride.
			break;

		case 'postgresql':
			// Free the PostgreSQL result set from memory.
			$row = pg_freeresult($resid);
			// End this joyride.
			break;

		case 'sqlite':
			// Free the SQLite result set from memory.
			unset($resid);
			$row = TRUE;
			// End this joyride.
			break;

		case 'sybase':
			// Free the Sybase result set from memory.
			$row = sybase_free_result($resid);
			// End this joyride.
			break;
	}

	// Return the success/failure of freeing the result identifier.
	return $row;
}


/**
 * Close connection to database represented by $dbid.
 *
 * @param  int $dbid   Connection identifier of database connection
 * @access public
 * @return bool Returns TRUE/FALSE condition regarding successful close of $dbid
 */
function sql_logout($dbid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Close the DB2 connection.
			$row = odbc_close($dbid);
			// End this joyride.
			break;

		case 'fbsql':
			// Close the Frontbase connection.
			$row = fbsql_close($dbid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Close the Firebird/Interbase connection.
			$row = ibase_close($dbid);
			// End this joyride.
			break;

		case 'informix':
			// Close the Informix connection.
			$row = ifx_close($dbid);
			// End this joyride.
			break;

		case 'mssql':
			// Close the Microsoft SQL connection.
			$row = mssql_close($dbid);
			// End this joyride.
			break;

		case 'mysql':
			// Close the MySQL connection.
			$row = mysql_close($dbid);
			// End this joyride.
			break;

		case 'oracle':
			// Close the Oracle OCI7 connection.
			$row = ora_logoff($dbid);
			// End this joyride.
			break;

		case 'oci8':
			// Close the Oracle OCI8 connection.
			$row = ocilogoff($dbid);
			// End this joyride.
			break;

		case 'postgresql':
			// Close the PostgreSQL connection.
			$row = pg_close($dbid);
			// End this joyride.
			break;

		case 'sqlite':
			// Close the SQLite connection.
			$row = sqlite_close($dbid);
			// End this joyride.
			break;

		case 'sybase':
			// Close the Sybase connection.
			$row = sybase_close($dbid);
			// End this joyride.
			break;
	}

	// Return the result of the connection closing.
	return $row;
}


/**
 * Submit a query ($query) to database and return the result ($resid).
 *
 * @param  string $query   SQL Query statement
 * @param  int    $dbid    Connection identifier of database connection
 * @access public
 * @return mixed Returns result identifier is successful and FALSE if not successful
 */
function sql_query($query, $dbid)
{
	// Debugging statement...uncomment line 366 to debug SQL_QUERY
//	echo "<pre>\r\n\r\n$query\r\n\r\n</pre>\r\n";

	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Execute the query against the DB2 database.
			$resid = odbc_exec($dbid, $query);
			// End this joyride.
			break;

		case 'fbsql':
			// Frontbase requires that all queries end with a semicolon (some RDBMS
			// actually do not require this).  This hack makes sure that all queries
			// end with a semicolon.
			$checkquery = $query;
			if ($checkquery[strlen($checkquery) - 1] != ';') {
				$checkquery .= ';';
			}
			// Execute the query against the Frontbase database.
			$resid = fbsql_query($checkquery, $dbid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Execute the query against the Firebird/Interbase database.
			$resid = ibase_query($dbid, $query);
			if ((!$GLOBALS['usetrans']) && (!stristr($query,'select')))  {
				// Since this is NOT a SELECT query and this connection does not use
				// transactions, commit this result to the database.
				$resid = sql_tcommit($dbid);
			}
			// End this joyride.
			break;

		case 'informix':
			if (isset($GLOBALS['ifx_cursor'])) {
				// Execute the query against the Informix database.
				$resid = ifx_query($query, $dbid, $GLOBALS['ifx_cursor']);
			} else {
				// Execute the query against the Informix database.
				$resid = ifx_query($query, $dbid);
			}
			// End this joyride.
			break;

		case 'mssql':
			// Execute the query against the Microsoft SQL database.
			$resid = mssql_query($query, $dbid);
			// End this joyride.
			break;

		case 'mysql':
			// Execute the query against the MySQL database.
			$resid = mysql_query($query, $dbid);
			// End this joyride.
			break;

		case 'oracle':
			// Execute the query against the Oracle OCI7 database.
			$resid = ora_open($dbid);
			if ($resid) {
				// A successful cursot was returned.
				if (!ora_parse($resid, $query)) {
					// This query didn't parse correctly, so return FALSE.
					return FALSE;
				} elseif (!ora_exec($resid)) {
					// This query parsed correctly, but wouldn't run successfully.
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'oci8':
			// Execute the query against the Frontbase database.
			$resid = ociparse($dbid, $query);
			if ($resid) {
				// A successful cursor was opened and the query was parsed correctly.

				// Assume the mode is not auto-committing.
				$modeint = OCI_DEFAULT;
				if (!$GLOBALS['usetrans']) {
					// Since transactions are not in use, set the mode for auto-
					// committing queries to the database.
					$modeint = OCI_COMMIT_ON_SUCCESS;
				}
				if (!ociexecute($resid,$modeint)) {
					// This query wouldn't run correctly.
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'postgresql':
			// Execute the query against the PostgreSQL database.
			$resid = pg_query($dbid, $query);
			// End this joyride.
			break;

		case 'sqlite':
			// Execute the query against the SQLite database.
			$resid = sqlite_query($query, $dbid);
			// End this joyride.
			break;

		case 'sybase':
			// Execute the query against the Sybase database.
			$resid = sybase_query($query, $dbid);
			// End this joyride.
			break;
	}

	// Return the identifier for the result set.
	return $resid;
}


/**
 * Determine the number of rows in a result set.
 *
 * @param  int    $resid      Identifier of current result set
 * @param  string $subquery   (optional) SQL Query sub-statement including list of
 *							  tables and where clause
 * @access public
 * @return mixed Returns result identifier is successful and FALSE if not successful
 */
function sql_num_rows($resid,$subquery = '')
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
		case 'fbsql':
		case 'ibase':
		case 'fbird':
		case 'informix':
			// Setup and execute a query to return the number of returned rows
			$str = 'SELECT Count(*) FROM '.$subquery;
			$temp_resid = sql_query($str, $GLOBALS['db_id']);

			// Determine the number of rows returned.
			if ($temp_array = sql_fetch_row($temp_resid)) {
				// Frontbase returns a float (sort of).
				$num_rows = intval($temp_array[0]);
			} else {
				// No rows were returned.
				return FALSE;
			}
			// End this joyride.
			break;

		case 'mssql':
			// Determine the number of rows returned.
			$num_rows = mssql_num_rows($resid);
			// End this joyride.
			break;

		case 'mysql':
			// Determine the number of rows returned.
			$num_rows = mysql_num_rows($resid);
			// End this joyride.
			break;

		case 'oracle':
			$str = 'SELECT Count(*) FROM '.$subquery;
			$temp_resid = sql_query($str, $GLOBALS['db_id']);
			if (ora_fetch($temp_resid)) {
				// Determine the number of rows returned.
				$num_rows = ora_getcolumn($temp_resid,0);
			} else {
				// No rows were returned.
				return FALSE;
			}
			// End this joyride.
			break;

		case 'oci8':
			$str = 'SELECT Count(*) FROM '.$subquery;
			$temp_resid = sql_query($str, $GLOBALS['db_id']);
			if (ocifetch($temp_resid)) {
				// Determine the number of rows returned.
				$num_rows = ociresult($temp_resid,1);
			} else {
				// No rows were returned.
				return FALSE;
			}
			// End this joyride.
			break;

		case 'postgresql':
			// Determine the number of rows returned.
			$num_rows = pg_numrows($resid);
			// End this joyride.
			break;

		case 'sqlite':
			// Determine the number of rows returned.
			$num_rows = sqlite_num_rows($resid);
			// End this joyride.
			break;

		case 'sybase':
			// Determine the number of rows returned.
			$num_rows = sybase_num_rows($resid);
			// End this joyride.
			break;
	}

	// Determine the number of rows returned.
	return $num_rows;
}


/**
 * Return the next row of data from the result set ($resid) as a numbered array.
 *
 * @param  int $resid   Identifier of current result set
 * @access public
 * @return array Returns a numbered array (element keys numbered from 0 on up)
 */
function sql_fetch_row($resid)
{
	// Initialize the arrays used to return the enumerated array of row.
	$rowarray = array();
	$temparray = array();

	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Get the next row of data.
			if (odbc_fetch_row($resid)) {
				if (!odbc_fetch_into($resid, &$rowarray)) {
					return FALSE;
				}
			}
			// End this joyride.
			break;

		case 'fbsql':
			// Get the next row of data.
			$rowarray = fbsql_fetch_row($resid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Get the next row of data.
			$rowarray = ibase_fetch_row($resid);
			// End this joyride.
			break;

		case 'informix':
			// Get the next row of data.
			$temparray = @ifx_fetch_row($resid);
			foreach($temparray as $field) {
				$rowarray[] = $field;
			}
			if ($temparray === FALSE) {
				return FALSE;
			}
			// End this joyride.
			break;

		case 'mssql':
			// Get the next row of data.
			$rowarray = mssql_fetch_row($resid);
			// End this joyride.
			break;

		case 'mysql':
			// Get the next row of data.
			$rowarray = mysql_fetch_row($resid);
			// End this joyride.
			break;

		case 'oracle':
			// Get the next row of data.
			if (ora_fetch_into($resid,$temparray,ORA_FETCHINTO_ASSOC)) {
				foreach($temparray as $field) {
					$rowarray[] = $field;
				}
			} else {
				return FALSE;
			}
			// End this joyride.
			break;

		case 'oci8':
			// Get the next row of data.
			ocifetchinto($resid,$rowarray,OCI_NUM);
			// End this joyride.
			break;

		case 'postgresql':
			// Get the next row of data.
			$rowarray = pg_fetch_row($resid);
			// End this joyride.
			break;

		case 'sqlite':
			// Get the next row of data.
			$rowarray = sqlite_fetch_array($resid,SQLITE_NUM);
			// End this joyride.
			break;

		case 'sybase':
			// Get the next row of data.
			$rowarray = sybase_fetch_row($resid);
			// End this joyride.
			break;
	}

	// Return the array of data.
	return $rowarray;
}


/**
 * Return the next row of data from the result set ($resid) as an associative array.
 *
 * @param  int $resid   Identifier of current result set
 * @access public
 * @return array Returns an associative array (element keys are named by)
 */
function sql_fetch_array($resid)
{
	// Initialize the arrays used to return the associative array of row.
	$rowarray = array();
	$temparray = array();

	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Get the next row of data.
			$temparray = odbc_fetch_array($resid);
			// End this joyride.
			break;

		case 'fbsql':
			// Get the next row of data.
			$temparray = fbsql_fetch_array($resid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Get the next row of data. Firebird/Interbird do not support the "fetch
			// array" function, so we use "fetch object" function and convert it.
			return get_object_vars(ibase_fetch_object($resid));
			// End this joyride.
			break;

		case 'informix':
			// Get the next row of data.
			$temparray = @ifx_fetch_row($resid);
			// End this joyride.
			break;

		case 'mssql':
			// Get the next row of data.
			$temparray = mssql_fetch_array($resid);
			// End this joyride.
			break;

		case 'mysql':
			// Get the next row of data.
			$temparray = mysql_fetch_array($resid);
			// End this joyride.
			break;

		case 'oracle':
			// Get the next row of data.
			ora_fetch_into($resid,$temparray,ORA_FETCHINTO_ASSOC);
			// End this joyride.
			break;

		case 'oci8':
			// Get the next row of data.
			ocifetchinto($resid,$temparray,OCI_ASSOC);
			// End this joyride.
			break;

		case 'postgresql':
			// Get the next row of data.
			$temparray = pg_fetch_array($resid);
			// End this joyride.
			break;

		case 'sqlite':
			// Get the next row of data.
			$temparray = sqlite_fetch_array($resid);
			// End this joyride.
			break;

		case 'sybase':
			// Get the next row of data.
			$temparray = sybase_fetch_array($resid);
			// End this joyride.
			break;
	}

	// Since some RDBMS have unusual treatment with regards to the case of column
	// names and table names, I've added this little hack to set all array keys to
	// upper or lower case.  To use this feature, set $GLOBALS['sql_changecase'] to
	// either 'upper' or 'lower', depending on the desired case change.

	if (isset($GLOBALS['sql_changecase'])) {
		if (is_array($temparray)) {
			// Move the array pointer to the beginning of the array.
			reset($temparray);
			while ($field = each($temparray)) {
				// Step through each element of the temporary array.
				if (is_numeric($field[0])) {
					// Since the field name isn't a string, assign the number as the
					// key to that column.
					$rowarray[$field[0]] = $field[1];
				} elseif ($GLOBALS['sql_changecase'] == 'upper') {
					// Insert the next column with an uppercase key.
					$rowarray[strtoupper($field[0])] = $field[1];
				} else {
					// Insert the next column with an lowercase key.
					$rowarray[strtolower($field[0])] = $field[1];
				}
			}
		} else {
			// How would you wind up here?  Give up and return the value we have.
			return $temparray;
		}
	} else {
		// Return the row of data without changing the case of its keys.
		return $temparray;
	}

	// Return the row of data with its adjusted keys.
	return $rowarray;
}


/**
 * Return the next row of data from the result set ($resid) as an associative object.
 *
 * Oracle OCI7/OCI8 and SQLite do not have a "fetch object" function, so we use the
 * "fetch array" function and convert its associative array into an object.
 *
 * @param  int $resid   Identifier of current result set
 * @access public
 * @return array Returns an object with the field names as its object elements
 */
function sql_fetch_object($resid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Get the next row of data.
			$rowobject = odbc_fetch_object($resid);
			// End this joyride.
			break;

		case 'fbsql':
			// Get the next row of data.
			$rowobject = fbsql_fetch_object($resid);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Get the next row of data.
			$rowobject = ibase_fetch_object($resid);
			// End this joyride.
			break;

		case 'informix':
			// Get the next row of data.
			$rowarray = @ifx_fetch_row($resid);
			// End this joyride.
			break;

		case 'mssql':
			// Get the next row of data.
			$rowobject = mssql_fetch_object($resid);
			// End this joyride.
			break;

		case 'mysql':
			// Get the next row of data.
			$rowobject = mysql_fetch_object($resid);
			// End this joyride.
			break;

		case 'oracle':
			// Get the next row of data.
			ora_fetch_into($resid,$rowarray,ORA_FETCHINTO_ASSOC);
			// End this joyride.
			break;

		case 'oci8':
			// Get the next row of data.
			ocifetchinto($resid,$rowarray,OCI_ASSOC);
			// End this joyride.
			break;

		case 'postgresql':
			// Get the next row of data.
			$rowobject = pg_fetch_object($resid);
			// End this joyride.
			break;

		case 'sqlite':
			// Get the next row of data.
			$rowarray = sqlite_fetch_array($resid,SQLITE_ASSOC);
			// End this joyride.
			break;

		case 'sybase':
			// Get the next row of data.
			$rowobject = sybase_fetch_object($resid);
			// End this joyride.
			break;
	}

	if (isset($rowarray)) {
		// Move the array pointer to the beginning of the array.
		reset($rowarray);
		while ($field = each($rowarray)) {
			// Create an object element for each array element.
			$rowobject -> $field[0] = $field[1];
		}
	}

	// Return the next row of data as an associative object.
	return $rowobject;
}


/**
 * Find the value stored in a particular field of a result set.
 *
 * Since Interbase 6.5+ and Firebird do not have a "result" function like the rest,
 * this is an SQL hack to achieve the same thing.  The query will return the $field
 * from the rowid specified.  BE AWARE that Interbase 6.0 doesn't support this.
 * <p>Since OCI7 and above does not have a "result" function, this is an SQL*Plus
 * hack to achieve the same thing.  The query will return the $field from the
 * subquery, based on the row_number as ranking.
 *
 * @param  int    $resid   Identifier of current result set
 * @param  int    $rowid   Row to return from current result set
 * @param  string $field   Field to return from current result set
 * @param  string $table   (Optional) Table used in current result set
 * @param  string $where   (Optional) WHERE clause ised in current result set
 * @access public
 * @return mixed Returns the field from the $rowid in $resid
 */
function sql_result($resid, $rowid, $field, $table = '', $where = '')
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			if (odbc_fetch_row($resid, $rowid)) {
				// Retrieve the requested field from $resid.
				$result = odbc_result($resid, $field);
			} else {
				return false;
			}
			// End this joyride.
			break;

		case 'fbsql':
			// Retrieve the requested field from $resid.
			$result = fbsql_result($resid, $rowid, $field);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Setup the query to find the specified row.
			if ($GLOBALS['dbtype'] == 'ibase') {
				$query_cmd = 'SELECT '.$fields.' FROM '.$table.
							 ' WHERE '.$where.' ROWS '.$rowid;
			} else {
				// Firebird needs the rowid before the requested row.
				$rowid--;
				$query_cmd = 'SELECT FIRST 1 SKIP '.$rowid.' '.$fields.
							 ' FROM '.$table.' WHERE '.$where;
			}
			// Execute the query to find the specified row.
			$rid = sql_query($query_cmd,$GLOBALS['db_id']);
			// Get the row of data.
			$row = sql_fetch_array($rid);
			// Retrieve the requested field from $row.
			$result = $row[$field];
			// End this joyride.
			break;

		case 'informix':
			// Retrieve the requested field from $resid.
			if ($temparray = @ifx_fetch_row($resid, $rowid)) {
				$result = $temparray[$field];
			} else {
				return false;
			}
			// End this joyride.
			break;

		case 'mssql':
			// Retrieve the requested field from $resid.
			$result = mssql_result($resid, $rowid, $field);
			// End this joyride.
			break;

		case 'mysql':
			// Retrieve the requested field from $resid.
			$result = mysql_result($resid, $rowid, $field);
			// End this joyride.
			break;

		case 'oracle':
		case 'oci8':
			// Oracle needs the rowid after the requested row.
			$rowid++;
			// Setup the query to find the specified row.
			$query_cmd = 'SELECT '.$field.' FROM '.
						 ' (SELECT '.$field.',row_number() OVER'.
						  ' (ORDER BY '.$field.' ASC) ranking'.
						  ' FROM '.$table.' WHERE '.$where.')'.
						 ' WHERE ranking = '.$rowid;
			// Execute the query to find the specified row.
			$rid = sql_query($query_cmd,$GLOBALS['db_id']);
			// Get the row of data.
			$row = sql_fetch_array($rid);
			// Retrieve the requested field from $row.
			$result = $row[$field];
			// End this joyride.
			break;

		case 'postgresql':
			// Retrieve the requested field from $resid.
			$result = pg_result($resid, $rowid, $field);
			// End this joyride.
			break;

		case 'sqlite':
			// Find the row requested.
			if (sqlite_seek($resid, $rowid)) {
				// Retrieve the requested field from $resid.
				$result = sqlite_column($field);
			} else {
				// Since no field was found, return FALSE.
				return FALSE;
			}
			// End this joyride.
			break;

		case 'sybase':
			// Retrieve the requested field from $resid.
			$result = sybase_result($resid, $rowid, $field);
			// End this joyride.
			break;
	}

	// Return the requested field from $resid.
	return $result;
}


/**
 * Begins a transaction.
 *
 * MSSQL, MySQL, PostgreSQL and Sybase do not yet directly include support for
 * transactions.  Instead, a simple query is used to begin the transaction.
 * <p>Frontbase and Oracle always supports transactions.  Set the global variable
 * $usetrans to TRUE in order to use transactions with Frontbase and Oracle OCI7/8.
 * Otherwise, FUNCTION sql_query() will operate with AUTO COMMIT turned on.
 *
 * @param  int    $dbid   Identifier of current database connection
 * @access public
 * @return bool TRUE for success and FALSE for no success
 */
function sql_tbegin($dbid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Start the transaction.
			$tid = odbc_autocommit($dbid,FALSE);
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Start the transaction.
			$tid = ibase_trans();
			// End this joyride.
			break;

		case 'mssql':
		case 'sqlite':
		case 'sybase':
			// Start the transaction.
			$tid = sql_query('BEGIN TRANSACTION',$dbid);
			// End this joyride.
			break;

		case 'informix':
		case 'mysql':
		case 'postgresql':
			// Start the transaction.
			$tid = sql_query('BEGIN',$dbid);
			// End this joyride.
			break;

		case 'fbsql':
		case 'oracle':
		case 'oci8':
			// Since these always support transactions, return true.
			return TRUE;
			// End this joyride.
			break;
	}

	// Typecast the returned value as a boolean value.
	settype($tid,'boolean');
	// Return the results.
	return $tid;
}


/**
 * Commits a transaction.
 *
 * MSSQL, MySQL, PostgreSQL and Sybase do not yet directly include support for
 * transactions.  Instead, a simple query is used to commit the transaction.
 *
 * @param  int    $dbid   Identifier of current database connection.
 * @access public
 * @return bool TRUE for success and FALSE for no success
 */
function sql_tcommit($dbid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Commit the transaction.
			$tid = odbc_commit($dbid);
			// End this joyride.
			break;

		case 'fbsql':
			// Commit the transaction.
			$tid = fbsql_commit();
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Commit the transaction.
			$tid = ibase_commit($dbid);
			// End this joyride.
			break;

		case 'mssql':
		case 'sybase':
			// Commit the transaction.
			$tid = sql_query('COMMIT TRANSACTION',$dbid);
			// End this joyride.
			break;

		case 'informix':
		case 'mysql':
		case 'postgresql':
		case 'sqlite':
			// Commit the transaction.
			$tid = sql_query('COMMIT',$dbid);
			// End this joyride.
			break;

		case 'oracle':
			// Commit the transaction.
			$tid = ora_commit($dbid);
			// End this joyride.
			break;

		case 'oci8':
			// Commit the transaction.
			$tid = ocicommit($dbid);
			// End this joyride.
			break;
	}

	// Typecast the returned value as a boolean value.
	settype($tid,'boolean');
	// Return the results.
	return $tid;
}


/**
 * Rollback a transaction.
 *
 * MSSQL, MySQL, PostgreSQL and Sybase do not yet directly include support for
 * transactions.  Instead, a simple query is used to rollback the transaction.
 *
 * @param  int    $dbid   Identifier of current database connection.
 * @access public
 * @return bool TRUE for success and FALSE for no success
 */
function sql_trollback($dbid)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			// Rollback the transaction.
			$tid = odbc_rollback($dbid);
			// End this joyride.
			break;

		case 'fbsql':
			// Rollback the transaction.
			$tid = fbsql_rollback();
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			// Rollback the transaction.
			$tid = ibase_rollback($dbid);
			// End this joyride.
			break;

		case 'mssql':
		case 'sybase':
			// Rollback the transaction.
			$tid = sql_query('ROLLBACK TRANSACTION',$dbid);
			// End this joyride.
			break;

		case 'informix':
		case 'mysql':
		case 'postgresql':
		case 'sqlite':
			// Rollback the transaction.
			$tid = sql_query('ROLLBACK',$dbid);
			// End this joyride.
			break;

		case 'oracle':
			// Rollback the transaction.
			$tid = ora_rollback($dbid);
			// End this joyride.
			break;

		case 'oci8':
			// Rollback the transaction.
			$tid = ocirollback($dbid);
			// End this joyride.
			break;
	}

	// Typecast the returned value as a boolean value.
	settype($tid,'boolean');
	// Return the results.
	return $tid;
}


/**
 * Return appropriate $op for the configured database.
 *
 * Both $text1 and $text2 are optional for all operators except "binaryand". BE AWARE
 * that support for "binaryand" with Interbase and Firebird requires the installation
 * and setup of the user-defined function BIN_AND.
 *
 * @param  string $op      Common name for a database operator or function
 * @param  string $text1   (optional) First component of function
 * @param  string $text2   (optional) Second component of function
 * @access public
 * @return string Returns the text to include in a query for $op
 */
function sql_operator($op, $text1 = '', $text2 = '')
{
	switch ($op) {
		case 'like':
			switch ($GLOBALS['dbtype']) {
				case 'db2':
				case 'fbsql':
				case 'ibase':
				case 'fbird':
				case 'informix':
				case 'mssql':
				case 'mysql':
				case 'oracle':
				case 'oci8':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return '%';
					// End this joyride.
					break;
			}
			// End this joyride.
			break;

		case 'notequal':
			switch ($GLOBALS['dbtype']) {
				case 'db2':
				case 'ibase':
				case 'fbird':
				case 'informix':
				case 'mssql':
				case 'mysql':
				case 'oracle':
				case 'oci8':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return '!=';
					// End this joyride.
					break;
				case 'fbsql':
					return '<>';
					// End this joyride.
					break;
	    	}
			// End this joyride.
			break;

		case 'binaryand':
			switch ($GLOBALS['dbtype']) {
				case 'ibase':
				case 'fbird':
					return 'BIN_AND('.$text1.', '.$text2.')';
					// End this joyride.
					break;
				case 'db2':
				case 'fbsql':
				case 'mssql':
				case 'mysql':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return '('.$text1.' & '.$text2.')';
					// End this joyride.
					break;
				case 'informix':
					return false;
				case 'oracle':
				case 'oci8':
					return 'BITAND('.$text1.', '.$text2.')';
					// End this joyride.
					break;
			}
			// End this joyride.
			break;

		case 'min':
			switch ($GLOBALS['dbtype']) {
				case 'db2':
				case 'fbsql':
				case 'ibase':
				case 'fbird':
				case 'informix':
				case 'mssql':
				case 'mysql':
				case 'oracle':
				case 'oci8':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return 'MIN';
					// End this joyride.
					break;
			}
			// End this joyride.
			break;

		case 'max':
			switch ($GLOBALS['dbtype']) {
				case 'db2':
				case 'fbsql':
				case 'ibase':
				case 'fbird':
				case 'informix':
				case 'mssql':
				case 'mysql':
				case 'oracle':
				case 'oci8':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return 'MAX';
					// End this joyride.
					break;
			}
			// End this joyride.
			break;

		case 'sum':
			switch ($GLOBALS['dbtype']) {
				case 'db2':
				case 'fbsql':
				case 'ibase':
				case 'fbird':
				case 'informix':
				case 'mssql':
				case 'mysql':
				case 'oracle':
				case 'oci8':
				case 'postgresql':
				case 'sqlite':
				case 'sybase':
					return 'SUM';
					// End this joyride.
					break;
			}
			// End this joyride.
			break;
	}
}


/**
 * Determine the existence of the "connect" function for a database $type.
 *
 * @param  string $type   Common name for a database operator or function
 * @access public
 * @return bool TRUE for success and FALSE for no success
 */
function sql_supported($type)
{
	switch ($type) {
		case 'db2':
			$connect = 'odbc_connect';
			// End this joyride.
			break;

		case 'fbsql':
			$connect = 'fbsql_connect';
			// End this joyride.
			break;

		case 'ibase':
		case 'fbird':
			$connect = 'ibase_connect';
			// End this joyride.
			break;

		case 'informix':
			$connect = 'ifx_connect';
			// End this joyride.
			break;

		case 'mssql':
			$connect = 'mssql_connect';
			// End this joyride.
			break;

		case 'mysql':
			$connect = 'mysql_connect';
			// End this joyride.
			break;

		case 'oracle':
			$connect = 'ora_logon';
			// End this joyride.
			break;

		case 'oci8':
			$connect = 'ocilogon';
			// End this joyride.
			break;

		case 'postgresql':
			$connect = 'pg_connect';
			// End this joyride.
			break;

		case 'sqlite':
			$connect = 'sqlite_open';
			// End this joyride.
			break;

		case 'sybase':
			$connect = 'sybase_connect';
			// End this joyride.
			break;
	}

	// Return the existence of the connect function.
	return function_exists($connect);
}


/**
 * Execute SELECT query with appropriate SQL language to limit result set for
 * $GLOBALS['dbtype'].
 *
 * @param  string $fields    List of column/field names to return in the query
 * @param  string $table     Name of the table from which to return results
 * @param  string $where     Arguments for the WHERE clause of the query
 * @param  string $orderby   Arguments for the ORDER BY clause of the query
 * @param  int    $start     Number of result rows to skip in the query
 * @param  int    $total     Number of result rows to return from the query
 * @access public
 * @return int Result identifier for the query results
 */
function sql_limitquery($fields,$table,$where,$orderby,$start,$total)
{
	switch ($GLOBALS['dbtype']) {
		case 'db2':
			$start++;
			$query_cmd = 'SELECT * FROM (SELECT '.$fields.', rownumber() OVER';
			if ($orderby != '') {
				$query_cmd .= ' (ORDER BY '.$orderby.')';
			}
			$query_cmd .= ' AS wpsrow FROM '.$table;
			if ($where != '') {
				$query_cmd .= ' WHERE '.$where;
			}
			$query_cmd .= ')';
			if ($total > 0) {
				$query_cmd .= ' WHERE wpsrow BETWEEN '.$start.' AND '.$total;
			}
			// End this joyride.
			break;

		case 'ibase':
			$start++;
			$query_cmd = 'SELECT '.$fields.' FROM '.$table;
			if ($where != '') {
				$query_cmd .= ' WHERE '.$where;
			}
			if ($orderby != '') {
				$query_cmd .= ' ORDER BY '.$orderby;
			}
			if ($total > 0) {
				$query_cmd .= ' ROWS '.$start.' TO '.$total;
			}
			// End this joyride.
			break;

		case 'fbird':
			$query_cmd = 'SELECT';
			if ($total > 0) {
				$query_cmd .= ' FIRST '.$total;
				if ($start > 0) {
					$query_cmd .= ' SKIP '.$start;
				}
			}
			$query_cmd .= ' '.$fields.' FROM '.$table;
			if ($where != '') {
				$query_cmd .= ' WHERE ';
				$query_cmd .= $where;
			}
			if ($orderby != '') {
				$query_cmd .= ' ORDER BY '.$orderby;
			}
			// End this joyride.
			break;

		case 'mysql':
		case 'postgresql':
		case 'sqlite':
			$query_cmd = 'SELECT '.$fields.' FROM '.$table;
			if ($where != '') {
				$query_cmd .= ' WHERE '.$where;
			}
			if ($orderby != '') {
				$query_cmd .= ' ORDER BY '.$orderby;
			}
			if ($total > 0) {
				if ($GLOBALS['dbtype'] == 'mysql') {
					$query_cmd .= ' LIMIT '.$start.', '.$total;
				} else {
					$query_cmd .= ' LIMIT '.$total.' OFFSET '.$start;
				}
			}
			// End this joyride.
			break;

		case 'fbsql':
		case 'mssql':
		case 'sybase':
			$query_cmd = 'SELECT';
			if ($total > 0) {
				$query_cmd .= ' TOP '.$total;
			}
			$query_cmd .= ' '.$fields.' FROM '.$table;
			if (($where != '') || ($start > 0)) {
				$query_cmd .= ' WHERE ';
				if ($where != '') {
					$query_cmd .= $where;
				}
				if (($start > 0) && ($total > 0)) {
					if ($where != '') {
						$query_cmd .= ' AND ';
					}
					$query_cmd .= '(id > '.$start.')';
				}
			}
			if ($orderby != '') {
				$query_cmd .= ' ORDER BY '.$orderby;
			}
			// End this joyride.
			break;

		case 'oracle':
		case 'oci8':
			$query_cmd = 'SELECT * FROM (SELECT '.$fields.' FROM '.$table;
			if ($where != '') {
				$query_cmd .= ' WHERE '.$where;
			}
			if ($orderby != '') {
				$query_cmd .= ' ORDER BY '.$orderby;
			}
			$query_cmd .= ')';
			if ($total > 0) {
				$limit = $total + $start + 1;
				$query_cmd .= ' WHERE (rownum > '.$start.')'.
								 ' AND (rownum < '.$limit.')';
			}
			// End this joyride.
			break;
	}

	// Return the result identifier for the query.
	return sql_query($query_cmd, $GLOBALS['db_id']);
}

?>