<?php
/**
 * Provides a lightweight HTML template class for building web pages.
 *
 * @package Core-Libraries
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +-------------------------------------------------------+
// | WEBEDIT.PHP                                           |
// +-------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC.  |
// +-------------------------------------------------------+
// | WEBEDIT.PHP is part of FreeWPS.                       |
// |                                                       |
// | FreeWPS was built using the FreeWPS Software          |
// | Development Kit (SDK), version 2.0.  Free Web         |
// | Publishing System[tm] and FreeWPS[tm] are both        |
// | trademarks of YTZ Technical Services, LLC.            |
// |                                                       |
// | FreeWPS is free software; you can redistribute        |
// | it and/or modify it under the terms of the GNU        |
// | General Public License as published by the Free       |
// | Software Foundation; either version 2 of the          |
// | License, or (at your option) any later version.       |
// |                                                       |
// | FreeWPS is distributed in the hope that it            |
// | will be useful, but WITHOUT ANY WARRANTY; without     |
// | even the implied warranty of MERCHANTABILITY or       |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        |
// | General Public License (included as COPYING.txt)      |
// | for more details.                                     |
// |                                                       |
// | You should have received a copy of the GNU General    |
// | Public License along with FreeWPS. If you did         |
// | not, you may download a copy at:                      |
// |                                                       |
// | URL:  http://www.fsf.org/licenses/gpl.txt             |
// |                                                       |
// | You may also request a copy from:                     |
// |                                                       |
// | Free Software Foundation, Inc.                        |
// | 59 Temple Place, Suite 330                            |
// | Boston, MA 02111-1307                                 |
// | USA                                                   |
// +-------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>             |
// +-------------------------------------------------------+
//
// $Id: webedit.php,v 1.7 2004/08/15 05:49:26 ytztech Exp $
//


/**
 * WebEditor class
 *
 * A class to insert the HTMLArea 3.0 editor into a webpage.
 * @package Class-WebEditor
 * @subpackage Core-Libraries
 */

class WebEditor
{
	// Define the properties of the class.

	/**
	 * Contains the two-character code for the language files to use
	 *
	 * @access public
	 * @var string
	 */
	var $language;

	/**
	 * Contains the ID/NAME of the TEXTAREA form element to replace with the Editor
	 *
	 * @access public
	 * @var string
	 */
	var $textarea;


	/**
	 * Class Constructor
	 *
	 * @return void
	 */
	function WebEditor()
	{
		$this->language = 'en';
		$this->textarea = 'content_text';
	}


	/**
	 * Inserts the HTML to replace a TEXTAREA form element with the Editor.
	 *
	 * Two global variables must be available to complete the setup of the editor:
	 * o $site_path - The webserver filesystem path to your FreeWPS site.
	 * o $site_url - The webserver URL (with trailing slash) to your FreeWPS site.
	 * To use the Styles drop down box, the WEBEDIT.CSS file must be present in the
	 * INCLUDES directory.  The custom styles from this stylesheet will be imported
	 * into the editor.
	 *
	 * @return string HTML to load the Editor.
	 */
	function CreateEditor()
	{
		// Determine what mode the editor should start in.
		if (!isset($GLOBALS['editor_mode'])) {
			$GLOBALS['editor_mode'] = 'wysiwyg';
			$query_cmd = 'INSERT INTO '.$GLOBALS['dbpref'].'_SETTINGS'.
						 " VALUES ('editor_mode',".
								 " 'Editor Startup Mode',".
								 " 'enum',".
								 " 'wysiwyg,textmode',".
								 " 'wysiwyg',".
								 " '<p>The default display of the Editor in".
								 " either:</p><ul><li>\"wysiwyg\" - Graphical".
								 " mode or \"What you see is what you get\"</li>".
								 "<li>\"textmode\" - Text-only mode or HTML".
								 " view</li></ul>', -2147483645)";
			sql_query($query_cmd, $GLOBALS['db_id']);
		}
		// Determine whether to load the Styles drop-down box.
		$use_css = file_exists($GLOBALS['site_path'].'/includes/webedit.css');
		if ($use_css) {
			// Since a stylesheet exists, import it for processing.
			$cssfile = file($GLOBALS['site_path'].'/includes/webedit.css');
			// Initialize the array of styles.
			$stylenames = array();
			for ($i = 0; $i < count($cssfile) - 1; $i++) {
				// Step through each line of the stylesheet to find style names that
				// begin with a period.
				if ($cssfile[$i]{0} == '.') {
					// Determine whether a comma appears in the line.
					$commapos = strpos($cssfile[$i],',');
					if ($commapos !== FALSE) {
						// A style was found, so include the style name in the list.
						// We have to extract just the style name.
						$stylenames[] = substr($cssfile[$i],1,$commapos-1);
					} else {
						// Determine whether a space appears on the line.
						$spacepos = strpos($cssfile[$i],' ');
						if ($spacepos !== FALSE) {
							// A style was found, so include the style name in the
							// list.  We have to extract just the style name.
							$stylenames[] = substr($cssfile[$i],1,$spacepos-1);
						} else {
							// Determine whether a brace appears on the line.
							$bracepos = strpos($cssfile[$i],'{');
							if ($bracepos !== FALSE) {
								// A style was found, so include the style name in
								// the list.  We have to extract just the style name.
								$stylenames[] = substr($cssfile[$i],1,$bracepos-1);
							} else {
								// It appears that this line only contains the style
								// name, so add it minus the period.
								$stylenames[] = substr($cssfile[$i],1);
							}
						}
					}
				}
			}
			// Set the initial drop-down entry to say "Styles".
			$styles  = ' "- Styles -" : "",'."\r\n".'						';
			// Set the second drop-down entry to say "None".
			$styles .= ' "None" : "",'."\r\n".'						';
			for ($i = 0; $i < count($stylenames); $i++) {
				// Step through the array of styles and add them to the list of style
				// names to be used in the HTML below.
				$styles .= ' "'.$stylenames[$i].'" : "';
				$styles .= $stylenames[$i].'"';
				if ($i < (count($stylenames) - 1)) {
					// The last style will not get a comma after it.
					$styles .= ',';
				}
				$styles .= "\r\n".'						';
			}
		}

		// Set the HTML to insert the HTMLArea editor.

		// The variables _editor_url and _editor_lang are required to be globally set
		// before including the HTMLArea javascripts.
		$html  = '<script type="text/javascript">'."\r\n";
		$html .= '  _editor_url = "'.$GLOBALS['site_url'].'htmlarea/";'."\r\n";
		$html .= '  _editor_lang = "'.$this->language."\";\r\n";
		$html .= '</script>'."\r\n\r\n";
		// Include the HTMLArea main javascript file.
		$html .= '<script type="text/javascript" src="htmlarea/htmlarea.js">';
		$html .= '</script>'."\r\n";
		// Include the FreeWPS addons javascript file.
		$html .= '<script type="text/javascript" src="htmlarea/wpsaddons.js">';
		$html .= '</script>'."\r\n";
		// Load three included plugins: ContentMenu,TableOperations,SpellChecker.
		$html .= '<script type="text/javascript"><!--'."\r\n";
		$html .= '  HTMLArea.loadPlugin("ContextMenu");'."\r\n";
		if ($use_css) {
			// Load the CSS plugin, since the stylesheet exists.
			$html .= '  HTMLArea.loadPlugin("CSS");'."\r\n";
		}
		$html .= '  HTMLArea.loadPlugin("TableOperations");'."\r\n";
		$html .= '  HTMLArea.loadPlugin("SpellChecker");'."\r\n";
		$html .= '--></script>'."\r\n\r\n";
		// Import the HTMLArea CSS file.
		$html .= '<style type="text/css">'."\r\n";
		$html .= '  @import url(htmlarea/htmlarea.css);'."\r\n";
		$html .= '</style>'."\r\n\r\n";
		$html .= '<script type="text/javascript">'."\r\n";
		// Initialize the editor.
		$html .= 'var editor = null;'."\r\n";
		// Create the configuration function.
		$html .= 'function initEditor() {'."\r\n";
		// Create a new editor config to customize the interface.
		$html .= '  var config = new HTMLArea.Config();'."\r\n";
		// Load the "WordHTML killer".
		$html .= '  config.killWordOnPaste = true;'."\r\n";
		// Modify the "Insert Image" function to use the Image Manager.
		$html .= '  config.btnList["insertimage"] = [ '."\r\n";
		$html .= '	\'Insert/Modify Image\', '."\r\n";
		$html .= '		_editor_url + \'images/ed_image.gif\', '."\r\n";
		$html .= '		true, '."\r\n";
		$html .= '		function(e) { e.wps_insertimage(); } '."\r\n";
		$html .= '  ];'."\r\n";
		// Modify the "Insert Link" function to use the Link Manager.
		$html .= '  config.btnList["createlink"] = [ '."\r\n";
		$html .= '	\'Insert/Modify Link\', '."\r\n";
		$html .= '		_editor_url + \'images/ed_link.gif\', '."\r\n";
		$html .= '		true, '."\r\n";
		$html .= '		function(e) {e.wps_insertlink();} '."\r\n";
		$html .= '  ];'."\r\n";
		// Modify the "Enlarge Editor" function.
		$html .= '  config.btnList["popupeditor"] = [ '."\r\n";
		$html .= '	\'Enlarge Editor\', '."\r\n";
		$html .= '		_editor_url + \'images/fullscreen_maximize.gif\', '."\r\n";
		$html .= '		true, '."\r\n";
		$html .= '		function(e) { e.wps_popupeditor(); } '."\r\n";
		$html .= '  ];'."\r\n";
		if ($use_css) {
			// Since the stylesheet exists, load the list of styles.
			$html .= '  config.pageStyle = '."\r\n";
			for ($i = 0; $i < count($cssfile) - 1; $i++) {
				$html .= '	\''.trim($cssfile[$i]).'\' + '."\r\n";
			}
			$html .= '	\''.trim($cssfile[$i]).'\';'."\r\n\r\n";
		}
		// Construct the editor.
		$html .= '  editor = new HTMLArea("'.$this->textarea.'",config);'."\r\n";
		// Register the plugins.
		$html .= '  editor.registerPlugin("ContextMenu");'."\r\n";
		if ($use_css) {
			// Register the CSS plugin, including the styles.
			$html .= '  editor.registerPlugin("CSS", {
			combos : [
				{ label: "",							// menu text
				options: {'.$styles.'},					// CSS class
				context: ""
				}
			]
			});'."\r\n";
		}
		$html .= '  editor.registerPlugin("TableOperations");'."\r\n";
		$html .= '  editor.registerPlugin("SpellChecker");'."\r\n";
		// Activate the "multi-level" undo function, since the undo/redo is broken in
		// IE and Mozilla.
		$html .= '  editor._customUndo = true;'."\r\n";
		// Determine whether to startup the editor in text-only mode.
		if ($GLOBALS['editor_mode'] == 'textmode') {
			$html .= '  editor._editMode = "textmode";'."\r\n";
		}
		// Generate the editor (replace the TEXTAREA).
		$html .= '  editor.generate();'."\r\n";
		// Determine whether to startup the editor in text-only mode.
		if ($GLOBALS['editor_mode'] == 'textmode') {
			$html .= '  editor.setMode("textmode");'."\r\n";
		}
		$html .= '  return false;'."\r\n";
		$html .= '}'."\r\n\r\n";
		$html .= '</script>'."\r\n\r\n";
		// Load the editor after the rest of the page has loaded.
		// Mozilla likes this better.
		$html .= '<script type="text/javascript" defer="defer">'."\r\n";
		$html .= '  initEditor();'."\r\n";
		$html .= '</script>'."\r\n\r\n";

		// Return the HTML to insert the editor.
		return $html;
	}
}
?>