<?php
/**
 * INSTALL.PHP provides the initial configuration and setup of FreeWPS.  The setup
 * process consists of three areas:
 * o Initial Database Setup
 * o Website Configuration
 * o Superuser Password
 * @package Core-Scripts
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | INSTALL.PHP                                          |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | INSTALL.PHP is part of FreeWPS.                      |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: install.php,v 1.10 2004/08/15 06:03:20 ytztech Exp $
//


/**
 * Specific value representing the version of this new FreeWPS installation.
 */
define('FREEWPS_INSTVER','2.1 RC1');

session_start();

$site_path = str_replace('/install','',str_replace('\\','/',dirname(__FILE__)));

$databases = array(
					'fbird'			=> 'Firebird',
					'fbsql'			=> 'Frontbase',
					'db2'			=> 'IBM DB2',
					'ibase'			=> 'Interbase',
					'mssql'			=> 'Microsoft SQL',
					'mysql'			=> 'MySQL',
					'oracle'		=> 'Oracle OCI7',
					'oci8'			=> 'Oracle OCI8',
					'postgresql'	=> 'PostgreSQL',
					'sqlite'		=> 'SQLite',
					'sybase'		=> 'Sybase SQL'
					);

if (!isset($_SESSION['language'])) {
	echo install_createLangPage();
	die();
} else {
	if (isset($_POST['setlang'])) {
		$_SESSION['language'] = $_POST['langselect'];
		header('Location: install.php');
		die();
	} else {
		include_once('languages/'.$_SESSION['language'].'/lang-install.php');
	}
}

if (!isset($_SESSION['step1'])) {
	$_SESSION['step1'] = array();
}

if (!isset($_SESSION['step2'])) {
	$_SESSION['step2'] = array();
}

if (!isset($_SESSION['step3'])) {
	$_SESSION['step3'] = array();
}

if (!isset($_SESSION['db_id'])) {
	$_SESSION['db_id'] = FALSE;
}

if (isset($_REQUEST['page_reload'])) {
	$page_reload = TRUE;
}

if (isset($_GET['menu'])) {
	$pagenum = $_GET['menu'];
	echo install_createMenuPage();
	die();
}

if (isset($_GET['main'])) {
	$pagenum = $_GET['main'];
	echo install_createMainPage();
	die();
}

$pagenum = (isset($_REQUEST['pagenum'])) ? $_REQUEST['pagenum'] : 0;

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	switch ($pagenum) {
		case 0:
			header('Location: install.php?main=1&page_reload=1');
			die();
			break;

		case 1:
			$_SESSION['continue2step2'] = TRUE;
			if ($_POST['dbhost'] != '') {
				// Strip slashes from hostname for those using multiple instances
				// under Microsoft SQL.
				$_SESSION['step1']['dbhost'] = stripslashes($_POST['dbhost']);
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_POST['dbtype'] != '-- '._INSTALL03.' --') {
				$_SESSION['step1']['dbtype'] = $_POST['dbtype'];
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_POST['dbuser'] != '') {
				$_SESSION['step1']['dbuser'] = $_POST['dbuser'];
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_POST['dbpass'] != '') {
				$_SESSION['step1']['dbpass'] = $_POST['dbpass'];
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_POST['dbname'] != '') {
				$_SESSION['step1']['dbname'] = $_POST['dbname'];
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_POST['dbpref'] != '') {
				$_SESSION['step1']['dbpref'] = $_POST['dbpref'];
			} else {
				$_SESSION['continue2step2'] = FALSE;
			}

			if ($_SESSION['continue2step2']) {
				$dbtype = $_SESSION['step1']['dbtype'];

				/** Includes the SQL functions. */
				include_once('../includes/sql_al.php');

				if (!sql_supported($dbtype)) {
					$_SESSION['db_id'] = -2;
					header('Location: install.php?main=1&page_reload=1');
					die();
				}

				$_SESSION['db_id'] = @sql_connect($_SESSION['step1']['dbhost'],
												  $_SESSION['step1']['dbuser'],
												  $_SESSION['step1']['dbpass'],
												  $_SESSION['step1']['dbname']);
				if ($_SESSION['db_id']) {
					header('Location: install.php?main=2&page_reload=1');
				}
				else {
					$_SESSION['db_id'] = -1;
					header('Location: install.php?main=1&page_reload=1');
				}
			} else {
				header('Location: install.php?main=1&page_reload=1');
			}
			unset($_SESSION['continue2step2']);
			die();
			break;

		case 2:
			$_SESSION['continue2step3'] = TRUE;
			if ($_POST['admin_contact'] != '') {
				$_SESSION['step2']['admin_contact'] = $_POST['admin_contact'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['admin_email'] != '') {
				$_SESSION['step2']['admin_email'] = $_POST['admin_email'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['auth_timeout'] != '') {
				$_SESSION['step2']['auth_timeout'] = $_POST['auth_timeout'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['login_timeout'] != '') {
				$_SESSION['step2']['login_timeout'] = $_POST['login_timeout'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['password_support'] != '') {
				$_SESSION['step2']['password_support'] = $_POST['password_support'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['site_name'] != '') {
				$_SESSION['step2']['site_name'] = $_POST['site_name'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['site_url'] != '') {
				$_SESSION['step2']['site_url'] = $_POST['site_url'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['template_main'] != '') {
				$_SESSION['step2']['template_main'] = $_POST['template_main'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['template_member'] != '') {
				$_SESSION['step2']['template_member'] = $_POST['template_member'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['template_popup'] != '') {
				$_SESSION['step2']['template_popup'] = $_POST['template_popup'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_POST['template_printable'] != '') {
				$_SESSION['step2']['template_printable'] = $_POST['template_printable'];
			} else {
				$_SESSION['continue2step3'] = FALSE;
			}

			if ($_SESSION['continue2step3']) {
				header('Location: install.php?main=3&page_reload=1');
			} else {
				header('Location: install.php?main=2&page_reload=1');
			}
			unset($_SESSION['continue2step3']);
			break;

		case 3:
			$_SESSION['step3']['user_name'] = $_POST['user_name'];
			$_SESSION['step3']['user_passhash'] = $_POST['user_passhash'];
			install_completeSetup();
			header('Location: install.php?main=4&page_reload=1');
			die();
			break;
	}
}

switch ($pagenum) {
	case 0:
		$title = _INSTALL04;
		break;

	case 1:
		$title = _INSTALL05;
		break;

	case 2:
		$title = _INSTALL06;
		break;

	case 3:
		$title = _INSTALL07;
		break;

	case 4:
		$title = _INSTALL08;
		break;

	case 5:
		header("Content-Type: text/phpfile");
		header("Content-Disposition: attachment; filename=config.php");
		for ($i = 0; $i < count($_SESSION['config_file']); $i++) {
			echo $_SESSION['config_file'][$i];
		}
		die();
		break;

	case 6:
		header('Location: '.$_SESSION['step2']['site_url'].'admin.php');
		unset($_SESSION['step1']);
		unset($_SESSION['step2']);
		unset($_SESSION['step3']);
		unset($_SESSION['sql_file']);
		unset($_SESSION['config_file']);
		unset($_SESSION['db_id']);
		unset($_SESSION['continue2step2']);
		unset($_SESSION['continue2step3']);
		unset($_SESSION['config_success']);
		unset($_SESSION['sql_success']);
		session_destroy();
		die();
		break;
}

install_createPage($title,'install.php?menu='.$pagenum,'install.php?main='.$pagenum);


/**
 * Displays the frameset to the FreeWPS Setup Wizard.
 *
 * @param  string $pagetitle   Page Title appearing in the client browser
 * @param  string $frame1src   URL for the menu bar
 * @param  string $frame2src   URL for the main page
 * @access private
 * @return string HTML for the frameset of the FreeWPS Setup Wizard
 */
function install_createPage($pagetitle,$frame1src,$frame2src)
{
	$page  = "<html>\r\n";
	$page .= "  <head>\r\n";
	$page .= "	<title>FreeWPS - "._INSTALL09." ($pagetitle)</title>\r\n";
	$page .= "  </head>\r\n";
	$page .= "  <frameset frameborder=\"no\" framespacing=\"0\" cols=\"200,*\">\r\n";
	$page .= "	<frame id=\"wps_menu\" name=\"wps_menu\" marginwidth=\"0\" marginheight=\"0\" scrolling=\"yes\" noresize=\"noresize\" frameborder=\"0\" src=\"$frame1src\">\r\n";
	$page .= "	<frame id=\"wps_main\" name=\"wps_main\" marginwidth=\"0\" marginheight=\"0\" scrolling=\"auto\" noresize=\"noresize\" frameborder=\"0\" src=\"$frame2src\">\r\n";
	$page .= "  </frameset>\r\n";
	$page .= "</html>\r\n";

	echo $page;

}


/**
 * Displays the "Choose Language" page.
 *
 * @access private
 * @return string HTML for the "Choose Language" page
 */
function install_createLangPage()
{
	if (!isset($_SESSION['language'])) {
		$_SESSION['language'] = 'english';
	}

	/** Includes the locale-specific constants for the FreeWPS Setup Wizard. */
	include_once('languages/'.$_SESSION['language'].'/lang-install.php');

	$page  = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\r\n";
	$page .= "<html xmlns=\"http://www.w3.org/1999/xhtml\">\r\n";
	$page .= "  <head>\r\n";
	$page .= "	<title>FreeWPS - "._INSTALL01."</title>\r\n";
	$page .= "	<meta http-equiv=\"Content-Type\" content=\"text/html; charset="._INSTALL_CHARSET."\" />\r\n";
	$page .= "	<style>\r\n";
	$page .= "		.buttonRegular {\r\n";
	$page .= "			border: 1px solid #666666;\r\n";
	$page .= "			margin: 2px;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			background-color: #EEEEEE;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: blue;\r\n";
	$page .= "		}\r\n";
	$page .= "		.buttonRegularFocus {\r\n";
	$page .= "			border: 1px solid black;\r\n";
	$page .= "			margin: 2px;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			background-color: #FFCCFF;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		body {\r\n";
	$page .= "			background-color: #eeeeee;\r\n";
	$page .= "		}\r\n";
	$page .= "		h2 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 18pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "	</style>\r\n";
	$page .= "  </head>\r\n";
	$page .= "  <body onLoad=\"document.forms[0].langselect.focus();\">\r\n";
	$page .= "	<br />\r\n";
	$page .= "	<form action=\"install.php\" method=\"post\" id=\"langform\" name=\"langform\">\r\n";
	$page .= "	<table border=\"0\" cellspacing=\"0\" cellpadding=\"0\" align=\"center\">\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\"><h2 align=\"center\">FreeWPS - "._INSTALL01."</h2>\r\n";
	$page .= "			</td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\"><select id=\"langselect\" name=\"langselect\">";

	//  Insert options for each known language file...

	if ($dirh = opendir('languages')) {
		while ($langname = readdir($dirh)) {
			if ($langname{0} != '.') {
				$page .= "<option value=\"$langname\"";
				if ($_SESSION['language'] == $langname) {
					$page .= ' selected="selected"';
				}
				$page .= ">$langname</option>";
			}
		}
	} else {
		$page .= "<option value=\"english\"";
		if ($_SESSION['language'] == 'english') {
			$page .= ' selected="selected"';
		}
		$page .= ">English</option>";
	}

	$page .= "</select>&nbsp; <input name=\"nextbtn\" id=\"nextbtn\" type=\"submit\" value=\""._INSTALL02."\" class=\"buttonRegular\" onmouseover=\"this.className='buttonRegularFocus'\" onmouseout=\"this.className='buttonRegular'\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "	</table>\r\n";
	$page .= "	<input type=\"hidden\" id=\"setlang\" name=\"setlang\" value=\"true\" />\r\n";
	$page .= "	</form>\r\n";
	$page .= "  </body>\r\n";
	$page .= "</html>\r\n";

	return $page;
}


/**
 * Displays the menu bar along the left of the FreeWPS Setup Wizard.
 *
 * @access private
 * @return string HTML for the menu bar of the FreeWPS Setup Wizard
 */
function install_createMenuPage()
{
	$img[0] = 'languages/'.$_SESSION['language'].'/images/intro.png';
	$img[1] = 'languages/'.$_SESSION['language'].'/images/step1.png';
	$img[2] = 'languages/'.$_SESSION['language'].'/images/step2.png';
	$img[3] = 'languages/'.$_SESSION['language'].'/images/step3.png';
	$img[4] = 'languages/'.$_SESSION['language'].'/images/complete.png';

	switch ($GLOBALS['pagenum']) {
		case 0:
			$img[0] = 'languages/'.$_SESSION['language'].'/images/intro-2.png';
			break;

		case 1:
			$img[1] = 'languages/'.$_SESSION['language'].'/images/step1-2.png';
			break;

		case 2:
			$img[2] = 'languages/'.$_SESSION['language'].'/images/step2-2.png';
			break;

		case 3:
			$img[3] = 'languages/'.$_SESSION['language'].'/images/step3-2.png';
			break;

		case 4:
			$img[4] = 'languages/'.$_SESSION['language'].'/images/complete-2.png';
			break;
	}

	$page  = "<html>\r\n";
	$page .= "  <head>\r\n";
	$page .= "	<title>FreeWPS - "._INSTALL10."</title>\r\n";
	$page .= "  </head>\r\n";
	$page .= "  <style>\r\n";
	$page .= "	body {background-color: #FFCCFF;}\r\n";
	$page .= "  </style>\r\n";
	$page .= "  <body>\r\n";
	$page .= "	<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"100%\">\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\" width=\"100%\"><img src=\"languages/".$_SESSION['language']."/images/install-sm.png\" border=\"0\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\" width=\"100%\"><hr style=\"width : 95%;\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\" width=\"100%\">";

	if (($GLOBALS['pagenum'] > 0) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '<a href="install.php?pagenum=0" target="_top">';
	}

	$page .= "<img src=\"".$img[0]."\" border=\"0\" />";

	if (($GLOBALS['pagenum'] > 0) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '</a>';
	}

	$page .= "</td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\" width=\"100%\"><img src=\"languages/".$_SESSION['language']."/images/dnarrow.png\" border=\"0\" HEIGHT=\"14\" width=\"14\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td align=\"center\" width=\"100%\">";

	if (($GLOBALS['pagenum'] > 1) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '<a href="install.php?pagenum=1" target="_top">';
	}

	$page .= "<img src=\"".$img[1]."\" border=\"0\" />";

	if (($GLOBALS['pagenum'] > 1) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '</a>';
	}

	$page .= "</td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\"><img src=\"languages/".$_SESSION['language']."/images/dnarrow.png\" border=\"0\" HEIGHT=\"14\" width=\"14\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\">";

	if (($GLOBALS['pagenum'] > 2) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '<a href="install.php?pagenum=2" target="_top">';
	}

	$page .= "<img src=\"".$img[2]."\" border=\"0\" />";

	if (($GLOBALS['pagenum'] > 2) && ($GLOBALS['pagenum'] < 4)) {
		$page .= '</a>';
	}

	$page .= "</td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\"><img src=\"languages/".$_SESSION['language']."/images/dnarrow.png\" border=\"0\" HEIGHT=\"14\" width=\"14\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\"><img src=\"".$img[3]."\" border=\"0\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\"><img src=\"languages/".$_SESSION['language']."/images/dnarrow.png\" border=\"0\" HEIGHT=\"14\" width=\"14\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "		<tr>\r\n";
	$page .= "		<td align=\"center\" width=\"100%\"><img src=\"".$img[4]."\" border=\"0\" /></td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "	</table>\r\n";
	$page .= "  </body>\r\n";
	$page .= "<html>\r\n";

	return $page;
}


/**
 * Loads the selection/content for the various steps of the FreeWPS Setup Wizard.
 *
 * @access private
 * @return string HTML for the various main pages of the FreeWPS Setup Wizard
 */
function install_createMainPage()
{
	$menu_reload = FALSE;

	switch ($GLOBALS['pagenum']) {
		case 0:
			$content  = '<h3>'._INSTALL71.'</h3>';
			$content .= '<p>'._INSTALL11.'</p>';
			$content .= '<h4>'._INSTALL12.'</h4>';
			$content .= '<UL><LI>'._INSTALL13.'</li>';
			$content .= '<LI>'._INSTALL14.'</li><LI>'._INSTALL15.'</li><LI>'._INSTALL16.'</li></UL>';
			$content .= '<p>'._INSTALL17.'</p>';
			$content .= '<p>'._INSTALL19.'</p>';
			$content .= '<table border="0" cellspacing="2" cellpadding="2" width="100%">';
			$content .= '<tr><td align="center"><form method="post" action="install.php">';
			$content .= '<input type="submit" class="buttonRegular" ';
			$content .= 'id="nextbtn" name="nextbtn" value="'._INSTALL18.'" ';
			$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
			$content .= 'onMouseOut="this.className=\'buttonRegular\'" />';
			$content .= '<input type="hidden" id="pagenum" id="pagenum" name="pagenum" value="0" />';
			$content .= '</form></td></tr></table>';
			break;

		case 1:
			$content  = '<h3>'._INSTALL05.' - '._INSTALL20.'</h3>';
			$content .= '<p>'._INSTALL21.'</p>';

			switch ($_SESSION['db_id']) {
				case -1:
				$content .= '<p align="center"><strong><TT><FONT COLOR="RED">'._INSTALL22.'</FONT></TT></strong> &nbsp;';
				$content .= str_replace('<!--SQLTYPE-->',$GLOBALS['databases'][$GLOBALS['dbtype']],_INSTALL23)."</p>\r\n\n";
				break;
				case -2:
				$content .= '<p align="center"><strong><TT><FONT COLOR="RED">'._INSTALL22.'</FONT></TT></strong> &nbsp;';
				$content .= str_replace('<!--SQLTYPE-->',$GLOBALS['databases'][$GLOBALS['dbtype']],_INSTALL24)."</p>\r\n\n";
				break;
				default:
				$content .= '<p align="center">'._INSTALL25.'</p>'."\n\n";
			}

			$content .= '<script language="Javascript" type="text/javascript">'."\n";
			$content .= '<!--'."\n\n";
			$content .= '  function submitForm(form) {'."\n";
			$content .= '	if (form.dbpass.value == \'\') {'."\n";
			$content .= '		alert("'._INSTALL26.'");'."\n";
			$content .= '		form.dbpass.focus();'."\n";
			$content .= '		return false;'."\n";
			$content .= '	}'."\n";
			$content .= '	if (form.confirmpass.value == \'\') {'."\n";
			$content .= '		alert("'._INSTALL27.'");'."\n";
			$content .= '		form.confirmpass.focus();'."\n";
			$content .= '		return false;'."\n";
			$content .= '	}'."\n";
			$content .= '	if (form.dbpass.value != form.confirmpass.value) {'."\n";
			$content .= '		alert("'._INSTALL28.'\n\n'._INSTALL29.'");'."\n";
			$content .= '		form.dbpass.value = \'\';'."\n";
			$content .= '		form.confirmpass.value = \'\';'."\n";
			$content .= '		form.dbpass.focus();'."\n";
			$content .= '		return false;'."\n";
			$content .= '	}'."\n";
			$content .= '  }'."\n\n";
			$content .= '//-->'."\n";
			$content .= '</script>'."\n\n";

			$content .= '<form method="post" action="install.php" ';
			$content .= 'id="installform" id="installform" name="installform" onsubmit="return submitForm(this)">';
			$content .= '<div align="center"><table align="center" border="0" cellspacing="2" cellpadding="2" width="100%">';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL13.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="dbhost" name="dbhost" value="';

			if (!isset($_SESSION['step1']['dbhost'])) {
				$content .= 'localhost';
			} else {
				$content .= $_SESSION['step1']['dbhost'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbhost'])) {
				if ($_SESSION['step1']['dbhost'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL14.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<select id="dbtype" name="dbtype">';
			$content .= '<option>-- '._INSTALL03.' --</option>';

			$notchangedsqltype = TRUE;
			reset($GLOBALS['databases']);
			while ($db = current($GLOBALS['databases'])) {
				$key = key($GLOBALS['databases']);
				$content .= '<option value="'.$key.'"';
				if (isset($_SESSION['step1']['dbtype'])) {
					if ($_SESSION['step1']['dbtype'] == $key) {
						$content .= ' selected="selected"';
						$notchangedsqltype = FALSE;
					}
				}
				$content .= '>'.$db.'</option>';
				next($GLOBALS['databases']);
			}
			$content .= '</select>&nbsp;';

			if ($notchangedsqltype) {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL30.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="dbuser" name="dbuser" value="';

			if (isset($_SESSION['step1']['dbuser'])) {
				$content .= $_SESSION['step1']['dbuser'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbuser'])) {
				if ($_SESSION['step1']['dbuser'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL31.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="password" id="dbpass" name="dbpass" value="';

			if (isset($_SESSION['step1']['dbpass'])) {
				$content .= $_SESSION['step1']['dbpass'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbpass'])) {
				if ($_SESSION['step1']['dbpass'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL32.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="password" id="confirmpass" name="confirmpass" value="';

			if (isset($_SESSION['step1']['dbpass'])) {
				$content .= $_SESSION['step1']['dbpass'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbpass'])) {
				if ($_SESSION['step1']['dbpass'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL33.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="dbname" name="dbname" value="';

			if (isset($_SESSION['step1']['dbname'])) {
				$content .= $_SESSION['step1']['dbname'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbname'])) {
				if ($_SESSION['step1']['dbname'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL73.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="dbpref" name="dbpref" value="';

			if (isset($_SESSION['step1']['dbpref'])) {
				$content .= $_SESSION['step1']['dbpref'];
			} else {
				$content .= 'WPS';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step1']['dbpref'])) {
				if ($_SESSION['step1']['dbpref'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="center" colspan="2"><input type="submit" class="buttonRegular" ';
			$content .= 'id="nextbtn" name="nextbtn" value="'._INSTALL34.'" ';
			$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
			$content .= 'onMouseOut="this.className=\'buttonRegular\'" />';
			$content .= '<input type="hidden" id="pagenum" name="pagenum" value="1" />';
			$content .= '</form></td></tr></table></div>';

			$menu_reload = TRUE;
			break;

		case 2:
			$content  = '<h3>'._INSTALL06.' - '._INSTALL35.'</h3>';
			$content .= '<p>'._INSTALL36.'</p>';
			$content .= '<p align="center">'._INSTALL25.'</p>';

			$content .= '<form method="post" action="install.php" id="installform" name="installform">';
			$content .= '<div align="center"><table border="0" cellspacing="2" cellpadding="2" width="100%">';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL37.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="admin_contact" name="admin_contact" value="';

			if (isset($_SESSION['step2']['admin_contact'])) {
				$content .= $_SESSION['step2']['admin_contact'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['admin_contact'])) {
				if ($_SESSION['step2']['admin_contact'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL38.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="admin_email" name="admin_email" value="';

			if (isset($_SESSION['step2']['admin_email'])) {
				$content .= $_SESSION['step2']['admin_email'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['admin_email'])) {
				if ($_SESSION['step2']['admin_email'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL39.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="auth_timeout" name="auth_timeout" value="';

			if (isset($_SESSION['step2']['auth_timeout'])) {
				$content .= $_SESSION['step2']['auth_timeout'];
			} else {
				$content .= '300';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['auth_timeout'])) {
				if ($_SESSION['step2']['auth_timeout'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL40.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="login_timeout" name="login_timeout" value="';

			if (isset($_SESSION['step2']['login_timeout'])) {
				$content .= $_SESSION['step2']['login_timeout'];
			} else {
				$content .= '60';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['login_timeout'])) {
				if ($_SESSION['step2']['login_timeout'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL41.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="password_support" name="password_support" value="';

			if (isset($_SESSION['step2']['password_support'])) {
				$content .= $_SESSION['step2']['password_support'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['password_support'])) {
				if ($_SESSION['step2']['password_support'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL42.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="site_name" name="site_name" value="';

			if (isset($_SESSION['step2']['site_name'])) {
				$content .= $_SESSION['step2']['site_name'];
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['site_name'])) {
				if ($_SESSION['step2']['site_name'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL44.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="site_url" name="site_url" value="';

			if (isset($_SESSION['step2']['site_url'])) {
				$content .= $_SESSION['step2']['site_url'];
			} else {
				$siteurl = str_replace('install/install.php','',$_SERVER['PHP_SELF']);
				$content .= 'http://'.$_SERVER['SERVER_NAME'].$siteurl;
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['site_url'])) {
				if ($_SESSION['step2']['site_url'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL45.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="template_main" name="template_main" value="';

			if (isset($_SESSION['step2']['template_main'])) {
				$content .= $_SESSION['step2']['template_main'];
			} else {
				$content .= 'green-theme.html';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['template_main'])) {
				if ($_SESSION['step2']['template_main'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL46.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="template_member" name="template_member" value="';

			if (isset($_SESSION['step2']['template_member'])) {
				$content .= $_SESSION['step2']['template_member'];
			} else {
				$content .= 'green-theme.html';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['template_member'])) {
				if ($_SESSION['step2']['template_member'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL74.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="template_popup" name="template_popup" value="';

			if (isset($_SESSION['step2']['template_popup'])) {
				$content .= $_SESSION['step2']['template_popup'];
			} else {
				$content .= 'popup.html';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['template_popup'])) {
				if ($_SESSION['step2']['template_popup'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="right">&nbsp;'._INSTALL47.'&nbsp; </td>';
			$content .= '<td align="left">&nbsp;<input type="text" id="template_printable" name="template_printable" value="';

			if (isset($_SESSION['step2']['template_printable'])) {
				$content .= $_SESSION['step2']['template_printable'];
			} else {
				$content .= 'printable.html';
			}

			$content .= '" />&nbsp;';

			if (isset($_SESSION['step2']['template_printable'])) {
				if ($_SESSION['step2']['template_printable'] == '') {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
				}
			} else {
				$content .= '<strong><tt style="color: red;">**</tt></strong>&nbsp;';
			}

			$content .= '</td></tr>';
			$content .= '<tr><td align="center" colspan="2"><input type="submit" class="buttonRegular" ';
			$content .= 'id="nextbtn" name="nextbtn" value="'._INSTALL48.'" ';
			$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
			$content .= 'onMouseOut="this.className=\'buttonRegular\'" />';
			$content .= '<input type="hidden" id="pagenum" name="pagenum" value="2" />';
			$content .= '</form></td></tr></table></div>';

			$menu_reload = TRUE;
			break;

		case 3:
			$content  = '<h3>'._INSTALL07.' - '._INSTALL49.'</h3>';
			$content .= '<p>'._INSTALL50.'</p>';

			$content .= '<script language="Javascript" src="../includes/md5.js" type="text/javascript"></script>

<script language="Javascript" type="text/javascript">
<!--

function submitLogin(form) {

	if (form.user_name.value == "") {
		alert("'._INSTALL51.'");
		form.user_name.focus();
		return false;
	}

	if (form.user_password.value == "") {
		alert("'._INSTALL52.'");
		form.user_password.focus();
		return false;
	}

	if (form.confirm_password.value == "") {
		alert("'._INSTALL53.'");
		form.confirm_password.focus();
		return false;
	}

	if (form.user_password.value != form.confirm_password.value) {
		alert("'._INSTALL54.'");
		form.user_password.value = "";
		form.confirm_password.value = "";
		form.user_password.focus();
		return false;
	}

	form.user_passhash.value = MD5(form.user_name.value + form.user_password.value);
	form.user_password.value = "";
	form.confirm_password.value = "";

	return true;

}
//--></script>';

			$content .= '<form method="post" action="install.php" id="loginform" name="loginform" onsubmit="return submitLogin(this)">';
			$content .= '<div align="center"><table border="0" cellspacing="2" cellpadding="2" width="100%">';
			$content .= '<tr><td align="right">'._INSTALL30.'</td>';
			$content .= '<td align="left"><input type="text" id="user_name" name="user_name" /></td></tr>';
			$content .= '<tr><td align="right">'._INSTALL31.'</td>';
			$content .= '<td align="left"><input type="password" id="user_password" name="user_password" autocomplete="off" /></td></tr>';
			$content .= '<tr><td align="right">'._INSTALL32.'</td>';
			$content .= '<td align="left"><input type="password" id="confirm_password" name="confirm_password" autocomplete="off" /></td></tr>';
			$content .= '<tr><td align="center" colspan="2"><input type="submit" class="buttonRegular" ';
			$content .= 'id="nextbtn" name="nextbtn" value="'._INSTALL55.'" ';
			$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
			$content .= 'onMouseOut="this.className=\'buttonRegular\'" />';
			$content .= '<input type="hidden" id="user_passhash" name="user_passhash" value="" />';
			$content .= '<input type="hidden" id="pagenum" name="pagenum" value="3" />';
			$content .= '</form></td></tr></table></div>';

			$menu_reload = TRUE;
			break;

		case 4:
			if ($_SESSION['sql_success']) {
				$content  = '<h3>'._INSTALL08.' - '._INSTALL56.'</h3>';
				$content .= '<p>'._INSTALL57.'</p>';

				if ($_SESSION['config_success'] == 'success') {
					$content .= '<p>'.str_replace('<!--USERNAME-->',$_SESSION['step3']['user_name'],_INSTALL59).'</p>';
				}
				else {
					$content .= '<p>'._INSTALL60.'</p>';
					$content .= '<blockquote><strong><TT><FONT COLOR="RED">'._INSTALL22.'&nbsp; ';

					switch ($_SESSION['config_success']) {
						case 'nopermsfile':
							$content .= _INSTALL61;
							break;

						case 'nopermsdir':
							$content .= _INSTALL62;
							break;

						case 'notarray':
							$content .= _INSTALL63;
							break;
					}
					$content .= '</FONT></TT></strong></blockquote>';
					$content .= '<p>'._INSTALL65.'</p>';
					$content .= '<p>'.str_replace('<!--USERNAME-->',$_SESSION['step3']['user_name'],_INSTALL66).'</p>';
				}
				$content .= '<form action="modules.php" method="post"><table border="0" cellspacing="2" cellpadding="2" width="100%">';

				if ($_SESSION['config_success'] != 'success') {
					$content .= '<tr><td align="center"><input type="button" ';
					$content .= 'CLASS="buttonRegular" name="nextbtn" value="'._INSTALL64.'" ';
					$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
					$content .= 'onMouseOut="this.className=\'buttonRegular\'" ';
					$content .= 'onClick="parent.location.href=\'install.php?pagenum=5\'" />';
					$content .= '</td></tr>';
				}

				$content .= '<tr><td align="center"><input type="button" ';
				$content .= 'CLASS="buttonRegular" id="nextbtn" name="nextbtn" value="'._INSTALL58.'" ';
				$content .= 'onMouseOver="this.className=\'buttonRegularFocus\'" ';
				$content .= 'onMouseOut="this.className=\'buttonRegular\'" ';
				$content .= 'onClick="parent.location.href=\'install.php?pagenum=6\'" />';
				$content .= '</form></td></tr></table>';
			}

			$menu_reload = TRUE;
	}

	$page  = "<html>\r\n";
	$page .= "  <head>\r\n";
	$page .= "	<title>FreeWPS - "._INSTALL67."</title>\r\n";
	$page .= "	<style>\r\n";
	$page .= "		.buttonRegular {\r\n";
	$page .= "			border: 1px solid #666666;\r\n";
	$page .= "			margin: 2px;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			background-color: #EEEEEE;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: blue;\r\n";
	$page .= "		}\r\n";
	$page .= "		.buttonRegularFocus {\r\n";
	$page .= "			border: 1px solid black;\r\n";
	$page .= "			margin: 2px;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			background-color: #FFCCFF;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		.columnRegular {\r\n";
	$page .= "			border: 1px solid black;\r\n";
	$page .= "			margin: 2px;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 12px;\r\n";
	$page .= "			background-color: #FFCCFF;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		.pageTD {\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			background-color: #FFCCFF;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		.pageTitle {\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 18pt;\r\n";
	$page .= "			background-color: #FFCCFF;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		a {\r\n";
	$page .= "			color: blue;\r\n";
	$page .= "			text-decoration: none;\r\n";
	$page .= "		}\r\n";
	$page .= "		a:hover {\r\n";
	$page .= "			text-decoration: underline;\r\n";
	$page .= "		}\r\n";
	$page .= "		body {\r\n";
	$page .= "			background-color: #eeeeee;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 6px;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h1 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-style: italic;\r\n";
	$page .= "			font-size: 24pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h2 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 18pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h3 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 14pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h4 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 12pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h5 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 11pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		h6 {\r\n";
	$page .= "			color: black;\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "		}\r\n";
	$page .= "		table {\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		td {\r\n";
	$page .= "			font-weight: normal;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "		th {\r\n";
	$page .= "			font-weight: bold;\r\n";
	$page .= "			font-size: 10pt;\r\n";
	$page .= "			font-family: Tahoma, Arial, Helvetica, sans-serif;\r\n";
	$page .= "			color: black;\r\n";
	$page .= "		}\r\n";
	$page .= "	</style>\r\n";
	$page .= "	<script language=\"Javascript\" type=\"text/javascript\">\r\n";
	$page .= '	<!--'."\n\n";
	$page .= "		function processLoading() {\r\n";

	if (isset($GLOBALS['page_reload'])) {
		$page .= "		parent.location.href = \"install.php?pagenum=".$GLOBALS['pagenum']."\";\r\n";
	}
	$page .= "		document.forms[0].elements[0].focus();\r\n";
	$page .= "		}\r\n";
	$page .= '	//-->'."\n";
	$page .= "	</script>\r\n\n";
	$page .= "  </head>\r\n";
	$page .= "  <body onLoad=\"processLoading()\">\r\n";
	$page .= "	<br />\r\n";
	$page .= "	<table border=\"0\" cellspacing=\"2\" cellpadding=\"2\" width=\"95%\">\r\n";
	$page .= "		<tr>\r\n";
	$page .= "			<td width=\"5\">&nbsp;</td>\r\n";
	$page .= "			<td align=\"left\">\r\n";
	$page .= "				<table align=\"center\" border=\"0\" cellspacing=\"0\" cellpadding=\"0\" width=\"100%\">\r\n";
	$page .= "				<tr>\r\n";
	$page .= "					<td valign=\"top\" class=\"columnRegular\" colspan=\"2\">\r\n";
	$page .= "					<table align=\"center\" border=\"0\" cellspacing=\"5\" cellpadding=\"5\" class=\"pageTD\" width=\"100%\">\r\n";
	$page .= "						<tr>\r\n";
	$page .= "							<td class=\"pageTD\"><CENTER><span class=\"pageTitle\">FreeWPS - "._INSTALL09."</span></CENTER></td>\r\n";
	$page .= "						</tr>\r\n";
	$page .= "					</table>\r\n";
	$page .= "					</td>\r\n";
	$page .= "				</tr>\r\n";
	$page .= "				<tr>\r\n";
	$page .= "					<td colspan=\"2\">&nbsp;</td>\r\n";
	$page .= "				</tr>\r\n";
	$page .= "				<tr>\r\n";
	$page .= "					<td colspan=\"2\">$content</td>\r\n";
	$page .= "				</tr>\r\n";
	$page .= "				<tr>\r\n";
	$page .= "					<td align=\"center\" colspan=\"2\"><hr style=\"width : 95%;\" /><strong>"._INSTALL68." &copy; 2003, YTZ Technical Services, LLC.  "._INSTALL69."</strong></td>\r\n";
	$page .= "				</tr>\r\n";
	$page .= "				</table>\r\n";
	$page .= "			</td>\r\n";
	$page .= "		</tr>\r\n";
	$page .= "	</table>\r\n";
	$page .= "  </body>\r\n";
	$page .= "</html>\r\n";

	return $page;
}


/**
 * Writes the configuration file to the filesystem and creates/installs various SQL tables/data for FreeWPS
 *
 * @access private
 * @return void
 */
function install_completeSetup()
{
	$currenttime = time();

	$_SESSION['config_file'] = @file('config.php.dist');

	if (!is_array($_SESSION['config_file'])) {
		$_SESSION['config_success'] = 'notarray';
	} else {
		$_SESSION['config_file'][58] = str_replace('<!--dbhost-->',$_SESSION['step1']['dbhost'],$_SESSION['config_file'][58]);
		$_SESSION['config_file'][65] = str_replace('<!--dbtype-->',$_SESSION['step1']['dbtype'],$_SESSION['config_file'][65]);
		$_SESSION['config_file'][68] = str_replace('<!--dbuser-->',$_SESSION['step1']['dbuser'],$_SESSION['config_file'][68]);
		$_SESSION['config_file'][71] = str_replace('<!--dbpass-->',$_SESSION['step1']['dbpass'],$_SESSION['config_file'][71]);
		$_SESSION['config_file'][79] = str_replace('<!--dbname-->',$_SESSION['step1']['dbname'],$_SESSION['config_file'][79]);
		$_SESSION['config_file'][82] = str_replace('<!--dbpref-->',$_SESSION['step1']['dbpref'],$_SESSION['config_file'][82]);

		$config_file = @fopen($GLOBALS['site_path'].'/includes/config.php','w');
		if ($config_file) {
			$file_str = '';
			for ($i = 0; $i < count($_SESSION['config_file']); $i++) {
				$file_str .= $_SESSION['config_file'][$i];
			}
			if (@fwrite($config_file,$file_str,strlen($file_str))) {
				$_SESSION['config_success'] = 'success';
			}
		} else {
			if (@file_exists($GLOBALS['site_path'].'/includes/config.php')) {
				$_SESSION['config_success'] = 'nopermsfile';
			} else {
				$_SESSION['config_success'] = 'nopermsdir';
			}
		}
	}

	switch ($_SESSION['step1']['dbtype']) {
		case 'db2':
		case 'fbird':
		case 'fbsql':
		case 'ibase':
		case 'oracle':
		case 'oci8':
			$sqlfile = 'sql/install.sql.ora';
			break;

		default:
			$sqlfile = 'sql/install.sql';
	}

	$GLOBALS['usetrans'] = FALSE;

	/** Include the locale-specific constants for the sample pages/settings. */
	include_once('languages/'.$_SESSION['language'].'/lang-sql.php');
	$_SESSION['sql_file'] = @file($sqlfile);

	if (!is_array($_SESSION['sql_file'])) {
		$_SESSION['sql_success'] = FALSE;
	} else {
		include_once($GLOBALS['site_path'].'/includes/sql_al.php');
		include_once($GLOBALS['site_path'].'/includes/style.php');

		// Set the initial creation time for all the pages and content.
		$_SESSION['sql_file'][24]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][24]);
		$_SESSION['sql_file'][25]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][25]);
		$_SESSION['sql_file'][26]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][26]);
		$_SESSION['sql_file'][27]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][27]);
		$_SESSION['sql_file'][28]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][28]);
		$_SESSION['sql_file'][29]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][29]);
		$_SESSION['sql_file'][30]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][30]);
		$_SESSION['sql_file'][31]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][31]);
		$_SESSION['sql_file'][32]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][32]);
		$_SESSION['sql_file'][75]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][75]);
		$_SESSION['sql_file'][76]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][76]);
		$_SESSION['sql_file'][77]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][77]);
		$_SESSION['sql_file'][78]	= str_replace('999999999',$currenttime,$_SESSION['sql_file'][78]);

		// Customize the content for the chosen installation.
		$_SESSION['sql_file'][74]	= str_replace('_SQL77',_SQL77,$_SESSION['sql_file'][74]);
		$_SESSION['sql_file'][75]	= str_replace('_SQL77',_SQL77,$_SESSION['sql_file'][75]);
		$_SESSION['sql_file'][76]	= str_replace('_SQL77',_SQL77,$_SESSION['sql_file'][76]);
		$_SESSION['sql_file'][77]	= str_replace('_SQL77',_SQL77,$_SESSION['sql_file'][77]);
		$_SESSION['sql_file'][78]	= str_replace('_SQL77',_SQL77,$_SESSION['sql_file'][78]);
		$_SESSION['sql_file'][19]	= str_replace('_SQL01',_SQL01,$_SESSION['sql_file'][19]);
		$_SESSION['sql_file'][19]	= str_replace('_SQL02',_SQL02,$_SESSION['sql_file'][19]);
		$_SESSION['sql_file'][20]	= str_replace('_SQL03',_SQL03,$_SESSION['sql_file'][20]);
		$_SESSION['sql_file'][20]	= str_replace('_SQL04',_SQL04,$_SESSION['sql_file'][20]);
		$_SESSION['sql_file'][21]	= str_replace('_SQL05',_SQL05,$_SESSION['sql_file'][21]);
		$_SESSION['sql_file'][21]	= str_replace('_SQL06',_SQL06,$_SESSION['sql_file'][21]);
		$_SESSION['sql_file'][22]	= str_replace('_SQL07',_SQL07,$_SESSION['sql_file'][22]);
		$_SESSION['sql_file'][23]	= str_replace('_SQL08',_SQL08,$_SESSION['sql_file'][23]);
		$_SESSION['sql_file'][24]	= str_replace('_SQL09',_SQL09,$_SESSION['sql_file'][24]);
		$_SESSION['sql_file'][24]	= str_replace('_SQL10',_SQL10,$_SESSION['sql_file'][24]);
		$_SESSION['sql_file'][25]	= str_replace('_SQL11',_SQL11,$_SESSION['sql_file'][25]);
		$_SESSION['sql_file'][25]	= str_replace('_SQL12',_SQL12,$_SESSION['sql_file'][25]);
		$_SESSION['sql_file'][26]	= str_replace('_SQL13',_SQL13,$_SESSION['sql_file'][26]);
		$_SESSION['sql_file'][26]	= str_replace('_SQL14',_SQL14,$_SESSION['sql_file'][26]);
		$_SESSION['sql_file'][27]	= str_replace('_SQL15',_SQL15,$_SESSION['sql_file'][27]);
		$_SESSION['sql_file'][27]	= str_replace('_SQL16',_SQL16,$_SESSION['sql_file'][27]);
		$_SESSION['sql_file'][28]	= str_replace('_SQL17',_SQL17,$_SESSION['sql_file'][28]);
		$_SESSION['sql_file'][28]	= str_replace('_SQL18',_SQL18,$_SESSION['sql_file'][28]);
		$_SESSION['sql_file'][29]	= str_replace('_SQL19',_SQL19,$_SESSION['sql_file'][29]);
		$_SESSION['sql_file'][29]	= str_replace('_SQL20',_SQL20,$_SESSION['sql_file'][29]);
		$_SESSION['sql_file'][30]	= str_replace('_SQL21',_SQL21,$_SESSION['sql_file'][30]);
		$_SESSION['sql_file'][30]	= str_replace('_SQL22',_SQL22,$_SESSION['sql_file'][30]);
		$_SESSION['sql_file'][31]	= str_replace('_SQL23',_SQL23,$_SESSION['sql_file'][31]);
		$_SESSION['sql_file'][31]	= str_replace('_SQL24',_SQL24,$_SESSION['sql_file'][31]);
		$_SESSION['sql_file'][32]	= str_replace('_SQL25',_SQL25,$_SESSION['sql_file'][32]);
		$_SESSION['sql_file'][32]	= str_replace('_SQL26',_SQL26,$_SESSION['sql_file'][32]);
		$_SESSION['sql_file'][64]	= str_replace('_SQL27',_SQL27,$_SESSION['sql_file'][64]);
		$_SESSION['sql_file'][65]	= str_replace('_SQL28',_SQL28,$_SESSION['sql_file'][65]);
		$_SESSION['sql_file'][66]	= str_replace('_SQL29',_SQL29,$_SESSION['sql_file'][66]);
		$_SESSION['sql_file'][67]	= str_replace('_SQL30',_SQL30,$_SESSION['sql_file'][67]);
		$_SESSION['sql_file'][68]	= str_replace('_SQL31',_SQL31,$_SESSION['sql_file'][68]);
		$_SESSION['sql_file'][74]	= str_replace('_SQL32',_SQL32,$_SESSION['sql_file'][74]);
		$_SESSION['sql_file'][75]	= str_replace('_SQL33',_SQL33,$_SESSION['sql_file'][75]);
		$_SESSION['sql_file'][76]	= str_replace('_SQL34',_SQL34,$_SESSION['sql_file'][76]);
		$_SESSION['sql_file'][77]	= str_replace('_SQL35',_SQL35,$_SESSION['sql_file'][77]);
		$_SESSION['sql_file'][78]	= str_replace('_SQL36',_SQL36,$_SESSION['sql_file'][78]);
		$_SESSION['sql_file'][79]	= str_replace('_SQL37',_SQL37,$_SESSION['sql_file'][79]);
		$_SESSION['sql_file'][79]	= str_replace('_SQL38',_SQL38,$_SESSION['sql_file'][79]);
		$_SESSION['sql_file'][80]	= str_replace('_SQL39',_SQL39,$_SESSION['sql_file'][80]);
		$_SESSION['sql_file'][80]	= str_replace('_SQL40',_SQL40,$_SESSION['sql_file'][80]);
		$_SESSION['sql_file'][81]	= str_replace('_SQL41',_SQL41,$_SESSION['sql_file'][81]);
		$_SESSION['sql_file'][81]	= str_replace('_SQL42',_SQL42,$_SESSION['sql_file'][81]);
		$_SESSION['sql_file'][82]	= str_replace('_SQL43',_SQL43,$_SESSION['sql_file'][82]);
		$_SESSION['sql_file'][82]	= str_replace('_SQL44',_SQL44,$_SESSION['sql_file'][82]);
		$_SESSION['sql_file'][83]	= str_replace('_SQL45',_SQL45,$_SESSION['sql_file'][83]);
		$_SESSION['sql_file'][83]	= str_replace('_SQL46',_SQL46,$_SESSION['sql_file'][83]);
		$_SESSION['sql_file'][84]	= str_replace('_SQL47',_SQL47,$_SESSION['sql_file'][84]);
		$_SESSION['sql_file'][84]	= str_replace('_SQL48',_SQL48,$_SESSION['sql_file'][84]);
		$_SESSION['sql_file'][85]	= str_replace('_SQL49',_SQL49,$_SESSION['sql_file'][85]);
		$_SESSION['sql_file'][85]	= str_replace('_SQL50',_SQL50,$_SESSION['sql_file'][85]);
		$_SESSION['sql_file'][86]	= str_replace('_SQL51',_SQL51,$_SESSION['sql_file'][86]);
		$_SESSION['sql_file'][86]	= str_replace('_SQL52',_SQL52,$_SESSION['sql_file'][86]);
		$_SESSION['sql_file'][87]	= str_replace('_SQL53',_SQL53,$_SESSION['sql_file'][87]);
		$_SESSION['sql_file'][87]	= str_replace('_SQL54',_SQL54,$_SESSION['sql_file'][87]);
		$_SESSION['sql_file'][88]	= str_replace('_SQL55',_SQL55,$_SESSION['sql_file'][88]);
		$_SESSION['sql_file'][88]	= str_replace('_SQL56',_SQL56,$_SESSION['sql_file'][88]);
		$_SESSION['sql_file'][89]	= str_replace('_SQL57',_SQL57,$_SESSION['sql_file'][89]);
		$_SESSION['sql_file'][89]	= str_replace('_SQL58',_SQL58,$_SESSION['sql_file'][89]);
		$_SESSION['sql_file'][90]	= str_replace('_SQL59',_SQL59,$_SESSION['sql_file'][90]);
		$_SESSION['sql_file'][90]	= str_replace('_SQL60',_SQL60,$_SESSION['sql_file'][90]);
		$_SESSION['sql_file'][91]	= str_replace('_SQL61',_SQL61,$_SESSION['sql_file'][91]);
		$_SESSION['sql_file'][91]	= str_replace('_SQL62',_SQL62,$_SESSION['sql_file'][91]);
		$_SESSION['sql_file'][92]	= str_replace('_SQL63',_SQL63,$_SESSION['sql_file'][92]);
		$_SESSION['sql_file'][92]	= str_replace('_SQL64',_SQL64,$_SESSION['sql_file'][92]);
		$_SESSION['sql_file'][93]	= str_replace('_SQL65',_SQL65,$_SESSION['sql_file'][93]);
		$_SESSION['sql_file'][93]	= str_replace('_SQL66',_SQL66,$_SESSION['sql_file'][93]);
		$_SESSION['sql_file'][94]	= str_replace('_SQL67',_SQL67,$_SESSION['sql_file'][94]);
		$_SESSION['sql_file'][94]	= str_replace('_SQL68',_SQL68,$_SESSION['sql_file'][94]);
		$_SESSION['sql_file'][95]	= str_replace('_SQL69',_SQL69,$_SESSION['sql_file'][95]);
		$_SESSION['sql_file'][95]	= str_replace('_SQL70',_SQL70,$_SESSION['sql_file'][95]);
		$_SESSION['sql_file'][96]	= str_replace('_SQL71',_SQL71,$_SESSION['sql_file'][96]);
		$_SESSION['sql_file'][96]	= str_replace('_SQL72',_SQL72,$_SESSION['sql_file'][96]);
		$_SESSION['sql_file'][97]	= str_replace('_SQL73',_SQL73,$_SESSION['sql_file'][97]);
		$_SESSION['sql_file'][97]	= str_replace('_SQL74',_SQL74,$_SESSION['sql_file'][97]);
		$_SESSION['sql_file'][98]	= str_replace('_SQL75',_SQL75,$_SESSION['sql_file'][98]);
		$_SESSION['sql_file'][98]	= str_replace('_SQL76',_SQL76,$_SESSION['sql_file'][98]);

		$_SESSION['sql_file'][79]	=			  str_replace('<!--admin_contact-->',$_SESSION['step2']['admin_contact'],$_SESSION['sql_file'][79]);
		$_SESSION['sql_file'][80]	=				  str_replace('<!--admin_email-->',$_SESSION['step2']['admin_email'],$_SESSION['sql_file'][80]);
		$_SESSION['sql_file'][81]	=	   str_replace('<!--authorization_timeout-->',$_SESSION['step2']['auth_timeout'],$_SESSION['sql_file'][81]);
		$_SESSION['sql_file'][82]	=			  str_replace('<!--login_timeout-->',$_SESSION['step2']['login_timeout'],$_SESSION['sql_file'][82]);
		$_SESSION['sql_file'][83]	=		str_replace('<!--password_support-->',$_SESSION['step2']['password_support'],$_SESSION['sql_file'][83]);
		$_SESSION['sql_file'][84]	=					  str_replace('<!--site_name-->',$_SESSION['step2']['site_name'],$_SESSION['sql_file'][84]);
		$_SESSION['sql_file'][85]	=					    str_replace('<!--site_url-->',$_SESSION['step2']['site_url'],$_SESSION['sql_file'][85]);
		$_SESSION['sql_file'][86]	=			  str_replace('<!--template_main-->',$_SESSION['step2']['template_main'],$_SESSION['sql_file'][86]);
		$_SESSION['sql_file'][87]	=		  str_replace('<!--template_member-->',$_SESSION['step2']['template_member'],$_SESSION['sql_file'][87]);
		$_SESSION['sql_file'][88]	=			str_replace('<!--template_popup-->',$_SESSION['step2']['template_popup'],$_SESSION['sql_file'][88]);
		$_SESSION['sql_file'][89]	=	str_replace('<!--template_printable-->',$_SESSION['step2']['template_printable'],$_SESSION['sql_file'][89]);
		$_SESSION['sql_file'][90]	=										str_replace('<!--version-->',FREEWPS_INSTVER,$_SESSION['sql_file'][90]);
		$_SESSION['sql_file'][95]	=										   str_replace('<!--error_404-->',_INSTALL75,$_SESSION['sql_file'][95]);
		$_SESSION['sql_file'][97]	=									  str_replace('<!--print_friendly-->',_INSTALL76,$_SESSION['sql_file'][97]);
		$_SESSION['sql_file'][]		= 'INSERT INTO '.$_SESSION['step1']['dbpref'].'_SETTINGS VALUES (\'freewps_language\', \''._INSTALL72.'\', \'string\', \'n/a\', \''.$_SESSION['language'].'\', \'<p>'._INSTALL70.'</p>\', -4)';
		$_SESSION['sql_file'][]		= 'INSERT INTO '.$_SESSION['step1']['dbpref'].'_USERS VALUES (0, \''.$_SESSION['step3']['user_name'].'\', \''.md5($_SESSION['step3']['user_name']).'\', \''.$_SESSION['step3']['user_passhash'].'\', \'y\', \'n\', \'n/a\', 0)';
		$_SESSION['sql_file'][]		= 'INSERT INTO '.$_SESSION['step1']['dbpref'].'_GRPUSERS VALUES (1, 0, -2147483647)';

		$GLOBALS['dbtype'] = $_SESSION['step1']['dbtype'];

		$db_id = sql_connect($_SESSION['step1']['dbhost'],$_SESSION['step1']['dbuser'],$_SESSION['step1']['dbpass'],$_SESSION['step1']['dbname']);

		for ($i = 0; $i < count($_SESSION['sql_file']); $i++) {
			$_SESSION['sql_file'][$i] = str_replace(' WPS',' '.$_SESSION['step1']['dbpref'],$_SESSION['sql_file'][$i]);
			sql_query(trim($_SESSION['sql_file'][$i]), $db_id);
		}

		sql_logout($db_id);
		unset($db_id);
		unset($dbtype);

		$_SESSION['sql_success'] = TRUE;
	}
}

?>
