<?php
/**
 * Login Screen page
 *
 * Displays a form requiring a username and password for authentication with FreeWPS.
 * The authentication info will not be sent unencrypted by the client to the server.
 * Instead, a Javascript file ("includes/md5.js") is called by the login page so that
 * the user will transmit the username and password in a discrete manner, using MD5
 * hashing.
 * @package Core-Scripts
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | LOGIN.PHP                                            |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | LOGIN.PHP is part of FreeWPS.                        |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: login.php,v 1.5 2004/08/15 05:47:42 ytztech Exp $
//

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

// Check for POST.
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
	// Check the hashingseed.
	if ($_POST['hashingseed'] == $_SESSION['seedhash']) {
		// Get the user permissions.
		$userperms = core_authorizeUser($_POST['passhash'],TRUE);
		if (!stristr($userperms,'[')) {
			// This user didn't login successfully.
			switch ($userperms) {
				// Error code for login timeout.
				case -1:
					// Record the error.
					core_createSyslog(1, $_POST['userhash']);
					// Get the login screen with an "login time expiration" message.
					$pgcontent = login_screen('time');
					// Add the timeout value to the expiration message.
					$t   = $GLOBALS['login_timeout'];
					$pgtitle   = str_replace('<!--TIMEOUT-->',$t,_ERRORLOGINTIME);
					$pgtitle   = str_replace('<br />',' ',$pgtitle);
					// Create the page.
					core_createPage($pgcontent, '', $pgtitle);
					// End this joyride.
					break;

				// Error code for bad passhash.
				default:
					// Record the error and check the account for lockout.
					core_createSyslog(0, $_POST['userhash']);
					// Get the login screen with an "incorrect login" message.
					$pgcontent = login_screen('yes');
					// Create the page.
					core_createPage($pgcontent, '', _ERRORLOGININCORRECT);
					// End this joyride.
					break;
			}
		} elseif (stristr($userperms,'[-')) {
			// This user logged in successfully as an admin user.
			// So, get the username and set the "registered user" session value.
			$_SESSION['registereduser'] = get_username($_POST['passhash']);
			// Set the login time.
			$_SESSION['user_timestamp'] = time();
			// Set the "authorization" session value to the "passhash".
			$_SESSION['authorization'] = $_POST['passhash'];
			if (!isset($_REQUEST['referer'])) {
				// Since another page was not requested, go to the Admin Panel.
				Header('Location: admin.php');
				die();
			} else {
				// Go to the requested page.
				Header('Location: '.urldecode($_REQUEST['referer']));
				die();
			}
		} else {
			// This user logged in successfully as an regular user.
			// So, get the username and set the "registered user" session value.
			$_SESSION['registereduser'] = get_username($_POST['passhash']);
			// Set the login time.
			$_SESSION['user_timestamp'] = time();
			// Set the "authorization" session value to the "passhash".
			$_SESSION['authorization'] = $_POST['passhash'];
			if (!isset($_REQUEST['referer'])) {
				// Since another page was not requested, go to the Home Page.
				Header('Location: index.php');
				die();
			}
			else {
				// Go to the requested page.
				Header('Location: '.urldecode($_REQUEST['referer']));
				die();
			}
		}
	} else {
		// Detected mismatch for hashingseed.
		// So, get the login screen with an "incorrect login" message.
		$pgcontent = login_screen('badhash');
		// Record the mismatch error.
		core_createSyslog(3, $_POST['userhash']);
		// Create the page.
		core_createPage($pgcontent, '', _ERRORINTRUSION);
	}
} else {
	switch ($user_perms) {
		// Error code for session timeout.
		case -2:
			// Record the error.
			core_createSyslog(2, md5($_SESSION['registereduser']));
			// Reset authentication token to ''.
			$_SESSION['authorization']  = '';
			// Reset username to ''.
			$_SESSION['registereduser'] = '';
			// Reset timestamp to now().
			$_SESSION['user_timestamp'] = time();

			// Get the login screen with an "session expiration" message.
			$pgcontent = login_screen('session');
			// Add the timeout value to the expiration message.
			$t         = $GLOBALS['authorization_timeout'];
			$pgtitle   = str_replace('<!--TIMEOUT-->',$t,_ERRORSESSIONEXPIRED);
			$pgtitle   = str_replace('<br />',' ',$pgtitle);
			// Create the page.
			core_createPage($pgcontent, '', $pgtitle);
			// End this joyride.
			break;
		default:
			// Get the standard login screen.
			$pgcontent = login_screen();
			// Create the page.
			core_createPage($pgcontent, '', _LOGIN);
			// End this joyride.
			break;
	}
}


/**
 * Find the username for $token.
 *
 * This function queries all user accounts against the "authorization" hashing (an
 * MD5 hashing of the username and password of the user).  The result of this query
 * will return the account name of the user in question.
 *
 * @param  string $token   MD5-hash stored as the "password" of a user
 * @access private
 * @return string Returns the username matching $token
 */
function get_username($token)
{
	// Setup and execute a query to match $token against all user accounts.
	$query_cmd = 'SELECT USERNAME FROM '.$GLOBALS['dbpref'].'_USERS'.
				  ' WHERE PASSHASH=\''.$token.'\'';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the contents of the match.
	if ($row = sql_fetch_row($results)) {
		// Return the matching "username".
		return $row[0];
	} else {
		// Return NULL.
		return '';
	}

}	// End of FUNCTION


/**
 * Display the login screen.
 *
 * This function prepares the various responses displayed in the login screen to the
 * user, with the Javascript used to validate the user's authentication information.
 * Two user session variables are set, one to track the "seedhash", and the other to
 * track the "user_timestamp" for the beginning the login process.
 * <p>The "seedhash" is used by the script to determine whether an intrusion has
 * occured.  The "seedhash" is the MD5 hashing of the "user_timestamp".  On the
 * server side, a validation of this "seedhash" will validate that the valid attempt
 * by the user to login without using brute-force methods.
 * <p>The "user_timestamp" is computed when the script displays the login page for
 * the user.  "user_timestamp" is used to determine how long a user has taken to
 * attempt to login.  The idea is that the system should prevent long stretches of
 * inactivity during the login process.  $logintime is also updated in all other
 * scripts to represent the last point at which the  user accessed the system while
 * logged in.  This tracking method allows the system to force a user to login again
 * after an extended period of inactivity.
 * <p>The "tryagain" parameter allows the script to display the same login page with
 * various messages, dependent on the user's input, or lack thereof.  This will
 * inform a user if they have been logged out due to session timeout, if they did not
 * authenticate before the login timeout expired, or if they have entered an invalid
 * combination of username and password.
 *
 * @param  string $tryagain   (optional) Display a try-again message with the page.
 * @access private
 * @return string Returns the HTML for the login screen
 */
function login_screen($tryagain = 'no')
{
	// Initialize the user's timestamp and assign the MD5-hash of the timestamp of
	// the seedhash included on the login screen.
	$_SESSION['user_timestamp'] = time();
	$time_stamp = $_SESSION['user_timestamp'];
	$_SESSION['seedhash'] = md5($time_stamp);

	// Set the initial page content, $page, to include the MD5 Javascript, as
	// well as the Login Form.
	$page =  '

  <script src="includes/md5.js" type="text/javascript"></script>

  <script type="text/javascript">
  <!--

  function submitLogin(form) {

	if (form.wps_username.value == "") {
		alert("'._ERRORTYPEUSERNAME.'");
		form.wps_username.focus();
		return false;
	}

	if (form.wps_password.value == "") {
		alert("'._ERRORTYPEPASSWORD.'");
		form.wps_password.focus();
		return false;
	}

	form.passhash.value = MD5(form.wps_username.value + form.wps_password.value);
	form.userhash.value = MD5(form.wps_username.value);
	form.wps_username.value = "";
	form.wps_password.value = "";

	return true;

  }
  //-->
  </script>

  <form id="loginform" name="loginform" method="post"
   action="login.php" onsubmit="return submitLogin(this)">
    <div align="center">
	  <table align="center" class="tableAdmin">
		<tr>
		  <td align="center">
            <h3 align="center">'._USERLOGINCOLON.'</h3>
            <table align="center" style="border: 0px solid #fff;">
              <tr>
                <td class="login" align="right">'._USERNAMECOLON.'&nbsp; </td>
                <td class="login" align="left"><input id="wps_username"
                 name="wps_username" type="text" class="textCool" size="30"
                 autocomplete="off" onfocus="this.className=\'textCoolFocus\'"
                 onblur="this.className=\'textCool\'" /></td>
              </tr>
              <tr>
                <td class="login" align="right">'._PASSWORDCOLON.'&nbsp; </td>
                <td class="login" align="left"><input id="wps_password"
                 name="wps_password" type="password" class="textCool" size="30"
                 autocomplete="off" onfocus="this.className=\'textCoolFocus\'"
                 onblur="this.className=\'textCool\'" /></td>
    			</tr>
            </table>
            <input type="submit" id="submit" name="submit" class="buttonRegular"
             onmouseover="this.className=\'buttonRegularFocus\'"
             onmouseout="this.className=\'buttonRegular\'" value="'._LOGIN.'" />
          </td>
        </tr>
      </table>
    </div>
';

	// Get the recover password link (or email for help link).
	$renewlink = set_recoverylink();

	if ($renewlink) {
	  	// With the link set, insert the "login help" page section.
		$page .= '<p><a href="'.$renewlink.'">';
		$page .= $GLOBALS['recoverylinktext'].'</a></p>'."\r\n";
	}

	if (isset($_REQUEST['referer'])) {
  	// With a referred link set, include that link with the form for submission.
		$page .= '<input type="hidden" id="referer" name="referer" value="';
		$page .= $_REQUEST['referer'].'" />';
	} elseif (($tryagain == 'session') || ($tryagain == 'time')) {
		$page .= '<input type="hidden" id="referer" name="referer"';
		$page .= ' value="'.core_getReferer().'" />';
	}

	$page .= '<input type="hidden" id="userhash" name="userhash" value="" />';
	$page .= '<input type="hidden" id="passhash" name="passhash" value="" />';
	$page .= '<input type="hidden" id="hashingseed" name="hashingseed" value="';
	$page .= $_SESSION['seedhash'].'" />';
	$page .= '</form>';

	switch ($tryagain) {
		// Display an error if $tryagain is not "no".
		case 'session':
			// Display a "session expired" message.
			$t = $GLOBALS['authorization_timeout'];
			$page .= '<h3><em>';
			$page .= str_replace('<!--TIMEOUT-->',$t,_ERRORSESSIONEXPIRED);
			$page .= '</em></h3>';
			// End this joyride.
			break;

		case 'time':
			// Display a "login time expired" message.
			$t = $GLOBALS['login_timeout'];
			$page .= '<h3><em>';
			$page .= str_replace('<!--TIMEOUT-->',$t,_ERRORLOGINTIME);
			$page .= '</em></h3>';
			// End this joyride.
			break;

		case 'yes':
		case 'badhash':
			// Display a "incorrect login" message.
			$page .= '<h3><em>'._ERRORLOGINWRONG.'</em></h3>';
			// End this joyride.
			break;
	}

	// Return the HTML for the login screen.
	return $page;
}

?>