<?php
/**
 * Offers administration for the "blocks" area on the pages rendered by FreeWPS.
 * "Blocks" fall somewhere between "content" sections and the HTML templates.  The
 * blocks are sections of content that should be common to all pages.  Each "block"
 * will contain dynamic content in much the same way that content sections will in
 * the "Pages Administration" module. The "blocks" can also be assigned group
 * permissions and used to restrict and/or customize the rendered pages for specific
 * groups.  For example, one set of blocks may be setup for all users, another set
 * exclusively for members only, and yet another for members and administrators.
 * @package Core-Modules
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | BLOCKS.PHP                                           |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | BLOCKS.PHP is part of FreeWPS.                       |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: blocks.php,v 1.11 2005/05/29 16:38:41 ytztech Exp $
//

/* ****  MODULE HEADER SECTION ENDS HERE  **** */

/* ****  MODULE INITIALIZATION SECTION BEGINS HERE  **** */

if (stristr($_SERVER['PHP_SELF'],'blocks.php')) {
	// To make sure no one calls this script directly, this conditional ensures
	// that the client browser is redirected to the Home Page if this script's
	// filename is found in $_SERVER['PHP_SELF'].
	header('Location: ../index.php');
	die();
}

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

if (file_exists('languages/'.$GLOBALS['freewps_language'].'/lang-blocks.php')) {
	/** Load the locale-specific constants for defined FreeWPS language. */
	include_once 'languages/'.$GLOBALS['freewps_language'].'/lang-blocks.php';
} else {
	/** Default to English (or to your native language, if not English). */
	include_once 'languages/english/lang-blocks.php';
}

if (core_checkUser(CONTENT_EDITORS)) {
	// Check for the existence of either GET/POST variable "mode".
	// "Mode" determines the actions taken by this module.
	if (isset($_REQUEST['mode'])) {
		// Set the mode to the requested mode.
		$mode = $_REQUEST['mode'];
	} else {
		// Set the mode to the default mode.
		$mode = 'admin';
	}
	// Check for the existence of either GET/POST variable "groupslist".
	// "Groupslist" is an array of group permissions.
	if (isset($_REQUEST['groupslist']) && !isset($_REQUEST['all_access'])) {
		// Set the groupslist to the requested groupslist.
		$groupslist = $_REQUEST['groupslist'];
	} else {
		// Set the groupslist to the default groupslist.
		$groupslist = EVERYONE_GROUP;
	}
	// Check for the existence of either GET/POST variable "pagelist".
	// "Pagelist" is an array of pages that a block appears on.
	if (isset($_REQUEST['pagelist']) && !isset($_REQUEST['all_access'])) {
		// Set the pagelist to the requested pagelist.
		$pagelist = $_REQUEST['pagelist'];
	} else {
		// Set the pagelist to the default pagelist.
		$pagelist = EVERYONE_GROUP;
	}
	// Check for the existence of either GET/POST variable "syslist".
	// "Syslist" is an array of system pages that a block appears on.
	if (isset($_REQUEST['syslist']) && !isset($_REQUEST['sysall_access'])) {
		// Set the syslist to the requested syslist.
		$syslist = $_REQUEST['syslist'];
	} else {
		// Set the syslist to the default syslist
		$syslist = EVERYONE_GROUP;
	}
	// Strip slashes from the block title and convert single and double quotes
	// to their WPS entities for the current charset.
	if (isset($_POST['blk_title'])) {
		$block_title = core_convertQuotes(stripslashes($_POST['blk_title']));
	}
	// Check for the existence of either GET/POST variable "blockid".
	// "Blockid" is an integer representing a block.
	if (isset($_REQUEST['blockid'])) {
		// Set the mode to the requested mode.
		$blockid = $_REQUEST['blockid'];
	} else {
		if ($mode == 'editblock') {
			// Only go to the ADMIN page when no blockid to edit.
			$mode = 'admin';
			// Set the groupslist to EVERYONE_GROUP.
			$groupslist = EVERYONE_GROUP;
		}
	}
	// Check for the existence of either GET/POST variable "content_text".
	// "Content_text" is a string representing HTML content for a block.
	if (isset($_REQUEST['content_text'])) {
		// Initialize block content with the submitted HTML text.
		$content = $_REQUEST['content_text'];
		// Check for the presence of $site_url in the block content and remove it.
		if (stristr($content,$site_url)) {
			$content = str_replace($site_url.'includes/','',$content);
		}
		// Strip slashes from the block content and convert single and double quotes
		// to their WPS entities for the current charset.
		$content = core_convertQuotes(stripslashes($content));
	}

/* ****  MODULE INITIALIZATION SECTION ENDS HERE  **** */

/* ****  REQUEST PROCESSING SECTION BEGINS HERE  **** */

	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		/* The POST processing section... */
		switch ($mode) {
			case 'addblock':
				// For new blocks, get the next block id.
				$blk_id     = core_getNextID($dbpref.'_BLOCKS');
				// Initialize the new content to add.
				$content    = '<p>&nbsp;</p>';
				// Setup and execute the query to determine the next available
				// precedence to assign to the new block.
				$results    = sql_query('SELECT ID FROM '.$dbpref.'_BLOCKS',$db_id);
				$precedence = sql_num_rows($results,$dbpref.'_BLOCKS');

				// Setup and execute the query to add the new block.
				$query_cmd  = 'INSERT INTO '.$dbpref.'_BLOCKS'.
							 ' VALUES ('.$blk_id.','.
									'\''.$block_title.'\','.
									'\''.$content.'\','.
										 $precedence.','.
										 '\'n\','.
										 '\'n\','.
										 '\'n/a\','.
										 '0,'.
										 '0,'.
										 '\'n\','.
										 '\'blocks\','.
										 '\'editblockcontent\')';
				sql_query($query_cmd,$db_id);

				// Set group permissions to new block.
				$perm_id   = core_getNextID($dbpref.'_GRPBLOCKS');
				$query_cmd = 'INSERT INTO '.$dbpref.'_GRPBLOCKS'.
							 ' VALUES ('.$perm_id.', '.$blk_id.', 0)';
				sql_query($query_cmd, $db_id);

				// Set page appearances for new block.
				$pg_id = core_getNextID($dbpref.'_PAGEBLOCKS');
				$query_cmd = 'INSERT INTO '.$dbpref.'_PAGEBLOCKS'.
							 ' VALUES ('.$pg_id.', '.$blk_id.', 0)';
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Block Content" form.
				$location  = 'modules.php?id=blocks';
				$location .= '&mode=editblockcontent&blockid='.$blk_id;
				header('Location: '.$location);
				// End this joyride.
				break;

			case 'editblockaccess':
				// When editing the group access of a block...
				if ($groupslist != EVERYONE_GROUP) {
					// Initialize an array for the groupids.
					$groups = array();
					// Setup and execute the query to return the list of existing
					// groups assigned to the block.
					$query_pt1 = 'SELECT GROUPID FROM ';
					$query_pt2 = $dbpref.'_GRPBLOCKS WHERE BLOCKID = '.$blockid;
					$results = sql_query($query_pt1.$query_pt2, $db_id);
					if (sql_num_rows($results,$query_pt2) > 0) {
						while ($row = sql_fetch_row($results)) {
							// Add the groupid to the groups array.
							$groups[] = $row[0];
						}
					}

					// Get the next available groupid.
					$next_id = core_getNextID($dbpref.'_GRPBLOCKS');
					for ($i = 0; $i < count($groupslist); $i++) {
						// Determine whether the new groups are already assigned.
						if (!in_array($groupslist[$i],$groups)) {
							// Since this group is not listed, setup and execute
							// the query to add the new group to the list of
							// groups for this block.
							$query_cmd = 'INSERT INTO '.$dbpref.'_GRPBLOCKS'.
										 ' VALUES ('.$next_id.', '.$blockid.', '.
										             $groupslist[$i].')';
							sql_query($query_cmd, $db_id);
							// Get the next pageid.
							$next_id++;
						} else {
							// Get the element key for matching group.
							$key = array_search($groupslist[$i],$groups);
							// Remove the group from array.
							unset($groups[$key]);
						}
					}

					// Reset the array point for the list of groups to the start.
					reset($groups);
					while (($element = current($groups)) !== FALSE) {
						// Setup and execute the query to delete the next
						// remaining removed group.
						$query_cmd = 'DELETE FROM '.$dbpref.'_GRPBLOCKS'.
									 ' WHERE BLOCKID = '.$blockid.
									 ' AND GROUPID = '.$element;
						sql_query($query_cmd, $db_id);
						// Advance the array pointer to the next element.
						next($groups);
					}
				} else {
					// Setup and execute the query to delete all group access
					// records for $blockid.
					$query_cmd = 'DELETE FROM '.$dbpref.'_GRPBLOCKS'.
								 ' WHERE BLOCKID = '.$blockid;
					sql_query($query_cmd, $db_id);

					// Get the next groupid.
					$next_id = core_getNextID($dbpref.'_GRPBLOCKS');
					// Setup and execute the query to specify EVERYONE_GROUP
					// accessibility for $blockid.
					$query_cmd = 'INSERT INTO '.$dbpref.'_GRPBLOCKS'.
								 ' VALUES ('.$next_id.', '.$blockid.', '.
								 			 EVERYONE_GROUP.')';
					sql_query($query_cmd,$GLOBALS['db_id']);
				}

				// Redirect the user to the Blocks Administration panel.
				header('Location: modules.php?id=blocks');
				// End this joyride.
				break;

			case 'editblockcontent':
				// Setup and execute the query to update the block content and then
				// unlock the block for another user.
				$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
							 ' SET CONTENT = \''.$content.'\','.
							 	 ' LOCKSET = \'n\','.
								 ' LOCKUSER = \'n/a\','.
								 ' LOCKTIME = 0'.
							 ' WHERE ID = '.$blockid;
				sql_query($query_cmd,$db_id);

				// Redirect the user to the Blocks Administration panel.
				header('Location: modules.php?id=blocks');
				// End this joyride.
				break;

			case 'editblockpages':
				if ($pagelist != EVERYONE_GROUP) {
					// Create an array for the pageids.
					$pageids = array();
					// Setup and execute the query to return the list of existing
					// pages assigned to the block.
					$query_pt1 = 'SELECT PAGEID FROM ';
					$query_pt2 = $dbpref.'_PAGEBLOCKS WHERE BLOCKID = '.$blockid;
					$results = sql_query($query_pt1.$query_pt2, $db_id);
					if (sql_num_rows($results,$query_pt2) > 0) {
						while ($row = sql_fetch_row($results)) {
							// Add the page to the pageids array.
							$pageids[] = $row[0];
						}
					}

					// Get the next available PAGEBLOCK ID.
					$next_id = core_getNextID($dbpref.'_PAGEBLOCKS');
					for ($i = 0; $i < count($pagelist); $i++) {
						// Determine whether the new pages are already assigned.
						if (!in_array($pagelist[$i],$pageids)) {
							// Since this pageid is not listed, setup and execute
							// the query to add the new page to the list of
							// pages for this block.
							$query_cmd = 'INSERT INTO '.$dbpref.'_PAGEBLOCKS'.
										 ' VALUES ('.$next_id.', '.$blockid.', '.
										             $pagelist[$i].')';
							sql_query($query_cmd, $db_id);
							// Get the next pageid.
							$next_id++;
						} else {
							// Get the element key for matching page.
							$key = array_search($pagelist[$i],$pageids);
							// Remove the page from array.
							unset($pageids[$key]);
						}
					}

					// Reset the array point for the list of pages to the start.
					reset($pageids);
					while (($element = current($pageids)) !== FALSE) {
						// Setup and execute the query to delete the next
						// remaining removed page.
						$query_cmd = 'DELETE FROM '.$dbpref.'_PAGEBLOCKS'.
									 ' WHERE BLOCKID = '.$blockid.
									 ' AND PAGEID = '.$element;
						sql_query($query_cmd, $db_id);
						// Advance the array pointer to the next element.
						next($pageids);
					}
				} else {
					// Setup and execute the query to delete all page access
					// records for $blockid.
					$query_cmd = 'DELETE FROM '.$dbpref.'_PAGEBLOCKS'.
								 ' WHERE BLOCKID = '.$blockid;
					sql_query($query_cmd, $db_id);

					if (isset($_POST['all_access'])) {
						// Get the next pageid.
						$next_id = core_getNextID($dbpref.'_PAGEBLOCKS');
						// Setup and execute the query to specify ALL PAGES
						// accessibility for $blockid.
						$query_cmd = 'INSERT INTO '.$dbpref.'_PAGEBLOCKS'.
									 ' VALUES ('.$next_id.', '.$blockid.', 0)';
						sql_query($query_cmd,$GLOBALS['db_id']);
					}
				}

				if ($syslist != EVERYONE_GROUP) {
					// Create an array for the sysids.
					$sysids = array();
					// Setup and execute the query to return the list of existing
					// system pages assigned to the block.
					$query_pt1 = 'SELECT PAGENAME FROM ';
					$query_pt2 = $dbpref.'_SYSBLOCKS WHERE BLOCKID = '.$blockid;
					$sysresults = sql_query($query_pt1.$query_pt2, $db_id);
					if (sql_num_rows($sysresults,$query_pt2) > 0) {
						while ($row = sql_fetch_row($sysresults)) {
							// Add the page to the sysids array.
							$sysids[] = $row[0];
						}
					}

					// Get the next available SYSBLOCK ID.
					$next_id = core_getNextID($dbpref.'_SYSBLOCKS');
					for ($i = 0; $i < count($syslist); $i++) {
						// Determine whether the new pages are already assigned.
						if (!in_array($syslist[$i],$sysids)) {
							// Since this pageid is not listed, setup and execute
							// the query to add the new page to the list of
							// pages for this block.
							$query_cmd = 'INSERT INTO '.$dbpref.'_SYSBLOCKS'.
										 ' VALUES ('.$next_id.', '.$blockid.', '.
										             '\''.$syslist[$i].'\')';
							sql_query($query_cmd, $db_id);
							// Get the next pageid.
							$next_id++;
						} else {
							// Get the element key for matching page.
							$key = array_search($syslist[$i],$sysids);
							// Remove the page from array.
							unset($sysids[$key]);
						}
					}

					// Reset the array point for the list of pages to the start.
					reset($sysids);
					while (($element = current($sysids)) !== FALSE) {
						// Setup and execute the query to delete the next
						// remaining removed page.
						$query_cmd = 'DELETE FROM '.$dbpref.'_SYSBLOCKS'.
									 ' WHERE BLOCKID = '.$blockid.
									 ' AND PAGENAME = \''.$element.'\'';
						sql_query($query_cmd, $db_id);
						// Advance the array pointer to the next element.
						next($sysids);
					}
				} else {
					// Setup and execute the query to delete all page access
					// records for $blockid.
					$query_cmd = 'DELETE FROM '.$dbpref.'_SYSBLOCKS'.
								 ' WHERE BLOCKID = '.$blockid;
					sql_query($query_cmd, $db_id);

					if (isset($_POST['sysall_access'])) {
						// Get the next pageid.
						$next_id = core_getNextID($dbpref.'_SYSBLOCKS');
						// Setup and execute the query to specify ALL PAGES
						// accessibility for $blockid.
						$query_cmd = 'INSERT INTO '.$dbpref.'_SYSBLOCKS'.
									 ' VALUES ('.$next_id.', '.$blockid.', \'all\')';
						sql_query($query_cmd,$GLOBALS['db_id']);
					}
				}

				// Redirect the user to the Blocks Administration panel.
				header('Location: modules.php?id=blocks');
				// End this joyride.
				break;

			case 'editblocktitle':
				// Setup and execute the query to update the title for $blockid.
				$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
							 ' SET TITLE = \''.$block_title.'\''.
							 ' WHERE ID = '.$blockid;
				sql_query($query_cmd,$db_id);
				// Redirect the user to the Blocks Administration panel.
				header('Location: modules.php?id=blocks');
				// End this joyride.
				break;

			case 'addside':
				// Get new sideid.
				$side_id = core_getNextID($dbpref.'_BLOCKSIDES');

				// Setup and execute the query to add the sidename.
				$query_cmd = 'INSERT INTO '.$dbpref.'_BLOCKSIDES'.
							 ' VALUES ('.$side_id.',\''.$_POST['sidename'].'\')';
				sql_query($query_cmd,$db_id);

				// Return to the "Manage Block Sides" form.
				header('Location: modules.php?id=blocks&mode=adminsides');
				// End this joyride.
				break;

			case 'editside':
				// Update the sidename.
				$query_cmd = 'UPDATE '.$dbpref.'_BLOCKSIDES'.
							 ' SET SIDENAME = \''.$_POST['sidename'].'\''.
							 ' WHERE ID = '.$_POST['sideid'];
				sql_query($query_cmd,$db_id);

				// Return to the "Manage Block Sides" form.
				header('Location: modules.php?id=blocks&mode=adminsides');
				// End this joyride.
				break;

			default:
				// Since an invalid $mode was given, display an error page.
				Header('Location: 404.php');
				// End this joyride.
				break;
		}
		// End this script without any further processing.
		die();
	}

	/* The GET processing section... */
	switch ($mode) {
		case 'admin':
			// Get the HTML for the "Blocks Administration" page.
			$pgcontent = blocks_admin();
			// Create the page.
			core_createPage($pgcontent,'',_BLOCKS_TITLE);
			// End this joyride.
			break;

		case 'adminsides':
			// Get the content for the "Manage Block Sides" form.
			$pgcontent = blocks_adminSides();
			// Create the page.
			core_createPage($pgcontent,'',_BLOCKS02);
			// End this joyride.
			break;

		case 'canceleditblock':
			// Setup and execute the query to unlock the block.
			$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
						 " SET LOCKSET = 'n', LOCKUSER = 'n/a', LOCKTIME = 0".
						 " WHERE ID = $blockid";
			sql_query($query_cmd,$db_id);

			// Return to the "Blocks Administration" page.
			header('Location:  modules.php?id=blocks');
			// End this joyride.
			break;


		case 'deleteblock':
			// Setup and execute the query to return the precedence to fix.
			$query_cmd = 'SELECT PRECEDENCE FROM '.$dbpref.'_BLOCKS'.
						 ' WHERE ID = '.$blockid;
			$results = sql_query($query_cmd,$db_id);
			$row = sql_fetch_row($results);

			// Setup and execute the query to update the precedence of the blocks
			// that are beneath the to-be-deleted block on the list of blocks.
			$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_BLOCKS'.
						 ' SET PRECEDENCE = (PRECEDENCE - 1)'.
						 ' WHERE PRECEDENCE > '.$row[0];
			sql_query($query_cmd,$GLOBALS['db_id']);

			// Setup and execute the query to delete the block.
			$query_cmd = 'DELETE FROM '.$dbpref.'_BLOCKS WHERE ID = '.$blockid;
			sql_query($query_cmd,$db_id);

			// Setup and execute the query to delete the block-group associations.
			$query_cmd = 'DELETE FROM '.$dbpref.'_GRPBLOCKS'.
						 ' WHERE BLOCKID = '.$blockid;
			sql_query($query_cmd,$db_id);

			// Setup and execute the query to delete the block-page associations.
			$query_cmd = 'DELETE FROM '.$dbpref.'_PAGEBLOCKS'.
						 ' WHERE BLOCKID = '.$blockid;
			sql_query($query_cmd,$db_id);

			// Setup and execute the query to remove all system page associations for
			// this block.
			$query_cmd = 'DELETE FROM '.$dbpref.'_SYSBLOCKS'.
						 ' WHERE BLOCKID = '.$blockid;
			sql_query($query_cmd, $GLOBALS['db_id']);
			// Redirect the user to the "Blocks Administration" panel.
			header('Location:  modules.php?id=blocks&mode=admin');
			// End this joyride.
			break;


		case 'deleteside':
			if ($_GET['sideid'] > 0) {
				// Setup and execute the query to return the number of blocks
				// contained on sideid.
				$query_pt1 = 'SELECT ID FROM ';
				$query_pt2 = $dbpref.'_BLOCKS WHERE SIDEID = '.$_GET['sideid'];
				$results   = sql_query($query_pt1.$query_pt2,$db_id);
				if (sql_num_rows($results,$query_pt2) > 0) {
					$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS SET SIDEID = 0'.
								 ' WHERE SIDEID = '.$_GET['sideid'];
					sql_query($query_cmd,$db_id);
				}

				// Delete the blockside.
				$query_cmd = 'DELETE FROM '.$dbpref.'_BLOCKSIDES'.
							 ' WHERE ID = '.$_GET['sideid'];
				sql_query($query_cmd,$db_id);
			}

			// Redirect the user to the "Manage Block Sides" form.
			header('Location: modules.php?id=blocks&mode=adminsides');
			// End this joyride.
			break;

		case 'editblockaccess':
			// Get the HTML for the "Edit Block Accessibility" form.
			$pgcontent = blocks_editBlockAccess($blockid);
			// Create the page.
			core_createPage($pgcontent,'',_BLOCKS08);
			// End this joyride.
			break;

		case 'editblockcontent':
			// Get a lock on the block.
			$record_status = core_checkLock($dbpref.'_BLOCKS',$blockid);
			if ($record_status == 'GRANTED') {
				// Get the HTML for the "Edit Block Content" form.
				$pgcontent = blocks_editBlockContent($blockid);
				// Create the page.
				core_createPage($pgcontent,'',_BLOCKS03);
			} else {
				// Display the "Record Locked" page.
				core_createPage($record_status,'',_RECORDLOCKED);
			}
			// End this joyride.
			break;

		case 'editblockpages':
			// Get the HTML for the "Edit Page Associations" form.
			$pgcontent = blocks_editBlockPages($blockid);
			// Create the page.
			core_createPage($pgcontent,'',_BLOCKS33);
			// End this joyride.
			break;

		case 'editblockside':
			// Setup and execute the query to update the sideid for $blockid.
			$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
						 ' SET SIDEID = '.$_GET['blockside'].
						 ' WHERE ID = '.$blockid;
			sql_query($query_cmd,$db_id);

			// Redirect the user to the Blocks Administration panel.
			header('Location: modules.php?id=blocks');
			// End this joyride.
			break;

		case 'editsettingactive':
			// Setup and execute the query to get the current setting for
			// $blockid in ISACTIVE.
			$query_cmd = 'SELECT ISACTIVE FROM '.$dbpref.'_BLOCKS'.
						 ' WHERE ID = '.$blockid;
			$results   = sql_query($query_cmd,$db_id);
			$row       = sql_fetch_row($results);

			// Flip the setting.
			$setting = ($row[0] == 'y') ? 'n' : 'y';

			// Update the setting for $blockid.
			$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
						 ' SET ISACTIVE = \''.$setting.'\''.
						 ' WHERE ID = '.$blockid;
			sql_query($query_cmd, $db_id);

			// Redirect the user to the "Blocks Administration" panel.
			header('Location: modules.php?id=blocks');
			// End this joyride.
			break;

		case 'moveblockdn':
		case 'moveblockup':
			if ($mode == 'moveblockdn') {
				// Set the previous precedence for $blockid.
				$previous = $_GET['blk_precedence'] + 1;
			} else {
				// Set the previous precedence for $blockid.
				$previous = $_GET['blk_precedence'] - 1;
			}

			// Setup and execute the query to update the precedence for the block
			// to be swapped with the current block.
			$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS'.
						 ' SET PRECEDENCE='.$_GET['blk_precedence'].
						 ' WHERE PRECEDENCE='.$previous;
			sql_query($query_cmd,$db_id);

			// Setup and execute the query to update the precedence for the current
			// block.
			$query_cmd = 'UPDATE '.$dbpref.'_BLOCKS SET PRECEDENCE='.$previous.
						 ' WHERE ID = '.$blockid;
			sql_query($query_cmd,$db_id);

			// Redirect the user to the "Blocks Administration" panel.
			header('Location:  modules.php?id=blocks&mode=admin');
			// End this joyride.
			break;

		default:
			// Since an invalid $mode was given, display an error page.
			Header('Location: 404.php');
			// End this joyride.
			break;
	}
} else {
	// No valid user rights were found.
	if ($_SESSION['authorization'] == '') {
		// Since the user hasn't logged in, send them to the login page with the
		// requested URL passed as a referral URL.
		Header('Location: login.php?referer='.core_getReferer());
		die();
	} else {							//
		// Since the user is logged in, display an "Access Denied" page instead.
		core_createPage(access_denied(),'',_ACCESSDENIED);
	}
}


/**
 * Display a list of all existing blocks and the layout order in which they will
 * appear on the rendered page.
 *
 * @access private
 * @return string HTML content of the "Blocks Administration" panel
 */
function blocks_admin()
{
	// Set the HTML for the "Blocks Administration" panel.
	$page = '
<script type="text/javascript">
<!--

function navAction (element)
{
	form = element.form;
	switch (element.value) {
		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			// End this joyride.
			break;
		case \'addblock\':
			form.blk_title.value = prompt(\''._BLOCKS04.'\',\''._BLOCKS05.'\');
			switch (form.blk_title.value) {
				case null:
				case \'null\':
				case \'\':
				case \''._BLOCKS05.'\':
					form.actionlist.selectedIndex = 0;
					form.actionlist.focus();
					break;
				default:
					form.id.value = \'blocks\';
					form.mode.value = \'addblock\';
					form.submit();
					break;
			}
			break;
		case \'adminsides\':
			location.href = \'modules.php?id=blocks&mode=adminsides\';
			break;
		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
	}
	return true;
}

function editTitle(blk_id,title)
{
	form = document.blklisting;
	form.blk_title.value = prompt(\''._BLOCKS06.'\',title);
	switch (form.blk_title.value) {
		case null:
		case \'null\':
		case \'\':
		case title:
			break;
		default:
			form.id.value = \'blocks\';
			form.mode.value = \'editblocktitle\';
			form.blockid.value = blk_id;
			form.submit();
			break;
	}
}

function changeBlockSide(blk_id,blockside)
{
	location.href = \'modules.php?id=blocks&mode=editblockside&blockid=\'+blk_id+
	                \'&blockside=\'+blockside.value;
}

function toggleSetting(setting,blk_id)
{
	location.href = \'modules.php?id=blocks&mode=editsetting\'+setting+
	                \'&blockid=\'+blk_id;
}

function deleteBlock(blk_id)
{
	if (confirm("'._BLOCKS15.'")) {
		location.href = \'modules.php?id=blocks&mode=deleteblock&blockid=\'+blk_id;
	}
}


//-->
</script>

<h3 align="center">'._BLOCKS_TITLE.'</h3>
<form method="post" action="modules.php" name="blklisting">
  <table align="center" class="tableNavigation">
    <tr>
      <td align="center" nowrap="nowrap">
        <select class="textCool" name="actionlist"
         onchange="navAction(this.options[this.selectedIndex])">
          <option value="default">- '._NAVIGATIONMENU.' -</option>
          <option value="addblock">'._BLOCKS01.'</option>
          <option value="adminsides">'._BLOCKS02.'</option>
          <option value="adminpanel">'._BACK2ADMIN.'</option>
        </select>
      </td>
    </tr>
  </table>
  <input type="hidden" name="blk_title" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="" />
  <input type="hidden" name="blockid" value="" />
  <input type="hidden" name="blockside" value="" />
  <hr class="paddedhr" />
  <table align="center" border="1" class="tableAdmin">
    <tr>
      <td align="center" class="columnAdminHeader">'._BLOCKS07.'</td>
      <td align="center" class="columnAdminHeader">'._BLOCKS09.'</td>
      <td align="center" class="columnAdminHeader">'._BLOCKS18.'</td>
      <td align="center" class="columnAdminHeader">'._BLOCKS19.'</td>
    </tr>';

	// Setup and execute the query to get the list of blocks.
	$query_pt1 = 'SELECT ID,TITLE,PRECEDENCE,ISACTIVE,SIDEID,MODNAME,MODMODE FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_BLOCKS';
	$query_pt3 = ' ORDER BY PRECEDENCE';
	$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

	// Determine how many blocks were returned.
	$blocktotal = sql_num_rows($results,$GLOBALS['dbpref'].'_BLOCKS');
	if ($blocktotal > 0 ) {
		// Setup and execute the query to get the names for all blocksides.
		$query_cmd = 'SELECT ID,SIDENAME'.
					 ' FROM '.$GLOBALS['dbpref'].'_BLOCKSIDES'.
					 ' ORDER BY SIDENAME';
		$side_results = sql_query($query_cmd, $GLOBALS['db_id']);
		$sides = array();
		while ($row = sql_fetch_row($side_results)) {
			$sides[] = array(0 => $row[0], 1 => $row[1]);
		}

		// Initialize the highlighted style number to use.
		$hilite = 1;

		// Get the properties for the next block until no more are listed.
		while ($row = sql_fetch_row($results)) {
			$style = 'columnAdminCell';
			if (($hilite % 2) == 0) {
				$style .= '2';
			}

			// Convert the WPS entities to single and double quotes.
			$title = core_convertQuotes($row[1],'revert');

			// Continue to set the HTML for the panel.
			$page .= '
    <tr>
      <td align="center" class="'.$style.'">
        <a href="javascript:editTitle('.$row[0].',\''.
        str_replace('&','&amp;',$title).'\');">'.$title.'</a>
      </td>
      <td align="center" class="'.$style.'">
        <select name="blk_side" id="blk_side"
         onchange="changeBlockSide('.$row[0].',this.options[this.selectedIndex]);"
         class="textCool" title="'._BLOCKS09.'">';

			for ($i = 0; $i < count($sides); $i++) {
				$page .= "\r\n".'          <option';
				if ($row[4] == $sides[$i][0]) {
					$page .= ' selected="selected"';
				}
				$page .= ' value="'.$sides[$i][0].'">'.$sides[$i][1].'</option>';
			}

			$page .= '
        </select>
      </td>
      <td align="center" class="'.$style.'">';

			if ($blocktotal == 1) {
				// Display 'n/a' if only one block is listed.
				$page .= 'n/a';
			} else {
				// Do not display a "Move Up" icon for the first block listed.
				if ($row[2] != 0) {
					$page .= ' <a href="modules.php?id=blocks&amp;mode=moveblockup';
					$page .= '&amp;blockid='.$row[0].'&amp;blk_precedence='.$row[2];
					$page .= '"><img src="modules/blocks/uparrow.png" border="0"';
					$page .= ' height="24" width="24" alt="Up" /></a>';
				}

				// Do not display a "Move Down" icon for the last block listed.
				if ($row[2] != ($blocktotal - 1)) {
					$page .= ' <a href="modules.php?id=blocks&amp;mode=moveblockdn';
					$page .= '&amp;blockid='.$row[0].'&amp;blk_precedence='.$row[2];
					$page .= '"><img src="modules/blocks/dnarrow.png" border="0"';
					$page .= ' height="24" width="24" alt="Down" /></a>';
				}
			}

			// Continue to set the HTML for the panel.
			$page .= '
      </td>
      <td align="center" nowrap="nowrap" class="'.$style.'">
        <a href="javascript:toggleSetting(\'active\','.$row[0].');">';

			if ($row[3] == 'n') {
				$imgname = 'deactivate';
				$imgtitle = _BLOCKS11;
			} else {
				$imgname = 'activate';
				$imgtitle = _BLOCKS12;
			}

			$page .=
        '<img src="modules/blocks/'.$imgname.'.png" border="0" alt="'.
          $imgtitle.'" height="24" width="24" hspace="0" vspace="0" /></a>';

			if ($row[5] == 'blocks') {
				$title = _BLOCKS03;
			} else {
				$title = _BLOCKS20;
			}

			$page .= '
        <a href="modules.php?id='.$row[5].'&amp;mode='.$row[6].'&amp;blockid='.
         $row[0].'"><img src="modules/blocks/contents.png" alt="'.$title.'"'.
         'height="24" width="24" hspace="0" vspace="0" border="0" /></a>
        <a href="modules.php?id=blocks&amp;mode=editblockaccess'.
         '&amp;blockid='.$row[0].'"><img src="modules/blocks/security.png"'.
         'alt="'._BLOCKS08.'" height="24" width="24" hspace="0" vspace="0"'.
         'border="0" /></a>
        <a href="modules.php?id=blocks&amp;mode=editblockpages'.
         '&amp;blockid='.$row[0].'"><img src="modules/blocks/pages.png"'.
         'alt="'._BLOCKS33.'" height="24" width="24" hspace="0" vspace="0"'.
         'border="0" /></a>
        <a href="javascript:deleteBlock('.$row[0].');">
        <img src="modules/blocks/delete.png" alt="'._BLOCKS14.'"
         height="24" width="24" hspace="0" vspace="0" border="0" /></a>
      </td>
    </tr>';

			$hilite++;
		}
	}
	$page .= '
  </table>
</form>
';
	// Return the HTML for the "Blocks Administration" panel.
	return $page;
}



/**
 * Display a list of all existing blocksides and allow users to make changes.
 *
 * @access private
 * @return string HTML content of the "Manage Block Sides" form
 */
function blocks_adminSides()
{
	// Set the HTML for the "Manage Block Sides" form.
	$page = '
<script type="text/javascript">
<!--

function navAction (element)
{
	form = element.form;
	switch (element.value) {
		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;

		case \'addside\':
			form.sidename.value = prompt(\''._BLOCKS21.'\',\''._BLOCKS22.'\');
			switch (form.sidename.value) {
				case null:
				case \'null\':
				case \'\':
					form.actionlist.selectedIndex = 0;
					form.actionlist.focus();
					return false;
					break;
				case \''._BLOCKS22.'\':
					alert(\''._BLOCKS23.'\');
					return false;
					break;
				default:
					form.mode.value = \'addside\';
					form.submit();
					break;
			}
			break;

		case \'admin\':
			location.href = \'modules.php?id=blocks&mode=admin\';
			break;

		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
	}
	return true;
}

function moduleAction (element)
{
	form = element.form;
	switch (element.name) {
		case \'editSide\':
			var selIndex = form.sideid.options[form.sideid.selectedIndex].value;
			var selSide = form.sideid.options[form.sideid.selectedIndex].text;
			form.sidename.value = prompt(\''._BLOCKS24.'\', selSide);
			switch (form.sidename.value) {
				case null:
				case \'null\':
				case \'\':
					form.actionlist.selectedIndex = 0;
					form.actionlist.focus();
					return false;
					break;
				case selSide:
					alert(\''._BLOCKS25.'\');
					return false;
					break;
				default:
					if (form.sidename.value != selSide) {
						form.mode.value = \'editside\';
						form.submit();
					} else {
						return false;
					}
					break;
			}
			break;

		case \'deleteSide\':
			var selIndex = form.sideid.options[form.sideid.selectedIndex].value;
			var selSide = form.sideid.options[form.sideid.selectedIndex].text;
			if (confirm(\''._BLOCKS26.'\')) {
				location.href = \'modules.php?id=blocks&mode=deleteside\'+
								\'&sideid=\'+selIndex;
			}
			break;
	}
	return true;
}

function checkDelete (form)
{
	var select    = form.sideid;
		editbtn   = form.editSide;
		deletebtn = form.deleteSide;
	editbtn.disabled = (select.options[select.selectedIndex].value == 0);
	deletebtn.disabled = editbtn.disabled;
	return true;
}

//-->
</script>
<h3 align="center">'._BLOCKS02.'</h3>
<form method="post" action="modules.php" name="actions">
  <table class="tableNavigation">
    <tr>
      <td align="center">
        <select class="textCool" name="actionlist"
          onchange="navAction(this.options[this.selectedIndex])">
          <option value="default">- '._NAVIGATIONMENU.' -</option>
          <option value="addside">'._BLOCKS27.'</option>
          <option value="admin">'._BLOCKS28.'</option>
          <option value="adminpanel">'._BACK2ADMIN.'</option>
        </select>
      </td>
    </tr>
  </table>
  <input type="hidden" name="sidename" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="blocks" />
</form>
<hr class="paddedhr" />
<form method="post" action="modules.php" name="sideform">
  <div align="center">
    <table align="center" class="tableNavigation">
      <tr>
        <td align="center">
          <h4>'._BLOCKS29.'&nbsp;
            <select class="textCool" name="sideid"
             onchange="checkDelete(this.form)">';

	// Setup and execute the query to get all the available blocksides.
	$query_cmd = 'SELECT ID,SIDENAME FROM '.$GLOBALS['dbpref'].'_BLOCKSIDES'.
				 ' ORDER BY SIDENAME';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Initialize the DISABLED setting for the edit/delete buttons.
	$disabled = 'first';
	while ($row = sql_fetch_row($results)) {
		if ($disabled == 'first') {
			// Determine whether to disable the buttons based on the first record.
			$disabled = ($row[0] == 0) ? 'disabled="disabled"' : '';
		}
		// Add each blockside
		$page .= '          <option value="'.$row[0].'">';
		if ($row[0] == 0) {
			$page .= '**&nbsp; ';
		}
		$page .= $row[1];
		if ($row[0] == 0) {
			$page .= '&nbsp; **';
		}
		$page .= '</option>';
	}

	// Continue to set the HTML for the "Manage Block Sides" form.
	$page .= '
            </select>
          </h4>
          <p>'._LEGENDCOLON.'&nbsp; <strong>** '._BLOCKS30.'</strong><br />&nbsp;</p>
        </td>
      </tr>
      <tr>
        <td align="center">
          <p>
            <input type="button" class="buttonRegular" name="editSide"
              value="'._BLOCKS31.'" onclick="moduleAction(this);"
              onmouseover="this.className = \'buttonRegularFocus\'"
              onmouseout="this.className = \'buttonRegular\'" '.$disabled.' />
          </p>
          <p>
            <input type="button" class="buttonRegular" name="deleteSide"
              value="'._BLOCKS32.'" onclick="moduleAction(this);"
              onmouseover="this.className = \'buttonRegularFocus\'"
              onmouseout="this.className = \'buttonRegular\'" '.$disabled.' />
          </p>
        </td>
      </tr>
    </table>
  </div>
  <input type="hidden" name="sidename" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="blocks" />
</form>
';
	// Return the HTML for the "Manage Block Sides" form.
	return $page;
}


/**
 * Display a form to change the list of user groups for $blockid that will be
 * permitted to view the block.
 *
 * @param  int     $blockid   ID of the block for which to display permissions
 * @access private
 * @return string HTML content of the "Edit Block Accessibility" form
 */
function blocks_editBlockAccess($blockid)
{
	// Setup and execute the query to get the group access for $blockid.
	$query_cmd = 'SELECT GROUPID FROM '.$GLOBALS['dbpref'].'_GRPBLOCKS'.
				 ' WHERE BLOCKID = '.$blockid;
	$grp_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Initialize and build a string of all groups assigned to $blockid.
	// String operations are significantly faster than array operations.  :)
	$grpids = '';
	while ($row = @sql_fetch_row($grp_results)) {
		// Wrap each group with brackets, to make matching clearer.
		$grpids .= '['.$row[0].']';
	}

	// Setup and execute the query to return the title of the $blockid.
	$query_cmd = 'SELECT TITLE FROM '.$GLOBALS['dbpref'].'_BLOCKS'.
				 ' WHERE ID = '.$blockid;
	$blk_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Grab the title and convert all WPS entities into single and double quotes.
	$row = sql_fetch_row($blk_results);
	$title = core_convertQuotes($row[0],'revert');

	// Set the HTML for the "Edit Block Accessibility" form.

	$page  = '
<h3 align="center">'._BLOCKS08.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="2">
      <tr>
        <td align="left">&nbsp;'._BLOCKS10.':</td>
      </tr>
      <tr>
        <td align="left">
          <select multiple="multiple" name="groupslist[]" class="textCool"';

	if ($grpids == '[0]') {
		// The select should be disabled if all groups are assigned.
		$page .= ' disabled="disabled"';
	}
	$page .= ' width="500" style="width: 500px" size="8">';

	// Get the "notequal" SQL operator.
	$notequal = sql_operator('notequal');
	// Setup and execute the query to return all groups.
	$query_cmd = 'SELECT ID, GRPNAME FROM '.$GLOBALS['dbpref'].'_GROUPS'.
				 ' WHERE ID '.$notequal.' '.EVERYONE_GROUP.
				 ' AND ID '.$notequal.' '.SUPERUSERS_GROUP.
				 ' ORDER BY GRPNAME';
	$results = sql_query($query_cmd, $GLOBALS['db_id']);
	while ($row = sql_fetch_row($results)) {
		// Add each group as a select option.
		$page .= "\r\n".'          <option value="'.$row[0].'"';
		if (strstr($grpids,'['.$row[0].']')) {
			// Since it's already assigned to this block, make it selected.
			$page .= ' selected="selected"';
		}
		$page .= '>'.$row[1].'</option>';
	}

	// Continue to set the HTML for the "Edit Block Accessibility" form.
	$page .= '
          </select>
        </td>
      </tr>
      <tr>
        <td align="left">
          <input type="checkbox" name="all_access" id="all_access"';

	if ($grpids == '[0]') {
		$page .= ' checked="checked"';
	}
	$page .= ' onclick="this.form.elements[0].disabled =';
	$page .= ' !this.form.elements[0].disabled;" /> '._BLOCKS16.'
        </td>
      </tr>
    </table>
  </div>
  <p align="center">
    <input type="submit" class="buttonRegular" value="'._BLOCKS13.'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />
    <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \''.$_SESSION['prev_page'].'\'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />
  </p>
  <input type="hidden" name="id" value="blocks" />
  <input type="hidden" name="mode" value="editblockaccess" />
  <input type="hidden" name="blockid" value="'.$blockid.'" />
</form>
';
	// Return the HTML for the "Edit Block Accessibility" form.
	return $page;
}


/**
 * Display a form to edit an existing block's HTML content.
 *
 * @param  int     $blockid   ID of the block for which to display HTML content
 * @access private
 * @return string HTML content of the "Edit Block Content" form
 */
function blocks_editBlockContent($blockid)
{
	// Setup and execute the query to get the HTML content of the block.
	$query_cmd = 'SELECT TITLE,CONTENT FROM '. $GLOBALS['dbpref'].'_BLOCKS'.
				 ' WHERE ID = '.$blockid;
	$results   = sql_query($query_cmd,$GLOBALS['db_id']);

	// Grab the title and HTML content.
	$row       = sql_fetch_row($results);
	// Convert the WPS entities to single and double quotes.  Make the HTML
	// display-friendly for the textarea.
	$content	= stripslashes($row[1]);
	$content	= htmlspecialchars(core_convertQuotes($content,'revert'));

	// Set the HTML for the "Edit Block Content" form.
	$page =  '
<h3 align="center">'._BLOCKS03.' - "'.$row[0].'"</h3>
<form method="post" action="modules.php">
  <div style="width: 650px;">
    <textarea id="content_text" name="content_text" rows="20" cols="80"
      style="width: 650px; height: 350px;">'.$content.'</textarea>
  </div>
  <p align="center">
    <input type="submit" class="buttonRegular" value="'._BLOCKS13.'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />&nbsp;
    <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \'modules.php?id=blocks&amp;mode=canceleditblock'.
       '&amp;blockid='.$blockid.'\'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />
  </p>
  <input type="hidden" name="id" value="blocks" />
  <input type="hidden" name="blockid" value="'.$blockid.'" />
  <input type="hidden" name="mode" value="editblockcontent" />
</form>
';
	// Add the Inline Web Editor to the page.
	$page .= core_getEditor('content_text');
	// Return the HTML for the "Edit Block Content" form.
	return $page;
}


/**
 * Display a form to change the list of pages on which $blockid will appear.
 *
 * @param  int     $blockid   ID of the block for which to display page associations
 * @access private
 * @return string HTML content of the "Edit Page Associations" form
 */
function blocks_editBlockPages($blockid)
{
	// Setup and execute the query to get the page associations for $blockid.
	$query_cmd = 'SELECT PAGEID FROM '.$GLOBALS['dbpref'].'_PAGEBLOCKS'.
				 ' WHERE '.$GLOBALS['dbpref'].'_PAGEBLOCKS.BLOCKID = '.$blockid;
	$pg_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Initialize and build a string of all page numbers assigned to $blockid.
	// String operations are significantly faster than array operations.  :)
	$pageids = '';
	while ($row = @sql_fetch_row($pg_results)) {
		// Wrap each page number with brackets, to make matching clearer.
		$pageids .= '['.$row[0].']';
	}

	// Setup and execute the query to get the syspage associations for $blockid.
	$query_cmd = 'SELECT PAGENAME FROM '.$GLOBALS['dbpref'].'_SYSBLOCKS'.
				 ' WHERE '.$GLOBALS['dbpref'].'_SYSBLOCKS.BLOCKID = '.$blockid;
	$sys_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Initialize and build a string of all syspage names assigned to $blockid.
	// String operations are significantly faster than array operations.  :)
	$sysids = '';
	while ($row = @sql_fetch_row($sys_results)) {
		// Wrap each page number with brackets, to make matching clearer.
		$sysids  .= '['.$row[0].']';
	}

	// Setup and execute the query to return the title of the $blockid.
	$query_cmd = 'SELECT TITLE FROM '.$GLOBALS['dbpref'].'_BLOCKS'.
				 ' WHERE ID = '.$blockid;
	$blk_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Grab the title and convert all WPS entities into single and double quotes.
	$row = sql_fetch_row($blk_results);
	$title = core_convertQuotes($row[0],'revert');

	// Set the HTML for the "Edit Page Associations" form.
	$page  = '
<h3 align="center">'._BLOCKS33.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="2">
      <tr>
        <td align="left">&nbsp;'._BLOCKS17.':</td>
      </tr>
      <tr>
        <td align="left">
          <select multiple="multiple" name="pagelist[]" class="textCool"';

	if ($pageids == '[0]') {
		$page .= ' disabled="disabled"';
	}
	$page .= ' width="500" style="width: 500px" size="8">';

	// Setup and execute the query to return all the page blocks.
	$query_cmd = 'SELECT ID, TITLE FROM '.$GLOBALS['dbpref'].'_PAGES ORDER BY TITLE';
	$results = sql_query($query_cmd, $GLOBALS['db_id']);
	while ($row = sql_fetch_row($results)) {
		// Add each page as a select option.
		$page .= "\r\n".'          <option value="'.$row[0].'"';
		if (strstr($pageids,'['.$row[0].']')) {
			// Since it's already assigned to this block, make it selected.
			$page .= ' selected="selected"';
		}
		$page .= '>'.$row[1].'</option>';
	}

	// Continue to set the HTML for the "Edit Page Associations" form.
	$page .= '
          </select>
        </td>
      </tr>
      <tr>
        <td align="left"><input type="checkbox" name="all_access" id="all_access"';

	if ($pageids == '[0]') {
		$page .= ' checked="checked"';
	}
	$page .= ' onclick="this.form.elements[0].disabled =';
	$page .= ' !this.form.elements[0].disabled;" /> '._BLOCKS34.'</td>
      </tr>
      <tr>
        <td>&nbsp;</td>
      </tr>
      <tr>
        <td align="left">&nbsp;'._BLOCKS35.':</td>
      </tr>
      <tr>
        <td align="left">
          <select multiple="multiple" name="syslist[]" class="textCool"';

	if ($sysids == '[all]') {
		$page .= ' disabled="disabled"';
	}
	$page .= ' width="500" style="width: 500px" size="8">';

	$syspages = explode('][',substr($GLOBALS['syspages'], 1, -1));
	// Cycle through the list of available syspages.
	foreach ($syspages as $syspage) {
		if ($syspage == 'modules.php') {
			// Setup and execute the query to return all the module names.
			$query_cmd	= 'SELECT MODNAME FROM '.$GLOBALS['dbpref'].'_MODULES'.
						 ' ORDER BY MODNAME';
			$sysresults	= sql_query($query_cmd, $GLOBALS['db_id']);
			while ($row = sql_fetch_row($sysresults)) {
				// Get the module URI.
				$uri = 'modules.php?id='.$row[0];
				// Add each page as a select option.
				$page .= "\r\n".'            <option value="'.$uri.'"';
				if (strstr($sysids,'['.$uri.']')) {
					// Since it's already assigned to this block, make it selected.
					$page .= ' selected="selected"';
				}
				$page .= '>'.$uri.'</option>';
			}
		} else {
			// Add each syspage as a select option.
			$page .= "\r\n".'            <option value="'.$syspage.'"';
			if (strstr($sysids,'['.$syspage.']')) {
				// Since it's already assigned to this block, make it selected.
				$page .= ' selected="selected"';
			}
			$page .= '>'.$syspage.'</option>';
		}
	}

	// Continue to set the HTML for the "Edit Page Associations" form.
	$page .= '
          </select>
        </td>
      </tr>
      <tr>
        <td align="left"><input type="checkbox" name="sysall_access" id="sysall_access"';

	if ($sysids == '[all]') {
		$page .= ' checked="checked"';
	}
	$page .= ' onclick="this.form.elements[2].disabled =';
	$page .= ' !this.form.elements[2].disabled;" /> '._BLOCKS36.'</td>
      </tr>
    </table>
  </div>
  <p align="center">
    <input type="submit" class="buttonRegular" value="'._BLOCKS13.'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />
    <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \''.$_SESSION['prev_page'].'\'"
       onmouseover="this.className = \'buttonRegularFocus\'"
       onmouseout="this.className = \'buttonRegular\'" />
  </p>
  <input type="hidden" name="id" value="blocks" />
  <input type="hidden" name="mode" value="editblockpages" />
  <input type="hidden" name="blockid" value="'.$blockid.'" />
</form>
';
	// Return the HTML for the "Edit Page Associations" form.
	return $page;
}

?>
