<?php
/**
 * Provides a means for managing the filesystem of a FreeWPS installation.
 * FILEMGMT.PHP offers the ability to upload and manage various files, including
 * IMAGES, TEMPLATES, and more.
 * @package Core-Modules
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | FILEMGMT.PHP                                         |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | FILEMGMT.PHP is part of FreeWPS.                     |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: filemgmt.php,v 1.11 2004/09/21 02:51:16 ytztech Exp $
//

/* ****  MODULE HEADER SECTION ENDS HERE  **** */

/* ****  MODULE INITIALIZATION SECTION BEGINS HERE  **** */

if (stristr($_SERVER['PHP_SELF'],'filemgmt.php')) {
	// To make sure no one calls this script directly, this conditional ensures
	// that the client browser is redirected to the Home Page if this script's
	// filename is found in $_SERVER['PHP_SELF'].
	header('Location: ../index.php');
	die();
}

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

if (file_exists('languages/'.$GLOBALS['freewps_language'].'/lang-filemgmt.php')) {
	/** Load the locale-specific constants for defined FreeWPS language. */
	include_once 'languages/'.$GLOBALS['freewps_language'].'/lang-filemgmt.php';
} else {
	/** Default to English (or to your native language, if not English). */
	include_once 'languages/english/lang-filemgmt.php';
}

if (core_checkUser(CONTENT_EDITORS)) {

	// Check for the existence of either GET/POST variable "mode".
	// "Mode" determines the actions taken by this module.
	if (isset($_REQUEST['mode'])) {
		// Set the mode to the requested mode.
		$mode = $_REQUEST['mode'];
	} else {
		// Set the mode to the default mode.
		$mode = 'admin';
	}

	if (isset($_REQUEST['filename'])) {
		// Set the filename to the requested urldecoded filename.
		$filename = urldecode($_REQUEST['filename']);
	}

	// Initialize the array of filenames used when multiple files are uploaded or
	// selected for copy/move/delete operations.
	$file_array = array();
	if (isset($_REQUEST['filename1'])) {
		$i = 1;
		while (isset($_REQUEST['filename'.$i])) {
			// Set the filename to the requested urldecoded filename.
			$file_array[] = urldecode($_REQUEST['filename'.$i]);
			// Goto the next filename.
			$i++;
		}
	}

	if (isset($_REQUEST['folder'])) {
		// Set the folder to the requested urldecoded folder name.
		$folder = urldecode($_REQUEST['folder']);
		if (substr($folder,-1,1) != '/') {
			$folder .= '/';
		}
		if (!stristr($folder,$site_path.'/')) {
			// Since the requested folder is outside the site path, send the user to
			// a view of the site path.  Only paths inside the FreeWPS site should be
			// manageable, for security reasons.
			Header('Location: modules.php?id=filemgmt&mode=admin');
			die();
		}
	} else {
		// Use the site path as the default starting place for all file operations.
		$folder = $site_path.'/';
	}

/* ****  MODULE INITIALIZATION SECTION ENDS HERE  **** */

/* ****  REQUEST PROCESSING SECTION BEGINS HERE  **** */

	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		/* The POST processing section... */
		switch ($mode) {
			case 'addeditable':
			case 'addviewable':
				// Determine the filetype being added.
				if ($mode == 'addeditable') {
					$type = '\'EDITABLE\'';
					$name = '\''.strtolower($_POST['editnew']).'\'';
				} else {
					$type = '\'VIEWABLE\'';
					$name = '\''.strtolower($_POST['viewnew']).'\'';
				}

				// Get the next available ID for a filetype entry.
				$new_typeid = core_getNextID($dbpref.'_FILETYPES');
				// Setup and execute the query to add the filetype.
				$query_cmd = 'INSERT INTO '.$dbpref.'_FILETYPES'.
						 	 ' VALUES ('.$new_typeid.','.$type.','.$name.')';
				sql_query($query_cmd, $db_id);

				// Go to the "Manage Known Filetypes" page.
				Header('Location: modules.php?id=filemgmt&mode=managetypes');
				// End this joyride.
				break;

			case 'changeedit':
			case 'changeview':
				// Determine the filetype being edited.
				if ($mode == 'changeedit') {
					$typeid = $_POST['editid'];
					$name = '\''.strtolower($_POST['editnew']).'\'';
				} else {
					$typeid = $_POST['viewid'];
					$name = '\''.strtolower($_POST['viewnew']).'\'';
				}

				// Setup and execute the query to change an existing filetype.
				$query_cmd = 'UPDATE '.$dbpref.'_FILETYPES SET EXTENSION = '.$name.
							 ' WHERE ID = '.$typeid;
				sql_query($query_cmd, $db_id);

				// Go to the "Manage Known Filetypes" page.
				Header('Location: modules.php?id=filemgmt&mode=managetypes');
				// End this joyride.
				break;

			case 'createfile':
				// When creating a new file...
				$fileh = fopen($folder.$filename,'w');
				fclose($fileh);
				if (!stristr(PHP_OS,'win')) {
					chmod($folder.$filename,0666);
				}

				// Go to the "File Editor" page.
				$newlocation = 'modules.php?id=filemgmt&mode=edit'.
							   '&folder='.urlencode($folder).
							   '&filename='.urlencode($filename);
				Header('Location: '.$newlocation);
				// End this joyride.
				break;

			case 'createfolder':
				// When creating a new folder...
				mkdir($folder.$filename);
				if (!stristr(PHP_OS,'win')) {
					chmod($folder.$filename,0777);
				}

				// Go to the "File Management" admin panel for the original folder.
				$newlocation = 'modules.php?id=filemgmt&mode=admin'.
							   '&folder='.urlencode($folder);
				Header('Location: '.$newlocation);
				// End this joyride.
				break;

			case 'edit':
				// When posting an edited version of a file...
				$fileh = fopen($folder.$filename,'w');
				fwrite($fileh,stripslashes($_POST['filetext']));
				fclose($fileh);

				// Go to the "File Management" admin panel for the original folder.
				$newlocation = 'modules.php?id=filemgmt&mode=admin'.
							   '&folder='.urlencode($folder);
				Header('Location: '.$newlocation);
				// End this joyride.
				break;

			case 'rename':
				// When renaming sa file...
				rename($folder.$filename,$folder.urldecode($_POST['newfilename']));

				// Go to the "File Management" admin panel for the original folder.
				$newlocation = 'modules.php?id=filemgmt&mode=admin'.
							   '&folder='.urlencode($folder);
				Header('Location: '.$newlocation);
				// End this joyride.
				break;

			default:
				// Since an invalid $mode was given, display an error page.
				Header('Location: 404.php');
				// End this joyride.
				break;
		}
		// End this script without any further processing.
		die();
	}

	/* The GET processing section... */
	switch ($mode) {
		case 'admin':
			// Get the HTML for the "File Management" admin panel.
			$pgcontent = filemgmt_admin($folder);
			// Create the page.
			core_createPage($pgcontent,'',_FILEMGMT_TITLE);
			// End this joyride.
			break;

		case 'copyfiles':
		case 'movefiles':
			for ($i = 0; $i < count($file_array); $i++) {
				// Initialize the destination filename.
				$filedest = $_GET['destfolder'].'/'.$file_array[$i];
				// Initialize the original filename.
				$fileorig = $folder.$file_array[$i];
				// Cycle through all requested file names.
				if (is_dir($fileorig)) {
					// Since this is a directory, we have to create the destination
					// if it doesn't yet exist.  Then we can copy the file/folder.
					if (!file_exists($filedest)) {
						// Make the destination folder.
						mkdir($filedest);
					}
					// Recursively copy the whole directory.
					core_copyDir($fileorig,$filedest);
					if ($mode == 'movefiles') {
						// Since we're moving this folder, recursively delete the
						// original after the copy has completed.
						core_removeDir($fileorig);
					}
				} else {
					// Since this is just a file. copy the file.
					@copy($fileorig,$filedest);
					if ($mode == 'movefiles') {
						// Since we're moving this file, delete the original.
						@unlink($fileorig);
					}
				}
			}

			// Go to the "File Management" admin panel for the original folder.
			$newlocation = 'modules.php?id=filemgmt&mode=admin'.
						   '&folder='.urlencode($folder);
			Header('Location: '.$newlocation);
			// End this joyride.
			break;

		case 'delete':
			for ($i = 0; $i < count($file_array); $i++) {
				if (is_dir($folder.$file_array[$i])) {
					// Since this is folder, recursively delete the folder.
					core_removeDir($folder.$file_array[$i]);
				} else {
					// Since this is a file, delete the file.
					unlink($folder.$file_array[$i]);
				}
			}

			// Go to the "File Management" admin panel for the original folder.
			$newlocation = 'modules.php?id=filemgmt&mode=admin'.
						   '&folder='.urlencode($folder);
			Header('Location: '.$newlocation);
			// End this joyride.
			break;

		case 'deleteedit':
		case 'deleteview':
			if ($mode = 'deleteedit') {
				$typeid = $_GET['editid'];
			} else {
				$typeid = $_GET['editid'];
			}
			$query_cmd = 'DELETE FROM '.$dbpref.'_FILETYPES WHERE ID = '.$typeid;
			sql_query($query_cmd,$db_id);

			// Go to the "Manage Known Filetypes" page.
			Header('Location: modules.php?id=filemgmt&mode=managetypes');
			// End this joyride.
			break;

		case 'edit':
			// Get the HTML for the "File Editor" page.
			$pgcontent = filemgmt_edit($folder,$filename);
			// Create the page.
			core_createPage($pgcontent,'',_FILEMGMT01);
			// End this joyride.
			break;

		case 'managetypes':
			// Get the HTML for the "Manage Editable Filetypes" page.
			$pgcontent = filemgmt_manage();
			// Create the page.
			core_createPage($pgcontent,'',_FILEMGMT02);
			// End this joyride.
			break;

		case 'popupchdir':
		case 'popupcopy':
		case 'popupmove':
			// Get the HTML/Title for the "Choose Directory" page.
			$pgcontent = filemgmt_chooseDir($folder,$file_array,$mode);
			// Create the page.
			core_createPage($pgcontent[0],'',$pgcontent[1],$template_popup);
			// End this joyride.
			break;

		case 'popupupload':
			// Get the HTML for the "Upload Files" page.
			$pgcontent = filemgmt_upload();
			// Create the page.
			core_createPage($pgcontent,'',_FILEMGMT03,$template_popup);
			// End this joyride.
			break;

		default:
			// Since an invalid $mode was given, display an error page.
			Header('Location: 404.php');
			// End this joyride.
			break;
	}
} else {
	// No valid user rights were found.
	if ($_SESSION['authorization'] == '') {
		// Since the user hasn't logged in, send them to the login page with the
		// requested URL passed as a referral URL.
		Header('Location: login.php?referer='.core_getReferer());
		die();
	} else {							//
		// Since the user is logged in, display an "Access Denied" page instead.
		core_createPage(access_denied(),'',_ACCESSDENIED);
	}
}


/**
 * Display a list of files from the server filesystem in $folder.
 *
 * @param  string  $folder   Filesystem path of folder to display
 * @access private
 * @return string HTML content of the "File Management" panel
 */
function filemgmt_admin($folder)
{
	// Initialize the list of editable filetypes.  This list is stored as a string
	// because strings are faster than array for searching operations. :)
	$text_ext = '';
	// Initialize the list of viewable filetypes.  This list is stored as a string
	// because strings are faster than array for searching operations. :)
	$img_ext = '';
	// Initialize the number of file items found.
	$totalitems = 0;

	// Setup and execute the query to get the list of editable and viewable types.
	$query_cmd = 'SELECT FILETYPE,EXTENSION FROM '.$GLOBALS['dbpref'].'_FILETYPES'.
				 ' ORDER BY FILETYPE, EXTENSION';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	while ($row = sql_fetch_row($results)) {
		if ($row[0] =='EDITABLE') {
			// Add the currently returned extension to the editable list.
			$text_ext .= '['.$row[1].']';
		} else {
			// Add the currently returned extension to the viewable list.
			$img_ext .= '['.$row[1].']';
		}
	}

	// Get the list of items in $folder.
	if ($dirh = @opendir($folder)) {
		// List of folder items from $folder.
		$dir_array = array();
		// List of file items from $folder.
		$file_array = array();
		// Get the permissions for current folder returned.
		$permissions = fileperms($folder);
		// Convert the permissions into 'rwx' format for the current folder.
		$folderperms = (($permissions & 0x0004) ? 'r' : '-').
					   (($permissions & 0x0002) ? 'w' : '-').
					   (($permissions & 0x0001) ? 'x' : '-');

		while (($item = readdir($dirh)) !== FALSE) {
			// This is a valid file item.
			if (($item == '.') || ($item == '..')) {
				// Ignore the '.' and '..' directory entries.
				continue;
			}
			// Increment the number of items returned.
			$totalitems++;
			// Get the properties of the file item.
			$stat_info = lstat($folder.$item);
			if ($stat_info['ctime'] > $stat_info['mtime']) {
				// Since the creation time is newer, display the creation date/time.
				$filedate = date('m/d/y h:i:s A',$stat_info['ctime']);
			} else {
				// Since the modified time is newer, display the modified date/time.
				$filedate = date('m/d/y h:i:s A',$stat_info['mtime']);
			}
			// Convert the permissions into 'rwx' format for the current file item.
			$fileperms = (($stat_info['mode'] & 0x0004) ? 'r' : '-').
						 (($stat_info['mode'] & 0x0002) ? 'w' : '-').
						 (($stat_info['mode'] & 0x0001) ? 'x' : '-');

			if (is_dir($folder.$item)) {
				// This file item is a folder.
				// Setup the "browse" link for the folder.
				$linkbegin = '';
				$linkend = '';
				if (stristr($fileperms,'r')) {
					$linkbegin = '<a href="modules.php?id=filemgmt&amp;mode=admin'.
								 '&amp;folder='.urlencode($folder.$item).'">';
					$linkend = '</a>';
				}
				// Add the folder item to the list of folders.  Use the filename as
				// the key to allow easier sorting.
				$dir_array[$item] = array(0 => $fileperms,
										  1 => $item,
										  2 => $linkbegin,
										  3 => $linkend,
										  4 => $filedate);
			} else {
				// Setup the "browse" link and icon file for the file.
				$linkbegin = '';
				$linkend = '';
				// All files get the "unknown" icon by default.
				$iconfile = 'unknown.png';
				// Get the file extension.
				$path_info = explode('.',$item);
				$extension = array_pop($path_info);

				if (stristr($img_ext,'['.strtolower($extension).']')) {
					$iconfile   = 'image.png';
				} elseif (stristr($text_ext,'['.strtolower($extension).']')) {
					$iconfile   = 'file.png';
					$linkbegin  = '<a href="modules.php?id=filemgmt&amp;mode=edit'.
								 '&amp;folder='.urlencode($folder).
								 '&amp;filename='.urlencode($item).'">';
					$linkend    = '</a>';
				}
				// Add the file item to the list of files.  Use the filename as the
				// key to allow easier sorting.
				$file_array[$item] = array(0 => $fileperms,
										   1 => $iconfile,
										   2 => $item,
										   3 => $linkbegin,
										   4 => $linkend,
										   5 => $stat_info['size'],
										   6 => $filedate);
			}
		}
	}

	// Sort the list of folders and files by filename.
	ksort($dir_array);
	ksort($file_array);

	// Set the HTML for the "File Management" admin panel.
	$page = '

<script type="text/javascript">
<!--

filearray = new Array('.$totalitems.');
';

	$i = 0;

	if (count($dir_array) > 0) {
		reset($dir_array);
		while ($diritem = each($dir_array)) {
			$page .= "\r\n".'filearray['.$i.'] = \''.$diritem[1][1].'\';';
			$i++;
		}
	}

	if (count($file_array) > 0) {
		reset($file_array);
		while ($fileitem = each($file_array)) {
		$page .= "\r\n".'filearray['.$i.'] = \''.$fileitem[1][2].'\';';
		$i++;
		}
	}


	$page .= '

function changeDirectory()
{
	loc = \'modules.php?id=filemgmt&mode=popupchdir&folder='.urlencode($folder).'\';
	opt = \'toolbar=no,menubar=no,personalbar=no,scrollbars=no,\'+
		  \'status=no,width=400,height=150,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
}

function checkStatus(cbox)
{
	var checkall = cbox.form.checkall;
	if (!cbox.checked && checkall.checked) {
		checkall.checked = false;
	}
	return true;
}

function deleteFile(filename)
{
	if (confirm(\''._FILEMGMT10.'\')) {
		loc = \'modules.php?id=filemgmt&mode=delete\'+
			  \'&folder='.urlencode($folder).'&filename1=\';
		location.href = loc + filename;
	}
	return true;
}

function moduleAction(element)
{
	switch (element.value) {
		case \'default\':
			alert(\''._FILEMGMT05.'\');
			break;

		case \'copy\':
		case \'move\':
			var j = 1, k = 1;
				targetURL = \'\';
			for (var i = 7; i < element.form.elements.length; i++) {
				if (element.form.elements[i].name == \'checkbox\'+j) {
					if (element.form.elements[i].checked) {
						targetURL += \'&filename\' + k + \'=\' + filearray[i-7];
						k++;
					}
					j++;
				}
			}
			loc = \'modules.php?id=filemgmt&mode=popup\' + element.value +
				  \'&folder='.urlencode($folder).'\' + targetURL;
			opt = \'toolbar=no,menubar=no,personalbar=no,scrollbars=auto,\'+
				  \'status=no,width=400,height=150,left=400,top=300\';
			open(loc, \'freewps_popup\', opt);
			break;

		case \'createfile\':
		case \'createfolder\':
			var newname = \'\';
			if (element.value == \'createfile\') {
				newname = prompt(\''._FILEMGMT06.'\',\''._FILEMGMT07.'\');
			} else {
				newname = prompt(\''._FILEMGMT08.'\',\''._FILEMGMT09.'\');
			}
			switch (newname) {
				case null:
				case \'null\':
					return false;
					break;
				case \'\':
				case \''._FILEMGMT07.'\':
				case \''._FILEMGMT09.'\':
					element.form.actionmenu.selectedIndex=0;
					element.form.actionmenu.focus();
					return false;
					break;
				default:
					element.form.filename.value = newname;
					element.form.mode.value = element.value;
					element.form.submit();
					break;
			}
			break;

		case \'deletefiles\':
			if (confirm(\''._FILEMGMT10.'\')) {
				var j = 1, k = 1;
				var targetURL = \'\';
				for (var i = 3; i < element.form.elements.length; i++) {
					if (element.form.elements[i].name == \'checkbox\'+j) {
						if (element.form.elements[i].checked) {
							targetURL += \'&filename\' + k + \'=\' + filearray[i-3];
							k++;
						}
						j++;
					}
				}
				location.href = \'modules.php?id=filemgmt&mode=delete\'+
								\'&folder='.urlencode($folder).'\' + targetURL;
			}
			break;

		case \'uploadfiles\':
			loc = \'modules.php?id=filemgmt&mode=popupupload\'+
				  \'&folder='.urlencode($folder).'\';
			opt = \'toolbar=no,menubar=no,personalbar=no,scrollbars=no,\'+
				  \'status=no,width=640,height=480,left=200,top=100\';
			open(loc, \'freewps_popup\', opt);
			break;
	}
	element.form.actionmenu.selectedIndex=0;
	return true;
}

function navAction (element)
{
	switch (element.value) {
		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;
		case \'managetypes\':
			window.location.href = \'modules.php?id=filemgmt&mode=managetypes\';
			break;
		case \'adminpanel\':
			window.location.href = \'admin.php\';
			break;
	}
	return true;
}

function fileAction(filename,action)
{
	loc = \'modules.php?id=filemgmt&mode=popup\'+action+
		  \'&folder='.urlencode($folder).'&filename1=\'+filename;
	opt = \'toolbar=no,menubar=no,personalbar=no,scrollbars=auto,\'+
		  \'status=no,width=400,height=150,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
}

function renameFile(filename)
{
	newname = prompt(\''._FILEMGMT23.'\',filename);
	switch (newname) {
		case null:
		case \'null\':
		case \'\':
		case filename:
			return false;
			break;
		default:
			document.actions.filename.value = filename;
			document.actions.newfilename.value = newname;
			document.actions.mode.value = \'rename\';
			document.actions.submit();
			break;
	}
}

function selectAll(form)
{
	var j = 1;
	for (var i = 0; i < form.elements.length; i++) {
		if (form.elements[i].name == \'checkbox\'+j) {
			form.elements[i].checked = form.checkall.checked;
			j++;
		}
	}
	return true;
}

//-->
</script>
<h3 align="center">'._FILEMGMT_TITLE.'</h3>
<form method="post" action="modules.php" name="actions">
  <div align="center">
    <select name="navmenu" onchange="navAction(this.options[this.selectedIndex])"
      class="textCool">
      <option value="default">- '._NAVIGATIONMENU.' -'.'</option>
      <option value="managetypes">'._FILEMGMT02.'</option>
      <option value="adminpanel">'._BACK2ADMIN.'</option>
    </select>
    &nbsp;
    <select name="actionmenu" class="textCool"
      onchange="moduleAction(this.options[this.selectedIndex])">
      <option value="default">- '._FILEMGMT11.' -'.'</option>
      <option value="copy">'._FILEMGMT12.'</option>
      <option value="createfile">'._FILEMGMT13.'</option>
      <option value="createfolder">'._FILEMGMT14.'</option>
      <option value="deletefiles">'._FILEMGMT15.'</option>
      <option value="move">'._FILEMGMT16.'</option>
      <option value="uploadfiles">'._FILEMGMT03.'</option>
    </select>
  </div>
  <hr class="paddedhr" />
  <div class="filemgmtLegend"><strong>'._FILEMGMT17.'</strong>&nbsp; [ ';

	if ($folder == $GLOBALS['site_path'].'/') {
		// The root of the site path should not display an "up one level" link.
		$page .= _FILEMGMT34.' ]&nbsp; [ <strong>';
		$page .= '<a href="javascript:changeDirectory();">';
		$page .= _FILEMGMT19.'</a></strong> ]</div>';
	} else {
		$encfolder = urlencode(implode('/',array_slice(explode('/', $folder),0,-2)));
		$page .= '<strong><a href="modules.php?id=filemgmt&amp;mode=admin';
		$page .= '&amp;folder='.$encfolder.'">';
		$page .= _FILEMGMT18.'</a></strong> ]&nbsp; [ <strong>';
		$page .= '<a href="javascript:changeDirectory();">';
		$page .= _FILEMGMT19.'</a></strong> ]</div>';
	}

	if (isset($dir_array)) {
		$page .= '
    <div class="filemgmtLegend">
      <input name="checkall" type="checkbox" id="checkall"
       onclick="selectAll(this.form);" />&nbsp; <strong>Select All Files</strong>
    </div>
    <div align="center">
      <table align="center" border="0" cellpadding="0" cellspacing="0" class="filemgmtTable">
        <tr>
          <td align="left" colspan="5" nowrap="nowrap" class="filemgmtStatusLeft">
            '._FILEMGMT20.'&nbsp; <em>'.htmlspecialchars($folder).'</em></td>
          <td align="right" colspan="5" nowrap="nowrap" class="filemgmtStatusRight">
            '._FILEMGMT21.'&nbsp; <em>'.$folderperms.'</em></td>
        </tr>
        <tr>
          <td align="center" class="filemgmtHeaderRow">
            <strong>'._FILEMGMT24.'</strong></td>
          <td align="center" class="filemgmtHeaderRow">-</td>
          <td align="center" class="filemgmtHeaderRow">
            <strong>'._FILEMGMT25.'</strong></td>
          <td align="center" class="filemgmtHeaderRow">
            <strong>'._FILEMGMT26.'</strong></td>
          <td align="center" class="filemgmtHeaderRow">
            <strong>'._FILEMGMT27.'</strong></td>
          <td align="center" class="filemgmtHeaderRow" colspan="5">
            <strong>'._FILEMGMT28.'</strong></td>
        </tr>';

		if ((count($dir_array) > 0) || (count($file_array) > 0)) {
			$returned = 0;
			reset($dir_array);
			while ($diritem = each($dir_array)) {
				$returned++;
				$hilite = $returned % 2;
				// Continue to set the HTML for the "File Management" admin panel.
				$page .= '
        <tr class="filemgmtItemRow'.$hilite.'">
          <td align="center" nowrap="nowrap" class="filemgmtPerms'.$hilite.'">
            '.$diritem[1][0].'</td>
          <td align="center" nowrap="nowrap" class="filemgmtBoxes'.$hilite.'">
            <input name="checkbox'.$returned.'" type="checkbox"
              onclick="checkStatus(this);" /></td>
          <td align="left" nowrap="nowrap" class="filemgmtName'.$hilite.'">
            '.$diritem[1][2].'<img src="modules/filemgmt/folder.png" width="24"
            height="24" border="0" alt="'.$diritem[1][1].'" align="absmiddle"
            />'.$diritem[1][3].'&nbsp; '.$diritem[1][2].$diritem[1][1].
            $diritem[1][3].'</td>
          <td align="right" nowrap="nowrap" class="filemgmtSize'.$hilite.'">
            &lt;folder&gt;</td>
          <td align="right" nowrap="nowrap" class="filemgmtDatetime'.$hilite.'">
            '.$diritem[1][4].'</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">
            '.$diritem[1][2]._FILEMGMT36.$diritem[1][3].'</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($diritem[1][0],'w')) {
					$page .= '<a href="javascript:renameFile(\''.$diritem[1][1];
					$page .= '\')">'._FILEMGMT30.'</a>';
				} else {
					$page .= _FILEMGMT30;
				}

			$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($diritem[1][0],'r')) {
					$page .= '<a href="javascript:fileAction(\'';
					$page .= urlencode($diritem[1][1]).'\',\'copy\')">';
					$page .= _FILEMGMT31.'</a>';
				} else {
					$page .= _FILEMGMT31;
				}

				$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($diritem[1][0],'rw')) {
					$page .= '<a href="javascript:fileAction(\'';
					$page .= urlencode($diritem[1][1]).'\',\'move\')">'._FILEMGMT32;
					$page .= '</a>';
				} else {
					$page .= _FILEMGMT32;
				}

				$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($diritem[1][0],'w')) {
					$page .= '<a href="javascript:deleteFile(\'';
					$page .= $diritem[1][1].'\')">'._FILEMGMT33.'</a>';
				} else {
					$page .= _FILEMGMT33;
				}
				$page .= '</td>
        </tr>';
			}

			// Walk through the list of file items from the beginning.
			reset($file_array);
			while ($fileitem = each($file_array)) {
				$returned++;
				$hilite = $returned % 2;
				$page .= '
        <tr class="filemgmtItemRow'.$hilite.'">
          <td align="center" nowrap="nowrap" class="filemgmtPerms'.$hilite.'">
            '.$fileitem[1][0].'</td>
          <td align="center" nowrap="nowrap" class="filemgmtBoxes'.$hilite.'">
            <input name="checkbox'.$returned.'" type="checkbox"
             onclick="checkStatus(this);" /></td>
          <td align="left" nowrap="nowrap" class="filemgmtName'.$hilite.'">
            '.$fileitem[1][3].'<img src="modules/filemgmt/'.$fileitem[1][1].'"
            width="24" height="24" border="0" alt="'.$fileitem[1][2].'"
            align="absmiddle" />'.$fileitem[1][4].'&nbsp; '.$fileitem[1][3].
            $fileitem[1][2].$fileitem[1][4].'</td>
          <td align="right" nowrap="nowrap" class="filemgmtSize'.$hilite.'">'.
            $fileitem[1][5].'</td>
          <td align="right" nowrap="nowrap" class="filemgmtDatetime'.$hilite.'">'.
            $fileitem[1][6].'</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				switch ($fileitem[1][1]) {
					case 'file.png':
						$page .= '<a href="modules.php?id=filemgmt&amp;mode=edit';
						$page .= '&amp;folder='.urlencode($folder).'&amp;filename=';
						$page .= urlencode($fileitem[1][2]).'">'._FILEMGMT35;
						$page .= '</a></td>';
						break;
					case 'image.png':
						$urlpath = substr($folder,strlen($GLOBALS['site_path'])+1);
						$page .= '<a href="'.$GLOBALS['site_url'].$urlpath;
						$page .= $fileitem[1][2].'" target="_blank">'._FILEMGMT29;
						$page .= '</a></td>';
						break;
					default:
						$page .= '&nbsp; '._FILEMGMT37.'&nbsp; </td>';
						break;
				}

				$page .= '
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($fileitem[1][0],'w')) {
					$page .= '<a href="javascript:renameFile(\''.$fileitem[1][2];
					$page .= '\')">'._FILEMGMT30.'</a>';
				} else {
					$page .= _FILEMGMT30;
				}
				$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($fileitem[1][0],'r')) {
					$page .= '<a href="javascript:fileAction(\'';
					$page .= urlencode($fileitem[1][2]).'\',\'copy\')">';
					$page .= _FILEMGMT31.'</a>';
				} else {
					$page .= _FILEMGMT31;
				}
				$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($fileitem[1][0],'w')) {
					$page .= '<a href="javascript:fileAction(\'';
					$page .= urlencode($fileitem[1][2]).'\',\'move\')">';
					$page .= _FILEMGMT32.'</a>';
				} else {
					$page .= _FILEMGMT32;
				}
				$page .= '</td>
          <td align="center" nowrap="nowrap" class="filemgmtAction'.$hilite.'">';

				if (stristr($fileitem[1][0],'w')) {
					$page .= '<a href="javascript:deleteFile(\''.$fileitem[1][2];
					$page .= '\')">'._FILEMGMT33.'</a>';
				} else {
					$page .= _FILEMGMT33;
				}
				$page .= '</td>
        </tr>';
			}
		} else {
			// No files were found.
			$page .= '
    <tr>
      <td align="left" colspan="10" class="filemgmtAction0">
        <blockquote>No files found.</blockquote>
      </td>
    </tr>';

		}
		$page .= '
  </table>
</div>';
	} else {
		$page .= '
  <h3>"'.$folder.'" is not accessible.<br />
      Click "Change Directory" to try another folder.</h3>
';
	}
	$page .= '
    <input type="hidden" name="id" value="filemgmt" />
    <input type="hidden" name="mode" value="" />
    <input type="hidden" name="filename" value="" />
    <input type="hidden" name="newfilename" value="" />
    <input type="hidden" name="folder" value="'.urlencode($folder).'" />
</form>
';
	// Return the HTML for the "File Management" admin panel.
	return $page;
}


/**
 * Display a popup window to let the end user choose a folder for copying or moving
 * files/folders (just or changing directories).
 *
 * @param  string  $folder   Filesystem path of folder to display
 * @param  array   $files    Array of files to process after form submission
 * @param  string  $mode     Operational mode to perform on the selected files
 * @access private
 * @return string HTML content of the "Choose a Folder" form
 */
function filemgmt_chooseDir($folder,$files,$mode)
{
	// Initialize the list of directories from which to choose.
	$dir_array = core_listDir($GLOBALS['site_path'].'/');

	// Initialize the URLencoded string of filenames to process.
	$filelist = '';
	if (count($files) > 0) {
		for ($i = 1; $i < count($files)+1; $i++) {
			$filelist .= '&filename'.$i.'='.urlencode($files[$i-1]);
		}
	}

	// Set the HTML for the "Choose a Folder" form.
	$page = '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--

centerPopupWin();

function makeSelection(select)
{
	if (select.options[select.selectedIndex].value != \''.$folder.'\') {
		window.opener.location.href = \'modules.php?id=filemgmt&mode=';

	// Setup the opener location based on the $mode.
	switch ($mode) {
		case 'popupchdir':
			$page .= 'admin&folder=\'+escape(';
			$page .= 'select.options[select.selectedIndex].value);';
			break;
		case 'popupcopy':
			$page .= 'copyfiles&folder='.urlencode($folder);
			$page .= '&destfolder=\'+escape(select.options[';
			$page .= 'select.selectedIndex].value)+\''.$filelist.'\';';
			break;
		case 'popupmove':
			$page .= 'movefiles&folder='.urlencode($folder);
			$page .= '&destfolder=\'+escape(select.options[';
			$page .= 'select.selectedIndex].value)+\''.$filelist.'\';';
			break;
	}

	$page .= '
	}
	self.close();
}

//-->
</script><h3 align="center">'._FILEMGMT47.'</h3>
<form method="get" action="modules.php">
  <div align="center">
    <select name="dirchoice" style="font-family: Courier New, Courier">
      <option value="/">/ (Site Path)</option>';

	for ($i = 0; $i < count($dir_array); $i++) {
		// For each available subfolder, add a select-option.
		$page .= "\r\n      <option ";
		if ($folder == $dir_array[$i][0].'/') {
			// If this folder matches the current folder, select it.
			$page .= 'selected="selected" ';
		}
		$page .= 'value="'.$dir_array[$i][0].'">'.$dir_array[$i][1].'</option>';
	}

	$page .= '
    </select>
  </div>
  <div align="center">
    <input type="button" name="choosedir" value="'._FILEMGMT48.'"
      onclick="makeSelection(this.form.dirchoice);" />
  </div>
</form>
';

	// Configure the title to return based on the selected $mode.
	switch ($mode) {
		case 'popupchdir':
			$title = _FILEMGMT19;
			break;
		case 'popupcopy':
			$title = _FILEMGMT31;
			break;
		case 'popupmove':
			$title = _FILEMGMT32;
			break;
	}

	// Return the HTML for the "Choose a Folder" form.
	return array(0 => $page, 1 => $title);

}



/**
 * Display a form to edit the text of an existing file.
 *
 * @param  string  $folder      Filesystem path of folder to display
 * @param  string  $filename    Filename to edit
 * @access private
 * @return string HTML content of the "Edit File" form
 */
function filemgmt_edit($folder, $filename)
{
	// Set the HTML for the "Edit File" form.
	$page = '
<h3 align="center">'._FILEMGMT01.' - &quot;'.$filename.'&quot;</h3>
<div align="center">'._FILEMGMT44.'&nbsp; <em>'.$folder.$filename.'</em></div>
<form method="post" action="modules.php">
  <div align="center">
    <textarea class="filemgmtEditor" name="filetext" rows="60" cols="80"
     style="width: 640px; height: 480px; white-space:pre;"
     onfocus="this.className=\'filemgmtEditorFocus\'"
     onblur="this.className=\'filemgmtEditor\'">'.
     file_get_contents($folder.$filename).'</textarea>
  </div>
  <div align="center">
    <input type="submit" class="buttonRegular" value="'._FILEMGMT45.'"
     onMouseMove="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />&nbsp;
    <input type="button" class="buttonRegular" value="'._CANCEL.'"
     onclick="location.href = \'modules.php?id=filemgmt&amp;mode=admin&amp;folder='.urlencode($folder).'\'"
     onMouseMove="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />
  </div>
  <input type="hidden" name="id" value="filemgmt" />
  <input type="hidden" name="mode" value="edit" />
  <input type="hidden" name="filename" value="'.urlencode($filename).'" />
  <input type="hidden" name="folder" value="'.urlencode($folder).'" />
</form>
';
	// Return the HTML for the "Edit File" form.
	return $page;
}


/**
 * Display a form to make changes to the lists of known filetypes.
 *
 * @access private
 * @return string HTML content of the "Manage Known Filetypes" form
 */
function filemgmt_manage()
{
	// Set the HTML for the "Manage Known Filetypes" form.
	$page = '
<script type="text/javascript">
<!--

function navAction (element) {

	function checkOther (optarray,matchvalue) {
		for (var i = 0; i < optarray.length; i++) {
			if (optarray[i].text == matchvalue) {
				return false;
			}
		}
		return true;
	}

	var form      = element.form;
		editarray = form.editid.options;
		viewarray = form.viewid.options;

	switch (element.value) {
		case \'addedittype\':
			form.editnew.value = prompt(\''._FILEMGMT38.'\',\'\');
			switch (form.editnew.value) {
				case null:
				case \'null\':
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
				case \'\':
					alert(\''._FILEMGMT39.'\');
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
				default:
					if (checkOther(editarray,form.editnew.value)) {
						if (checkOther(viewarray,form.editnew.value)) {
							form.mode.value = \'addeditable\';
							form.submit();
						} else {
							alert(\''._FILEMGMT40.'\');
						}
					} else {
						alert(\''._FILEMGMT41.'\');
					}
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
			}
			break;

		case \'addviewtype\':
			form.viewnew.value = prompt(\''._FILEMGMT43.'\',\'\');
			switch (form.viewnew.value) {
				case null:
				case \'null\':
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
				case \'\':
					alert(\''._FILEMGMT39.'\');
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
				default:
					if (checkOther(viewarray,form.editnew.value)) {
						if (checkOther(editarray,form.viewnew.value)) {
							form.mode.value = \'addviewable\';
							form.submit();
						} else {
							alert(\''._FILEMGMT41.'\');
						}
					} else {
						alert(\''._FILEMGMT40.'\');
					}
					form.actionlist.selectedIndex=0;
					form.actionlist.focus();
					return false;
					break;
			}
			break;

		case \'admin\':
			location.href = \'modules.php?id=filemgmt&mode=admin\';
			break;

		case \'adminpanel\':
			location.href = \'admin.php\';
			break;

		default:
			alert(\''._NAVIGATIONERROR.'\');
			break;
	}
	return true;
}


function moduleAction (element)
{
	var selIndex = \'\';
		selExt = \'\';
		form = element.form;

	switch (element.name) {
		case \'changeedit\':
			selIndex = form.editid.options[form.editid.selectedIndex].value;
			selExt = form.editid.options[form.editid.selectedIndex].text;
			form.editnew.value = prompt(\''._FILEMGMT42.'\', selExt);

			switch (form.editnew.value) {
				case null:
				case \'null\':
					form.editid.focus();
					return false;
					// End this joyride.
					break;
				case \'\':
					alert(\''._FILEMGMT39.'\');
					form.editid.focus();
					return false;
					// End this joyride.
					break;
				default:
					if (form.editnew.value != selExt) {
						form.mode.value = \'changeedit\';
						form.submit();
					} else {
						form.editid.focus();
						return false;
					}
					// End this joyride.
					break;
			}
			break;

		case \'changeview\':
			selIndex = form.viewid.options[form.viewid.selectedIndex].value;
			selExt = form.viewid.options[form.viewid.selectedIndex].text;
			form.viewnew.value = prompt(\''._FILEMGMT42.'\', selExt);

			switch (form.viewnew.value) {
				case null:
				case \'null\':
					form.viewid.focus();
					return false;
					// End this joyride.
					break;
				case \'\':
					alert(\''._FILEMGMT39.'\');
					form.viewid.focus();
					return false;
					// End this joyride.
					break;
				default:
					if (form.viewnew.value != selExt) {
						form.mode.value = \'changeview\';
						form.submit();
					} else {
						form.viewid.focus();
						return false;
					}
					// End this joyride.
					break;
			}
			break;


		case \'deleteedit\':
			selIndex = form.editid.options[form.editid.selectedIndex].value;
			selExt = form.editid.options[form.editid.selectedIndex].text;
			if (confirm(\''.
			    str_replace('<!--FILENAME-->','\'+selExt+\'',_FILEMGMT22).'\')) {
				location.href = \'modules.php?id=filemgmt&mode=deleteedit&editid=\'+
				                selIndex;
			}
			break;

		case \'deleteview\':
			selIndex = form.viewid.options[form.viewid.selectedIndex].value;
			selExt = form.viewid.options[form.viewid.selectedIndex].text;
			if (confirm(\''.
			    str_replace('<!--FILENAME-->','\'+selExt+\'',_FILEMGMT22).'\')) {
				location.href = \'modules.php?id=filemgmt&mode=deleteview&viewid=\'+
				                selIndex;
			}
			break;
	}
	return true;
}

//-->
</script>
<h3 align="center">'._FILEMGMT02.'</h3>
<form method="post" action="modules.php" name="actions">
  <table class="tableNavigation">
    <tr>
      <td align="center">
        <select class="textCool" name="actionlist"
         onchange="navAction(this.options[this.selectedIndex])">
          <option value="default">- '._NAVIGATIONMENU.' -</option>
          <option value="addedittype">'._FILEMGMT51.'</option>
          <option value="addviewtype">'._FILEMGMT52.'</option>
          <option value="admin">'._FILEMGMT58.'</option>
          <option value="adminpanel">'._BACK2ADMIN.'</option>
        </select>
      </td>
    </tr>
  </table>
  <hr class="paddedhr" />';

	// Setup and execute the query to get total number of filetypes for the File
	// Management display.
	$query_cmd = 'SELECT ID FROM '.$GLOBALS['dbpref'].'_FILETYPES';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the total returned filetypes.
	$returned = sql_num_rows($results,$GLOBALS['dbpref'].'_FILETYPES');
	// Release the query results.
	sql_free_result($results);

	if ($returned > 0) {
		// Continue to set the HTML for the "Manage Known Filetypes" form.
		$page .= '
  <div align="center">
    <h4>'._FILEMGMT53.'&nbsp;
      <select class="textCool" name="editid">';

		// Setup and execute the query to get the "editable" filetypes for the File
		// Management display.
		$query_cmd = 'SELECT ID,EXTENSION FROM '.$GLOBALS['dbpref'].'_FILETYPES'.
					 ' WHERE FILETYPE = \'EDITABLE\' ORDER BY EXTENSION';
		$results = sql_query($query_cmd,$GLOBALS['db_id']);

		while ($row = sql_fetch_row($results)) {
			// Add each filetype to the list of select options.
			$page .= '
        <option value="'.$row[0].'">'.$row[1].'</option>';
		}

		// Release the query results.
		sql_free_result($results);

		// Continue to set the HTML for the "Manage Known Filetypes" form.
		$page .= '
      </select>
    </h4>
    <input type="button" class="buttonRegular" name="changeedit"
     value="'._FILEMGMT54.'" onclick="moduleAction(this);"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />
    <br style="padding: 0px; margin: 0px; margin-bottom: 3px;" />
    <input type="button" class="buttonRegular" name="deleteedit"
     value="'._FILEMGMT55.'" onclick="moduleAction(this);"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" /><br />&nbsp;
  </div>
  <div align="center">
    <h4>'._FILEMGMT56.'&nbsp;
    <select class="textCool" name="viewid">';

		// Setup and execute the query to get the "viewable" filetypes for the File
		// Management display.
		$query_cmd = 'SELECT ID,EXTENSION FROM '.$GLOBALS['dbpref'].'_FILETYPES'.
					 ' WHERE FILETYPE = \'VIEWABLE\' ORDER BY EXTENSION';
		$results = sql_query($query_cmd,$GLOBALS['db_id']);

		while ($row = sql_fetch_row($results)) {
			// Add each filetype to the list of select options.
			$page .= '
        <option value="'.$row[0].'">'.$row[1].'</option>';
		}

		// Continue to set the HTML for the "Manage Known Filetypes" form.
		$page .= '
      </select>
    </h4>
    <input type="button" class="buttonRegular" name="changeedit"
     value="'._FILEMGMT54.'" onclick="moduleAction(this);"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />
    <br style="padding: 0px; margin: 0px; margin-bottom: 3px;" />
    <input type="button" class="buttonRegular" name="deleteedit"
     value="'._FILEMGMT55.'" onclick="moduleAction(this);"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />
  </div>';
	} else {
		// Since no filetypes exist, show an error message
		$page .= '
  <h4 align="center">'._FILEMGMT57.'</h4>';
	}

	// Continue to set the HTML for the "Manage Known Filetypes" form.
	$page .= '
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="filemgmt" />
  <input type="hidden" name="viewnew" value="" />
  <input type="hidden" name="editnew" value="" />
</form>
';
	// Return the HTML for the "Manage Known Filetypes" form.
	return $page;
}


/**
 * Display a popup window with the JUpload applet to allow multiple file uploads.
 *
 * @access private
 * @return string HTML content of the "Upload Files" popup window
 */
function filemgmt_upload()
{
	// Set the HTML for the "Upload Files" popup window.
	$page = '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--

centerPopupWin();

--></script>

<h3 align="center">'._FILEMGMT03.'</h3>
<p>&nbsp;<strong>'._FILEMGMT20.'</strong>&nbsp; <em>'.$GLOBALS['site_path'].'/upload/</em></p>
<div align="center">
  <applet archive  = "'.$GLOBALS['site_url'].'modules/filemgmt/jupload.jar"
		  codebase = "."
		  code     = "wjhk.jupload.JUploadApplet"
		  name     = "JUploadApplet"
		  width    = "550"
		  height   = "300"
		  hspace   = "0"
		  vspace   = "0"
		  align    = "top">
    <param name="posturl" value="'.$GLOBALS['site_url'].'upload.php" />
  </applet>
</div>
<form method="get" action="modules.php">
  <p align="center">
    <strong><a href="http://www.php.net/manual/en/configuration.directives.php'.
    '#ini.upload-max-filesize" target="_blank">'.
    str_replace('<!--FILESIZE-->',ini_get('upload_max_filesize'),_FILEMGMT59).
    '</a></strong>&nbsp; &nbsp; &nbsp; <input type="button" name="closethis" '.
    'value="'._FILEMGMT49.'" onclick="window.opener.location.href=\'modules.php'.
    '?id=filemgmt&amp;mode=admin&amp;folder='.
    urlencode($GLOBALS['site_path'].'/upload/').'\'; self.close();" />
  </p>
</form>
<p align="center">('._FILEMGMT50.'&nbsp; '._FILEMGMT46.')</p>
';
	// Return the HTML for the "Upload Files" popup window.
	return $page;
}

?>