<?php
/**
 * Offers administration for the "pages" rendered by FreeWPS.
 * Web "pages", as defined for use in context of the operation of FreeWPS, are
 * dynamically created using an HTML template and filling in certain "tags"
 * throughout the template to display a page with dynamic content and a uniform look
 * and feel.
 * @package Core-Modules
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | PAGES.PHP                                            |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | PAGES.PHP is part of FreeWPS.                        |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: pages.php,v 1.17 2005/05/29 16:38:41 ytztech Exp $
//

/* ****  MODULE HEADER SECTION ENDS HERE  **** */

/* ****  MODULE INITIALIZATION SECTION BEGINS HERE  **** */

if (stristr($_SERVER['PHP_SELF'],'pages.php')) {
	// To make sure no one calls this script directly, this conditional ensures
	// that the client browser is redirected to the Home Page if this script's
	// filename is found in $_SERVER['PHP_SELF'].
	header('Location: ../index.php');
	die();
}

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

if (file_exists('languages/'.$GLOBALS['freewps_language'].'/lang-pages.php')) {
	/** Load the locale-specific constants for defined FreeWPS language. */
	include_once 'languages/'.$GLOBALS['freewps_language'].'/lang-pages.php';
} else {
	/** Default to English (or to your native language, if not English). */
	include_once 'languages/english/lang-pages.php';
}

// Determine whether the user has sufficient rights to access this module.  These
// global variables ($is_author,$is_editor) are reused throughout the module to
// present different views to each user.

$is_author = core_checkUser(CONTENT_AUTHORS);
$is_editor = core_checkUser(CONTENT_EDITORS);

if ($is_author || $is_editor) {
	// Get the current time for use in the various sections of the script.
	$currenttime = time();
	// Check for the existence of either GET/POST variable "mode".
	// "Mode" determines the actions taken by this module.
	if (isset($_REQUEST['mode'])) {
		// Set the mode to the requested mode.
		$mode = $_REQUEST['mode'];
	} else {
		// Set the mode to the default mode.
		$mode = 'admin';
	}
	// Check for the existence of either GET/POST variable "sort".
	// "Sort" determines the manner in which items are displayed on
	// a page.
	if (isset($_REQUEST['sort'])) {
		// Set the sort to the requested sort.
		$sort = $_REQUEST['sort'];
	} else {
		// Set the sort to the default sort.
		$sort = 'title';
	}
	// Check for the existence of either GET/POST variable "owner".
	// "Owner" value denotes editorial autonomy for authors of the
	// requested page.  When no ownership exists, the "owner" variable
	// should be set to 0, or "system owned".
	if (isset($_REQUEST['owner'])) {
		// Set the owner to the requested owner.
		$owner = $_REQUEST['owner'];
	} else {
		// Set the owner to the default owner.
		$owner = 0;
	}
	// Check for the existence of either GET/POST variable "groupslist".
	// "Groupslist" is an array of group permissions.
	if (isset($_REQUEST['groupslist'])) {
		// Set the groupslist to the requested groupslist.
		$groupslist = $_REQUEST['groupslist'];
	} else {
		// Set the groupslist to the default groupslist.
		$groupslist = EVERYONE_GROUP;
	}
	// Check for the existence of either GET/POST variable "catlist".
	// "Catlist" is an list of category numbers (in string form).
	if (isset($_REQUEST['catlist'])) {
		// Set the catlist to the requested catlist.
		$catlist = $_REQUEST['catlist'];
	} else {
		// Set the catlist to the default catlist.
		$catlist = '0';
	}
	// Check for the existence of either GET/POST variable "catid".
	// "Catid" is a single number representing a page category.
	if (isset($_REQUEST['catid'])) {
		// Set the catid to the requested catid.
		$catid = $_REQUEST['catid'];
		// Determine whether a page is changing categories
		if (stristr($catid,':')) {
			$temp = explode(':',$catid);
			$catid = $temp[0];
			$newcatid = $temp[1];
		}
	} else {
		// Set the catid to the default catid.
		$catid = 0;
	}
	// Check for the existence of either GET/POST variable "linkid".
	// "Linkid" is a single number representing a related link for a page.
	if (isset($_REQUEST['linkid'])) {
		// Set the linkid to the requested linkid.
		$linkid = $_REQUEST['linkid'];
	} else {
		// Set the linkid to the default linkid.
		$linkid = 0;
	}
	// Check for the existence of either GET/POST variable "pageids".
	// "Pageids" is a list of user ids (in string form).
	if (isset($_REQUEST['pageids'])) {
		// Set the pageids to the requested pageids.
		$pageids = $_REQUEST['pageids'];
	} else {
		// Set the pageids to the default pageids.
		$pageids = '';
	}
	// Check for the existence of either GET/POST variable "userids".
	// "Userids" is a list of user ids (in string form).
	if (isset($_REQUEST['userids'])) {
		// Set the userids to the requested userids.
		$userids = $_REQUEST['userids'];
	} else {
		// Set the userids to the default userids.
		$userids = '';
	}
	// Check for the existence of either GET/POST variable "pageid".
	// "Pageid" is a single number representing a page.
	if (isset($_REQUEST['pageid'])) {
		// Set the pageid to the requested page.
		$pageid = $_REQUEST['pageid'];
		if ($_SERVER['REQUEST_METHOD'] == 'GET') {
			// When requesting a GET, a lock must be granted to the page.
			$pagelock = core_checkLock($dbpref.'_PAGES',$pageid);
			if ($pagelock != 'GRANTED') {
				// Since a lock was not granted, create the page.
				core_createPage($pagelock,'',_RECORDLOCKED);
				die();
			}
		}
	}
	// Check for the existence of either GET/POST variable "pg_name".
	// "Pg_name" is a simple word or phrase representing a page.
	if (isset($_REQUEST['pg_name'])) {
		// Set the pagename to the requested pg_name.
		$pagename = $_REQUEST['pg_name'];
	}
	// Check for the existence of either GET/POST variable "contentid".
	// "Contentid" is a single number representing a content section.
	if (isset($_REQUEST['contentid'])) {
		// Set the contentid to the requested contentid.
		$contentid = $_REQUEST['contentid'];
	}
	// Check for the existence of either GET/POST variable "sect_name".
	// "Sect_name" is a simple word or phrase representing a page section.
	if (isset($_REQUEST['sect_name'])) {
		// Set the pagename to the requested pg_name.
		$sectname = $_REQUEST['sect_name'];
	}
	// Check for the existence of either GET/POST variable "content_text".
	// "Content_text" is the text representing a content section.
	// "Content_text" generally needs to be cleaned before storing in an SQL RDBMS.
	if (isset($_REQUEST['content_text'])) {
		// Strip slashes in the page content and convert the quotes.
		$content_text = core_convertQuotes(stripslashes($_REQUEST['content_text']));
		// Remove all instances of the INCLUDES url from the page content.
		$content_text = str_replace($site_url.'includes/','',$content_text);
	}
	// Check for the existence of either GET/POST variable "content_title".
	// "Content_title" is the title representing a content section.
	// "Content_title" generally needs to be cleaned before storing in an SQL RDBMS.
	if (isset($_POST['content_title'])) {
		// Converts quotes in the content_title (for SQL syntax purposes).
		$content_title = core_convertQuotes($_POST['content_title']);
	} else {
		// Makeup a title for the new content section.
		$content_title = 'New Content';
	}
	// Initialize the $location variable for adding the appropriate catid
	// to the potential redirection URLs.
	$location = '';
	if ($catid != 0) {
		// Since the page category isn't the default, specify the page category.
		$location = '&catid='.$catid;
	}
	if ($sort != 'title') {
		// Since the sorting type isn't default, specify the sorting type.
		$location .= '&sort='.$_REQUEST['sort'];
	}
	if (isset($_REQUEST['dir'])) {
		// Since a direction is specified, include the sorting direction.
		$location .= ($_REQUEST['dir'] == 'DESC') ? '&dir=desc' : '';
	}

/* ****  MODULE INITIALIZATION SECTION ENDS HERE  **** */

/* ****  REQUEST PROCESSING SECTION BEGINS HERE  **** */

	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		/* The POST processing section... */
		switch ($mode) {
			case 'addcategory':
				// Get the next available category id.
				$category_nextid = core_getNextID($dbpref.'_PAGECATS');
				// Convert quotes in the category name (for SQL syntax purposes).
				$category_name = core_convertQuotes($_POST['categoryNew']);
				// Setup and execute the query to add the new category.
				$query_cmd = 'INSERT INTO '.$dbpref.'_PAGECATS'.
							 ' VALUES ('.$category_nextid.', '.
							 		'\''.$category_name.'\', '.
							 			 $owner.')';
				sql_query($query_cmd, $db_id);

				// Return to the "Edit Page Categories" form.
				header('Location: modules.php?id=pages&mode=adminpagecats');
				// End this joyride.
				break;

			case 'editcategory':
				// Convert quotes in the category name (for SQL syntax purposes).
				$category_name = core_convertQuotes($_POST['categoryEdit']);
				// Setup and execute the query to update the category name.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGECATS'.
							 ' SET CATNAME=\''.$category_name.'\''.
							 ' WHERE ID='.$catid;
				sql_query($query_cmd, $db_id);

				// Return to the "Edit Page Categories" form.
				header('Location: modules.php?id=pages&mode=adminpagecats');
				// End this joyride.
				break;

			case 'addcontent':
				// Setup and execute the query to get the next content precedence for
				// the page in question.
				$query_pt1 = 'SELECT ID FROM ';
				$query_pt2 = $dbpref.'_CONTENT WHERE PAGEID='.$pageid;
				$query_pt3 = ' ORDER BY ID';
				$results = sql_query($query_pt1.$query_pt2.$query_pt3,$db_id);
				$new_prec = sql_num_rows($results,$query_pt2);

				// Get the next available content_id.
				$newid = core_getNextID($dbpref.'_CONTENT');

				// Setup and execute the query to insert the page content.
				$query_cmd = 'INSERT INTO '.$dbpref.'_CONTENT'.
							 ' VALUES ('.$newid.', '.
									   "'$content_title', ".
									   "'<p>&nbsp;</p>', ".
									     $pageid.', '.
									     $currenttime.', '.
									     $new_prec.', '.
									     "'n', ".
									     "'n', ".
									     "'n', ".
									     "'')";
				sql_query($query_cmd, $db_id);

				// Setup and execute the query to update the pagedate for $pageid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES SET PAGEDATE='.$currenttime.
							 ' WHERE ID='.$pageid;
				sql_query($query_cmd,$db_id);

				// Redirect the user to the "Edit Page Content" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=editcontent&contentid='.$newid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'deletecontent':
				// Setup and execute the query to delete the page content.
				$query_cmd = 'DELETE FROM '.$dbpref.'_CONTENT WHERE ID='.$contentid;
				sql_query($query_cmd,$db_id);

				// Setup and execute the query to get the list of "content" sections
				// for $pageid.
				$query_pt1 = 'SELECT ID,PRECEDENCE FROM ';
				$query_pt2 = $dbpref.'_CONTENT WHERE PAGEID='.$pageid.
							 ' AND PRECEDENCE > '.$_POST['precedence'];
				$query_pt3 = ' ORDER BY ID';
				$results = sql_query($query_pt1.$query_pt2.$query_pt3,$db_id);

				// Determine the number of rows returned.
				$contents = sql_num_rows($results,$query_pt2);

				if ($contents > 0) {
					// Since some content sections already exist, fix the precedence
					// of the sections below the one deleted.
					while ($row = sql_fetch_row($results)) {
						// Set the new "precedence" to be less than the existing
						// precedence.
						$new_prec = $row[1] - 1;

						// Setup and execute the query to update the value for the
						// "precedence" of the current "content" section to the new
						// "precedence" value.
						$query_cmd = 'UPDATE '.$dbpref.'_CONTENT'.
									 ' SET PRECEDENCE='.$new_prec.
									 ' WHERE ID='.$row[0];
						sql_query($query_cmd,$db_id);
					}
				}

				// Redirect the user to the "Edit Page Content" page.
				$newloc = 'modules.php?id=pages&mode=admincontent&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'editcontent':
				// Setup and execute the query to update the page content.
				$query_cmd = 'UPDATE '.$dbpref.'_CONTENT'.
							 ' SET CONTENT = \''.$content_text.'\', '.
								  'CONTENTDATE = '.$currenttime.
							 ' WHERE ID = '.$contentid;
				sql_query($query_cmd, $db_id);

				// Setup and execute the query to update the pagedate and remove the
				// lock for $pageid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 ' SET PAGEDATE = '.$currenttime.', '.
								  "LOCKSET = 'n', ".
								  "LOCKUSER = 'n/a', ".
								  'LOCKTIME = 0'.
							 ' WHERE ID='.$pageid;
				sql_query($query_cmd, $db_id);

				// Return the user to the real previous page.
				header('Location: '.$_SESSION['prev_page']);
				// End this joyride.
				break;

			case 'editcontentname':
				// Determine whether the new section name already exists.
				$query_pt1 = 'SELECT ID FROM ';
				$query_pt2 = $dbpref.'_CONTENT WHERE SECTNAME = \''.$sectname.'\''.
												' AND PAGEID = '.$pageid;
				$results = sql_query($query_pt1.$query_pt2,$db_id);
				if (sql_num_rows($results,$query_pt2) != 1) {
					// Setup and execute the query to update page $pageid with the
					// new $pagename.
					$query_cmd = 'UPDATE '.$dbpref.'_CONTENT'.
								 ' SET SECTNAME = \''.$sectname.'\''.
								 ' WHERE ID = '.$contentid;
					sql_query($query_cmd, $db_id);
				} else {
					// Include an error indicating the name is already in use.
					$location .= '&error=samename';
				}

				// Redirect the user to the "Edit Page Content" page.
				$newloc = 'modules.php?id=pages&mode=admincontent&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'editcontentshowdate':
			case 'editcontentshowtitle':
			case 'editcontentshowactive':
				// Determine the setting to retrieve.
				$field = 'ISACTIVE';
				if ($mode != 'editcontentshowactive') {
					$field = (stristr($mode,'date')) ? 'SHOWDATE' : 'SHOWTITLE';
				}

				// Setup and execute the query to get the current setting for
				// $contentid in ISACTIVE/SHOWDATE/SHOWTITLE.
				$query_cmd = 'SELECT '.$field.' FROM '.$dbpref.'_CONTENT'.
							 ' WHERE ID='.$contentid;
				$results = sql_query($query_cmd,$db_id);

				// Get content properties.
				$row = sql_fetch_row($results);
				// If $row[0] == y, setting should be n.  Vice versa.
				$setting = ($row[0] == 'y') ? 'n' : 'y';

				// Setup and execute the query to update the field's status.
				$query_cmd = 'UPDATE '.$dbpref.'_CONTENT'.
							 ' SET '.$field.' = \''.$setting.'\', '.
								   'CONTENTDATE = '.$currenttime.
							 ' WHERE ID = '.$contentid;
				sql_query($query_cmd, $db_id);

				// Setup and execute the query to update the pagedate for $pageid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES SET PAGEDATE='.$currenttime.
							 ' WHERE ID='.$pageid;
				sql_query($query_cmd,$db_id);

				// Redirect the user to the "Edit Page Content" page.
				$newloc = 'modules.php?id=pages&mode=admincontent&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'editcontenttitle':
				// Setup and execute the query to update section $contentid with the
				// new title $_POST['content_title'].
				$new_title = core_convertQuotes($_POST['content_title']);
				$query_cmd = 'UPDATE '.$dbpref.'_CONTENT'.
							 " SET TITLE = '$new_title', ".
								  'CONTENTDATE = '.$currenttime.
							 ' WHERE ID = '.$contentid;
				sql_query($query_cmd, $db_id);

				// Setup and execute the query to update the pagedate for $pageid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES SET PAGEDATE='.$currenttime.
							 ' WHERE ID='.$pageid;
				sql_query($query_cmd,$db_id);

				// Redirect the user to the "Edit Page Content" page.
				$newloc = 'modules.php?id=pages&mode=admincontent&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'addpage':
				// Get the next available pageid.
				$page_nextid = core_getNextID($dbpref.'_PAGES');
				// Convert quotes in the page title (for SQL syntax purposes).
				$page_title = core_convertQuotes($_POST['pg_title']);

				// Setup and execute the query to add the page.
				$query_cmd = 'INSERT INTO '.$dbpref.'_PAGES'.
							 ' VALUES ('.$page_nextid.', '.
									   "'$page_title', ".
									    '-1, '.
									     $currenttime.', '.
									    "'n', ".
									    "'n', ".
									    "'n', ".
									    "'n', ".
									    "'n/a', ".
									     '0, '.
									     '\'!default\', '.
									     '\'\', '.
									     '\''._RELATEDLINKS.'\')';
				sql_query($query_cmd, $db_id);

				if (!$is_editor) {
					// Since this user is an author, get the next available
					// pageowner_id.
					$pageowner_id = core_getNextID($dbpref.'_PAGEOWNERS');

					// Setup and execute the query to add an ownership entry for
					// $owner on $page_nextid.
					$query_cmd = 'INSERT INTO '.$dbpref.'_PAGEOWNERS'.
								 ' VALUES ('.$pageowner_id.','.
											 $page_nextid.','.
											 $owner.','.
											 $catid.')';
					sql_query($query_cmd, $db_id);
				}

				// Redirect the user to the "Edit Page Content" page.
				$newloc = 'modules.php?id=pages&mode=admincontent&pageid='.
						  $page_nextid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'deletepage':
				// Prevent anyone from programatically deleting the home page.
				if ($pageid > 1) {
					// Setup and execute the queries to delete all entries for
					// $pageid from the TABLES $dbpref_PAGES, $dbpref_CONTENT,
					// $dbpref_PAGEOWNERS, $dbpref_PAGEBLOCKS.
					sql_query('DELETE FROM '.$dbpref.'_PAGES'.
							  ' WHERE ID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_CONTENT'.
							  ' WHERE PAGEID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_GRPPAGES'.
							  ' WHERE PAGEID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_PAGEBLOCKS'.
							  ' WHERE PAGEID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_PAGELINKS'.
							  ' WHERE PAGEID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_PAGEOWNERS'.
							  ' WHERE PAGEID='.$pageid,$db_id);
					sql_query('DELETE FROM '.$dbpref.'_PAGETAGS'.
							  ' WHERE PAGEID='.$pageid,$db_id);
				}

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpageaccess':
				if ($is_editor) {
					if ($groupslist != EVERYONE_GROUP) {
						// Initialize an array for the groupids.
						$groups = array();
						// Setup and execute the query to get the list of groupids
						// for $pageid.
						$query_pt1 = 'SELECT GROUPID FROM ';
						$query_pt2 = $dbpref.'_GRPPAGES WHERE PAGEID = '.$pageid;
						$results = sql_query($query_pt1.$query_pt2, $db_id);
						if (sql_num_rows($results,$query_pt2) > 0) {
							while ($row = sql_fetch_row($results)) {
								// Add the next group to the group array.
								$groups[] = $row[0];
							}
						}

						// Get the next available groupid._GRPPAGES
						$next_id = core_getNextID($dbpref.'_GRPPAGES');
						for ($i = 0; $i < count($groupslist); $i++) {
							// Determine whether the new groups are already assigned.
							if (!in_array($groupslist[$i],$groups)) {
								// Since this group is not listed, setup and execute
								// the query to add the new group to the list of
								// groups for this block.
								$query_cmd = 'INSERT INTO '.$dbpref.'_GRPPAGES'.
											 ' VALUES ('.$next_id.', '.$pageid.', '.
											             $groupslist[$i].')';
								sql_query($query_cmd, $db_id);
								// Get the next pageid.
								$next_id++;
							} else {
								// Get the element key for matching group.
								$key = array_search($groupslist[$i],$groups);
								// Remove the group from array.
								unset($groups[$key]);
							}
						}

						// Reset the array point for the list of groups to the start.
						reset($groups);
						while (($element = current($groups)) !== FALSE) {
							// Setup and execute the query to delete the next
							// remaining removed group.
							$query_cmd = 'DELETE FROM '.$dbpref.'_GRPPAGES'.
										 ' WHERE PAGEID = '.$pageid.
										 ' AND GROUPID = '.$element;
							sql_query($query_cmd, $db_id);
							// Advance the array pointer to the next element.
							next($groups);
						}
					} else {
						// Setup and execute the query to delete all group access
						// records for $pageid.
						$query_cmd = 'DELETE FROM '.$dbpref.'_GRPPAGES'.
									 ' WHERE PAGEID = '.$pageid;
						sql_query($query_cmd, $db_id);

						// Get the next groupid.
						$next_id = core_getNextID($dbpref.'_GRPPAGES');
						// Setup and execute the query to specify EVERYONE_GROUP
						// accessibility for $pageid.
						$query_cmd = 'INSERT INTO '.$dbpref.'_GRPPAGES'.
									 ' VALUES ('.$next_id.', '.$pageid.', '.
									 			 EVERYONE_GROUP.')';
						sql_query($query_cmd,$GLOBALS['db_id']);
					}
				}
				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpagecategory':
				// Setup the query to update the category for $pageid.
				if ($owner == 0) {
					// This is an editor.
					$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
								 ' SET CATID = '.$newcatid.
								 ' WHERE ID = '.$pageid;
				} else {
					// This is an author.
					$query_cmd = 'UPDATE '.$dbpref.'_PAGEOWNERS'.
								 ' SET CATID = '.$newcatid.
								 ' WHERE PAGEID = '.$pageid.
								 ' AND USERID = '.$owner;
				}

				// Execute the query to update the category for $pageid.
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpagename':
				// Determine whether the new page name already exists.
				$query_pt1 = 'SELECT ID FROM ';
				$query_pt2 = $dbpref.'_PAGES WHERE PAGENAME = \''.$pagename.'\'';
				$results = sql_query($query_pt1.$query_pt2,$db_id);
				if (sql_num_rows($results,$query_pt2) != 1) {
					// Setup and execute the query to update page $pageid with the
					// new $pagename.
					$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
								 ' SET PAGENAME = \''.$pagename.'\''.
								 ' WHERE ID = '.$pageid;
					sql_query($query_cmd, $db_id);
				} else {
					// Include an error indicating the name is already in use.
					$location .= '&error=samename';
				}

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpageowners':
				if ($is_editor) {
					if (isset($_POST['owners'])) {
						// Since an $groupslist was set, specify the groups that
						// should have access to the page.

						// Initialize the array for the ownerids.
						$owners = array();

						// Setup and execute the query to get the list of userids for
						// the owners of $pageid.
						$query_pt1 = 'SELECT USERID FROM ';
						$query_pt2 = $dbpref.'_PAGEOWNERS WHERE PAGEID = '.$pageid;
						$results = sql_query($query_pt1.$query_pt2, $db_id);

						// Check that at least one owner exists.

						if (sql_num_rows($results,$query_pt2) > 0) {
							while ($row = sql_fetch_row($results)) {
								// Add the userid to the owner array.
								$owners[] = $row[0];
							}
						}

						for ($i = 0; $i < count($_POST['owners']); $i++) {
							if (!in_array($_POST['owners'][$i],$owners)) {
								// Since this owner is not listed, get the next
								// available ownerid.
								$next_id = core_getNextID($dbpref.'_PAGEOWNERS');

								// Setup and execute the query to add the new owner
								// to the list of existing owners for $pageid.
								$query_cmd = 'INSERT INTO '.$dbpref.'_PAGEOWNERS'.
											 ' VALUES ('.$next_id.', '.
														 $pageid.', '.
														 $_POST['owners'][$i].', '.
														 '0)';
								sql_query($query_cmd, $db_id);
							} else {
								// Get the element key for matching owner.
								$key = array_search($_POST['owners'][$i],$owners);
								// Remove the owner from array.
								unset($owners[$key]);
							}
						}

						// Move the pointer for the group array to the beginning.
						reset($owners);

						while ($element = current($owners)) {
							// Setup and execute the query to delete the next
							// remaining removed owner.
							$query_cmd = 'DELETE FROM '.$dbpref.'_PAGEOWNERS'.
										 ' WHERE PAGEID = '.$pageid.
										 ' AND USERID = '.$element;
							sql_query($query_cmd, $db_id);
							// Move the array pointer to the next element.
							next($owners);
						}
					} else {
						// Since no groups were specified, setup and execute the
						// query to delete all group access records for $pageid.
						$query_cmd = 'DELETE FROM '.$dbpref.'_PAGEOWNERS'.
									 ' WHERE PAGEID = '.$pageid;
						sql_query($query_cmd, $db_id);
					}
				}
				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpageshowdate':
			case 'editpageshowprintable':
			case 'editpageshowtitle':
				// Determine the setting to retrieve.
				$field = 'PRINTERFRIENDLY';
				if ($mode != 'editpageshowprintable') {
					$field = (stristr($mode,'date')) ? 'SHOWDATE' : 'SHOWTITLE';
				}

				// Setup and execute the query to get the current setting for $pageid
				// in ISACTIVE/SHOWDATE/SHOWTITLE.
				$query_cmd = 'SELECT '.$field.' FROM '.$dbpref.'_PAGES'.
							 ' WHERE ID='.$pageid;
				$results = sql_query($query_cmd,$db_id);

				// Get content properties.
				$row = sql_fetch_row($results);
				// If $row[0] == y, setting should be n.  Vice versa.
				$setting = ($row[0] == 'y') ? 'n' : 'y';

				// Setup and execute the query to update the field's status.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 ' SET '.$field.' = \''.$setting.'\', '.
								   'PAGEDATE = '.$currenttime.
							 ' WHERE ID = '.$pageid;
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpagetemplate':
				// Setup and execute the query to update the template used for
				// $pageid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 ' SET TEMPLATE = \''.$_POST['pagetemplate'].'\','.
								 ' PAGEDATE = '.$currenttime.
							 ' WHERE ID = '.$pageid;
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editpagetitle':
				// Setup and execute the query to update page $pageid with the new
				// title $_POST['pg_title'].
				$title = core_convertQuotes($_POST['pg_title']);
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 " SET TITLE = '$title', ".
								  "PAGEDATE = $currenttime ".
							 " WHERE ID = $pageid";
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			case 'editlinkstitle':
				// Setup and execute the query to update page $pageid with the new
				// title $_POST['sect_title'] for its related links section.
				$title = core_convertQuotes($_POST['sect_title']);
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 " SET LINKSTITLE = '$title'".
							 " WHERE ID = $pageid";
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Related Links" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=adminrelated&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'addrelated':
				// Setup and execute the query to get the next content precedence for
				// the page in question.
				$query_pt1 = 'SELECT ID FROM ';
				$query_pt2 = $dbpref.'_PAGELINKS'.
							 ' WHERE PAGEID='.$pageid;
				$results = sql_query($query_pt1.$query_pt2,$db_id);
				$new_prec = sql_num_rows($results,$query_pt2);

				// Get the next available linkid.
				$newid = core_getNextID($dbpref.'_PAGELINKS');

				// Setup and execute the query to insert the related link.
				$query_cmd = 'INSERT INTO '.$dbpref.'_PAGELINKS'.
							 ' VALUES ('.$newid.', '.
									     $pageid.', '.
									   "'".$_POST['link_url']."', ".
									   "'".$_POST['link_text']."', ".
									   "'".$_POST['link_target']."', ".
									   "'".$_POST['link_title']."', ".
									     $new_prec.')';
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Related Links" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=adminrelated&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'deleterelated':
				// Setup and execute the query to delete the related link.
				$query_cmd = 'DELETE FROM '.$dbpref.'_PAGELINKS WHERE ID='.$linkid;
				sql_query($query_cmd,$db_id);

				// Setup and execute the query to get the list of related links
				// for $pageid.
				$query_pt1 = 'SELECT ID,PRECEDENCE FROM ';
				$query_pt2 = $dbpref.'_PAGELINKS WHERE PAGEID='.$pageid.
							 ' AND PRECEDENCE > '.$_POST['precedence'];
				$query_pt3 = ' ORDER BY ID';
				$results = sql_query($query_pt1.$query_pt2.$query_pt3,$db_id);

				// Determine the number of rows returned.
				$contents = sql_num_rows($results,$query_pt2);

				if ($contents > 0) {
					// Since some related links already exist, fix the precedence
					// of the links below the one deleted.
					while ($row = sql_fetch_row($results)) {
						// Set the new "precedence" to be less than the existing
						// precedence.
						$new_prec = $row[1] - 1;

						// Setup and execute the query to update the value for the
						// "precedence" of the current related link to the new
						// "precedence" value.
						$query_cmd = 'UPDATE '.$dbpref.'_PAGELINKS'.
									 ' SET PRECEDENCE='.$new_prec.
									 ' WHERE ID='.$row[0];
						sql_query($query_cmd,$db_id);
					}
				}

				// Redirect the user to the "Edit Related Links" page.
				$newloc = 'modules.php?id=pages&mode=adminrelated&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'editrelated':
				// Setup and execute the query to update the related link.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGELINKS'.
							 ' SET LINKTEXT = \''.$_POST['link_text'].'\', '.
								  'LINKURL = \''.$_POST['link_url'].'\', '.
								  'LINKTARGET = \''.$_POST['link_target'].'\', '.
								  'LINKTITLE = \''.$_POST['link_title'].'\' '.
							 ' WHERE ID = '.$linkid;
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Related Links" page.
				$newloc = 'modules.php?id=pages&mode=adminrelated&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'addmetatag':
				// Get the next available tagid.
				$newid = core_getNextID($dbpref.'_PAGETAGS');

				// Setup and execute the query to insert the META tag.
				$query_cmd = 'INSERT INTO '.$dbpref.'_PAGETAGS'.
							 ' VALUES ('.$newid.', '.
									     $pageid.', '.
									   "'".$_POST['tag_name']."', ".
									   "'".$_POST['tag_type']."', ".
									   "'".$_POST['tag_content']."')";
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Page META Tags" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=adminmetatags&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'deletemetatag':
				// Setup and execute the query to delete the META tag.
				$query_cmd = 'DELETE FROM '.$dbpref.'_PAGETAGS WHERE ID='.$tagid;
				sql_query($query_cmd,$db_id);

				// Redirect the user to the "Edit Page META Tags" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=adminmetatags&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'editmetatag':
				// Setup and execute the query to update the META tag.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGETAGS'.
							 ' SET TAGTYPE = \''.$_POST['tag_type'].'\', '.
								  'TAGNAME = \''.$_POST['tag_name'].'\', '.
								  'TAGCONTENT = \''.$_POST['tag_content'].'\' '.
							 ' WHERE ID = '.$tagid;
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Edit Page META Tags" page for $pageid.
				$newloc = 'modules.php?id=pages&mode=adminmetatags&pageid='.$pageid;
				header('Location: '.$newloc);
				// End this joyride.
				break;

			case 'setcattemplate':
				// Setup and execute the query to update the page template for all
				// pages in $catid.
				$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
							 ' SET TEMPLATE = "'.$_POST['template'].'"'.
							 ' WHERE CATID = '.$catid;
				sql_query($query_cmd, $db_id);

				// Redirect the user to the "Pages Administration" panel.
				header('Location: modules.php?id=pages&mode=admin'.$location);
				// End this joyride.
				break;

			default:
				// Since an invalid $mode was given, display an error page.
				header('Location: 404.php');
				// End this joyride.
				break;
		}
		// End this script without any further processing.
		die();
	}

	/* The GET processing section... */
	switch ($mode) {
		case 'admin':
			// Get the content for the "Pages Administration" panel.
			$pgcontent = pages_admin($catid,$sort);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES_TITLE);
			// End this joyride.
			break;

		case 'admincontent':
			// Get the content for the "Edit Page Content" page.
			$pgcontent = pages_listContent($pageid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES002);
			// End this joyride.
			break;

		case 'adminpagecats':
			// Get the content for the "Edit Page Categories" form.
			$pgcontent = pages_listCategories();
			// Create the page.
			core_createPage($pgcontent,'',_PAGES003);
			// End this joyride.
			break;

		case 'adminrelated':
			// Get the content for the "Edit Related Links" page.
			$pgcontent = pages_listRelated($pageid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES080);
			// End this joyride.
			break;

		case 'adminmetatags':
			// Get the content for the "Edit Page META Tags" page.
			$pgcontent = pages_listMetaTags($pageid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES103);
			// End this joyride.
			break;

		case 'canceleditpage':
			// Setup and execute the query to unlock the page.
			$query_cmd = 'UPDATE '.$dbpref.'_PAGES'.
						 " SET LOCKSET = 'n', LOCKUSER = 'n/a', LOCKTIME = 0".
						 " WHERE ID = $pageid";
			sql_query($query_cmd,$db_id);

			// Determine whether the previous page would result in a loop.
			if (strstr($_SESSION['referer'],'canceleditpage')) {
				// Setup and execute the query to determine the catid for $pageid.
				$field = ($is_editor) ? 'ID' : 'PAGEID';
				$table = ($is_editor) ? $dbpref.'_PAGES' : $dbpref.'_PAGEOWNERS';
				$query_cmd = 'SELECT CATID FROM '.$table.
							 ' WHERE '.$field.' = '.$pageid;
				$results = sql_query($query_cmd,$db_id);

				// Determine whether the page is in a category.
				if ($row = @sql_fetch_row($results)) {
					// Previous page should be the Pages Administration panel.
					$_SESSION['prev_page'] = 'modules.php?id=pages&catid='.$row[0];
				} else {								// If no category is found...
					// Previous page should be the Pages Administration panel.
					$_SESSION['prev_page'] = 'modules.php?id=pages';
				}
			}

			// Redirect the user to the real previous page.
			header('Location:  '.$_SESSION['prev_page']);
			// End this joyride.
			break;

		case 'deletepagecat':
			if ($is_editor) {
				// Editors remove categories from listing in WPS_PAGES.
				$table = $dbpref.'_PAGES';
			} else {
				// Authors remove categories from listing in WPS_PAGEOWNERS.
				$table = $dbpref.'_PAGEOWNERS';
			}

			// Setup and execute the query to determine if any pages have been
			// categorized with $catid.
			$query_pt1 = 'SELECT ID FROM ';
			$query_pt2 = $table.' WHERE CATID='.$catid;
			$results = sql_query($query_pt1.$query_pt2,$db_id);
			if (sql_num_rows($results,$query_pt2) > 0) {
				// Since some pages are using $catid, setup and execute the query to
				// reset those pages to no category before we can remove the page
				// category.
				$query_cmd = 'UPDATE '.$table.' SET CATID=0 WHERE CATID='.$catid;
				sql_query($query_cmd,$db_id);
			}

			// Setup and execute the query to delete the page category.
			sql_query('DELETE FROM '.$dbpref.'_PAGECATS WHERE ID='.$catid,$db_id);

			// Redirect the user to the "Edit Page Categories" form.
			header('Location: modules.php?id=pages&mode=adminpagecats');
			// End this joyride.
			break;

		case 'editcontent':
			// Get the content for the "Edit Content" form.
			$pgcontent = pages_editContent($contentid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES004);
			// End this joyride.
			break;

		case 'editpageaccess':
			// Get the content for the "Edit Page Accessibility" form.
			$pgcontent = pages_editPageAccess($pageid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES043);
			// End this joyride.
			break;

		case 'editpageowners':
			if ($is_editor) {
				// Only editors are allowed to modify the list of owners.
				// Get the content for the "Edit Page Ownership" form.
				$pgcontent = pages_editPageOwners($pageid);
				// Create the page.
				core_createPage($pgcontent,'',_PAGES006);
			} else {
				// Since this user isn't an editor, display an "Access Denied"
				// message.
				core_createPage(access_denied(),'',_ACCESSDENIED);
			}
			// End this joyride.
			break;

		case 'movedn':
		case 'moveup':
		case 'movednlink':
		case 'moveuplink':
			if (stristr($mode,'movedn')) {
				// Set the previous precedence for $contentid.
				$prev_prec = $_GET['new_prec'] + 1;
			} else {
				// Set the previous precedence for $contentid.
				$prev_prec = $_GET['new_prec'] - 1;
			}

			$table		= (stristr($mode,'link')) ? 'PAGELINKS' : 'CONTENT';
			$newmode	= (stristr($mode,'link')) ? 'related' : 'content';
			$newmode	= 'admin'.$newmode;
			// Setup and execute the query to update the precedence for both
			// content sections.
			$query_cmd	= 'UPDATE '.$dbpref.'_'.$table.
							' SET PRECEDENCE='.$_GET['new_prec'].
							' WHERE PRECEDENCE='.$prev_prec.
							' AND PAGEID='.$pageid;
			sql_query($query_cmd,$db_id);
			$query_cmd	= 'UPDATE '.$dbpref.'_'.$table.
							' SET PRECEDENCE='.$prev_prec.
							' WHERE ID='.$contentid;
			sql_query($query_cmd,$db_id);

			// Redirect the user to the "Edit Page Content" page.
			$newloc = 'modules.php?id=pages&mode='.$newmode.'&pageid='.$pageid;
			header('Location: '.$newloc);
			// End this joyride.
			break;

		case 'popupauthor':
			if ($is_editor) {
				// Only editors are allowed to modify the list of owners.
				// Get the HTML for the "Select Page Owner" popup form.
				$pgcontent = pages_popupAuthor($pageid, $userids);
				// Create the page.
				core_createPage($pgcontent,'',_PAGES026,$template_popup);
			} else {
				// Since this user isn't an editor, display an "Access Denied"
				// message.
				core_createPage(access_denied(),'',_ACCESSDENIED);
			}
			// End this joyride.
			break;

		case 'popupcategory':
			// Get the HTML for the "Change Page Category" popup form.
			$pgcontent = pages_popupCategory($pageid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES059,$template_popup);
			// End this joyride.
			break;

		case 'setcattemplate':
			// Get the HTML for the "Set Category Template" page.
			$pgcontent = pages_setCatTemplate($catid);
			// Create the page.
			core_createPage($pgcontent,'',_PAGES073);
			// End this joyride.
			break;

		default:
			// Since an invalid $mode was given, display an error page.
			header('Location: 404.php');
			// End this joyride.
			break;
	}
} else {
	// No valid user rights were found.
	if ($_SESSION['authorization'] == '') {
		// Since the user hasn't logged in, send them to the login page with the
		// requested URL passed as a referral URL.
		header('Location: login.php?referer='.core_getReferer());
		die();
	} else {							//
		// Since the user is logged in, display an "Access Denied" page instead.
		core_createPage(access_denied(),'',_ACCESSDENIED);
	}
}


/**
 * Display a form to make changes an existing content section ($content_id).
 *
 * @param  int     $content_id   ID of the HTML content section to edit
 * @access private
 * @return string HTML content of the "Edit Content" form
 */
function pages_editContent($content_id)
{
	// Setup and execute the query to get the current properties for $content_id.
	$query_cmd = 'SELECT TITLE,CONTENT,PAGEID FROM '.$GLOBALS['dbpref'].'_CONTENT'.
				 ' WHERE ID='.$content_id;
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Get the properties of the content section.
	$row = sql_fetch_row($results);
	// Convert the WPS entities to single and double quotes.
	$title = core_convertQuotes($row[0],'revert');
	// Convert the WPS entities to single and double quotes and remove any slashes.
	$content = core_convertQuotes(stripslashes($row[1]),'revert');
	// Convert all HTML entities to their textarea-safe forms.
	$content = htmlspecialchars($content);

	// Set the HTML for the "Edit Content" form.
	$page = '
<h3 align="center">'._PAGES004.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php" id="content_form" name="content_form"">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="7" width="600">
      <tr>
        <td align="left">
          <textarea id="content_text" name="content_text" rows="20" cols="80"
           style="width: 650px; height: 350px;">'.$content.'</textarea>
        </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" class="buttonRegular" value="'._PAGES036.'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />&nbsp;
      <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \'modules.php?id=pages'.
       '&amp;mode=canceleditpage&amp;pageid='.$row[2].'\'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
    </div>
  </div>
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="contentid" value="'.$content_id.'" />
  <input type="hidden" name="pageid" value="'.$row[2].'" />
  <input type="hidden" name="mode" value="editcontent" />
</form>
';
	// Add the Inline Web Editor to the page.
	$page .= core_getEditor('content_text');
	// Return the HTML for the "Edit Content" form.
	return $page;
}


/**
 * Display a form listing the existing content sections for $pageid.
 *
 * @param  int     $pageid   ID of the page from which to list content sections
 * @access private
 * @return string HTML content of the "Edit Page Content" page
 */
function pages_listContent($pageid)
{
	// Setup the query to list the title property for $pageid.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_PAGES.TITLE FROM ';

	// Build the subquery used to gauge the number of returned rows for those
	// RDBMS that do not correctly support the FUNCTION sql_num_rows().
	$query_pt2 = $GLOBALS['dbpref'].'_PAGES';
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS to the table list
		// in $query_pt2.
		$query_pt2 .= ', '.$GLOBALS['dbpref'].'_PAGEOWNERS';
	}

	// Continue setting up the subquery with the WHERE clause.
	$query_pt2 .= ' WHERE '.$GLOBALS['dbpref'].'_PAGES.ID = '.$pageid;
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS.pageid to the WHERE
		// clause in $query_pt2.
		$query_pt2 .= ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.$pageid;
	}

	// Execute the query to get the title property for $pageid.
	$page_results = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
	if (sql_num_rows($page_results,$query_pt2) == 1) {
		// Retrieve that title property for $pageid.
		$row = sql_fetch_row($page_results);
		// Convert the WPS entities to single and double quotes.
		$title = core_convertQuotes($row[0],'revert');

		// Set the HTML for the "Edit Page Content" page.
		$page = '
<script type="text/javascript">
<!--

function addSection()
{
	form = document.sections;
	form.content_title.value = prompt(\''._PAGES007.'\',\''._PAGES069.'\');
	switch (form.content_title.value) {
		case null:
		case \'null\':
		case \'\':
		case \''._PAGES069.'\':
			break;
		default:
			form.mode.value = \'addcontent\';
			form.submit();
			break;
	}
}


function deleteSection(content_id,precedence)
{
	if (confirm("'._PAGES016.'")) {
		form = document.sections;
		form.mode.value = \'deletecontent\';
		form.contentid.value = content_id;
		form.precedence.value = precedence;
		form.submit();
	}
}


function editName(content_id,sectname)
{
	form = document.sections;
	form.sect_name.value = prompt(\''._PAGES078.'\',sectname);
	switch (form.sect_name.value) {
		case null:
		case \'null\':
		case \'\':
		case sectname:
			break;
		default:
			form.mode.value = \'editcontentname\';
			form.contentid.value = content_id;
			form.submit();
			break;
	}
}


function editPageTitle()
{
	form = document.sections;
	form.page_title.value = prompt(\''._PAGES076.'\',\''.$title.'\');
	switch (form.page_title.value) {
		case null:
		case \'null\':
		case \'\':
		case \''.$title.'\':
			break;
		default:
			form.mode.value = \'editlangpgtitle\';
			form.submit();
			break;
	}
}


function editTitle(content_id,title)
{
	form = document.sections;
	form.content_title.value = prompt(\''._PAGES031.'\',title);
	switch (form.content_title.value) {
		case null:
		case \'null\':
		case \'\':
		case title:
			break;
		default:
			form.mode.value = \'editcontenttitle\';
			form.contentid.value = content_id;
			form.submit();
			break;
	}
}


function toggleSetting(setting,content_id)
{
	form = document.sections;
	form.mode.value = \'editcontentshow\'+setting;
	form.contentid.value = content_id;
	form.submit();
}


//-->
</script>
<h3 align="center">'._PAGES030.' &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php" name="sections">
  <div align="center">
    <table align="center" class="tableNavigation">
      <tr>
        <td align="center" nowrap="nowrap">
          <input type="button" class="buttonRegular" value="'._PAGES001.'"
           onclick="addSection()"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />&nbsp;
          <input type="button" class="buttonRegular" value="'._PAGES019.'"
           onclick="location.href = \'modules.php?id=pages'.
           '&amp;mode=canceleditpage&amp;pageid='.$pageid.'\'"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />';

		if (isset($_GET['error'])) {
			$page .= '<H4 style="font-color: red">'._PAGES076.'</H4>';
		}

		// Continue to set the HTML for the "Pages Administration" page.
		$page .= '
    <table align="center" border="1" class="tableAdmin">
      <tr>
        <td align="center" class="columnAdminHeader">'._PAGES077.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES010.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES021.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES022.'</td>
        <td align="center" class="columnAdminHeader">'._SETTINGS.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES020.'</td>
      </tr>';

		// Setup and execute the query to get the list of content sections.
		$query_pt1 = 'SELECT ID,TITLE,CONTENTDATE,PRECEDENCE,'.
							'SHOWDATE,SHOWTITLE,ISACTIVE,SECTNAME FROM ';
		$query_pt2 = $GLOBALS['dbpref'].'_CONTENT WHERE PAGEID = '.$pageid;
		$query_pt3 = ' ORDER BY PRECEDENCE';
		$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

		// Get the number of sections returned.
		$contenttotal = sql_num_rows($results,$query_pt2);

		if ($contenttotal > 0 ) {
			// Initialize the highlight number to highlight rows in the table.
			$hilite = 1;
			while ($row = sql_fetch_row($results)) {
				// Initialize the class to highlight this row in the table.
				$style = 'columnAdminCell';
				if (($hilite % 2) == 0) {
					$style .= '2';
				}

				// Verify a section name exists.
				$sectname = ($row[7] == '') ? 'section'.$row[0] : $row[7];

				// Convert the WPS entities to single and double quotes.
				$title = core_convertQuotes($row[1],'revert');

				// Continue to set the HTML for the "Edit Page Content" page.
				$page .= '
      <tr>
        <td align="center" class="'.$style.'">
          <a href="javascript:editName('.$row[0].',\''.$sectname.'\')"'.
          ' title="'._PAGES078.'">'.$sectname.'</a>
        </td>
        <td align="center" class="'.$style.'">
          <a href="javascript:editTitle('.$row[0].',\''.
           str_replace('&','&amp;',$title).'\')" title="'._PAGES031.'">'.$title.'</a>
        </td>
        <td align="center" class="'.$style.'">'.date('n/d/Y g:i:s A',$row[2]).'</td>
        <td align="center" class="'.$style.'">';

				if ($contenttotal == 1) {
					// Since only one section was returned, do not include the
					// "precedence" setting.
					$page .= 'n/a';
				} else {
					if ($row[3] != 0) {
						// Include the "moveup" link when not the first content
						// section.
						$page .= "\r\n".'          <a href="modules.php?id=pages';
						$page .= '&amp;mode=moveup&amp;pageid='.$pageid;
						$page .= '&amp;contentid='.$row[0];
						$page .= '&amp;new_prec='.$row[3].'"><img';
						$page .= ' src="modules/pages/uparrow.png" border="0"';
						$page .= ' height="24" width="24" alt="'._UP.'" />';
						$page .= '</a>';
					}
					if ($row[3] != ($contenttotal - 1)) {
						// Include the "movedn" link when not the last content
						// section.
						$page .= "\r\n".'          <a href="modules.php?id=pages';
						$page .= '&amp;mode=movedn&amp;pageid='.$pageid;
						$page .= '&amp;contentid='.$row[0];
						$page .= '&amp;new_prec='.$row[3].'"><img';
						$page .= ' src="modules/pages/dnarrow.png" border="0"';
						$page .= ' height="24" width="24" alt="'._DOWN.'" />';
						$page .= '</a>';
					}
				}

	 			// Continue to set the HTML for the "Edit Page Content" page.
	  			$page .= '
        </td>
        <td align="center" class="'.$style.'">
          <a href="javascript:toggleSetting(\'date\','.$row[0].');"><img'.
          ' src="modules/pages/showdate.png" border="0" alt="';

				if ($row[4] == 'n') {
					$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
					$page .= _PAGES033;
				} else {
					$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
					$page .= _PAGES035;
				}

				$page .= '" height="24" width="24" hspace="0" vspace="0"';
				$page .= ' style="'.$opacity.';" /></a>
          <a href="javascript:toggleSetting(\'title\','.$row[0].');"><img'.
          ' src="modules/pages/showtitle.png" border="0" alt="';

				if ($row[5] == 'n') {
					$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
					$page .= _PAGES039;
				} else {
					$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
					$page .= _PAGES067;
				}

				$page .= '"height="24" width="24" hspace="0" vspace="0"';
				$page .= ' style="'.$opacity.';" /></a>
          <a href="javascript:toggleSetting(\'active\','.$row[0].');"><img'.
          ' src="modules/pages/activate.png" border="0" alt="';

				if ($row[6] == 'n') {
					$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
					$page .= _PAGES008;
				} else {
					$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
					$page .= _PAGES009;
				}

				$page .= '" height="24" width="24" hspace="0" vspace="0"';
				$page .= ' style="'.$opacity.';" /></a>
        </td>
        <td align="center" nowrap="nowrap" class="'.$style.'">
          <a href="modules.php?id=pages&amp;mode=editcontent&amp;contentid='.
           $row[0].'"><img'.
          ' src="modules/pages/contents.png" alt="'._PAGES004.'"'.
          ' height="24" width="24" hspace="0" vspace="0" border="0" /></a>
          <a href="javascript:deleteSection('.$row[0].','.$row[3].');"><img'.
          ' src="modules/pages/delete.png" alt="'._PAGES018.'"'.
          ' height="24" width="24" hspace="0" vspace="0" border="0" /></a>
        </td>
      </tr>';

				$hilite++;
			}
		} else {
			$page .= '
      <tr>
        <td align="center" colspan="6" class="columnAdminCell">'._PAGES024.'</td>
      </tr>';
		}

		$page .= '
    </table>
  </div>
  <input type="hidden" name="sect_name" value="" />
  <input type="hidden" name="content_title" value="" />
  <input type="hidden" name="page_title" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="precedence" value="" />
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="pageid" value="'.$pageid.'" />
  <input type="hidden" name="contentid" value="" />
</form>
';
		if ($contenttotal == 0 ) {
			// Since no sections were returned, display an error message.
			$page .= '
<h4 align="center">'._PAGES071.'</h4>
';
		}
	} else {
		// Since no editorial or ownership rights were found, display an
		// "Access Denied" error message.
		return access_denied();
	}
	// Return the HTML for the "Edit Page Content" page.
	return $page;
}


/**
 * Display a list of pages in category $catid to be managed.
 *
 * @param  int     $catid     ID of the page category to view
 * @param  string  $orderby   Field by which to sort the list of pages
 * @access private
 * @return string HTML content of the "Pages Administration" page
 */
function pages_admin($catid,$orderby)
{
	// Determine the direction the table will be sorted.
	$dir = 'ASC';
	$imgfile = 'asc.png';
	$sym = '&uarr;';
	if (isset($_GET['dir'])) {
		$dir = 'DESC';
		$imgfile = 'desc.png';
		$sym = '&darr;';
	}

	// Setup the query to return all the pages for category $catid.
	$query_pt1 =  'SELECT '.$GLOBALS['dbpref'].'_PAGES.ID, '.
							$GLOBALS['dbpref'].'_PAGES.TITLE, '.
							$GLOBALS['dbpref'].'_PAGES.CATID, '.
							$GLOBALS['dbpref'].'_PAGES.PAGEDATE, '.
							$GLOBALS['dbpref'].'_PAGES.TEMPLATE, '.
							$GLOBALS['dbpref'].'_PAGES.PRINTERFRIENDLY, '.
							$GLOBALS['dbpref'].'_PAGES.SHOWDATE, '.
							$GLOBALS['dbpref'].'_PAGES.SHOWTITLE, '.
							$GLOBALS['dbpref'].'_PAGES.PAGENAME FROM ';

	// Build the subquery used to gauge the number of returned rows for those
	// RDBMS that do not correctly support the FUNCTION sql_num_rows().
	$query_pt2 = $GLOBALS['dbpref'].'_PAGES';
	if ($GLOBALS['is_editor']) {
		// All editors share page categories system-wide, so the $ownerid is zero.
		$ownerid = 0;
		// Continue to build the subquery.
		$query_pt2 .= ' WHERE '.$GLOBALS['dbpref'].'_PAGES.CATID = '.$catid.
					  ' AND '.$GLOBALS['dbpref'].'_PAGES.ID > 0';
	} else {
		// Setup and execute the query to get the userid for the current user.
		$query_cmd = 'SELECT ID FROM '.$GLOBALS['dbpref'].'_USERS'.
					 ' WHERE PASSHASH = \''.$_SESSION['authorization'].'\'';
		$user_results = sql_query($query_cmd, $GLOBALS['db_id']);

		// Retrieve the userid.
		$row = sql_fetch_row($user_results);
		// Set the $ownerid to the current userid.
		$ownerid = $row[0];

		// Continue to build the subquery.
		$query_pt2 .= ', '.$GLOBALS['dbpref'].'_PAGEOWNERS'.
					  ' WHERE '.$GLOBALS['dbpref'].'_PAGES.ID = '.
					  			$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID'.
					  ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.CATID = '.$catid.
					  ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.USERID = '.$ownerid;

		// Setup and execute the query to determine if the user has created any pages
		// at all.  Used to display a message saying such if no pages are returned.
		$query_cmd1 = 'SELECT ID FROM ';
		$query_cmd2 = $GLOBALS['dbpref'].'_PAGEOWNERS WHERE USERID = '.$ownerid;
		$total_results = sql_query($query_cmd1.$query_cmd2, $GLOBALS['db_id']);
		$total_pages = sql_num_rows($total_results, $query_cmd2);
	}

	// Setup the ORDER BY clause.
	$sort = $GLOBALS['dbpref'].'_PAGES.'.strtoupper($orderby).' '.$dir;
	if ($orderby != 'title') {
		// Sorting by template or date should leave the entries sorted by title
		// in ascending order for any secondary sorting.
		$sort .= ', '.$GLOBALS['dbpref'].'_PAGES.TITLE ASC';
	}

	// Execute the query to get the list of pages in category $catid.
	$results = sql_query($query_pt1.$query_pt2.' ORDER BY '.$sort,$GLOBALS['db_id']);
	// Get the total number of pages returned.
	$pagetotal = sql_num_rows($results,$query_pt2);

	// Set the HTML for the "Pages Administration" page.
	$page = '
<script type="text/javascript">
<!--

var dialogArguments;
var modstr = \'modules.php?id=pages&mode=\';

function navAction(element)
{
	switch (element.value) {

		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;

		case \'addpage\':

			element.form.pg_title.value = prompt(\''._PAGES065.'\',\''._PAGES066.'\');

			switch (element.form.pg_title.value) {
			case null:
			case \'null\':
			case \'\':
			case \''._PAGES066.'\':
				element.form.actionlist.selectedIndex=0;
				element.form.actionlist.focus();
				// End this joyride.
				break;
			default:
				element.form.mode.value = \'addpage\';
				element.form.submit();
				// End this joyride.
				break;
			}

			break;

		case \'adminpagecats\':
			location.href = modstr+\'adminpagecats\';
			break;
		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
		case \'setcattemplate\':
			location.href = modstr+\'setcattemplate&catid='.$catid.'\';
			break;
	}
}

function execCatAction(element)
{
	switch (element.value) {

		case 0:
			location.href = modstr+\'admin\';
			break;
		default:
			location.href = modstr+\'admin&catid=\'+element.value;
			break;
	}
}

function editName(pg_id,name)
{
	form = document.pagelisting;
	form.pg_name.value = prompt(\''._PAGES075.'\',name);
	switch (form.pg_name.value) {
		case null:
		case \'null\':
		case \'\':
		case name:
			break;
		default:
			form.mode.value = \'editpagename\';
			form.pageid.value = pg_id;
			form.submit();
			break;
	}
}

function editTitle(pg_id,title)
{
	form = document.pagelisting;
	form.pg_title.value = prompt(\''._PAGES040.'\',title);
	switch (form.pg_title.value) {
		case null:
		case \'null\':
		case \'\':
		case title:
			break;
		default:
			form.mode.value = \'editpagetitle\';
			form.pageid.value = pg_id;
			form.submit();
			break;
	}
}

function changePageTemplate(pg_id,template)
{
	form = document.pagelisting;
	form.mode.value = \'editpagetemplate\';
	form.pageid.value = pg_id;
	form.pagetemplate.value = template.value;
	form.submit();
}


function changeCategory(pg_id)
{
	dialogArguments = document.pagelisting;
	loc = modstr+\'popupcategory&pageid=\'+pg_id;
	opt = \'toolbar=no,menubar=no,personalbar=no,status=no,scrollbars=no,\'+
		  \'width=300,height=150,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
}

function toggleSetting(setting,pg_id)
{
	form = document.pagelisting;
	form.mode.value = \'editpageshow\'+setting;
	form.pageid.value = pg_id;
	form.submit();
}


function deletePage(pg_id)
{
	if (confirm("'._PAGES037.'")) {
		form = document.pagelisting;
		form.mode.value = \'deletepage\';
		form.pageid.value = pg_id;
		form.submit();
	}
}

//-->
</script>
<h3 align="center">'._PAGES_TITLE.'</h3>
<form method="post" action="modules.php" name="pagelisting">
  <div align="center">
    <table align="center" class="tableNavigation">
      <tr>
        <td align="center" nowrap="nowrap">
          <select class="textCool" name="actionlist"
           onchange="navAction(this.options[this.selectedIndex])">
            <option value="default">- '._NAVIGATIONMENU.' -</option>
            <option value="addpage">'._PAGES068.'</option>
            <option value="adminpagecats">'._PAGES003.'</option>
            <option value="setcattemplate">'._PAGES073.'</option>
            <option value="adminpanel">'._BACK2ADMIN.'</option>
          </select>
          &nbsp; '._PAGES045.'
          <select class="textCool" name="catactions"
           onchange="execCatAction(this.options[this.selectedIndex])">
            <option value="0">- '._PAGES060.' -</option>';

	// Setup and execute the query to get the list of possible page categories.
	$query_pt1 = 'SELECT ID,CATNAME FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_PAGECATS WHERE CATOWNER = '.$ownerid;
	$query_pt3 = ' ORDER BY CATNAME';
	$cat_results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);
	// Determine the number of rows returned.
	$cat_total = sql_num_rows($cat_results,$query_pt2);

	if ($cat_total > 0) {
		while ($row = sql_fetch_row($cat_results)) {
			// Convert the WPS entities to single and double quotes.
			$catname = core_convertQuotes($row[1],'revert');
			$page .= "\r\n".'            <option value="'.$row[0].'"';
			if ($row[0] == $catid) {
				// Since a match exists, show $catid as the selected option.
				$page .= ' selected="selected"';
			}

			$page .= '>'.$catname.'</option>';
		}
	}

	// Continue to set the HTML for the "Pages Administration" page.
	$page .= '
          </select>
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />';

	if (!$GLOBALS['is_editor']) {
		// Authors should have a short description of the symbols used in the table.
		$page .= '
    <div class="legendAdmin">'._LEGENDCOLON.' &nbsp;* = '.
    _PAGES049.'&nbsp; &dagger; = '._PAGES050.'</div>';
	}

	if (isset($_GET['error'])) {
		$page .= '<H4 style="font-color: red">'._PAGES076.'</H4>';
	}

	// Continue to set the HTML for the "Pages Administration" page.
	$page .= '
    <table align="center" border="1" class="tableAdmin">
      <tr>
        <td align="center" class="columnAdminHeader">ID</td>
        <td align="center" class="columnAdminHeader">'._PAGES074.'</td>
        <td align="center" class="columnAdminHeader">
          <a href="modules.php?id=pages&mode=admin';

	if (($orderby == 'title') && ($dir != 'DESC')) {
		// Since we're already listing the pages by title in ascending order, set the
		// "sort by title" link to allow the pages to be listed by title in
		// descending order.
		$page .= '&dir=desc';
	}
	if ($catid != 0) {
		// Since this is not the default category, pass the current category ID in
		// the URL.
		$page .= '&catid='.$catid;
	}
	$page .= '" class="linkAdminHeader">'._PAGES010.'</a>';
	if ($orderby == 'title') {
		// Display an image of an arrow showing the sorting direction.
		$page .= '<img src="modules/pages/'.$imgfile.'" alt="'.$sym.'" height="12"';
		$page .= ' width="12" hspace="0" vspace="0" border="0" />';
	}
	$page .= '
        </td>
        <td align="center" class="columnAdminHeader">
          <a href="modules.php?id=pages&mode=admin&sort=pagedate';
	if (($orderby == 'pagedate') && ($dir != 'DESC')) {
		// Since we're already listing the pages by date in ascending order, set the
		// "sort by date" link to allow the pages to be listed by date in descending
		// order.
		$page .= '&dir=desc';
	}
	if ($catid != 0) {
		// Since this is not the default category, pass the current category ID in
		// the URL.
		$page .= '&catid='.$catid;
	}
	$page .= '" class="linkAdminHeader">'._PAGES021.'</a>';
	if ($orderby == 'pagedate') {
		// Display an image of an arrow showing the sorting direction.
		$page .= '<img src="modules/pages/'.$imgfile.'" alt="'.$sym.'" height="12"';
		$page .= ' width="12" hspace="0" vspace="0" border="0" />';
	}
	$page .= '
        </td>
        <td align="center" class="columnAdminHeader">
          <a href="modules.php?id=pages&mode=admin&sort=template';
	if (($orderby == 'template') && ($dir != 'DESC')) {
		// Since we're already listing the pages by template in ascending order, set
		// the "sort by date" link to allow the pages to be listed by date in
		// descending order.
		$page .= '&dir=desc';
	}
	if ($catid != 0) {
		// Since this is not the default category, pass the current category ID in
		// the URL.
		$page .= '&catid='.$catid;
	}
	$page .= '" class="linkAdminHeader">'._PAGES038.'</a>';
	if ($orderby == 'template') {
		// Display an image of an arrow showing the sorting direction.
		$page .= '<img src="modules/pages/'.$imgfile.'" alt="'.$sym.'" height="12"';
		$page .= ' width="12" hspace="0" vspace="0" border="0" />';
	}
	$page .= '
        </td>
        <td align="center" class="columnAdminHeader">'._SETTINGS.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES020.'</td>
      </tr>';

	if ($pagetotal > 0 ) {
		if ($filelist = @opendir($GLOBALS['site_path'].'/templates')) {
			// Initialize the list of templates.
			$tpl = array();
			while (($filename = readdir($filelist)) !== FALSE) {
				// Get the list of template filenames from the templates folder.
				if (($filename{0} != '.') &&
					(!is_dir($GLOBALS['site_path'].'/templates/'.$filename))) {
					// This filename is not a directory or special file.
					$p = pathinfo($GLOBALS['site_path'].'/templates/'.$filename);
					$ext = 'css,php,pl,cgi,js,jpg,gif,jpeg,png,swf,jar';
					if (!stristr($ext,$p['extension'])) {
						$tpl[] = $filename;
					}
				}
			}
			// Close the folder handle.  Not closing the folder handle is bad, m'kay.
			closedir($filelist);
		}

		// Initialize the highlight number to highlight rows in the table.
		$hilite = 1;
		while ($row = sql_fetch_row($results)) {
			// Initialize the class to highlight this row in the table.
			$style = 'columnAdminCell';
			if (($hilite % 2) == 0) {
				$style .= '2';
			}

			// Convert WPS entities to single and double quotes.
			$title = core_convertQuotes($row[1],'revert');

			// Prevent blank pagenames.
			$pgname = $row[8];
			if ($pgname == '') {
				$pgname = 'page'.$row[0];
			}

			$page .= '
      <tr>
        <td align="center" class="'.$style.'">'.$row[0].'</td>
        <td align="center" class="'.$style.'">
          <a href="javascript:editName('.$row[0].',\''.
           str_replace('&','&amp;',$pgname).'\');" title="'.
           _PAGES075.'">'.$pgname.'</a></td>
        <td align="center" class="'.$style.'">
          <a href="javascript:editTitle('.$row[0].',\''.
           str_replace('&','&amp;',$title).'\');" title="'.
           _PAGES040.'">'.$title.'</a>';

			if (!$GLOBALS['is_editor']) {
				// Add symbols for disabled or unapproved pages.
				switch ($row[2]) {
					case -1:
						$page .= ' *';
						// End this joyride.
						break;
					case -2:
						$page .= ' &dagger;';
						// End this joyride.
						break;
					}
			}

			$page .= '
        </td>
        <td align="center" class="'.$style.'">'.
          date('n/d/Y\<\b\r\>g:i:s A',$row[3]).'</td>
        <td align="center" class="'.$style.'">
          <select name="page_template" id="page_template" class="textCool"
           onchange="changePageTemplate('.$row[0].
           ',this.options[this.selectedIndex]);"
           title="'._PAGES005.'">
            <option value="!default">- '._DEFAULT.' -</option>';

			sort($tpl);
			reset($tpl);
			for ($i = 0; $i < count($tpl); $i++) {
				// Add each template file as a select option.
				$page .= "\r\n".'            <option';
				if ($row[4] == $tpl[$i]) {
					$page .= ' selected="selected"';
				}
				$page .= ' value="'.$tpl[$i].'">'.$tpl[$i].'</option>';
			}

			$page .= '
          </select>
        </td>
        <td align="center" nowrap="nowrap" class="'.$style.'">
          <a href="javascript:toggleSetting(\'printable\','.$row[0].');">'.
            '<img src="modules/pages/showprint.png" border="0" alt="';

			if ($row[5] == 'n') {
				$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
				$page .= _PAGES015;
			} else {
				$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
				$page .= _PAGES017;
			}

			$page .= '"height="24" width="24" hspace="0" vspace="0"';
			$page .= ' style="'.$opacity.';" /></a>
          <a href="javascript:toggleSetting(\'date\','.$row[0].');">'.
            '<img src="modules/pages/showdate.png" border="0" alt="';

			if ($row[6] == 'n') {
				$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
				$page .= _PAGES013;
			} else {
				$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
				$page .= _PAGES041;
			}

			$page .= '"height="24" width="24" hspace="0" vspace="0"';
			$page .= ' style="'.$opacity.';" /></a>
          <a href="javascript:toggleSetting(\'title\','.$row[0].');">'.
            '<img src="modules/pages/showtitle.png" border="0" alt="';

			if ($row[7] == 'n') {
				$opacity = 'filter: alpha(opacity = 50); -moz-opacity: 0.5;';
				$page .= _PAGES014;
			} else {
				$opacity = 'filter: alpha(opacity = 100); -moz-opacity: 1;';
				$page .= _PAGES042;
			}

			$page .= '"height="24" width="24" hspace="0" vspace="0"';
			$page .= ' style="'.$opacity.';" /></a>
        </td>
        <td align="left" nowrap="nowrap" class="'.$style.'">
          <a href="modules.php?id=pages&amp;mode=admincontent&amp;pageid='.
            $row[0].'">'.
            '<img src="modules/pages/contents.png" alt="'._PAGES002.'" height="24"
             width="24" hspace="0" vspace="0" border="0" /></a>';

			if ($GLOBALS['is_editor']) {
				$page .= '
          <a href="modules.php?id=pages&amp;mode=editpageaccess'.
          '&amp;pageid='.$row[0].'"><img src="modules/pages/security.png"'.
          ' alt="'._PAGES043.'" height="24" width="24" hspace="0" vspace="0"'.
          ' border="0" /></a>
          <a href="modules.php?id=pages&amp;mode=editpageowners'.
          '&amp;pageid='.$row[0].'"><img src="modules/pages/ownership.png"'.
          ' alt="'._PAGES006.'" height="24" width="24" hspace="0" vspace="0"'.
          ' border="0" /></a>
          <a href="modules.php?id=pages&amp;mode=adminrelated'.
          '&amp;pageid='.$row[0].'"><img src="modules/pages/links.png"'.
          ' alt="'._PAGES080.'" height="24" width="24" hspace="0" vspace="0"'.
          ' border="0" /></a>
          <a href="modules.php?id=pages&amp;mode=adminmetatags'.
          '&amp;pageid='.$row[0].'"><img src="modules/pages/tags.png"'.
          ' alt="'._PAGES103.'" height="24" width="24" hspace="0" vspace="0"'.
          ' border="0" /></a>';
			}

			if ($row[0] != 1) {
				$page .= '
          <a href="javascript:changeCategory('.$row[0].');"><img'.
          ' src="modules/pages/category.png" alt="'._PAGES059.'" height="24"'.
          ' width="24" hspace="0" vspace="0" border="0" /></a>
          <a href="javascript:deletePage('.$row[0].');"><img'.
          ' src="modules/pages/delete.png" alt="'._PAGES051.'" height="24"'.
          ' width="24" hspace="0" vspace="0" border="0" /></a>';
			}
			$page .= '
        </td>
      </tr>';

			$hilite++;
		}
	} else {
		// Display a message that no pages exist system-wide.
		$page .= '
      <tr>
        <td align="center" colspan="7" class="columnAdminCell">'._PAGES070.'</td>
      </tr>';
	}

	$page .= '
    </table>
  </div>
  <input type="hidden" name="pg_name" value="" />
  <input type="hidden" name="pg_title" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="pageid" value="" />
  <input type="hidden" name="pagetemplate" value="" />
  <input type="hidden" name="sort" value="'.$orderby.'" />
  <input type="hidden" name="dir" value="'.$dir.'" />
  <input type="hidden" name="owner" value="'.$ownerid.'" />
  <input type="hidden" name="catid" value="'.$catid.'" />
</form>
';
	if ($pagetotal == 0 ) {
		// Since no pages were returned, display a helpful message on how to create
		// a new page.
		$page .= '<h4 align="center">'._PAGES072.'</h4>';
	}

	// Return the HTML for the "Pages Administration" page.
	return $page;
}


/**
 * Display a form to change the list of user groups for page $pageid that will be
 * permitted to view the page.
 *
 * @param  int     $pageid    ID of the page for which to edit group access
 * @access private
 * @return string HTML content of the "Edit Page Accessibility" form
 */
function pages_editPageAccess($pageid)
{
	// Setup and execute the query to get the group access for $blockid.
	$query_cmd = 'SELECT GROUPID FROM '.$GLOBALS['dbpref'].'_GRPPAGES'.
				 ' WHERE PAGEID = '.$pageid;
	$grp_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Initialize the string of groups against which to match.
	$grpids = '';
	while ($row = @sql_fetch_row($grp_results)) {
		// Add the next ID to the list of groups.
		$grpids .= '['.$row[0].']';
	}

	// Setup and execute the query to return the title and category of the $pageid.
	$query_cmd = 'SELECT TITLE,CATID FROM '.$GLOBALS['dbpref'].'_PAGES'.
				 ' WHERE ID = '.$pageid;
	$pg_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Retrieve the title and category of $pageid.
	$row = sql_fetch_row($pg_results);
	$catid = $row[1];
	// Convert WPS entities to single and double quotes.
	$title = core_convertQuotes($row[0],'revert');

	// Set the HTML for the "Edit Page Accessibility" form.
	$page  = '
<h3 align="center">'._PAGES043.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="2">
      <tr><td align="left">&nbsp;'._PAGES044.':</td></tr>
      <tr>
        <td align="left">
          <select multiple="multiple" name="groupslist[]" class="textCool"';

	if ($grpids == '[0]') {
		$page .= ' disabled="disabled"';
	}
	$page .= '
           width="500" style="width: 500px" size="8">';

	// Get the SQL operator for "notequal".
	$notequal = sql_operator('notequal');
	// Setup and execute the query to return all groups except the EVERYONE group
	// and the SUPERUSERS group.
	$query_cmd = 'SELECT ID, GRPNAME FROM '.$GLOBALS['dbpref'].'_GROUPS'.
				 ' WHERE ID '.$notequal.' '.EVERYONE_GROUP.
				 ' AND ID '.$notequal.' '.SUPERUSERS_GROUP.
				 ' ORDER BY GRPNAME';
	$results = sql_query($query_cmd, $GLOBALS['db_id']);

	while ($row = sql_fetch_row($results)) {
		// Add the group to the select.
		$page .= "\r\n".'            <option value="'.$row[0].'"';
		if (strstr($grpids,'['.$row[0].']')) {
			// This group is already assigned to the page.
			$page .= ' selected="selected"';
		}
		$page .= '>'.$row[1].'</option>';
	}

	// Continue to set the HTML for the "Edit Page Accessibility" form.
	$page .= '
          </select>
        </td>
      </tr>
      <tr>
        <td align="left">
          <input type="checkbox" name="all_access" id="all_access"';

	if ($grpids == '[0]') {
		// Since no groups are assigned, check the "All Groups" checkbox.
		$page .= ' checked="checked"';
	}

	$page .= '
           onclick="this.form.elements[0].disabled = '.
           '!this.form.elements[0].disabled;" /> '._PAGES023.'
        </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" class="buttonRegular" value="'._PAGES036.'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
      <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \''.$_SESSION['prev_page'].'\'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
    </div>
  </div>
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="mode" value="editpageaccess" />
  <input type="hidden" name="pageid" value="'.$pageid.'" />
  <input type="hidden" name="catid" value="'.$catid.'" />
</form>
';
	// Return the HTML for the "Edit Page Accessibility" form.
	return $page;
}


/**
 * Display a form to make changes the ownership of page $pageid.
 *
 * @param  int     $pageid    ID of the page for which to edit ownership
 * @access private
 * @return string HTML content of the "Edit Page Ownership" form
 */
function pages_editPageOwners($pageid)
{
	// Setup and execute the query to return the title of the $pageid.
	$query_cmd = 'SELECT '.$GLOBALS['dbpref'].'_PAGES.TITLE'.
				 ' FROM '.$GLOBALS['dbpref'].'_PAGES WHERE ID = '.$pageid;
	$pg_results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Retrieve the title.
	$row = sql_fetch_row($pg_results);
	// Convert the WPS entities to single and double quotes.
	$title = core_convertQuotes($row[0],'revert');

	// Set the HTML for the "Edit Page Ownership" form.
	$page =  '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--
var dialogArguments;

function checkSubmit (form)
{
	var options = form.elements[\'owners[]\'].options;
	if (options.length < 1) {
		if (confirm("'._PAGES011.'\n'._PAGES012.'")) {
			return true;
		} else {
			form.inputbtn.focus();
			return false;
		}
	} else {
		for (var i = 0; i < options.length; i++) {
			options[i].selected = true;
		}
		return true;
	}
}

function getValue (select)
{
	dialogArguments = select;
	var userlist = \'\';
	for (var i = 0; i < select.options.length; i++) {
		userlist += \'[\'+select.options[i].value+\']\';
	}
	loc = \'modules.php?id=pages&mode=popupauthor&pageid='.$pageid.'\'+
		  \'&userids=\'+userlist;
	opt = \'toolbar=no,menubar=no,personalbar=no,status=no,scrollbars=no,\'+
		  \'width=300,height=150,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
	checkSelect(select,select.form.deletebtn);
}

//-->
</script>
<h3 align="center">'._PAGES006.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php" onsubmit="return checkSubmit(this)">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center">
          <input type="button" name="inputbtn" class="buttonRegular"
           value="'._PAGES028.'" onclick="getValue(this.form.elements[2])"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />&nbsp;
          <input type="button" name="deletebtn" class="buttonRegular"
           value="'._PAGES032.'" onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" disabled="disabled"
           onclick="deleteOption(this.form.elements[2],this)" />
          <br />&nbsp;
        </td>
      </tr>
      <tr><td align="left">&nbsp;'._PAGES034.':</td></tr>
      <tr>
        <td align="left">
          <select multiple="multiple" name="owners[]" class="textCool"
           onchange="checkSelect(this,this.form.deletebtn)" width="500"
           style="width: 500px" size="8">';

	// Setup and execute the query to return all the page owners.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_USERS.ID, '.
						   $GLOBALS['dbpref'].'_USERS.USERNAME FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_PAGEOWNERS, '.$GLOBALS['dbpref'].'_USERS'.
				 ' WHERE '.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.$pageid.
				 ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.USERID = '.
						 $GLOBALS['dbpref'].'_USERS.ID';
	$results = sql_query($query_pt1.$query_pt2, $GLOBALS['db_id']);

	// Determine the number of row returned.
	$owner_total = sql_num_rows($results, $query_pt2);

	if ($owner_total > 0) {
		while ($row = sql_fetch_row($results)) {
			// Add each owner as a select option.
			$page .= "\r\n".'          <option value="'.$row[0].'">';
			$page .= $row[1].'</option>';
		}
	}

	// Continue to set the HTML for the "Edit Page Ownership" form.
	$page .= '
          </select>
        </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" class="buttonRegular" value="'._PAGES036.'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
      <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \''.$_SESSION['prev_page'].'\'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
     </div>
  </div>
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="mode" value="editpageowners" />
  <input type="hidden" name="pageid" value="'.$pageid.'" />
</form>
';
	// Return the HTML for the "Edit Page Ownership" form.
	return $page;
}


/**
 * Display a form to manage the available page categories.
 *
 * @access private
 * @return string HTML content of the "Edit Page Categories" form
 */
function pages_listCategories()
{
	if ($GLOBALS['is_editor']) {
		// Editors do not get personal categories.
		$ownerid = 0;
	} else {
		// Setup and execute the query to get the userid for the current user.
		$query_cmd = 'SELECT ID FROM '.$GLOBALS['dbpref'].'_USERS'.
					 ' WHERE PASSHASH = \''.$_SESSION['authorization'].'\'';
		$user_results = sql_query($query_cmd, $GLOBALS['db_id']);
		$row = sql_fetch_row($user_results);
		$ownerid = $row[0];
	}

	// Set the HTML for the "Edit Page Categories" form.
	$page = '
<script type="text/javascript">
<!--
var modstr = \'modules.php?id=pages&mode=\';

function navAction (element)
{
	form = element.form;
	switch (element.value) {
		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;

		case \'addcategory\':
			form.categoryNew.value = prompt(\''._PAGES052.'\',\''._PAGES053.'\');
			switch (form.categoryNew.value) {
			case null:
			case \'null\':
				form.actionlist.selectedIndex=0;
				form.actionlist.focus();
				return false;
				// End this joyride.
				break;
			case \'\':
			case \'New Category Name\':
				alert(\''._PAGES054.'\');
				form.actionlist.selectedIndex=0;
				form.actionlist.focus();
				return false;
				// End this joyride.
				break;
			default:
				form.mode.value = \'addcategory\';
				form.submit();
				// End this joyride.
				break;
			}
			break;
		case \'admin\':
			location.href = modstr+\'admin\';
			break;

		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
	}
	return true;
}

function moduleAction (element)
{
	form = element.form;
	switch (element.name) {
		case \'editCategory\':
			var selIndex = form.catid.options[form.catid.selectedIndex].value;
			var selCategory = form.catid.options[form.catid.selectedIndex].text;
			form.categoryEdit.value = prompt(\''._PAGES055.'\', selCategory);
			switch (form.categoryEdit.value) {
				case null:
				case \'null\':
					form.catid.focus();
					return false;
					// End this joyride.
					break;
				case \'\':
					alert(\''._PAGES056.'\');
					form.catid.focus();
					return false;
					// End this joyride.
					break;
				default:
					if (form.categoryEdit.value != selCategory) {
						form.mode.value = \'editcategory\';
						form.submit();
					} else {
						form.catid.focus();
						return false;
					}
					// End this joyride.
					break;
			}

			break;

		case \'deleteCategory\':
			var selIndex = form.catid.options[form.catid.selectedIndex].value;
			var selCategory = form.catid.options[form.catid.selectedIndex].text;
			if (confirm(\''._PAGES057.'\')) {
				location.href = modstr+\'deletepagecat&catid=\'+selIndex;
			}
			break;

	}

	return true;

}

//-->
</script>
<h3 align="center">'._PAGES003.'</h3>
<form method="post" action="modules.php" name="actions">
  <div align="center">
    <table class="tableNavigation" border="0" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center">
          <select class="textCool" name="actionlist"
           onchange="navAction(this.options[this.selectedIndex])">
            <option value="default">- '._NAVIGATIONMENU.' -</option>
            <option value="addcategory">'._PAGES058.'</option>
            <option value="admin">'._PAGES019.'</option>
            <option value="adminpanel">'._BACK2ADMIN.'</option>
          </select>
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />';

	// Setup and execute the query to get all the page categories for $ownerid.
	$query_pt1 = 'SELECT ID,CATNAME FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_PAGECATS'.
				 ' WHERE ID > 0'.
				 ' AND CATOWNER = '.$ownerid;
	$query_pt3 = ' ORDER BY CATNAME';
	$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

	// Determine the number of rows returned.
	$cattotal = sql_num_rows($results,$query_pt2);
	if ($cattotal > 0) {
		// Continue to set the HTML for the "Edit Page Categories" form.
		$page .= '
    <table class="tableAdmin" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center">
          <h4>'._PAGES061.'&nbsp;
            <select class="textCool" name="catid">';

		while ($row = sql_fetch_row($results)) {
			// Add each category as a select option.
			$page .= "\r\n".'            <option value="'.$row[0].'">';
			$page .= core_convertQuotes($row[1],'revert').'</option>';
		}

		// Continue to set the HTML for the "Edit Page Categories" form.
		$page .= '
            </select>
          </h4>
        </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="button" class="buttonRegular" name="editCategory"
       value="'._PAGES062.'" onclick="moduleAction(this);"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" /><br /><br />
      <input type="button" class="buttonRegular" name="deleteCategory"
       value="'._PAGES063.'" onclick="moduleAction(this);"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
    </div>';
	} else {
		// Since no categories exist, display an error message.
		$page .= '
  <h4>'._PAGES064.'</h4>';
	}

	// Continue to set the HTML for the "Edit Page Categories" form.

	$page .= '
  </div>
  <input type="hidden" name="categoryNew" value="" />
  <input type="hidden" name="categoryEdit" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="owner" value="'.$ownerid.'" />
</form>
';
	// Return the HTML for the "Edit Page Categories" form.
	return $page;
}


/**
 * Display a popup form allowing the editor to select an author from a list and grant
 * ownership to $pageid.
 *
 * @param  int     $pageid     ID of the page for which to select an owner
 * @param string  $user_ids   String of IDs for users with Author permissions
 * @access private
 * @return string HTML content of the "Add Page Owner" popup
 */
function pages_popupAuthor($pageid,$user_ids)
{
	// Initialize the array of users passed as a string.
	$userarray = explode('][',substr($user_ids,1,-1));

	// Get the SQL operators for "notequal".
	$notequal = sql_operator('notequal');

	// Setup the query to return the list of available authors.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_USERS.ID, '.
						   $GLOBALS['dbpref'].'_USERS.USERNAME FROM ';
	$query_pt2 = $GLOBALS['dbpref'].'_GRPUSERS, '.$GLOBALS['dbpref'].'_USERS'.
				 ' WHERE '.$GLOBALS['dbpref'].'_GRPUSERS.USERID = '.
						   $GLOBALS['dbpref'].'_USERS.ID'.
				   ' AND '.$GLOBALS['dbpref'].'_GRPUSERS.GROUPID = '.CONTENT_AUTHORS.
				   ' AND '.$GLOBALS['dbpref'].'_GRPUSERS.GROUPID '.
						   $notequal.' '.CONTENT_EDITORS.
				   ' AND '.$GLOBALS['dbpref'].'_GRPUSERS.GROUPID '.
						   $notequal.' '.SUPERUSERS_GROUP;
	if ($user_ids != '') {
		// At least one author must be passed.
		for ($i = 0; $i < count($userarray); $i++) {
			// Add all the available page authors.
			$query_pt2 .= ' AND '.$GLOBALS['dbpref'].'_USERS.ID '.
								  $notequal.' '.$userarray[$i];
		}
	}
	$query_pt3 = ' ORDER BY '.$GLOBALS['dbpref'].'_USERS.USERNAME';

	// Execute the query to return the list of available authors.
	$results = sql_query($query_pt1.$query_pt2.$query_pt3, $GLOBALS['db_id']);

	// Set the HTML for the "Add Page Owner" popup.
	$page = '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--
centerPopupWin();
--></script>';

	if (sql_num_rows($results,$query_pt2) > 0) {
		// Continue to set the HTML for the "Add Page Owner" form.
		$page .=  '
<script type="text/javascript">
<!--
function insertOption (form)
{
	var select1 = window.opener.dialogArguments;
		select2 = form.users;
		text1 = form.text1;
		newopt = select1.options.length;
	select1.disabled = false;
	select1.options.length = newopt + 1;
	select1.options[newopt].text = select2.options[select2.selectedIndex].text;
	select1.options[newopt].value = select2.options[select2.selectedIndex].value;
	select2.options[select2.selectedIndex] = null;
	select2.selectedIndex = 0;
	window.close();
}

function checkAdd (form)
{
	var select = form.users;
	form.inputbtn.disabled = (select.options[select.selectedIndex].value == 0);
}

//-->
</script>
<h2 align="center">'._PAGES026.'</h2>
<form actions="modules.php" method="GET" name="formname">
  <div align="center">
    <select name="users" onchange="checkAdd(this.form)">
      <option value="0">-- '._PAGES027.' --</option>';

		while ($row = sql_fetch_row($results)) {
			// Add each author to the select.
			$page .= "\r\n".'      <option value="'.$row[0].'">';
			$page .= $row[1].'</option>';
		}

		// Continue to set the HTML for the "Add Page Owner" form.
		$page .= '
    </select>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="button" name="inputbtn" value="'._PAGES028.'"
       onclick="insertOption(this.form)" disabled="disabled" />
    </div>
  </div>
</form>
';

	} else {
		$page .= '
<h2 align="center">'._PAGES026.'</h2>
<div align="center">'._PAGES029.'</div>
<form method="get" action="modules.php">
  <div align="center">
    <input type="button" onclick="window.close()" value="'._PAGES025.'" />
  </div>
</form>
';
	}
	// Return the HTML for the "Add Page Owner" form.
	return $page;
}


/**
 * Display a popup form allowing the user to select the category in which to place
 * the current page.
 *
 * @param  int     $pageid     ID of the page for which to select an category
 * @access private
 * @return string HTML content of the "Change Page Category" popup
 */
function pages_popupCategory($pageid)
{
	// Determine the query parameters for editors vs. authors.
	if ($GLOBALS['is_editor']) {
		// Setup the query to get the $catid for editors.
		$query_cmd = 'SELECT CATID FROM '.$GLOBALS['dbpref'].'_PAGES'.
					 ' WHERE ID = '.$pageid;
	} else {
		$query_cmd = 'SELECT '.$GLOBALS['dbpref'].'_PAGEOWNERS.CATID, '.
							   $GLOBALS['dbpref'].'_USERS.ID'.
					  ' FROM '.$GLOBALS['dbpref'].'_PAGEOWNERS, '.
							   $GLOBALS['dbpref'].'_USERS'.
					 ' WHERE '.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.$pageid.
					   ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.USERID = '.
							   $GLOBALS['dbpref'].'_USERS.ID'.
					   ' AND '.$GLOBALS['dbpref'].'_USERS.USERNAME = '.
						  '\''.$_SESSION['registereduser'].'\'';
	}

	// Execute the query to get the $catid for $pageid.
	$catresults = sql_query($query_cmd, $GLOBALS['db_id']);
	// Retrieve the data.
	$row = sql_fetch_row($catresults);
	// Determine the ownerid for this user.
	$ownerid = ($GLOBALS['is_editor']) ? 0 : $row[1];
	// Get the $catid from the returned row.
	$catid = $row[0];

	// Set the HTML for the "Change Page Category" form.
	$page  = '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--
centerPopupWin();

function checkButton(form)
{
	select = form.groups;
	if (select.options[select.selectedIndex].value == '.$catid.') {
		disableButton(form.inputbtn);
	}
	else {
		enableButton(form.inputbtn);
	}
}

function saveChange(form)
{
	select = form.groups;
	var oform = window.opener.dialogArguments;
	oform.catid.value = oform.catid.value+\':\'+select.options[select.selectedIndex].value;
	oform.pageid.value = \''.$pageid.'\';
	oform.mode.value = \'editpagecategory\';
	oform.submit();
	window.close();
}

//-->
</script>
<h2 align="center">'._PAGES059.'</h2>
<form actions="modules.php" method="GET" name="formname">
  <div align="center">
    <select name="groups" onchange="checkButton(this.form)">
      <option value="0">-- '._PAGES046.' --</option>';

	// Get the SQL operator for "notequal".
	$notequal = sql_operator('notequal');

	// Setup and execute the query to get the user's page categories (global for
	// editors, personal for authors).
	$query_cmd = 'SELECT ID,CATNAME FROM '.$GLOBALS['dbpref'].'_PAGECATS'.
				 ' WHERE ID > 0  AND CATOWNER = '.$ownerid.' ORDER BY CATNAME';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	while ($row = sql_fetch_row($results)) {
		// Add each page category returned to the select.
		$page .= "\r\n".'      <option value="'.$row[0].'"';
		if ($row[0] == $catid) {
			// Since this row contains the current catid, show it as selected.
			$page .= ' selected = "selected"';
		}
		$page .= '>'.$row[1].'</option>';
	}

	// Continue to set the HTML for the "Change Page Category" form.
	if ($GLOBALS['is_editor']) {
		$page .= "\r\n".'      <option value="-2"';
		if ($catid == -2) {
			// Since this page is disabled, show this option as selected.
			$page .= ' selected = "selected"';
		}
		$page .= '>'._PAGES047.'</option>';
		$page .= "\r\n".'      <option value="-1"';
		if ($catid == -1) {
			// Since this page is unapproved, show this option as selected.
			$page .= ' selected = "selected"';
		}
		$page .= '>'._PAGES048.'</option>';
	}

	$page .= '
    </select>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="button" name="inputbtn" value="'._PAGES036.'"
       onclick="saveChange(this.form)" disabled="disabled" />
    </div>
  </div>
</form>
';
	// Return the HTML for the "Change Page Category" form.
	return $page;
}


/**
 * Display a form allowing all pages in a category to have the same template applied.
 *
 * @param  int     $catid     ID of the category of pages for which to set the page
 *                            template.
 * @access private
 * @return string HTML content of the "Set Category Template" page
 */
function pages_setCatTemplate($catid)
{
	// Set the HTML for the "Set Category Template" page.
	$page  = '
<h3 align="center">'._PAGES073.'</h3>
<form actions="modules.php" method="POST" name="formname">
  <div align="center">
    <table align="center" border="0" cellpadding="2" cellspacing="2" width="100%">
      <tr>
        <td align="right">'._PAGES061.':&nbsp; </td>
        <td align="left">
          <select name="catid">
            <option value="0">-- '._PAGES060.' --</option>';

	// Setup the query to get all page categories.
	$query_pt1	= 'SELECT ID,CATNAME FROM ';
	$query_pt2	= $GLOBALS['dbpref'].'_PAGECATS WHERE ID > 0 ORDER BY CATNAME';
	// Execute the query to get the list of pagecats.
	$results = sql_query($query_pt1.$query_pt2, $GLOBALS['db_id']);

	while ($row = sql_fetch_row($results)) {
		// Add each page category returned to the select.
		$page .= "\r\n".'            <option value="'.$row[0].'"';
		if ($row[0] == $catid) {
			// Since this row contains the current catid, show it as selected.
			$page .= ' selected = "selected"';
		}
		$page .= '>'.$row[1].'</option>';
	}

	// Continue to set the HTML for the "Set Category Template" page.
	$page .= '
          </select>
        </td>
      </tr>
      <tr>
        <td align="right">'._PAGES038.':&nbsp; </td>
        <td align="left">
          <select name="template">
            <option value="!default">- '._DEFAULT.' -</option>';

	if ($filelist = @opendir($GLOBALS['site_path'].'/templates')) {
		while (($filename = readdir($filelist)) !== FALSE) {
			// Get the list of template filenames from the templates folder.
			if (stristr($filename,'.htm') &&
			   ($filename != $GLOBALS['template_main'])) {
			   	// Since this is a valid HTML file and it's not the main
			   	// template, add it to the list.
			$page .= "\r\n            <option";
			$page .= ' value="'.$filename.'">'.$filename.'</option>';
			}
		}
		// Close the folder handle.  Not closing the folder handle is bad, m'kay.
		closedir($filelist);
	}

	// Continue to set the HTML for the "Set Category Template" page.
	$page .= '
          </select>
        </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" name="submit" value="'._PAGES036.'" />
    </div>
  </div>
  <input type="hidden" name="mode" value="setcattemplate" />
  <input type="hidden" name="id" value="pages" />
</form>
';
	// Return the HTML for the "Set Category Template" page.
	return $page;
}


/**
 * Display a list of the related links for $pageid.
 *
 * @param  int     $pageid   ID of the page from which to list related links
 * @access private
 * @return string HTML content of the "Edit Related Links" page
 */
function pages_listRelated($pageid)
{
	// Setup the query to list the title and linkstitle property for $pageid.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_PAGES.TITLE,'.
						   $GLOBALS['dbpref'].'_PAGES.LINKSTITLE FROM ';

	// Build the subquery used to gauge the number of returned rows for those
	// RDBMS that do not correctly support the FUNCTION sql_num_rows().
	$query_pt2 = $GLOBALS['dbpref'].'_PAGES';
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS to the table list
		// in $query_pt2.
		$query_pt2 .= ', '.$GLOBALS['dbpref'].'_PAGEOWNERS';
	}

	// Continue setting up the subquery with the WHERE clause.
	$query_pt2 .= ' WHERE '.$GLOBALS['dbpref'].'_PAGES.ID = '.$pageid;
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS.pageid to the WHERE
		// clause in $query_pt2.
		$query_pt2 .= ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.$pageid;
	}

	// Execute the query to get the title property for $pageid.
	$page_results = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
	if (sql_num_rows($page_results,$query_pt2) == 1) {
		// Retrieve that title property for $pageid.
		$row = sql_fetch_row($page_results);
		// Convert the WPS entities to single and double quotes.
		$title = core_convertQuotes($row[0],'revert');
		$linkstitle = core_convertQuotes($row[1],'revert');

		// Set the HTML for the "Edit Related Links" page.
		$page = '
<script type="text/javascript">
<!--

function editLink(link_id)
{
	dialogArguments = document.links;
	loc = \''.$GLOBALS['url_path'].'modules/pages/insert_link.php?linkid=\'+link_id;
	opt = \'toolbar=0,menubar=0,personalbar=0,status=0,scrollbars=0,\'+
		  \'width=300,height=150,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
}


function editTitle(title)
{
	form = document.links;
	form.sect_title.value = prompt(\''._PAGES031.'\',title);
	switch (form.sect_title.value) {
		case null:
		case \'null\':
		case \'\':
		case title:
			break;
		default:
			form.mode.value = \'editlinkstitle\';
			form.pageid.value = '.$pageid.';
			form.submit();
			break;
	}
}


function deleteRelated(link_id,precedence)
{
	if (confirm("'._PAGES079.'")) {
		form = document.links;
		form.mode.value = \'deleterelated\';
		form.linkid.value = link_id;
		form.precedence.value = precedence;
		form.submit();
	}
}

//-->
</script>
<h3 align="center">'._PAGES080.' &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php" name="links">
  <div align="center">
    <table align="center" class="tableNavigation">
      <tr>
        <td align="center" nowrap="nowrap">
          <input type="button" class="buttonRegular" value="'._PAGES081.'"
           onclick="editLink(0)" onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />&nbsp;
          <input type="button" class="buttonRegular" value="'._PAGES019.'"
           onclick="location.href = \'modules.php?id=pages'.
           '&amp;mode=canceleditpage&amp;pageid='.$pageid.'\'"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />
    <h4><a href="javascript:editTitle(\''.htmlentities($linkstitle).'\')"
     title="'._PAGES031.'">'._PAGES031.' - &quot;'.$linkstitle.'&quot;</a></h4>
    <table align="center" border="1" class="tableAdmin">
      <tr>
        <td align="center" class="columnAdminHeader">'._PAGES082.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES083.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES022.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES020.'</td>
      </tr>';

		// Setup and execute the query to get the list of content sections.
		$query_pt1 = 'SELECT ID,LINKURL,LINKTEXT,PRECEDENCE FROM ';
		$query_pt2 = $GLOBALS['dbpref'].'_PAGELINKS WHERE PAGEID = '.$pageid;
		$query_pt3 = ' ORDER BY PRECEDENCE';
		$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

		// Get the number of sections returned.
		$contenttotal = sql_num_rows($results,$query_pt2);

		if ($contenttotal > 0 ) {
			// Initialize the highlight number to highlight rows in the table.
			$hilite = 1;
			while ($row = sql_fetch_row($results)) {
				// Initialize the class to highlight this row in the table.
				$style = 'columnAdminCell';
				if (($hilite % 2) == 0) {
					$style .= '2';
				}

				// Continue to set the HTML for the "Edit Related Links" page.
				$page .= '
      <tr>
        <td align="center" class="'.$style.'">
          <a href="javascript:editLink('.$row[0].')"'.
          ' title="'._PAGES084.'">'.$row[2].'</a>
        </td>
        <td align="center" class="'.$style.'">
          <a href="javascript:editLink('.$row[0].')"'.
          ' title="'._PAGES084.'">'.$row[1].'</a>
        </td>
        <td align="center" class="'.$style.'">';

				if ($contenttotal == 1) {
					// Since only one section was returned, do not include the
					// "precedence" setting.
					$page .= 'n/a';
				} else {
					if ($row[3] != 0) {
						// Include the "moveup" link when not the first content
						// section.
						$page .= "\r\n".'          <a href="modules.php?id=pages';
						$page .= '&amp;mode=moveuplink&amp;pageid='.$pageid;
						$page .= '&amp;contentid='.$row[0];
						$page .= '&amp;new_prec='.$row[3].'"><img';
						$page .= ' src="modules/pages/uparrow.png" border="0"';
						$page .= ' height="24" width="24" alt="'._UP.'" />';
						$page .= '</a>';
					}
					if ($row[3] != ($contenttotal - 1)) {
						// Include the "movedn" link when not the last content
						// section.
						$page .= "\r\n".'          <a href="modules.php?id=pages';
						$page .= '&amp;mode=movednlink&amp;pageid='.$pageid;
						$page .= '&amp;contentid='.$row[0];
						$page .= '&amp;new_prec='.$row[3].'"><img';
						$page .= ' src="modules/pages/dnarrow.png" border="0"';
						$page .= ' height="24" width="24" alt="'._DOWN.'" />';
						$page .= '</a>';
					}
				}

	 			// Continue to set the HTML for the "Edit Related Links" page.
	  			$page .= '
        </td>
        <td align="center" nowrap="nowrap" class="'.$style.'">
          <a href="javascript:editLink('.$row[0].')">'.
          ' <img src="modules/pages/contents.png" alt="'._PAGES084.'"'.
          ' height="24" width="24" hspace="0" vspace="0" border="0" /></a>
          <a href="javascript:deleteRelated('.$row[0].','.$row[3].');">'.
          ' <img src="modules/pages/delete.png" alt="'._PAGES085.'"'.
          ' height="24" width="24" hspace="0" vspace="0" border="0" /></a>
        </td>
      </tr>';

				$hilite++;
			}
		} else {
			$page .= '
      <tr>
        <td align="center" colspan="6" class="columnAdminCell">'._PAGES086.'</td>
      </tr>';
		}

		$page .= '
    </table>
  </div>
  <input type="hidden" name="link_url" value="" />
  <input type="hidden" name="link_text" value="" />
  <input type="hidden" name="link_title" value="" />
  <input type="hidden" name="link_target" value="" />
  <input type="hidden" name="sect_title" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="precedence" value="" />
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="pageid" value="'.$pageid.'" />
  <input type="hidden" name="linkid" value="" />
</form>
';
		if ($contenttotal == 0 ) {
			// Since no sections were returned, display an error message.
			$page .= '
<h4 align="center">'._PAGES087.'</h4>
';
		}
	} else {
		// Since no editorial or ownership rights were found, display an
		// "Access Denied" error message.
		return access_denied();
	}
	// Return the HTML for the "Edit Related Links" page.
	return $page;
}


/**
 * Display a list of the selected META tags for $pageid.
 *
 * @param  int     $pageid   ID of the page from which to list META tags
 * @access private
 * @return string HTML content of the "Edit Page META Tags" page
 */
function pages_listMetaTags($pageid)
{
	// Setup the query to list the title property for $pageid.
	$query_pt1 = 'SELECT '.$GLOBALS['dbpref'].'_PAGES.TITLE FROM ';

	// Build the subquery used to gauge the number of returned rows for those
	// RDBMS that do not correctly support the FUNCTION sql_num_rows().
	$query_pt2 = $GLOBALS['dbpref'].'_PAGES';
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS to the table list
		// in $query_pt2.
		$query_pt2 .= ', '.$GLOBALS['dbpref'].'_PAGEOWNERS';
	}

	// Continue setting up the subquery with the WHERE clause.
	$query_pt2 .= ' WHERE '.$GLOBALS['dbpref'].'_PAGES.ID = '.$pageid;
	if (!$GLOBALS['is_editor']) {
		// Since only author rights exist, add $dbpref_PAGEOWNERS.pageid to the WHERE
		// clause in $query_pt2.
		$query_pt2 .= ' AND '.$GLOBALS['dbpref'].'_PAGEOWNERS.PAGEID = '.$pageid;
	}

	// Execute the query to get the title property for $pageid.
	$page_results = sql_query($query_pt1.$query_pt2,$GLOBALS['db_id']);
	if (sql_num_rows($page_results,$query_pt2) == 1) {
		// Retrieve that title property for $pageid.
		$row = sql_fetch_row($page_results);
		// Convert the WPS entities to single and double quotes.
		$title = core_convertQuotes($row[0],'revert');

		// Set the HTML for the "Edit Page META Tags" page.
		$page = '
<script type="text/javascript" src="'.$GLOBALS['url_path'].'includes\functions.js"></script>
<script type="text/javascript">
<!--
function editTag(tag_id)
{
	dialogArguments = document.tags;
	loc = \''.$GLOBALS['url_path'].'modules/pages/metaedit.php?pageid='.$pageid.'&tagid=\'+tag_id;
	opt = \'toolbar=no,menubar=no,personalbar=no,status=no,scrollbars=no,width=300,height=100,left=400,top=300\';
	open(loc, \'freewps_popup\', opt);
}


function deleteTag(tag_id)
{
	if (confirm("'._PAGES104.'")) {
		form = document.tags;
		form.mode.value = \'deletemetatag\';
		form.tagid.value = tag_id;
		form.submit();
	}
}

//-->
</script>
<h3 align="center">'._PAGES103.' - &quot;'.$title.'&quot;</h3>
<form method="post" action="modules.php" name="tags">
  <div align="center">
    <table align="center" class="tableNavigation">
      <tr>
        <td align="center" nowrap="nowrap">
          <input type="button" class="buttonRegular" value="'._PAGES110.'"
           onclick="editTag(0)" onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />&nbsp;
          <input type="button" class="buttonRegular" value="'._PAGES019.'"
           onclick="location.href = \'modules.php?id=pages'.
           '&amp;mode=canceleditpage&amp;pageid='.$pageid.'\'"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />
    <table align="center" border="1" class="tableAdmin">
      <tr>
        <td align="center" class="columnAdminHeader">'._PAGES106.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES107.'</td>
        <td align="center" class="columnAdminHeader">'._PAGES020.'</td>
      </tr>';

		// Setup and execute the query to get the list of META tags.
		$query_pt1 = 'SELECT ID,TAGTYPE,TAGNAME,TAGCONTENT FROM ';
		$query_pt2 = $GLOBALS['dbpref'].'_PAGETAGS WHERE PAGEID = '.$pageid;
		$query_pt3 = ' ORDER BY TAGTYPE, TAGNAME';
		$results = sql_query($query_pt1.$query_pt2.$query_pt3,$GLOBALS['db_id']);

		// Get the number of META tags returned.
		$tagtotal = sql_num_rows($results,$query_pt2);

		if ($tagtotal > 0 ) {
			// Initialize the highlight number to highlight rows in the table.
			$hilite = 1;
			while ($row = sql_fetch_row($results)) {
				// Initialize the class to highlight this row in the table.
				$style = 'columnAdminCell';
				if (($hilite % 2) == 0) {
					$style .= '2';
				}

				$content = $row[3];
				if (strlen($content) > 50) {
					$content = substr($content,0,50).'...';
				}

				// Continue to set the HTML for the "Edit Page META Tags" page.
				$page .= '
      <tr>
        <td align="center" class="'.$style.'">
          <a href="javascript:editTag('.$row[0].')"'.
          ' title="'._PAGES105.'">'.strtoupper($row[1]).'=&quot;'.$row[2].'&quot</a>
        </td>
        <td align="center" class="'.$style.'">
          <a href="javascript:editTag('.$row[0].')"'.
          ' title="'._PAGES105.'">'.$content.'</a>
        </td>
        <td align="center" nowrap="nowrap" class="'.$style.'">
          <a href="javascript:deleteTag('.$row[0].');">'.
          ' <img src="modules/pages/delete.png" alt="'._PAGES108.'"'.
          ' height="24" width="24" hspace="0" vspace="0" border="0" /></a>
        </td>
      </tr>';

				$hilite++;
			}
		} else {
			$page .= '
	      <tr>
	        <td align="center" colspan="3" class="columnAdminCell">'._PAGES109.'</td>
	      </tr>';
		}

		$page .= '
    </table>
  </div>
  <input type="hidden" name="tag_type" value="" />
  <input type="hidden" name="tag_name" value="" />
  <input type="hidden" name="tag_content" value="" />
  <input type="hidden" name="mode" value="" />
  <input type="hidden" name="id" value="pages" />
  <input type="hidden" name="pageid" value="'.$pageid.'" />
  <input type="hidden" name="tagid" value="" />
</form>
';
		if ($tagtotal == 0 ) {
			// Since no sections were returned, display an error message.
			$page .= '
<h4 align="center">'._PAGES111.'</h4>
';
		}
	} else {
		// Since an invalid page was requested, assume a security problem exists and
		// display an "Access Denied" error message.
		return access_denied();
	}
	// Return the HTML for the "Edit Page META Tags" page.
	return $page;
}

?>