<?php
/**
 * Offers administration for the various global configuration values used throughout
 * all the scripts in FreeWPS.
 * @package Core-Modules
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | SETTINGS.PHP                                         |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | SETTINGS.PHP is part of FreeWPS.                     |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: settings.php,v 1.13 2004/09/21 02:51:17 ytztech Exp $
//

/* ****  MODULE HEADER SECTION ENDS HERE  **** */

/* ****  MODULE INITIALIZATION SECTION BEGINS HERE  **** */

if (stristr($_SERVER['PHP_SELF'],'settings.php')) {
	// To make sure no one calls this script directly, this conditional ensures
	// that the client browser is redirected to the Home Page if this script's
	// filename is found in $_SERVER['PHP_SELF'].
	header('Location: ../index.php');
	die();
}

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

if (file_exists('languages/'.$GLOBALS['freewps_language'].'/lang-settings.php')) {
	/** Load the locale-specific constants for defined FreeWPS language. */
	include_once 'languages/'.$GLOBALS['freewps_language'].'/lang-settings.php';
} else {
	/** Default to English (or to your native language, if not English). */
	include_once 'languages/english/lang-settings.php';
}

// Determine whether the user has sufficient rights to access this module.
// These global variables ($is_accadm,$is_editor) are reused throughout
// the module to present different views to each user.

$is_accadm = core_checkUser(ACCOUNT_ADMINS);
$is_editor = core_checkUser(CONTENT_EDITORS);

if ($is_accadm || $is_editor) {
	// Check for the existence of either GET/POST variable "mode".
	// "Mode" determines the actions taken by this module.
	if (isset($_REQUEST['mode'])) {
		// Set the mode to the requested mode.
		$mode = $_REQUEST['mode'];
	} else {
		// Set the mode to the default mode.
		$mode = 'admin';
	}
	// Check for the existence of either GET/POST variable "mode".
	// "Mode" determines the actions taken by this module.
	if (isset($_REQUEST['problem'])) {
		// Set the problem to the requested problem.
		$problem = $_REQUEST['problem'];
	} else {
		// Initial the default problem as an array, which indicates no problem.
		$problem = array();
	}

/* ****  MODULE INITIALIZATION SECTION ENDS HERE  **** */

/* ****  REQUEST PROCESSING SECTION BEGINS HERE  **** */

	if ($_SERVER['REQUEST_METHOD'] == 'POST') {
		/* The POST processing section... */
		switch ($mode) {
			case 'edit':
				// Initialize the problem for returning to the user.
				$new_prob = '';
				// Initialize the setting name to save.
				$name = $_POST['setting_name'];
				// Initialize the setting value to save.
				$value = $_POST['setting_value'];
				// Setup and execute the query to get the current setting_type,
				// possible value, and setting_value for the requested "settingname".
				$query_cmd = 'SELECT SETTING_TYPE,POSSIBLE_VALUES,SETTING_VALUE'.
							 ' FROM '.$dbpref.'_SETTINGS'.
							 ' WHERE SETTING_NAME = \''.$name.'\'';
				$results = sql_query($query_cmd, $db_id);
				$row = sql_fetch_row($results);
				$old_value = ($row[0] == 'html') ? $row[1] : $row[2];

				if ($old_value != $value) {
					// Since the setting changed, evaluate the setting_type.
					if (($row[0] == 'integer') &&
						(!is_numeric(trim($value)))) {
							// Set the problem to "integer".
							$new_prob = 'integer';
					} elseif (($row[0] == 'enum') &&
							  (!stristr($row[1],$value))) {
							// Set the problem to "enum".
							$new_prob = 'enum';
					}
					$fld = ($row[0] == 'html') ? 'POSSIBLE_VALUES' : 'SETTING_VALUE';
					if ($new_prob == '') {
						// Setup and execute the query to update the setting value.
							$query_cmd = 'UPDATE '.$dbpref.'_SETTINGS'.
										 " SET $fld = '$value'".
										 " WHERE SETTING_NAME = '$name'";
						sql_query($query_cmd,$db_id);
						// Redirect the user to the "Settings Administration" panel.
						if ($name == 'freewps_language') {
							$loc = 'modules.php?id=settings&mode=updateglobals';
							header('Location: '.$loc);
							die();
						}
					} else {
						$loc = 'modules.php?id=settings&mode=edit'.
							   '&name='.$name.'&problem=not'.$new_prob;
						header('Location: '.$loc);
						die();
					}
				}

				if ($name == 'site_url') {
					// Make sure to update the Site URL value in the session, or else
					// users will get logged out upon changing this property.
					$_SESSION['siteurl'] = $value;
				}

				// Redirect the user to the "Settings Administration" panel.
				header('Location:  modules.php?id=settings&mode=admin');
				// End this joyride.
				break;

			case 'edittags':
				// Setup and execute the query to update the template tags.
				$query_cmd = 'UPDATE '.$dbpref.'_SETTINGS'.
							 ' SET SETTING_VALUE = \''.$_POST['tag_start'].'\''.
							 ' WHERE SETTING_NAME = \'tag_start\'';
				sql_query($query_cmd,$db_id);
				$query_cmd = 'UPDATE '.$dbpref.'_SETTINGS'.
							 ' SET SETTING_VALUE = \''.$_POST['tag_stop'].'\''.
							 ' WHERE SETTING_NAME = \'tag_stop\'';
				sql_query($query_cmd,$db_id);

				// Redirect the user to the "Update Your Templates" page.
				header('Location:  modules.php?id=settings&mode=updatetags');
				// End this joyride.
				break;

			default:
				// Since an invalid $mode was given, display an error page.
				header('Location: 404.php');
				// End this joyride.
				break;
		}
		// End this script without any further processing.
		die();
	}

	/* The GET processing section... */
	switch ($mode) {
		case 'admin':
			// Get the HTML for the "Settings Administraton" panel.
			$pgcontent = settings_admin();
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS01);
			break;

		case 'description':
			// Get the HTML for the $_GET['name'] popup help.
			$pgcontent = settings_showDesc($_GET['name']);
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS02.' - "'.$_GET['name'].'"',
							$template_popup);
			break;

		case 'edit':
			// Get the HTML for the "Edit Setting" form.
			$pgcontent = settings_edit($_GET['name'], $problem);
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS03.' - "'.$_GET['name'].'"');
			break;

		case 'edittags':
			// Get the HTML for the "Modify Template Tags" form.
			$pgcontent = settings_editTags();
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS46);
			break;

		case 'modadmin':
			// Get the HTML for the "Module Administraton" panel.
			$pgcontent = settings_modAdmin();
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS01);
			break;

		case 'moddetail':
			// Get the HTML for the "Show Module Detail" screen.
			$pgcontent = settings_showInfo($_GET['modname']);
			// Create the page.
			core_createPage($pgcontent,'',_SETTINGS43);
			break;

		case 'modinstall':
		case 'moduninstall':
			// Run the install/uninstall routine for $_GET['modname'].
			settings_modInstall($mode,$_GET['modname']);
			break;

		case 'updateglobals':
			// Update the global settings.
			settings_updateTitles();
			// Goto the Admin Panel.
			header('Location:  modules.php?id=settings&mode=admin');
			break;

		case 'updatetags':
			echo '
<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <title>'._SETTINGS49.'</title>
    <meta http-equiv="Content-Type" content="text/html; charset='._CHARSET.'" />
  </head>
  <body>
    <div align="center">
      <table align="center" border="0" cellpadding="2" cellspacing="2" width="400">
        <tr><td align="center">'._SETTINGS50.'</td></tr>
        <tr>
          <td align="center">
            <form method="get" action="modules.php">
              <input type="button" value="'._BACK2ADMIN.'"
               onclick="location.href=\'admin.php\';" />
            </form>
          </td>
        </tr>
      </table>
    </div>
  </body>
</html>';
			break;

		default:
			// Since an invalid $mode was given, display an error page.
			header('Location: 404.php');
			// End this joyride.
			break;
	}
} else {
	// No valid user rights were found.
	if ($_SESSION['authorization'] == '') {
		// Since the user hasn't logged in, send them to the login page with the
		// requested URL passed as a referral URL.
		header('Location: login.php?referer='.core_getReferer());
		die();
	} else {							//
		// Since the user is logged in, display an "Access Denied" page instead.
		core_createPage(access_denied(),'',_ACCESSDENIED);
	}
}


/**
 * Display a list of all possible global configuration parameters that are available
 * for changing in FreeWPS.
 *
 * @access private
 * @return string HTML content of the "Settings Administration" panel
 */
function settings_admin()
{
	// Set the HTML for the "Settings Administration" panel.
	$page  = '
<script type="text/javascript">
<!--
function navAction (element)
{
	switch (element.value) {
		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;';

	if ($GLOBALS['is_editor']) {
		// Only Editors can change the template tags.
		$page .= '
		case \'edittags\':
			location.href = \'modules.php?id=settings&mode=edittags\';
			break;';
	}

	if ($GLOBALS['is_accadm']) {
		// Only Acct Admins install modules.
		$page .= '
		case \'modadmin\':
			location.href = \'modules.php?id=settings&mode=modadmin\';
			break;';
	}

	// Continue to set the HTML for the "Settings Administration" panel.
	$page .= '
		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
	}
	return true;
}
//-->
</script>
<form method="post" action="modules.php">
  <div align="center">
    <table class="tableAdmin" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center">
          <h3>'._SETTINGS13.'<br />
              FreeWPS&trade; v'.FREEWPS_VERSION.'</h3>
        </td>
      </tr>
      <tr>
        <td align="center">
          <select class="textCool" name="actionlist"
           onchange="navAction(this.options[this.selectedIndex])">
            <option value="default">- '._NAVIGATIONMENU.' -</option>';

	if ($GLOBALS['is_editor']) {
		// Only Editors can change the template tags.
		$page .= "\r\n".'            <option value="edittags">';
		$page .= _SETTINGS46.'</option>';
	}
	if ($GLOBALS['is_accadm']) {
		// Only Account Admins can install/maintain modules.
		$page .= "\r\n".'            <option value="modadmin">';
		$page .= _SETTINGS32.'</option>';
	}

	// Continue to set the HTML for the "Settings Administration" panel.
	$page .= '
            <option value="adminpanel">'._BACK2ADMIN.'</option>
          </select>
        </td>
      </tr>
      <tr><td align="center">'._SETTINGS15.'</td></tr>
    </table>
    <hr class="paddedhr" />
    <table border="1" class="tableAdmin" cellpadding="2" cellspacing="2">
      <tr>
        <th align="center" class="columnAdminHeader">'._SETTINGS16.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS17.'</th>
      </tr>';

	// Get the SQL operator "notequal".
	$sql_op = sql_operator('notequal');

	// Setup the query to get all the settings to list.
	$query_cmd = 'SELECT SETTING_NAME,SETTING_TITLE,SETTING_VALUE,'.
						'SETTING_TYPE,POSSIBLE_VALUES'.
				 ' FROM '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' WHERE SETTING_GRP '.$sql_op.' 0';

	if (core_checkUser(SUPERUSERS_GROUP,FALSE)) {
		// Skip additional restrictions for Superusers.
		if ($GLOBALS['is_accadm'] || $GLOBALS['is_editor']) {
			$query_cmd .= ' AND';
			if ($GLOBALS['is_accadm']) {
				// Return Account Admin settings as well.
				$query_cmd .= ' (SETTING_GRP = '.ACCOUNT_ADMINS;
			}
			if ($GLOBALS['is_editor']) {
				if ($GLOBALS['is_accadm']) {
					$query_cmd .= ' OR';
				}
				// Return Content Editor settings as well.
				$query_cmd .= ' SETTING_GRP = '.CONTENT_EDITORS;
				if ($GLOBALS['is_accadm']) {
					$query_cmd .= ')';
				}
			} else {
				$query_cmd .= ')';
			}
			$query_cmd .= ' OR SETTING_NAME = \'freewps_language\'';
		}
	}
	$query_cmd .= ' ORDER BY SETTING_NAME';

	// Execute the query to get all the settings to list.
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Initialize the highlight number to highlight rows in the table.
	$hilite = 1;
	while ($row = sql_fetch_row($results)) {
		// Initialize the class to highlight this row in the table.
		$style = 'columnAdminCell';
		if (($hilite % 2) == 0) {
			$style .= '2';
		}

		if ($row[3] == 'html') {
			$value = (strlen($row[4]) > 40) ? substr($row[4],0,40).'...' : $row[4];
		} else {
			$value = (strlen($row[2]) > 40) ? substr($row[2],0,40).'...' : $row[2];
		}

		// Continue to set the HTML for the "Settings Administration" panel.
		$page .= '
      <tr>
        <td align="left" class="'.$style.'">&nbsp;
          <a href="modules.php?id=settings&amp;mode=edit&amp;name='.
           $row[0].'">'.$row[1].'</a>&nbsp;
        </td>
        <td align="left" class="'.$style.'">&nbsp; '.htmlspecialchars($value).'&nbsp; </td>
      </tr>';
		$hilite++;
	}

	// Continue to set the HTML for the "Settings Administration" panel.
	$page .= '
    </table>
  </div>
</form>
';
	// Return the HTML for the "Settings Administration" panel.
	return $page;
}


/**
 * Display a form to make changes an existing global configuration setting.
 *
 * @param  string  $setting_name   Name of the setting to edit
 * @param  string  $problem        (optional) Error message in the previous operation
 * @access private
 * @return string HTML content of the "Edit Setting" panel
 */
function settings_edit($setting_name, $problem = '')
{
	// Setup and execute the query to get the title, type, possible values, and
	// current value for the $setting_name.
	$query_cmd = 'SELECT SETTING_TITLE, SETTING_TYPE, '.
						'POSSIBLE_VALUES, SETTING_VALUE'.
				 ' FROM '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' WHERE SETTING_NAME = \''.$setting_name.'\'';
	$results = sql_query($query_cmd, $GLOBALS['db_id']);

	// Retrieve the data.
	$row = sql_fetch_row($results);
	$value = htmlspecialchars($row[3]);
	$row_title1 = '<strong>'._SETTINGS09.':</strong>';
	$row_title2 = '<strong>'._SETTINGS10.':</strong>';
	if ($setting_name == 'freewps_language') {
		$row[1] = 'enum';
	}

	// Set the HTML for the "Edit Setting" form.
	$page = '
<script type="text/javascript">
<!--
function popupHelp()
{
	loc = \'modules.php?id=settings&amp;mode=description\'+
		  \'&amp;name='.$setting_name.'\';
	opt = \'scrollbars=auto, width=520, height=380\';
	window.open(loc, \'freewps_popup\', opt);
}

function submitForm(form)
{
	v = form.setting_value;';

	// Include the Form-Checking javascript in the "Edit Setting" form depending on
	// the setting_type.
	switch ($row[1]) {
		case 'html':
		case 'string':
			$page .= '
	if (v.value == "") {
		alert("'.str_replace('<!--SETTING_TITLE-->',$row[0],_SETTINGS04).'");';
			break;

		case 'integer':
			$page .= '
	if (v.value == "") {
		alert("'.str_replace('<!--SETTING_TITLE-->',$row[0],_SETTINGS05).'");';
			break;

		case 'enum':
			$page .= '
	if (v.options[v.selectedIndex].value == "-- '._SETTINGS07.' --") {
		alert("'.str_replace('<!--SETTING_TITLE-->',$row[0],_SETTINGS06).'");';
			break;
	}

	if ($row[1] != 'template') {
		// Continue to set the HTML for the form.
		$page .= '
		v.focus();
		return false;
	}';
	}

	// Continue to set the HTML for the form.
	$page .= '
	return true;
}
//-->
</script>
<h3 align="center">'._SETTINGS03.' - "'.$row[0].'"</h3>
<form method="post" action="modules.php" onsubmit="return submitForm(this)">
  <div align="center">
    <input type="button" name="description" value="'._SETTINGS08.'"
     class="buttonRegular" onclick="popupHelp()"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />
    <hr class="paddedhr" />';

    if ($row[1] != 'html') {
    	$page .= '
    <table border="1" class="tableAdmin" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center" class="columnAdminCell">&nbsp; '.$row_title1.'&nbsp; </td>
        <td align="center" class="columnAdminCell2">&nbsp; "'.$value.'"&nbsp; </td>
      </tr>';
    }

	// Include the input code of the form depending on the setting_type.
	switch ($row[1]) {
		case 'html':
			// Convert the WPS entities to single and double quotes and remove any
			// slashes.
			$content 	= core_convertQuotes(stripslashes($row[2]),'revert');
			// Convert all HTML entities to their textarea-safe forms.
			$content 	= htmlspecialchars($content);
			$input_tag  = '<div align="left">';
			$input_tag .= '<textarea id="setting_value" name="setting_value"';
			$input_tag .= ' rows="20" cols="76" style="width: 635px;';
			$input_tag .= ' height: 350px;">'.$content.'</textarea></div>';
			break;
		case 'string':
			$input_tag  = '<input type="text" class="textCool"';
			$input_tag .= ' name="setting_value" value="" size="32"';
			$input_tag .= ' onfocus="this.className=\'textCoolFocus\'"';
			$input_tag .= ' onblur="this.className=\'textCool\'" />';
			break;

		case 'integer':
			$input_tag  = '<input type="text" class="textCool"';
			$input_tag .= ' name="setting_value" value="" size="8" maxsize="8"';
			$input_tag .= ' onfocus="this.className=\'textCoolFocus\'"';
			$input_tag .= ' onblur="this.className=\'textCool\'" />';
			break;

		case 'enum':
			$input_tag =  '<select class="textCool" name="setting_value" size="1">';
			$input_tag .= '<option>-- '._SETTINGS07.' --</option>';
			// The language drop down must be treated separately.
			if ($setting_name == 'freewps_language') {
				$dirh = @opendir($GLOBALS['site_path'].'/languages');
				if ($dirh) {
					// The languages directory exists.
					$lang_array = array();
					while ($lang_row = readdir($dirh)) {
						// For each entry, only show entries other than the two
						// directory entries and the current language.
						if (($lang_row{0} != '.') &&
							($GLOBALS['freewps_language'] != $lang_row)) {
							$lang_array[] = $lang_row;
						}
					}
					sort($lang_array);
					foreach ($lang_array as $lang) {
						$input_tag .= '<option>'.$lang.'</option>';
					}
				}
			} else {
				// Separate the possible values into an array.
				$values = split(',', $row[2]);
				// Cycle through each value and add it as an option.
				for ($i = 0; $i < count($values); $i++) {
					if ($values[$i] != $row[3]) {
						// Don't show the existing setting in the list.
						$input_tag .= '<option>'.$values[$i].'</option>';
					}
				}
			}
			$input_tag .= '</select>';
			break;

		case 'template':
			// Templates also must be treated as a special case.
			$tpl = array();
			$input_tag =  '<select class="textCool" name="setting_value" size="1">';
			if ($filelist = @opendir($GLOBALS['site_path'].'/templates')) {
				// The templates directory exists.
				while (($filename = readdir($filelist)) !== FALSE) {
					// For each entry, show filenames excluding common files, like
					// css or js or php.
					if (($filename{0} != '.') &&
						(!is_dir($GLOBALS['site_path'].'/templates/'.$filename))) {
						// This filename is not a directory or special file.
						$p = pathinfo($GLOBALS['site_path'].'/templates/'.$filename);
						$ext = 'css,php,pl,cgi,js,jpg,gif,jpeg,png,swf,jar';
						if (!stristr($ext,$p['extension'])) {
							$tpl[] = $filename;
						}
					}
				}
				// Close the file handle.  Not closing the file handle is bad, m'kay.
				closedir($filelist);
			}

			sort($tpl);
			reset($tpl);
			for ($i = 0; $i < count($tpl); $i++) {
				// Add each template file as a select option.
				$input_tag .= "\r\n".'            <option';
				if ($row[3] == $tpl[$i]) {
					$input_tag .= ' selected="selected"';
				}
				$input_tag .= ' value="'.$tpl[$i].'">'.$tpl[$i].'</option>';
			}
			$input_tag .= '</select>';
			break;
	}

	// Continue to set the HTML for the form.
	if ($row[1] != 'html') {
		$page .= '
      <tr>
        <td align="center" class="columnAdminCell">&nbsp; '.$row_title2.'&nbsp; </td>
        <td align="center" class="columnAdminCell2">&nbsp; '.$input_tag.'&nbsp; </td>
      </tr>
    </table>';
    } else {
    	$page .= $input_tag;
    }

    $page .= '
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" class="buttonRegular" value="'._SETTINGS11.'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />&nbsp;
      <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \'modules.php?id=settings&amp;mode=admin\'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
    </div>
  </div>
  <input type="hidden" name="id" value="settings" />
  <input type="hidden" name="mode" value="edit" />
  <input type="hidden" name="setting_name" value="'.$setting_name.'" />
</form>
';

	// If a problem was not returned as an array,
	// include the "Invalid value" message.
	if (!is_array($problem)) {
		$page .= '<p><strong>'._SETTINGS12.'</strong></p>';
	}
	if ($row[1] == 'html') {
		// Add the Inline Web Editor to the page.
		$page .= core_getEditor('setting_value');
	}
	// Return the HTML for the "Edit Setting" form.
	return $page;
}


/**
 * Display a form to allow changes to the beginning and ending tag delimiters used in
 * HTML templates.
 *
 * @access private
 * @return string HTML content of the "Modify Tag Delimiters" form
 */
function settings_editTags()
{
	// Setup and execute the query to get the current value for the tag delimiters.
	$query_cmd  = 'SELECT SETTING_VALUE FROM '.$GLOBALS['dbpref'].'_SETTINGS'.
				  ' WHERE SETTING_NAME = \'tag_start\''.
				  ' OR SETTING_NAME = \'tag_stop\''.
				  ' ORDER BY SETTING_NAME';
	$results    = sql_query($query_cmd, $GLOBALS['db_id']);

	// Initialize and retrieve the data.
	$tagstart   = sql_fetch_row($results);
	$tag1       = '&quot;<strong>'.htmlspecialchars($tagstart[0]).'</strong>&quot;';
	$tagstop    = sql_fetch_row($results);
	$tag2       = '&quot;<strong>'.htmlspecialchars($tagstop[0]).'</strong>&quot;';
	$row_title1 = '<strong>'._SETTINGS49.':</strong>';
	$row_title2 = '<strong>'._SETTINGS47.':</strong>';
	$row_title3 = '<strong>'._SETTINGS48.':</strong>';

	// Set the HTML for the "Modify Tag Delimiters" form.
	$page = '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--
function popupHelp()
{
	loc = \'modules.php?id=settings&amp;mode=description\'+
		  \'&amp;name=tagdelimiters\';
	opt = \'scrollbars=auto, width=520, height=380\';
	window.open(loc, \'freewps_popup\', opt);
}

function submitForm(form)
{
	if (form.tag_start.value == \'\') {
		alert("'.str_replace('<!--SETTING_TITLE-->',_SETTINGS47,_SETTINGS04).'");
		form.tag_start.focus();
		return false;
	}
	if (form.tag_stop.value == \'\') {
		alert("'.str_replace('<!--SETTING_TITLE-->',_SETTINGS48,_SETTINGS04).'");
		form.tag_stop.focus();
		return false;
	}
	return true;
}
//-->
</script>
<h3 align="center">'._SETTINGS46.'</h3>
<form method="post" action="modules.php" onsubmit="return submitForm(this)">
  <div align="center">
    <table class="tableNavigation" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center" colspan="2">
          <input type="button" name="description" value="'._SETTINGS08.'"
           class="buttonRegular" onclick="popupHelp()"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" />
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />
    <table border="1" class="tableAdmin" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center" class="columnAdminCell">&nbsp; '.$row_title1.'&nbsp; </td>
        <td align="center" class="columnAdminCell2">'.$tag1.' &nbsp;'.$tag2.'</td>
      </tr>
      <tr>
        <td align="center" class="columnAdminCell">&nbsp; '.$row_title2.'&nbsp; </td>
        <td align="center" class="columnAdminCell2">&nbsp;
          <input type="text" class="textCool" name="tag_start" value="" size="8"
           onfocus="this.className=\'textCoolFocus\'"
           onblur="this.className=\'textCool\'" />&nbsp; </td>
      </tr>
      <tr>
        <td align="center" class="columnAdminCell">&nbsp; '.$row_title3.'&nbsp; </td>
        <td align="center" class="columnAdminCell2">&nbsp;
          <input type="text" class="textCool" name="tag_stop" value="" size="8"
           onfocus="this.className=\'textCoolFocus\'"
           onblur="this.className=\'textCool\'" />&nbsp; </td>
      </tr>
    </table>
    <div style="padding: 0px; margin: 0px; margin-top: 6px;">
      <input type="submit" class="buttonRegular" value="'._SETTINGS11.'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />&nbsp;
      <input type="button" class="buttonRegular" value="'._CANCEL.'"
       onclick="location.href = \'modules.php?id=settings&amp;mode=admin\'"
       onmouseover="this.className=\'buttonRegularFocus\'"
       onmouseout="this.className=\'buttonRegular\'" />
    </div>
  </div>
  <input type="hidden" name="id" value="settings" />
  <input type="hidden" name="mode" value="edittags" />
</form>
';
	// Return the HTML for the "Modify Tag Delimiters" form.
	return $page;
}


/**
 * Return a list of all modules found in the file system with names, titles and the
 * ID from WPS_MODULES if installed (or "none" if not installed).
 *
 * @access private
 * @return array   List of all modules (core, installed, notinstalled)
 */
function settings_getMod()
{
	// Initialize the list of SQL installed modules.
	$sqlmodules = array();

	// Setup and execute the query to retrieve the list of SQL installed modules.
	$query_cmd = 'SELECT ID,MODNAME FROM '.$GLOBALS['dbpref'].'_MODULES ORDER BY ID';
	$results = sql_query($query_cmd, $GLOBALS['db_id']);
	while ($row = sql_fetch_row($results)) {
		$sqlmodules[$row[1]] = $row[0];
	}

	// Initialize the list of modules to return to the calling function.
	$modulelist = array();
	// Initialize the string of module names used for fast matching.
	$modnames = '';
	// Initialize the language file for all modules.
	$lang = 'languages/'.$GLOBALS['freewps_language'].'/lang-';

	// Open a file handle to the MODULES directory.
	$dirh = opendir($GLOBALS['site_path'].'/modules');
	while ($file = readdir($dirh)) {
		// Match the PHP extension in valid modules.
		if (stristr($file,'.php')) {
			// Retrieve the module name from the filename.
			$modname = substr($file,0,-4);
			if (!stristr($modnames,'['.$modname.']')) {
				// This module hasn't been processed yet.
				$modnames .= '['.$modname.']';
				// Set the constant name for the TITLE constant.
				$moduleconstant = '_'.strtoupper($modname).'_TITLE';
				if (!defined($moduleconstant)) {
					// This module is not currently loaded.
					if (file_exists($lang.$modname.'.php')) {
						// Load the locale-specific constants for $modname.
						/** @ignore */
						include_once $lang.$modname.'.php';
					} else {
						// Load the English-specific constants for $modname.
						/** @ignore */
						include_once 'languages/english/lang-'.$modname.'.php';
					}
				}
				if (isset($sqlmodules[$modname])) {
					// This module has been installed.
					$moduleid = $sqlmodules[$modname];
				} else {
					// This module has not been installed.
					$moduleid = 'none';
				}
				// Add the module to the returning list.
				$modulelist[] = array(0 => $modname,
									  1 => constant($moduleconstant),
									  2=> $moduleid);
			}
		}
	}
	// Return the list of modules found to the calling function.
	return $modulelist;
}


/**
 * Allows ACCOUNT_ADMINS to install, configure and maintain the core and add-in
 * modules in FreeWPS.
 *
 * @access private
 * @return string  HTML content for the "Modules Administration" panel
 */
function settings_modAdmin()
{
	// Set the HTML for the "Modules Administration" panel.
	$page  = '
<script type="text/javascript">
<!--
function navAction (element)
{
	switch (element.value) {

		case \'default\':
			alert(\''._NAVIGATIONERROR.'\');
			break;
		case \'settingsadmin\':
			location.href = \'modules.php?id=settings\';
			break;
		case \'adminpanel\':
			location.href = \'admin.php\';
			break;
	}
	return true;
}
//-->
</script>
<h3 align="center">'._SETTINGS32.'</h3>
<form method="get" action="modules.php">
  <div align="center">
    <table class="tableNavigation" cellpadding="2" cellspacing="2">
      <tr>
        <td align="center">
          <select class="textCool" name="actionlist"
           onchange="navAction(this.options[this.selectedIndex])">
           <option value="default">- '._NAVIGATIONMENU.' -</option>
           <option value="settingsadmin">'._SETTINGS33.'</option>
           <option value="adminpanel">'._BACK2ADMIN.'</option>
          </select>
        </td>
      </tr>
    </table>
    <hr class="paddedhr" />';

	// Get all the module names and titles to a list.
	$modules_all = settings_getMod();

	// Initialize the lists of modules.
	$modules_core = array();
	$modules_addon = array();
	$modules_other = array();

	// Move the array pointer to the beginning of the modules array.
	reset($modules_all);

	for ($i = 0; $i < count($modules_all); $i++) {
		if ($modules_all[$i][2] == 'none') {
			// This module hasn't been installed.
			$modules_other[$modules_all[$i][0]] = $modules_all[$i][1];
		} elseif ($modules_all[$i][2] < 0) {
			// This is a core module, because the module ID is a negative integer.
			$modules_core[$modules_all[$i][0]] = $modules_all[$i][1];
		} else {
			// This is an add-on module, because the module ID is a positive integer.
			$modules_addon[$modules_all[$i][0]] = $modules_all[$i][1];
		}
	}

	// Sort the module lists and reset the pointers to the beginning of the arrays.
	asort($modules_core);
	asort($modules_addon);
	asort($modules_other);
	reset($modules_core);
	reset($modules_addon);
	reset($modules_other);

	// Continue to set the HTML for the "Modules Administration" panel.
	$page .= '
    <h4>'._SETTINGS34.'</h4>
    <table border="1" class="tableAdmin">
      <tr>
        <th align="center" class="columnAdminHeader">'._SETTINGS35.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS36.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS37.'</th>
      </tr>';

	// Initialize the highlight number to highlight rows in the table.
	$hilite = 1;
	while ($module_title = current($modules_core)) {
		// Initialize the class to highlight this row in the table.
		$style = 'columnAdminCell';
		if (($hilite % 2) == 0) {
			$style .= '2';
		}
		$module_name = key($modules_core);
		$page .= '
      <tr>
        <td class="'.$style.'">&nbsp; '.$module_name.'.php&nbsp; </td>
        <td class="'.$style.'">&nbsp; '.$module_title.'&nbsp; </td>
        <td class="'.$style.'">&nbsp; <a href="modules.php?id=settings'.
        '&amp;mode=moddetail&amp;modname='.$module_name.'">'.
        _SETTINGS38.'</a>&nbsp;</td>
      </tr>';
		next($modules_core);
		$hilite++;
	}

	// Continue to set the HTML for the "Modules Administration" panel.
	$page .= '
    </table>
    <div style="font-size: 12px; height:12px; width: 12px;" /></div>
    <h4>'._SETTINGS39.'</h4>
    <table border="1" class="tableAdmin">
      <tr>
        <th align="center" class="columnAdminHeader">'._SETTINGS35.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS36.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS37.'</th>
      </tr>';

	// Cycle through each module and include its properties in the table.

	if (count($modules_addon) > 0) {
		// Initialize the highlight number to highlight rows in the table.
		$hilite = 1;
		while ($module_title = current($modules_addon)) {
			// Initialize the class to highlight this row in the table.
			$style = 'columnAdminCell';
			if (($hilite % 2) == 0) {
				$style .= '2';
			}
			$module_name = key($modules_addon);
			$page .= '
      <tr>
        <td class="'.$style.'">&nbsp; '.$module_name.'.php&nbsp; </td>
        <td class="'.$style.'">&nbsp; '.$module_title.'&nbsp; </td>
        <td class="'.$style.'">&nbsp; <a href="modules.php?id=settings'.
        '&amp;mode=moddetail&amp;modname='.$module_name.'">'.
        _SETTINGS38.'</a>&nbsp; ::&nbsp; <a href="modules.php?id=settings'.
        '&amp;mode=moduninstall&amp;modname='.$module_name.'">'._SETTINGS40.'</a>'.
        '&nbsp; </td>
      </tr>';
			next($modules_addon);
			$hilite++;
		}
	} else {
		// Since no uninstallable modules exist, display an "No Modules" message.
		$page .= '
      <tr>
        <td align="center" class="columnAdminCell" colspan="3">'._SETTINGS52.'</td>
      </tr>';
	}

	// Continue to set the HTML for the "Modules Administration" panel.
	$page .= '
    </table>
    <div style="font-size: 12px; height:12px; width: 12px;" /></div>
    <h4>'._SETTINGS41.'</h4>
    <table border="1" class="tableAdmin">
      <tr>
        <th align="center" class="columnAdminHeader">'._SETTINGS35.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS36.'</th>
        <th align="center" class="columnAdminHeader">'._SETTINGS37.'</th>
      </tr>';

	if (count($modules_other) > 0) {
		// Initialize the highlight number to highlight rows in the table.
		$hilite = 1;
		while ($module_title = current($modules_other)) {
			// Initialize the class to highlight this row in the table.
			$style = 'columnAdminCell';
			if (($hilite % 2) == 0) {
				$style .= '2';
			}
			$module_name = key($modules_other);
			$page .= '
      <tr>
        <td class="'.$style.'">&nbsp; '.$module_name.'.php&nbsp; </td>
        <td class="'.$style.'">&nbsp; '.$module_title.'&nbsp; </td>
        <td class="'.$style.'">&nbsp; <a href="modules.php?id=settings'.
        '&amp;mode=moddetail&amp;modname='.$module_name.'">'.
        _SETTINGS38.'</a>&nbsp; ::&nbsp; <a href="modules.php?id=settings'.
        '&amp;mode=modinstall&amp;modname='.$module_name.'">'._SETTINGS42.'</a>'.
        '&nbsp; </td>
      </tr>';
			next($modules_other);
			$hilite++;
		}
	} else {
		// Since no installable modules exist, display an "No Modules" message.
		$page .= '
      <tr>
        <td align="center" class="columnAdminCell" colspan="3">'._SETTINGS53.'</td>
      </tr>';
	}

	// Continue to set the HTML for the "Modules Administration" panel.
	$page .= '
    </table>
  </div>
</form>';

	// Return the HTML for the "Modules Administration" panel.
	return $page;
}


/**
 * Install/uninstall the specified module.
 *
 * @param  string  $mode_name     Either "modinstall" or "moduninstall"
 * @param  string  $module_name   Name of the module to install/uninstall
 * @access private
 * @return void
 */
function settings_modInstall($mode_name,$module_name)
{
	// Determine whether this is an install or uninstall from the $mode.
	$mode = ucfirst(substr($mode_name,3));

	// Load the INSTALL.php for module $module_name.
	/** @ignore */
	include_once 'modules/'.$module_name.'/install.php';

	// Call the maintenance function for $module_name.
	call_user_func($module_name.'_module'.$mode);

	// Redirect the user to the "Modules Administration" panel.
	header('Location: modules.php?id=settings&mode=modadmin');
	die();
}


/**
 * Display the description for the particular $setting_name.  This description
 * provides details about the meaning of the setting.
 *
 * @param  string  $setting_name   The name of the setting for which to display help
 * @access private
 * @return string  HTML content for the "Show Description" popup
 */
function settings_showDesc($setting_name) {

	// Set the HTML for the "Show Description" popup.

	$page =  '
<script type="text/javascript" src="includes/functions.js"></script>
<script type="text/javascript">
<!--
centerPopupWin();
//-->
</script>
<div align="center">
  <table align="center" border="0" cellspacing="2" cellpadding="2" width="100%">
    <tr>
      <td align="left" nowrap="nowrap"><h3>"'.$setting_name.'"</h3></td>
      <td align="right" nowrap="nowrap" valign="top">
        <p>&nbsp; <a href="javascript:void(0);"
                   onclick="window.close()">'._SETTINGS18.'</a>&nbsp; </p>
      </td>
    </tr>
    <tr><td align="left" colspan="2"><hr class="paddedhr" /></td></tr>';

	// Initialize the setting name.
	$setting = ($setting_name == 'tagdelimiters') ? 'tag_start' : $setting_name;
	// Determine whether to delay including the horizontal rule.
	$includehr = ($setting_name == 'tagdelimiters') ? '' : '<hr class="paddedhr" />';

	// Setup and execute the query to get the description for the $setting_name.
	$query_cmd = 'SELECT DESCRIPTION FROM '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' WHERE SETTING_NAME = \''.$setting.'\'';
	$results = sql_query($query_cmd,$GLOBALS['db_id']);

	// Retrieve the data.
	$row = sql_fetch_row($results);
	// Convert the WPS entities to single and double quotes.
	$desc = core_convertQuotes(stripslashes($row[0]),'revert');

	// Continue to set the HTML for the "Show Description" popup.
	$page .= '
    <tr>
      <td align="left" colspan="2">'.$desc.$includehr.'</td>
    </tr>';

	if ($setting_name == 'tagdelimiters') {
		// The tag delimiter description requires a secondary description.
		// Setup and execute the query to get the secondary description.
		$query_cmd = 'SELECT DESCRIPTION FROM '.$GLOBALS['dbpref'].'_SETTINGS'.
					 ' WHERE SETTING_NAME = \'tag_stop\'';
		$results2 = sql_query($query_cmd,$GLOBALS['db_id']);
		// Retrieve the data.
		$row = sql_fetch_row($results2);
		// Convert the WPS entities to single and double quotes.
		$desc = core_convertQuotes(stripslashes($row[0]),'revert');

		// Continue to set the HTML for the "Show Description" popup.
		$page .= '
    <tr>
      <td align="left" colspan="2">'.$desc.'<hr class="paddedhr" /></td>
    </tr>';
	}

	$page .= '
  </table>
</div>
';
	// Return the HTML for the "Show Description" popup.
	return $page;
}


/**
 * Display the various details for the particular $module_name.  These details can
 * include module author(s), description, version information, copyright information,
 * build date, etc.
 *
 * @param  string  $module_name   The name of the module for which to describe
 * @access private
 * @return string  HTML content for the "Show Module Details" popup
 */
function settings_showInfo($module_name)
{
	// Initialize the proper name for $module_name.
	$modname = strtoupper($module_name).'.PHP';
	// Set the HTML for the "Show Module Details" popup.
	$page  = '
<h3 align="center">'._SETTINGS43.' - "'.$modname.'"</h3>
<form method="get" action="modules.php">
  <div align="center">
    <input type="button" class="buttonRegular" value="'._SETTINGS45.'"
     onclick="location.href = \'modules.php?id=settings&amp;mode=modadmin\'"
     onmouseover="this.className=\'buttonRegularFocus\'"
     onmouseout="this.className=\'buttonRegular\'" />&nbsp;
    <hr class="paddedhr" />';

	if (file_exists('modules/'.$module_name.'/info.php')) {
		include_once 'modules/'.$module_name.'/info.php';		// Load the INFO.php for module $module_name.
	}

	if (function_exists($module_name.'_moduleDetail')) {
		$modinfo = call_user_func($module_name.'_moduleDetail');
		$page .= '
    <table border="1" class="tableAdmin">
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS35.':</strong></td>
        <td align="left" class="columnModuleCell" valign="top">'.$modinfo[0].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS36.':</strong></td>
        <td align="left" class="columnModuleCell2" valign="top">'.$modinfo[1].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS56.':</strong></td>
        <td align="left" class="columnModuleCell" valign="top">'.$modinfo[2].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS62.':</strong></td>
        <td align="left" class="columnModuleCell2" valign="top"><a href="'.$modinfo[3].'"
         target="_blank">'.$modinfo[3].'</a></td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS57.':</strong></td>
        <td align="left" class="columnModuleCell" valign="top">'.$modinfo[4].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS58.':</strong></td>
        <td align="left" class="columnModuleCell2" valign="top">'.$modinfo[5].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS59.':</strong></td>
        <td align="left" class="columnModuleCell" valign="top">'.$modinfo[6].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS60.':</strong></td>
        <td align="left" class="columnModuleCell2" valign="top">'.$modinfo[7].'</td>
      </tr>
      <tr>
        <td align="left" nowrap="nowrap" class="columnModuleHeader"
         valign="top"><strong>'._SETTINGS61.':</strong></td>
        <td align="left" class="columnModuleCell" valign="top">'.$modinfo[8].'</td>
      </tr>
    </table>';
	} else {
		$page .= '
<p>'.str_replace('<!--MODULE_NAME-->',$modname,_SETTINGS44).'</p>';
	}

	$page .= '
  </div>
</form>
';
	// Return the HTML for the "Show Module Details" popup.
	return $page;
}


/**
 * Update the "Setting Titles" when the SETTING "freewps_language" changes.
 *
 * @access private
 * @return void
 */
function settings_updateTitles()
{
	// Get the strings for the modules.
	$modules_all = settings_getMod();
	for ($i = 0; $i < count($modules_all); $i++) {
		// Setup and execute the query to update the title of each module.
		$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_MODULES'.
					 ' SET TITLE = \''.$modules_all[$i][1].'\''.
					 ' WHERE MODNAME = \''.$modules_all[$i][0].'\'';
		sql_query($query_cmd,$GLOBALS['db_id']);
	}

	// Setup and execute the query to update the title of each setting.
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS19.'\''.
				 ' WHERE SETTING_NAME = \'admin_contact\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS20.'\''.
				 ' WHERE SETTING_NAME = \'admin_email\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS21.'\''.
				 ' WHERE SETTING_NAME = \'authorization_timeout\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS22.'\''.
				 ' WHERE SETTING_NAME = \'freewps_language\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS23.'\''.
				 ' WHERE SETTING_NAME = \'freewps_version\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS24.'\''.
				 ' WHERE SETTING_NAME = \'login_timeout\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS25.'\''.
				 ' WHERE SETTING_NAME = \'password_support\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS26.'\''.
				 ' WHERE SETTING_NAME = \'site_name\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS27.'\''.
				 ' WHERE SETTING_NAME = \'site_path\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS28.'\''.
				 ' WHERE SETTING_NAME = \'site_url\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS29.'\''.
				 ' WHERE SETTING_NAME = \'template_main\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS30.'\''.
				 ' WHERE SETTING_NAME = \'template_member\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS31.'\''.
				 ' WHERE SETTING_NAME = \'template_printable\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS48.'\''.
				 ' WHERE SETTING_NAME = \'tag_start\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS48.'\''.
				 ' WHERE SETTING_NAME = \'tag_stop\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS51.'\''.
				 ' WHERE SETTING_NAME = \'template_popup\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS63.'\''.
				 ' WHERE SETTING_NAME = \'error_404\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS64.'\''.
				 ' WHERE SETTING_NAME = \'editor_mode\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS65.'\''.
				 ' WHERE SETTING_NAME = \'link_format\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS66.'\''.
				 ' WHERE SETTING_NAME = \'print_link\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
	$query_cmd = 'UPDATE '.$GLOBALS['dbpref'].'_SETTINGS'.
				 ' SET SETTING_TITLE = \''._SETTINGS67.'\''.
				 ' WHERE SETTING_NAME = \'prnlink_format\'';
	sql_query($query_cmd,$GLOBALS['db_id']);
}

?>