<?php
/**
 * Search Engine script
 *
 * Serves as the search engine for FreeWPS.  This performs a simple text search
 * against page content stored by FreeWPS.
 * @package Core-Scripts
 */
/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +------------------------------------------------------+
// | SEARCH.PHP                                           |
// +------------------------------------------------------+
// | Copyright (c) 2003-2004 YTZ Technical Services, LLC. |
// +------------------------------------------------------+
// | SEARCH.PHP is part of FreeWPS.                       |
// |                                                      |
// | FreeWPS was built using the FreeWPS Software         |
// | Development Kit (SDK), version 2.0.  Free Web        |
// | Publishing System[tm] and FreeWPS[tm] are both       |
// | trademarks of YTZ Technical Services, LLC.           |
// |                                                      |
// | FreeWPS is free software; you can redistribute       |
// | it and/or modify it under the terms of the GNU       |
// | General Public License as published by the Free      |
// | Software Foundation; either version 2 of the         |
// | License, or (at your option) any later version.      |
// |                                                      |
// | FreeWPS is distributed in the hope that it will      |
// | be useful, but WITHOUT ANY WARRANTY; without even    |
// | the implied warranty of MERCHANTABILITY or           |
// | FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       |
// | General Public License (included as COPYING.txt)     |
// | for more details.                                    |
// |                                                      |
// | You should have received a copy of the GNU General   |
// | Public License along with FreeWPS. If you did        |
// | not, you may download a copy at:                     |
// |                                                      |
// | URL:  http://www.fsf.org/licenses/gpl.txt            |
// |                                                      |
// | You may also request a copy from:                    |
// |                                                      |
// | Free Software Foundation, Inc.                       |
// | 59 Temple Place, Suite 330                           |
// | Boston, MA 02111-1307                                |
// | USA                                                  |
// +------------------------------------------------------+
// | Author: Justin White <jwhite@ytztech.com>            |
// +------------------------------------------------------+
//
// $Id: search.php,v 1.8 2004/09/15 15:36:36 ytztech Exp $
//

/** Include the main set of FreeWPS APIs. */
include_once 'includes/functions.php';

if (isset($_GET['search_string'])) {
	// A search string has to be available to perform a search.
	$search = $_GET['search_string'];
	if (!isset($_GET['results'])) {
		// If no number of results are specified, default to 10 per page.
		$sumtotal = 10;
	} else {
		// Otherwise, use the specified number of results per page.
		$sumtotal = $_GET['results'];
	}

	if (!isset($_GET['startat'])) {
		// If no number of results to start from are specified, start at the top.
		$startat = 0;
	} else {
		// Otherwise, start the list of results from the specified number.
		$startat = $_GET['startat'];
	}

	$terms = search_getTerms($search);

	if (isset($_GET['newsearch'])) {
		// A new search was requested.
		if (count($terms) > 0) {
			// Go search!
			$resultset = search_findResults($terms);
		} else {
			// With no search terms available, display an error telling the user that
			// their search was invalid..
			$page  = '
  <script type="text/javascript">
  <!--
    function checkForm(form) {
  	if (form.search_string.value == "") {
  		alert("'._ERRORVALIDSEARCH.'");
  		form.search_string.focus();
  		return false;
  	}
  	return true;
    }
  //-->
  </script>
  <br />
  <form method="get" action="search.php" onsubmit="return checkForm(this)">
    <table cellspacing="0" cellpadding="0" border="0" width="100%">
      <tr>
          <td><p><strong>'._ERRORNOSEARCHRESULTS.'</strong> &nbsp;"'.$search.'".<br />
                   <strong>'._REASONCOLON.'</strong>&nbsp; &nbsp;'._ERRORNOVALIDKEYWORDS.'</p>
              <p>'._REVISESEARCH.'</p></td>
      </tr>
      <tr>
        <td align="center">'._SEARCHCOLON.'&nbsp;
          <input type="text" class="textCool" id="search_string"
           name="search_string" size="50" value="'.$search.'"
           onfocus="this.className=\'textCoolFocus\'"
           onblur="this.className=\'textCool\'" />
          <input id="newsearch" type="hidden" name="newsearch" />
          <input type="submit" class="buttonRegular" id="submit"
           name="submit" value="'._GOSEARCH.'"
           onmouseover="this.className=\'buttonRegularFocus\'"
           onmouseout="this.className=\'buttonRegular\'" /></td>
      </tr>
    </table>
  </form>
';
			// Create the "search_results" page.
			core_createPage($page, '', _SEARCHRESULTS);
			die();
		}
	} else {
		// Since no new search was requested, get the next result set.
		$resultset = search_findResults($terms, $startat, $sumtotal);
	}

	if ($resultset == FALSE) {
		// Since no search_results were found to match, display a "no match found"
		// error to the user.
		$page = '
	<script type="text/javascript">
	<!--
	  function checkForm(form) {
		if (form.search_string.value == "") {
			alert("'._ERRORVALIDSEARCH.'");
			form.search_string.focus();
			return false;
		}
		return true;
	  }
	//-->
	</script>
	<br />
	<form method="get" action="search.php" onsubmit="return checkForm(this)">
	    <table cellspacing="0" cellpadding="0" border="0" width="100%">
			<tr>
				<td><p><strong>'._ERRORNOSEARCHRESULTS.'</strong> "<em>'.$search.'</em>".</p>
					<p>'._REVISESEARCH.'</p></td>
			</tr>
			<tr>
				<td align="center">'._SEARCHCOLON.'&nbsp;
				<input type="text" class="textCool" id="search_string"
				 name="search_string" size="50" value="'.$search.'"
				 onfocus="this.className=\'textCoolFocus\'"
				 onblur="this.className=\'textCool\'" />
				<input id="newsearch" type="hidden" name="newsearch" />
				<input type="submit" class="buttonRegular" id="submit" name="submit"
				 onmouseover="this.className=\'buttonRegularFocus\'"
				 onmouseout="this.className=\'buttonRegular\'"
				 value="'._GOSEARCH.'" /></td>
			</tr>
		</table>
	</form>
';
	} else {
		// Since matches were found, prepare to display the results.
		// Get the total number of matches found.
		$hitcount = $resultset[-1];
		// Get the total number of limited matches found.
		$sumtotal = $resultset[-2];
		// Set the number of the first match displayed.
		$beginat = $startat + 1;
		// Set the number of the last match overall.
		$endat = $startat + $sumtotal;
		if ($endat > $hitcount) {
			// If more matches exist than can be displayed on the page, end the list
			// at the end of the number of results.
			$endat = $hitcount;
		}

		// Set the HTML to display the search_results to the user.
		$page = '
	<p><strong>'._SEARCHRESULTSFOR.'</strong> "<em>'.$search.'</em>"</p>
	<p>'._SEARCHRETURNED.' '.$beginat.'-'.$endat.'
	  ('._SEARCHTOTALHITS.' '.$hitcount.')</p>
    <table cellspacing="5" cellpadding="0" border="0" width="100%">';

		// Add each match found to the list of results in $page.

		for ($i = 0; $i < $sumtotal; $i++) {
			// Set the pageid to include in the link.
			$link = core_getLinkFormat($resultset[$i]['page']);
			$title = $resultset[$i]['title'];
			$html = $resultset[$i]['content'];
			$page .= '
		<tr>
			<td><a href="'.$link.'">'.$title.'</a>
			&#8212;&nbsp;'.$html.'</td>
		</tr>';

		}

		// Close the table.
		$page .= '
	</table>';

		if ($hitcount > $endat) {
			// Since this is not the last page, include a "show next results" form.
			$page .= '
	<div align="center">
		<form method="get" action="search.php">'._DISPLAYNEXT.'
			<select id="results" name="results"><option>10</option>';

			// Include a list of results to display.  Lets the user choose how many
			// should appear on the next page.
			for ($n = 20; $n < 51; $n = $n + 10) {
				if ($n == $sumtotal) {

					// Make the "OPTION" the "OPTION selected" if it matches the last
					// "results" chosen.
					$page .= '
				<option selected="selected">'.$n.'</option>';

				} else {

					// Otherwise, just add the "OPTION".
					$page .= '
				<option>'.$n.'</option>';

				}
			}

			$page .= '
			</select>&nbsp; <input type="submit" value="'._NEXT.'" />
			<input type="hidden" id="startat"name="startat" value="'.$endat.'" />
			<input type="hidden" id="search_string" name="search_string"
			 value="'.$search.'" />
		</form>
	</div>
';
		}

		// Include a form at the end of the search page to allow the user to refine
		// (or redefine) their search in a new way.
		$page .= '
	<script type="text/javascript">
	<!--
	  function checkForm(form) {
		if (form.search_string.value == "") {
			alert("'._ERRORVALIDSEARCH.'");
			form.search_string.focus();
			return false;
		}
		return true;
	  }
	//-->
	</script>
	<br />
	<form method="get" action="search.php" onsubmit="return checkForm(this)">
	    <table cellspacing="0" cellpadding="0" border="0" width="100%">
			<tr>
				<td align="center">'._SEARCHCOLON.'&nbsp;
					<input type="text" class="textCool" id="search_string"
					 name="search_string" size="50" value="'.$search.'"
					 onfocus="this.className=\'textCoolFocus\'"
					 onblur="this.className=\'textCool\'" />&nbsp;
					<input id="newsearch" type="hidden" name="newsearch" />
					<input type="submit" class="buttonRegular" id="submit"
					 name="submit" value="'._GOSEARCH.'"
					 onmouseover="this.className=\'buttonRegularFocus\'"
					 onmouseout="this.className=\'buttonRegular\'" />
				</td>
			</tr>
		</table>
	</form>
';
	}

	// Create the search results page.
	core_createPage($page, '', 'Search Results');
} else {
	// Since no search was submitted, display a new search page.
	$page  = '
	<script type="text/javascript">
	<!--
	  function checkForm(form) {
		if (form.search_string.value == "") {
			alert("'._ERRORVALIDSEARCH.'");
			form.search_string.focus();
			return false;
		}
		return true;
	  }
	//-->
	</script>
	<br />
	<form method="get" action="search.php" onsubmit="return checkForm(this)">
	    <table cellspacing="0" cellpadding="0" border="0">
			<tr>
				<td align="center"><h3>'._SEARCHCOLON.'</h3>
					<p>'._SEARCHNOTE.'</p></td>
			</tr>
			<tr>
				<td align="center">
					<input type="text" class="textCool" id="search_string"
					 name="search_string" size="50" value=""
					 onfocus="this.className=\'textCoolFocus\'"
					 onblur="this.className=\'textCool\'" />&nbsp;
					<input id="newsearch" type="hidden" name="newsearch" />
					<input type="submit" class="buttonRegular" id="submit"
					 name="submit" value="'._GOSEARCH.'"
					 onmouseover="this.className=\'buttonRegularFocus\'"
					 onmouseout="this.className=\'buttonRegular\'" />
				</td>
			</tr>
		</table>
	</form>
';
	// Create the search_results page.
	core_createPage($page, '', _SEARCH);
}


/**
 * Get search terms from a string.
 *
 * This function gleans keywords from the parameter $str for use with searching page
 * content for matches against the search query entered in SEARCH.PHP.
 *
 * @param  string $str   A string of words separated by spaces
 * @access private
 * @return array Returns an array of search terms
 */
function search_getTerms($str)
{
	// Remove all HTML/PHP tags from the search terms string and split the search
	// terms into an array.
	$temp_terms = split("[^[:alpha:]']+", strip_tags($str));
	// Initialize the array and string to hold the usable search terms.
	$terms_str = '';
	$terms = array();

	for ($i = 0; $i < count($temp_terms); $i++) {
		// Stepping through the list of terms, ensure all terms are in lowercase.
		$needle_str = strtolower($temp_terms[$i]);
		if (strlen($needle_str) > 2) {
			// Use only terms that are longer than two letters.
			if (!stristr($terms_str,'['.$needle_str.']')) {
				// The $terms_str provides a faster method of tracking which terms
				// have been added to the $terms array.  Previous use of in_array()
				// proved to be MUCH slower.  Note to self:  Always try to use
				// strings instead of arrays if possible.
				$terms_str .= '['.$needle_str.']';
				$terms[] = $needle_str;
			}
		}
	}

	// Returns the array of search terms.
	return $terms;
}



/**
 * Find the matching search results.
 *
 * This function searches for pages in FreeWPS that contain the terms listed in the
 * $terms array.  The results are limited by the beginning ($begin) value and the
 * total ($total) value.
 *
 * @param  array  $terms   An array of search terms
 * @param  int    $begin   The number of results from which to start the search
 * @param  int    $total   The number of results to return from the search
 * @access private
 * @return array Returns a multi-dimensional array of the the search results
 */
function search_findResults($terms, $begin = 0, $total = 10)
{
	// Set the first result-array element number at zero.
	$index = 0;
	// Get the sql operator for like.
	$like = sql_operator('like');
	// Begin setting up the WHERE clause, looking only for Active content.
	$where = $GLOBALS['dbpref'].'_CONTENT.ISACTIVE=\'y\'';

	if (strstr($GLOBALS['user_perms'],'['.SUPERUSERS_GROUP.']') === FALSE) {
		// If the page has access to everyone, be sure to find that match.
		$where .= ' AND ('.$GLOBALS['dbpref'].'_GRPPAGES.GROUPID = '.EVERYONE_GROUP;
		// Non-superusers must have their results qualified by their access.
		if (strstr($GLOBALS['user_perms'],'[') !== FALSE) {
			// Users that are logged in have additional pages that may be available.
			// So, the WHERE clause must include a check for each group membership.
			// Get the groups of which the user is a member as an array.
			$groups = explode('][',substr($GLOBALS['user_perms'], 1, -1));
			// Step through the groups from the first array element.
			reset($groups);
			while ($groupid = current($groups)) {
				// Stepping through the list of groups will add another OR condition.
				$where .= ' OR '.$GLOBALS['dbpref'].'_GRPPAGES.GROUPID = '.$groupid;
				// Advance the array pointer to the next element.
				next($groups);
			}
		}

		// Ensure that the group permission matches the pageid of the content.
		$where .= ') AND '.$GLOBALS['dbpref'].'_GRPPAGES.PAGEID = '.
						   $GLOBALS['dbpref'].'_CONTENT.PAGEID';
	}

	for ($i = 0; $i < count($terms); $i++) {
		// Add the conditional for each search terms, wrapped by the like operator.
		$where .= ' AND UPPER('.$GLOBALS['dbpref'].'_CONTENT.CONTENT) LIKE \''.
						$like.strtoupper($terms[$i]).$like.'\'';
	}

	// Set the list of fields to return in the limitquery.
	$fields = $GLOBALS['dbpref'].'_CONTENT.PAGEID, '.
			  $GLOBALS['dbpref'].'_CONTENT.CONTENT, '.
			  $GLOBALS['dbpref'].'_CONTENT.TITLE';

	// Set the list of tables from which to return the data.
	$tables = $GLOBALS['dbpref'].'_CONTENT';
	if (strstr($GLOBALS['user_perms'],'['.SUPERUSERS_GROUP.']') === FALSE) {
		$tables .= ', '.$GLOBALS['dbpref'].'_GRPPAGES';
	}

	// Determine the number of results returned.
	$query_cmd    = 'SELECT COUNT(*) FROM '.$tables.' WHERE '.$where;
	$hits_results = sql_query($query_cmd,$GLOBALS['db_id']);
	$total_hits   = sql_fetch_row($hits_results);

	if ($total_hits[0] > 0) {
		// More than one result returned, so let's grab just the results wanted from
		// that result set.

		// Include the total number of hits in the array to return.
		$resultset[-1] = $total_hits[0];

		// Get the results from the limitquery.
		$hits = sql_limitquery($fields,$tables,$where,'PAGEID,TITLE',$begin,$total);

		// Include the total number of limited matches found.
		$resultset[-2] = sql_num_rows($hits,$tables.' WHERE '.$where);

		while ($row = sql_fetch_row($hits)) {
			// Get matches for the page containing the $hits.
			$query_cmd    = 'SELECT TITLE FROM '.$GLOBALS['dbpref'].'_PAGES'.
							' WHERE ID = '.$row[0].' AND CATID > -1 ORDER BY ID';
			$page_results = sql_query($query_cmd,$GLOBALS['db_id']);
			$page_row     = sql_fetch_row($page_results);

			// Clean up the content of the content section returned.
			$content      = strip_tags(core_convertQuotes($row[1]));

			if (strlen($content) > 200) {
				// Limit the result to 200 characters.
				$content = substr($content,0,200).'...';
			}

			// Clean up the titles of the page and content section.
			$pgtitle = strip_tags(core_convertQuotes($page_row[0]));
			$title = strip_tags(core_convertQuotes($row[2]));

			// Add the returned row to the result array to be returned to the calling
			// function.  This array includes a "page_id", "title" and "$content" for
			// each element. The "title" will include the "page title" with the
			// "section title" in parentheses.
			$resultset[$index] = array('page'	 => $row[0],
									   'title'   => $pgtitle.' ('.$title.')',
									   'content' => $content);
			$index++;
		}

		// Return the results array.
		return $resultset;
	} else {
		// Return FALSE, indicating that no matches were found.
		return false;
	}

}

?>